
#include "nir.h"
#include "nir_builder.h"
#include "nir_search.h"
#include "nir_search_helpers.h"

/* What follows is NIR algebraic transform code for the following 1090
 * transforms:
 *    ('imul', 'a', '#b@32(is_pos_power_of_two)') => ('ishl', 'a', ('find_lsb', 'b'))
 *    ('imul', 'a', '#b@32(is_neg_power_of_two)') => ('ineg', ('ishl', 'a', ('find_lsb', ('iabs', 'b'))))
 *    ('ishl', 'a', '#b@32') => ('imul', 'a', ('ishl', 1, 'b'))
 *    ('unpack_64_2x32_split_x', ('imul_2x32_64(is_used_once)', 'a', 'b')) => ('imul', 'a', 'b')
 *    ('unpack_64_2x32_split_x', ('umul_2x32_64(is_used_once)', 'a', 'b')) => ('imul', 'a', 'b')
 *    ('imul_2x32_64', 'a', 'b') => ('pack_64_2x32_split', ('imul', 'a', 'b'), ('imul_high', 'a', 'b'))
 *    ('umul_2x32_64', 'a', 'b') => ('pack_64_2x32_split', ('imul', 'a', 'b'), ('umul_high', 'a', 'b'))
 *    ('udiv', 'a', 1) => a
 *    ('idiv', 'a', 1) => a
 *    ('umod', 'a', 1) => 0
 *    ('imod', 'a', 1) => 0
 *    ('udiv', 'a', '#b@32(is_pos_power_of_two)') => ('ushr', 'a', ('find_lsb', 'b'))
 *    ('idiv', 'a', '#b@32(is_pos_power_of_two)') => ('imul', ('isign', 'a'), ('ushr', ('iabs', 'a'), ('find_lsb', 'b')))
 *    ('idiv', 'a', '#b@32(is_neg_power_of_two)') => ('ineg', ('imul', ('isign', 'a'), ('ushr', ('iabs', 'a'), ('find_lsb', ('iabs', 'b')))))
 *    ('umod', 'a', '#b(is_pos_power_of_two)') => ('iand', 'a', ('isub', 'b', 1))
 *    ('fneg', ('fneg', 'a')) => a
 *    ('ineg', ('ineg', 'a')) => a
 *    ('fabs', ('fabs', 'a')) => ('fabs', 'a')
 *    ('fabs', ('fneg', 'a')) => ('fabs', 'a')
 *    ('fabs', ('u2f', 'a')) => ('u2f', 'a')
 *    ('iabs', ('iabs', 'a')) => ('iabs', 'a')
 *    ('iabs', ('ineg', 'a')) => ('iabs', 'a')
 *    ('f2b', ('fneg', 'a')) => ('f2b', 'a')
 *    ('i2b', ('ineg', 'a')) => ('i2b', 'a')
 *    ('~fadd', 'a', 0.0) => a
 *    ('iadd', 'a', 0) => a
 *    ('usadd_4x8', 'a', 0) => a
 *    ('usadd_4x8', 'a', -1) => -1
 *    ('~fadd', ('fmul', 'a', 'b'), ('fmul', 'a', 'c')) => ('fmul', 'a', ('fadd', 'b', 'c'))
 *    ('iadd', ('imul', 'a', 'b'), ('imul', 'a', 'c')) => ('imul', 'a', ('iadd', 'b', 'c'))
 *    ('~fadd', ('fneg', 'a'), 'a') => 0.0
 *    ('iadd', ('ineg', 'a'), 'a') => 0
 *    ('iadd', ('ineg', 'a'), ('iadd', 'a', 'b')) => b
 *    ('iadd', 'a', ('iadd', ('ineg', 'a'), 'b')) => b
 *    ('~fadd', ('fneg', 'a'), ('fadd', 'a', 'b')) => b
 *    ('~fadd', 'a', ('fadd', ('fneg', 'a'), 'b')) => b
 *    ('fadd', ('fsat', 'a'), ('fsat', ('fneg', 'a'))) => ('fsat', ('fabs', 'a'))
 *    ('~fmul', 'a', 0.0) => 0.0
 *    ('imul', 'a', 0) => 0
 *    ('umul_unorm_4x8', 'a', 0) => 0
 *    ('umul_unorm_4x8', 'a', -1) => a
 *    ('fmul', 'a', 1.0) => a
 *    ('imul', 'a', 1) => a
 *    ('fmul', 'a', -1.0) => ('fneg', 'a')
 *    ('imul', 'a', -1) => ('ineg', 'a')
 *    ('fmul', ('fsign', 'a'), ('fmul', 'a', 'a')) => ('fmul', ('fabs', 'a'), 'a')
 *    ('fmul', ('fmul', ('fsign', 'a'), 'a'), 'a') => ('fmul', ('fabs', 'a'), 'a')
 *    ('~ffma', 0.0, 'a', 'b') => b
 *    ('~ffma', 'a', 'b', 0.0) => ('fmul', 'a', 'b')
 *    ('ffma', 1.0, 'a', 'b') => ('fadd', 'a', 'b')
 *    ('ffma', -1.0, 'a', 'b') => ('fadd', ('fneg', 'a'), 'b')
 *    ('~flrp', 'a', 'b', 0.0) => a
 *    ('~flrp', 'a', 'b', 1.0) => b
 *    ('~flrp', 'a', 'a', 'b') => a
 *    ('~flrp', 0.0, 'a', 'b') => ('fmul', 'a', 'b')
 *    ('~flrp', 'a', ('fadd(is_used_once)', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a')
 *    ('~flrp@32', 'a', ('fadd', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a')
 *    ('~flrp@64', 'a', ('fadd', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a')
 *    ('~flrp@32', ('fadd', 'a', 'b'), ('fadd', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a')
 *    ('~flrp@64', ('fadd', 'a', 'b'), ('fadd', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a')
 *    ('~flrp@32', 'a', ('fmul(is_used_once)', 'a', 'b'), 'c') => ('fmul', ('flrp', 1.0, 'b', 'c'), 'a')
 *    ('~flrp@64', 'a', ('fmul(is_used_once)', 'a', 'b'), 'c') => ('fmul', ('flrp', 1.0, 'b', 'c'), 'a')
 *    ('~flrp', ('fmul(is_used_once)', 'a', 'b'), ('fmul(is_used_once)', 'a', 'c'), 'd') => ('fmul', ('flrp', 'b', 'c', 'd'), 'a')
 *    ('~flrp', 'a', 'b', ('b2f', 'c@1')) => ('bcsel', 'c', 'b', 'a')
 *    ('~flrp', 'a', 0.0, 'c') => ('fadd', ('fmul', ('fneg', 'a'), 'c'), 'a')
 *    ('ftrunc', 'a') => ('bcsel', ('flt', 'a', 0.0), ('fneg', ('ffloor', ('fabs', 'a'))), ('ffloor', ('fabs', 'a')))
 *    ('ffloor', 'a') => ('fsub', 'a', ('ffract', 'a'))
 *    ('fadd', 'a', ('fneg', ('ffract', 'a'))) => ('ffloor', 'a')
 *    ('ffract', 'a') => ('fsub', 'a', ('ffloor', 'a'))
 *    ('fceil', 'a') => ('fneg', ('ffloor', ('fneg', 'a')))
 *    ('~fadd', ('fmul', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1')))), ('fmul', 'b', ('b2f', 'c'))) => ('bcsel', 'c', 'b', 'a')
 *    ('~fadd@32', ('fmul', 'a', ('fadd', 1.0, ('fneg', 'c'))), ('fmul', 'b', 'c')) => ('flrp', 'a', 'b', 'c')
 *    ('~fadd@64', ('fmul', 'a', ('fadd', 1.0, ('fneg', 'c'))), ('fmul', 'b', 'c')) => ('flrp', 'a', 'b', 'c')
 *    ('~fadd@32', ('fmul', 'a', ('fsat', ('fadd', 1.0, ('fneg', 'c')))), ('fmul', 'b', ('fsat', 'c'))) => ('flrp', 'a', 'b', ('fsat', 'c'))
 *    ('~fadd@64', ('fmul', 'a', ('fsat', ('fadd', 1.0, ('fneg', 'c')))), ('fmul', 'b', ('fsat', 'c'))) => ('flrp', 'a', 'b', ('fsat', 'c'))
 *    ('~fadd', 'a', ('fmul', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')))) => ('bcsel', 'c', 'b', 'a')
 *    ('~fadd@32', 'a', ('fmul', 'c', ('fadd', 'b', ('fneg', 'a')))) => ('flrp', 'a', 'b', 'c')
 *    ('~fadd@64', 'a', ('fmul', 'c', ('fadd', 'b', ('fneg', 'a')))) => ('flrp', 'a', 'b', 'c')
 *    ('ffma', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('~fadd', ('fmul', 'a', 'b'), 'c') => ('ffma', 'a', 'b', 'c')
 *    ('~fmul', ('fadd', ('iand', ('ineg', ('b2i32', 'a@bool')), ('fmul', 'b', 'c')), '#d'), '#e') => ('bcsel', 'a', ('fmul', ('fadd', ('fmul', 'b', 'c'), 'd'), 'e'), ('fmul', 'd', 'e'))
 *    ('fdph', 'a', 'b') => ('fdot4', ('vec4', 'a.x', 'a.y', 'a.z', 1.0), 'b')
 *    ('fdot4', ('vec4', 'a', 'b', 'c', 1.0), 'd') => ('fdph', ('vec3', 'a', 'b', 'c'), 'd')
 *    ('fdot4', ('vec4', 'a', 0.0, 0.0, 0.0), 'b') => ('fmul', 'a', 'b')
 *    ('fdot4', ('vec4', 'a', 'b', 0.0, 0.0), 'c') => ('fdot2', ('vec2', 'a', 'b'), 'c')
 *    ('fdot4', ('vec4', 'a', 'b', 'c', 0.0), 'd') => ('fdot3', ('vec3', 'a', 'b', 'c'), 'd')
 *    ('fdot3', ('vec3', 'a', 0.0, 0.0), 'b') => ('fmul', 'a', 'b')
 *    ('fdot3', ('vec3', 'a', 'b', 0.0), 'c') => ('fdot2', ('vec2', 'a', 'b'), 'c')
 *    ('fdot2', ('vec2', 'a', 0.0), 'b') => ('fmul', 'a', 'b')
 *    ('fdot2', 'a', 1.0) => ('fadd', 'a.x', 'a.y')
 *    ('fdot2', 'a', 'b') => ('fsum2', ('fmul', 'a', 'b'))
 *    ('fdot3', 'a', 'b') => ('fsum3', ('fmul', 'a', 'b'))
 *    ('fdot4', 'a', 'b') => ('fsum4', ('fmul', 'a', 'b'))
 *    ('fsum2', 'a') => ('fadd', 'a.x', 'a.y')
 *    ('~fadd', ('fneg(is_used_once)', ('fsat(is_used_once)', 'a(is_not_fmul)')), 1.0) => ('fsat', ('fadd', 1.0, ('fneg', 'a')))
 *    ('~fadd@32', 1.0, ('fneg', ('fmul', ('fadd', 1.0, ('fneg', 'a')), ('fadd', 1.0, ('fneg', 'b'))))) => ('flrp', 'b', 1.0, 'a')
 *    ('ishl', ('iadd', ('imul', 'a', '#b'), '#c'), '#d') => ('iadd', ('imul', 'a', ('ishl', 'b', 'd')), ('ishl', 'c', 'd'))
 *    ('ishl', ('imul', 'a', '#b'), '#c') => ('imul', 'a', ('ishl', 'b', 'c'))
 *    ('ishl@8', ('ishl@8', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 255), ('iand', 'c', 255)), 8), ('ishl@8', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ushr@8', ('ushr@8', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 255), ('iand', 'c', 255)), 8), ('ushr@8', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ishr@8', ('ishr@8', 'a', '#b'), '#c') => ('ishr@8', 'a', ('imin', ('iadd', ('iand', 'b', 255), ('iand', 'c', 255)), 7))
 *    ('ishl@16', ('ishl@16', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 65535), ('iand', 'c', 65535)), 16), ('ishl@16', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ushr@16', ('ushr@16', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 65535), ('iand', 'c', 65535)), 16), ('ushr@16', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ishr@16', ('ishr@16', 'a', '#b'), '#c') => ('ishr@16', 'a', ('imin', ('iadd', ('iand', 'b', 65535), ('iand', 'c', 65535)), 15))
 *    ('ishl@32', ('ishl@32', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 4294967295), ('iand', 'c', 4294967295)), 32), ('ishl@32', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ushr@32', ('ushr@32', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 4294967295), ('iand', 'c', 4294967295)), 32), ('ushr@32', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ishr@32', ('ishr@32', 'a', '#b'), '#c') => ('ishr@32', 'a', ('imin', ('iadd', ('iand', 'b', 4294967295), ('iand', 'c', 4294967295)), 31))
 *    ('ishl@64', ('ishl@64', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 18446744073709551615), ('iand', 'c', 18446744073709551615)), 64), ('ishl@64', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ushr@64', ('ushr@64', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 18446744073709551615), ('iand', 'c', 18446744073709551615)), 64), ('ushr@64', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ishr@64', ('ishr@64', 'a', '#b'), '#c') => ('ishr@64', 'a', ('imin', ('iadd', ('iand', 'b', 18446744073709551615), ('iand', 'c', 18446744073709551615)), 63))
 *    ('ishl', ('iadd', 'a', '#b'), '#c') => ('iadd', ('ishl', 'a', 'c'), ('ishl', 'b', 'c'))
 *    ('~inot', ('flt', 'a', 'b')) => ('fge', 'a', 'b')
 *    ('~inot', ('fge', 'a', 'b')) => ('flt', 'a', 'b')
 *    ('inot', ('feq', 'a', 'b')) => ('fne', 'a', 'b')
 *    ('inot', ('fne', 'a', 'b')) => ('feq', 'a', 'b')
 *    ('inot', ('ilt', 'a', 'b')) => ('ige', 'a', 'b')
 *    ('inot', ('ult', 'a', 'b')) => ('uge', 'a', 'b')
 *    ('inot', ('ige', 'a', 'b')) => ('ilt', 'a', 'b')
 *    ('inot', ('uge', 'a', 'b')) => ('ult', 'a', 'b')
 *    ('inot', ('ieq', 'a', 'b')) => ('ine', 'a', 'b')
 *    ('inot', ('ine', 'a', 'b')) => ('ieq', 'a', 'b')
 *    ('iand', ('feq', 'a', 'b'), ('fne', 'a', 'b')) => False
 *    ('iand', ('flt', 'a', 'b'), ('flt', 'b', 'a')) => False
 *    ('iand', ('ieq', 'a', 'b'), ('ine', 'a', 'b')) => False
 *    ('iand', ('ilt', 'a', 'b'), ('ilt', 'b', 'a')) => False
 *    ('iand', ('ult', 'a', 'b'), ('ult', 'b', 'a')) => False
 *    ('flt', ('fneg', 'a'), ('fneg', 'b')) => ('flt', 'b', 'a')
 *    ('fge', ('fneg', 'a'), ('fneg', 'b')) => ('fge', 'b', 'a')
 *    ('feq', ('fneg', 'a'), ('fneg', 'b')) => ('feq', 'b', 'a')
 *    ('fne', ('fneg', 'a'), ('fneg', 'b')) => ('fne', 'b', 'a')
 *    ('flt', ('fneg', 'a'), -1.0) => ('flt', 1.0, 'a')
 *    ('flt', -1.0, ('fneg', 'a')) => ('flt', 'a', 1.0)
 *    ('fge', ('fneg', 'a'), -1.0) => ('fge', 1.0, 'a')
 *    ('fge', -1.0, ('fneg', 'a')) => ('fge', 'a', 1.0)
 *    ('fne', ('fneg', 'a'), -1.0) => ('fne', 1.0, 'a')
 *    ('feq', -1.0, ('fneg', 'a')) => ('feq', 'a', 1.0)
 *    ('flt', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('flt', 'a', 'b')
 *    ('flt', '#b(is_gt_0_and_lt_1)', ('fsat(is_used_once)', 'a')) => ('flt', 'b', 'a')
 *    ('fge', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fge', 'a', 'b')
 *    ('fge', '#b(is_gt_0_and_lt_1)', ('fsat(is_used_once)', 'a')) => ('fge', 'b', 'a')
 *    ('feq', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('feq', 'a', 'b')
 *    ('fne', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fne', 'a', 'b')
 *    ('fge', ('fsat(is_used_once)', 'a'), 1.0) => ('fge', 'a', 1.0)
 *    ('flt', ('fsat(is_used_once)', 'a'), 1.0) => ('flt', 'a', 1.0)
 *    ('fge', 0.0, ('fsat(is_used_once)', 'a')) => ('fge', 0.0, 'a')
 *    ('flt', 0.0, ('fsat(is_used_once)', 'a')) => ('flt', 0.0, 'a')
 *    ('fge', 0.0, ('b2f', 'a@1')) => ('inot', 'a')
 *    ('fge', ('fneg', ('b2f', 'a@1')), 0.0) => ('inot', 'a')
 *    ('fne', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('ior', 'a', 'b')
 *    ('fne', ('fmax', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('ior', 'a', 'b')
 *    ('fne', ('bcsel', 'a', 1.0, ('b2f', 'b@1')), 0.0) => ('ior', 'a', 'b')
 *    ('fne', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))) => ('ior', 'a', 'b')
 *    ('fne', ('fmul', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('iand', 'a', 'b')
 *    ('fne', ('fmin', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('iand', 'a', 'b')
 *    ('fne', ('bcsel', 'a', ('b2f', 'b@1'), 0.0), 0.0) => ('iand', 'a', 'b')
 *    ('fne', ('fadd', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))), 0.0) => ('ixor', 'a', 'b')
 *    ('fne', ('b2f', 'a@1'), ('b2f', 'b@1')) => ('ixor', 'a', 'b')
 *    ('fne', ('fneg', ('b2f', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('ixor', 'a', 'b')
 *    ('feq', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('inot', ('ior', 'a', 'b'))
 *    ('feq', ('fmax', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('inot', ('ior', 'a', 'b'))
 *    ('feq', ('bcsel', 'a', 1.0, ('b2f', 'b@1')), 0.0) => ('inot', ('ior', 'a', 'b'))
 *    ('feq', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))) => ('inot', ('ior', 'a', 'b'))
 *    ('feq', ('fmul', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('inot', ('iand', 'a', 'b'))
 *    ('feq', ('fmin', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('inot', ('iand', 'a', 'b'))
 *    ('feq', ('bcsel', 'a', ('b2f', 'b@1'), 0.0), 0.0) => ('inot', ('iand', 'a', 'b'))
 *    ('feq', ('fadd', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))), 0.0) => ('ieq', 'a', 'b')
 *    ('feq', ('b2f', 'a@1'), ('b2f', 'b@1')) => ('ieq', 'a', 'b')
 *    ('feq', ('fneg', ('b2f', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('ieq', 'a', 'b')
 *    ('flt', ('fneg', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))), 0.0) => ('ior', 'a', 'b')
 *    ('flt', 0.0, ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))) => ('ior', 'a', 'b')
 *    ('fge', ('fneg', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))), 0.0) => ('inot', ('ior', 'a', 'b'))
 *    ('fge', 0.0, ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))) => ('inot', ('ior', 'a', 'b'))
 *    ('flt', 'a', ('fneg', 'a')) => ('flt', 'a', 0.0)
 *    ('fge', 'a', ('fneg', 'a')) => ('fge', 'a', 0.0)
 *    ('flt', ('fmin', 'c', ('fneg', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1')))), 0.0) => ('ior', ('flt', 'c', 0.0), ('ior', 'a', 'b'))
 *    ('~flt', ('fadd', 'a', 'b'), 'a') => ('flt', 'b', 0.0)
 *    ('~fge', ('fadd', 'a', 'b'), 'a') => ('fge', 'b', 0.0)
 *    ('~feq', ('fadd', 'a', 'b'), 'a') => ('feq', 'b', 0.0)
 *    ('~fne', ('fadd', 'a', 'b'), 'a') => ('fne', 'b', 0.0)
 *    ('~flt', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('flt', 'a', ('fadd', 'c', ('fneg', 'b')))
 *    ('~flt', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('flt', ('fneg', ('fadd', 'c', 'b')), 'a')
 *    ('~fge', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('fge', 'a', ('fadd', 'c', ('fneg', 'b')))
 *    ('~fge', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('fge', ('fneg', ('fadd', 'c', 'b')), 'a')
 *    ('~feq', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('feq', 'a', ('fadd', 'c', ('fneg', 'b')))
 *    ('~feq', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('feq', ('fneg', ('fadd', 'c', 'b')), 'a')
 *    ('~fne', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('fne', 'a', ('fadd', 'c', ('fneg', 'b')))
 *    ('~fne', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('fne', ('fneg', ('fadd', 'c', 'b')), 'a')
 *    ('ieq', ('iadd', 'a', 'b'), 'a') => ('ieq', 'b', 0)
 *    ('ine', ('iadd', 'a', 'b'), 'a') => ('ine', 'b', 0)
 *    ('fge', ('fmin', ('fneg', ('b2f', 'a@1')), 'b@1'), 0.0) => ('iand', ('inot', 'a'), ('fge', 'b', 0.0))
 *    ('feq', ('fmin', ('fneg', ('b2f', 'a@1')), 'b@1'), 0.0) => ('iand', ('inot', 'a'), ('fge', 'b', 0.0))
 *    ('feq', ('b2f', 'a@1'), 0.0) => ('inot', 'a')
 *    ('fne', ('b2f', 'a@1'), 0.0) => a
 *    ('ieq', ('b2i', 'a@1'), 0) => ('inot', 'a')
 *    ('ine', ('b2i', 'a@1'), 0) => a
 *    ('fne', ('u2f', 'a'), 0.0) => ('ine', 'a', 0)
 *    ('feq', ('u2f', 'a'), 0.0) => ('ieq', 'a', 0)
 *    ('fge', ('u2f', 'a'), 0.0) => True
 *    ('fge', 0.0, ('u2f', 'a')) => ('uge', 0, 'a')
 *    ('flt', ('u2f', 'a'), 0.0) => False
 *    ('flt', 0.0, ('u2f', 'a')) => ('ult', 0, 'a')
 *    ('fne', ('i2f', 'a'), 0.0) => ('ine', 'a', 0)
 *    ('feq', ('i2f', 'a'), 0.0) => ('ieq', 'a', 0)
 *    ('fge', ('i2f', 'a'), 0.0) => ('ige', 'a', 0)
 *    ('fge', 0.0, ('i2f', 'a')) => ('ige', 0, 'a')
 *    ('flt', ('i2f', 'a'), 0.0) => ('ilt', 'a', 0)
 *    ('flt', 0.0, ('i2f', 'a')) => ('ilt', 0, 'a')
 *    ('~flt', 0.0, ('fabs', 'a')) => ('fne', 'a', 0.0)
 *    ('~flt', ('fneg', ('fabs', 'a')), 0.0) => ('fne', 'a', 0.0)
 *    ('fge', 0.0, ('fabs', 'a')) => ('feq', 'a', 0.0)
 *    ('fge', ('fneg', ('fabs', 'a')), 0.0) => ('feq', 'a', 0.0)
 *    ('iand', ('fge', 'a', 0.0), ('fge', 1.0, 'a')) => ('feq', 'a', ('fsat', 'a'))
 *    ('ior', ('flt', 'a', 0.0), ('flt', 1.0, 'a')) => ('fne', 'a', ('fsat', 'a'))
 *    ('fmax', ('b2f(is_used_once)', 'a@1'), ('b2f', 'b@1')) => ('b2f', ('ior', 'a', 'b'))
 *    ('fmax', ('fneg(is_used_once)', ('b2f(is_used_once)', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('fneg', ('b2f', ('ior', 'a', 'b')))
 *    ('fmin', ('b2f(is_used_once)', 'a@1'), ('b2f', 'b@1')) => ('b2f', ('iand', 'a', 'b'))
 *    ('fmin', ('fneg(is_used_once)', ('b2f(is_used_once)', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('fneg', ('b2f', ('iand', 'a', 'b')))
 *    ('fmin', ('b2f', 'a@1'), '#b') => ('bcsel', 'a', ('fmin', 'b', 1.0), ('fmin', 'b', 0.0))
 *    ('flt', ('fadd(is_used_once)', 'a', ('fneg', 'b')), 0.0) => ('flt', 'a', 'b')
 *    ('fge', ('fneg', ('fabs', 'a')), 0.0) => ('feq', 'a', 0.0)
 *    ('~bcsel', ('flt', 'b', 'a'), 'b', 'a') => ('fmin', 'a', 'b')
 *    ('~bcsel', ('flt', 'a', 'b'), 'b', 'a') => ('fmax', 'a', 'b')
 *    ('~bcsel', ('fge', 'a', 'b'), 'b', 'a') => ('fmin', 'a', 'b')
 *    ('~bcsel', ('fge', 'b', 'a'), 'b', 'a') => ('fmax', 'a', 'b')
 *    ('bcsel', ('i2b', 'a'), 'b', 'c') => ('bcsel', ('ine', 'a', 0), 'b', 'c')
 *    ('bcsel', ('inot', 'a'), 'b', 'c') => ('bcsel', 'a', 'c', 'b')
 *    ('bcsel', 'a', ('bcsel', 'a', 'b', 'c'), 'd') => ('bcsel', 'a', 'b', 'd')
 *    ('bcsel', 'a', 'b', ('bcsel', 'a', 'c', 'd')) => ('bcsel', 'a', 'b', 'd')
 *    ('bcsel', 'a', ('bcsel', 'b', 'c', 'd'), ('bcsel(is_used_once)', 'b', 'c', 'e')) => ('bcsel', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('bcsel(is_used_once)', 'b', 'c', 'd'), ('bcsel', 'b', 'c', 'e')) => ('bcsel', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('bcsel', 'b', 'c', 'd'), ('bcsel(is_used_once)', 'b', 'e', 'd')) => ('bcsel', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', ('bcsel(is_used_once)', 'b', 'c', 'd'), ('bcsel', 'b', 'e', 'd')) => ('bcsel', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', True, 'b') => ('ior', 'a', 'b')
 *    ('bcsel', 'a', 'a', 'b') => ('ior', 'a', 'b')
 *    ('bcsel', 'a', 'b', False) => ('iand', 'a', 'b')
 *    ('bcsel', 'a', 'b', 'a') => ('iand', 'a', 'b')
 *    ('fmin', 'a', 'a') => a
 *    ('fmax', 'a', 'a') => a
 *    ('imin', 'a', 'a') => a
 *    ('imax', 'a', 'a') => a
 *    ('umin', 'a', 'a') => a
 *    ('umax', 'a', 'a') => a
 *    ('fmax', ('fmax', 'a', 'b'), 'b') => ('fmax', 'a', 'b')
 *    ('umax', ('umax', 'a', 'b'), 'b') => ('umax', 'a', 'b')
 *    ('imax', ('imax', 'a', 'b'), 'b') => ('imax', 'a', 'b')
 *    ('fmin', ('fmin', 'a', 'b'), 'b') => ('fmin', 'a', 'b')
 *    ('umin', ('umin', 'a', 'b'), 'b') => ('umin', 'a', 'b')
 *    ('imin', ('imin', 'a', 'b'), 'b') => ('imin', 'a', 'b')
 *    ('fmax', 'a', ('fneg', 'a')) => ('fabs', 'a')
 *    ('imax', 'a', ('ineg', 'a')) => ('iabs', 'a')
 *    ('fmin', 'a', ('fneg', 'a')) => ('fneg', ('fabs', 'a'))
 *    ('imin', 'a', ('ineg', 'a')) => ('ineg', ('iabs', 'a'))
 *    ('fmin', 'a', ('fneg', ('fabs', 'a'))) => ('fneg', ('fabs', 'a'))
 *    ('imin', 'a', ('ineg', ('iabs', 'a'))) => ('ineg', ('iabs', 'a'))
 *    ('fmin', 'a', ('fabs', 'a')) => a
 *    ('imin', 'a', ('iabs', 'a')) => a
 *    ('fmax', 'a', ('fneg', ('fabs', 'a'))) => a
 *    ('imax', 'a', ('ineg', ('iabs', 'a'))) => a
 *    ('fmax', 'a', ('fabs', 'a')) => ('fabs', 'a')
 *    ('imax', 'a', ('iabs', 'a')) => ('iabs', 'a')
 *    ('fmax', 'a', ('fneg', 'a')) => ('fabs', 'a')
 *    ('imax', 'a', ('ineg', 'a')) => ('iabs', 'a')
 *    ('~fmax', ('fabs', 'a'), 0.0) => ('fabs', 'a')
 *    ('~fmin', ('fmax', 'a', 0.0), 1.0) => ('fsat', 'a')
 *    ('~fmax', ('fmin', 'a', 1.0), 0.0) => ('fsat', 'a')
 *    ('~fmin', ('fmax', 'a', -1.0), 0.0) => ('fneg', ('fsat', ('fneg', 'a')))
 *    ('~fmax', ('fmin', 'a', 0.0), -1.0) => ('fneg', ('fsat', ('fneg', 'a')))
 *    ('fsat', ('fsign', 'a')) => ('b2f', ('flt', 0.0, 'a'))
 *    ('fsat', ('b2f', 'a')) => ('b2f', 'a')
 *    ('fsat', 'a') => ('fmin', ('fmax', 'a', 0.0), 1.0)
 *    ('fsat', ('fsat', 'a')) => ('fsat', 'a')
 *    ('fsat', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b'))) => ('fsat', ('fadd', ('fneg', 'a'), ('fneg', 'b')))
 *    ('fsat', ('fneg(is_used_once)', ('fmul(is_used_once)', 'a', 'b'))) => ('fsat', ('fmul', ('fneg', 'a'), 'b'))
 *    ('fsat', ('fabs(is_used_once)', ('fmul(is_used_once)', 'a', 'b'))) => ('fsat', ('fmul', ('fabs', 'a'), ('fabs', 'b')))
 *    ('fmin', ('fmax', ('fmin', ('fmax', 'a', 'b'), 'c'), 'b'), 'c') => ('fmin', ('fmax', 'a', 'b'), 'c')
 *    ('imin', ('imax', ('imin', ('imax', 'a', 'b'), 'c'), 'b'), 'c') => ('imin', ('imax', 'a', 'b'), 'c')
 *    ('umin', ('umax', ('umin', ('umax', 'a', 'b'), 'c'), 'b'), 'c') => ('umin', ('umax', 'a', 'b'), 'c')
 *    ('fmax', ('fsat', 'a'), '#b@32(is_zero_to_one)') => ('fsat', ('fmax', 'a', 'b'))
 *    ('fmin', ('fsat', 'a'), '#b@32(is_zero_to_one)') => ('fsat', ('fmin', 'a', 'b'))
 *    ('extract_u8', ('imin', ('imax', 'a', 0), 255), 0) => ('imin', ('imax', 'a', 0), 255)
 *    ('~ior', ('flt(is_used_once)', 'a', 'b'), ('flt', 'a', 'c')) => ('flt', 'a', ('fmax', 'b', 'c'))
 *    ('~ior', ('flt(is_used_once)', 'a', 'c'), ('flt', 'b', 'c')) => ('flt', ('fmin', 'a', 'b'), 'c')
 *    ('~ior', ('fge(is_used_once)', 'a', 'b'), ('fge', 'a', 'c')) => ('fge', 'a', ('fmin', 'b', 'c'))
 *    ('~ior', ('fge(is_used_once)', 'a', 'c'), ('fge', 'b', 'c')) => ('fge', ('fmax', 'a', 'b'), 'c')
 *    ('~ior', ('flt', 'a', '#b'), ('flt', 'a', '#c')) => ('flt', 'a', ('fmax', 'b', 'c'))
 *    ('~ior', ('flt', '#a', 'c'), ('flt', '#b', 'c')) => ('flt', ('fmin', 'a', 'b'), 'c')
 *    ('~ior', ('fge', 'a', '#b'), ('fge', 'a', '#c')) => ('fge', 'a', ('fmin', 'b', 'c'))
 *    ('~ior', ('fge', '#a', 'c'), ('fge', '#b', 'c')) => ('fge', ('fmax', 'a', 'b'), 'c')
 *    ('~iand', ('flt(is_used_once)', 'a', 'b'), ('flt', 'a', 'c')) => ('flt', 'a', ('fmin', 'b', 'c'))
 *    ('~iand', ('flt(is_used_once)', 'a', 'c'), ('flt', 'b', 'c')) => ('flt', ('fmax', 'a', 'b'), 'c')
 *    ('~iand', ('fge(is_used_once)', 'a', 'b'), ('fge', 'a', 'c')) => ('fge', 'a', ('fmax', 'b', 'c'))
 *    ('~iand', ('fge(is_used_once)', 'a', 'c'), ('fge', 'b', 'c')) => ('fge', ('fmin', 'a', 'b'), 'c')
 *    ('~iand', ('flt', 'a', '#b'), ('flt', 'a', '#c')) => ('flt', 'a', ('fmin', 'b', 'c'))
 *    ('~iand', ('flt', '#a', 'c'), ('flt', '#b', 'c')) => ('flt', ('fmax', 'a', 'b'), 'c')
 *    ('~iand', ('fge', 'a', '#b'), ('fge', 'a', '#c')) => ('fge', 'a', ('fmax', 'b', 'c'))
 *    ('~iand', ('fge', '#a', 'c'), ('fge', '#b', 'c')) => ('fge', ('fmin', 'a', 'b'), 'c')
 *    ('ior', ('ilt(is_used_once)', 'a', 'b'), ('ilt', 'a', 'c')) => ('ilt', 'a', ('imax', 'b', 'c'))
 *    ('ior', ('ilt(is_used_once)', 'a', 'c'), ('ilt', 'b', 'c')) => ('ilt', ('imin', 'a', 'b'), 'c')
 *    ('ior', ('ige(is_used_once)', 'a', 'b'), ('ige', 'a', 'c')) => ('ige', 'a', ('imin', 'b', 'c'))
 *    ('ior', ('ige(is_used_once)', 'a', 'c'), ('ige', 'b', 'c')) => ('ige', ('imax', 'a', 'b'), 'c')
 *    ('ior', ('ult(is_used_once)', 'a', 'b'), ('ult', 'a', 'c')) => ('ult', 'a', ('umax', 'b', 'c'))
 *    ('ior', ('ult(is_used_once)', 'a', 'c'), ('ult', 'b', 'c')) => ('ult', ('umin', 'a', 'b'), 'c')
 *    ('ior', ('uge(is_used_once)', 'a', 'b'), ('uge', 'a', 'c')) => ('uge', 'a', ('umin', 'b', 'c'))
 *    ('ior', ('uge(is_used_once)', 'a', 'c'), ('uge', 'b', 'c')) => ('uge', ('umax', 'a', 'b'), 'c')
 *    ('iand', ('ilt(is_used_once)', 'a', 'b'), ('ilt', 'a', 'c')) => ('ilt', 'a', ('imin', 'b', 'c'))
 *    ('iand', ('ilt(is_used_once)', 'a', 'c'), ('ilt', 'b', 'c')) => ('ilt', ('imax', 'a', 'b'), 'c')
 *    ('iand', ('ige(is_used_once)', 'a', 'b'), ('ige', 'a', 'c')) => ('ige', 'a', ('imax', 'b', 'c'))
 *    ('iand', ('ige(is_used_once)', 'a', 'c'), ('ige', 'b', 'c')) => ('ige', ('imin', 'a', 'b'), 'c')
 *    ('iand', ('ult(is_used_once)', 'a', 'b'), ('ult', 'a', 'c')) => ('ult', 'a', ('umin', 'b', 'c'))
 *    ('iand', ('ult(is_used_once)', 'a', 'c'), ('ult', 'b', 'c')) => ('ult', ('umax', 'a', 'b'), 'c')
 *    ('iand', ('uge(is_used_once)', 'a', 'b'), ('uge', 'a', 'c')) => ('uge', 'a', ('umax', 'b', 'c'))
 *    ('iand', ('uge(is_used_once)', 'a', 'c'), ('uge', 'b', 'c')) => ('uge', ('umin', 'a', 'b'), 'c')
 *    ('~ior', ('flt(is_used_once)', 0.0, 'a@32'), ('flt', 'b@32', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('~ior', ('flt', 0.0, 'a@32'), ('flt(is_used_once)', 'b@32', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('~ior', ('fge(is_used_once)', 0.0, 'a@32'), ('fge', 'b@32', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~ior', ('fge', 0.0, 'a@32'), ('fge(is_used_once)', 'b@32', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('flt(is_used_once)', 0.0, 'a@32'), ('flt', 'b@32', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('flt', 0.0, 'a@32'), ('flt(is_used_once)', 'b@32', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('fge(is_used_once)', 0.0, 'a@32'), ('fge', 'b@32', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('~iand', ('fge', 0.0, 'a@32'), ('fge(is_used_once)', 'b@32', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('ior', ('ieq', 'a', 0), ('ieq', 'a', 1)) => ('uge', 1, 'a')
 *    ('ior', ('uge', 1, 'a'), ('ieq', 'a', 2)) => ('uge', 2, 'a')
 *    ('ior', ('uge', 2, 'a'), ('ieq', 'a', 3)) => ('uge', 3, 'a')
 *    ('bcsel@32', ('feq', 'a', 0.0), 1.0, ('i2f32', ('iadd', ('b2i32', ('flt', 0.0, 'a@32')), ('ineg', ('b2i32', ('flt', 'a@32', 0.0)))))) => ('ior', 1065353216, ('iand', 'a', 2147483648))
 *    ('ior', 'a', ('ieq', 'a', False)) => True
 *    ('ior', 'a', ('inot', 'a')) => -1
 *    ('ine', ('ineg', ('b2i32', 'a@1')), ('ineg', ('b2i32', 'b@1'))) => ('ine', 'a', 'b')
 *    ('b2i32', ('ine', 'a@1', 'b@1')) => ('b2i32', ('ixor', 'a', 'b'))
 *    ('iand', ('ieq', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('ior', 'a@32', 'b@32'), 0)
 *    ('~flt', 'a', ('fmax', 'b', 'a')) => ('flt', 'a', 'b')
 *    ('~flt', ('fmin', 'a', 'b'), 'a') => ('flt', 'b', 'a')
 *    ('~fge', 'a', ('fmin', 'b', 'a')) => True
 *    ('~fge', ('fmax', 'a', 'b'), 'a') => True
 *    ('~flt', 'a', ('fmin', 'b', 'a')) => False
 *    ('~flt', ('fmax', 'a', 'b'), 'a') => False
 *    ('~fge', 'a', ('fmax', 'b', 'a')) => ('fge', 'a', 'b')
 *    ('~fge', ('fmin', 'a', 'b'), 'a') => ('fge', 'b', 'a')
 *    ('ilt', 'a', ('imax', 'b', 'a')) => ('ilt', 'a', 'b')
 *    ('ilt', ('imin', 'a', 'b'), 'a') => ('ilt', 'b', 'a')
 *    ('ige', 'a', ('imin', 'b', 'a')) => True
 *    ('ige', ('imax', 'a', 'b'), 'a') => True
 *    ('ult', 'a', ('umax', 'b', 'a')) => ('ult', 'a', 'b')
 *    ('ult', ('umin', 'a', 'b'), 'a') => ('ult', 'b', 'a')
 *    ('uge', 'a', ('umin', 'b', 'a')) => True
 *    ('uge', ('umax', 'a', 'b'), 'a') => True
 *    ('ilt', 'a', ('imin', 'b', 'a')) => False
 *    ('ilt', ('imax', 'a', 'b'), 'a') => False
 *    ('ige', 'a', ('imax', 'b', 'a')) => ('ige', 'a', 'b')
 *    ('ige', ('imin', 'a', 'b'), 'a') => ('ige', 'b', 'a')
 *    ('ult', 'a', ('umin', 'b', 'a')) => False
 *    ('ult', ('umax', 'a', 'b'), 'a') => False
 *    ('uge', 'a', ('umax', 'b', 'a')) => ('uge', 'a', 'b')
 *    ('uge', ('umin', 'a', 'b'), 'a') => ('uge', 'b', 'a')
 *    ('ult', 'a', ('iand', 'b', 'a')) => False
 *    ('ult', ('ior', 'a', 'b'), 'a') => False
 *    ('uge', 'a', ('iand', 'b', 'a')) => True
 *    ('uge', ('ior', 'a', 'b'), 'a') => True
 *    ('ilt', '#a', ('imax', '#b', 'c')) => ('ior', ('ilt', 'a', 'b'), ('ilt', 'a', 'c'))
 *    ('ilt', ('imin', '#a', 'b'), '#c') => ('ior', ('ilt', 'a', 'c'), ('ilt', 'b', 'c'))
 *    ('ige', '#a', ('imin', '#b', 'c')) => ('ior', ('ige', 'a', 'b'), ('ige', 'a', 'c'))
 *    ('ige', ('imax', '#a', 'b'), '#c') => ('ior', ('ige', 'a', 'c'), ('ige', 'b', 'c'))
 *    ('ult', '#a', ('umax', '#b', 'c')) => ('ior', ('ult', 'a', 'b'), ('ult', 'a', 'c'))
 *    ('ult', ('umin', '#a', 'b'), '#c') => ('ior', ('ult', 'a', 'c'), ('ult', 'b', 'c'))
 *    ('uge', '#a', ('umin', '#b', 'c')) => ('ior', ('uge', 'a', 'b'), ('uge', 'a', 'c'))
 *    ('uge', ('umax', '#a', 'b'), '#c') => ('ior', ('uge', 'a', 'c'), ('uge', 'b', 'c'))
 *    ('ilt', '#a', ('imin', '#b', 'c')) => ('iand', ('ilt', 'a', 'b'), ('ilt', 'a', 'c'))
 *    ('ilt', ('imax', '#a', 'b'), '#c') => ('iand', ('ilt', 'a', 'c'), ('ilt', 'b', 'c'))
 *    ('ige', '#a', ('imax', '#b', 'c')) => ('iand', ('ige', 'a', 'b'), ('ige', 'a', 'c'))
 *    ('ige', ('imin', '#a', 'b'), '#c') => ('iand', ('ige', 'a', 'c'), ('ige', 'b', 'c'))
 *    ('ult', '#a', ('umin', '#b', 'c')) => ('iand', ('ult', 'a', 'b'), ('ult', 'a', 'c'))
 *    ('ult', ('umax', '#a', 'b'), '#c') => ('iand', ('ult', 'a', 'c'), ('ult', 'b', 'c'))
 *    ('uge', '#a', ('umax', '#b', 'c')) => ('iand', ('uge', 'a', 'b'), ('uge', 'a', 'c'))
 *    ('uge', ('umin', '#a', 'b'), '#c') => ('iand', ('uge', 'a', 'c'), ('uge', 'b', 'c'))
 *    ('bcsel', ('ilt', 'a', 0), ('ineg', ('ishr', 'a', 'b')), ('ishr', 'a', 'b')) => ('iabs', ('ishr', 'a', 'b'))
 *    ('iabs', ('ishr', ('iabs', 'a'), 'b')) => ('ishr', ('iabs', 'a'), 'b')
 *    ('fabs', ('slt', 'a', 'b')) => ('slt', 'a', 'b')
 *    ('fabs', ('sge', 'a', 'b')) => ('sge', 'a', 'b')
 *    ('fabs', ('seq', 'a', 'b')) => ('seq', 'a', 'b')
 *    ('fabs', ('sne', 'a', 'b')) => ('sne', 'a', 'b')
 *    ('slt', 'a', 'b') => ('b2f', ('flt', 'a', 'b'))
 *    ('sge', 'a', 'b') => ('b2f', ('fge', 'a', 'b'))
 *    ('seq', 'a', 'b') => ('b2f', ('feq', 'a', 'b'))
 *    ('sne', 'a', 'b') => ('b2f', ('fne', 'a', 'b'))
 *    ('seq', ('seq', 'a', 'b'), 1.0) => ('seq', 'a', 'b')
 *    ('seq', ('sne', 'a', 'b'), 1.0) => ('sne', 'a', 'b')
 *    ('seq', ('slt', 'a', 'b'), 1.0) => ('slt', 'a', 'b')
 *    ('seq', ('sge', 'a', 'b'), 1.0) => ('sge', 'a', 'b')
 *    ('sne', ('seq', 'a', 'b'), 0.0) => ('seq', 'a', 'b')
 *    ('sne', ('sne', 'a', 'b'), 0.0) => ('sne', 'a', 'b')
 *    ('sne', ('slt', 'a', 'b'), 0.0) => ('slt', 'a', 'b')
 *    ('sne', ('sge', 'a', 'b'), 0.0) => ('sge', 'a', 'b')
 *    ('seq', ('seq', 'a', 'b'), 0.0) => ('sne', 'a', 'b')
 *    ('seq', ('sne', 'a', 'b'), 0.0) => ('seq', 'a', 'b')
 *    ('seq', ('slt', 'a', 'b'), 0.0) => ('sge', 'a', 'b')
 *    ('seq', ('sge', 'a', 'b'), 0.0) => ('slt', 'a', 'b')
 *    ('sne', ('seq', 'a', 'b'), 1.0) => ('sne', 'a', 'b')
 *    ('sne', ('sne', 'a', 'b'), 1.0) => ('seq', 'a', 'b')
 *    ('sne', ('slt', 'a', 'b'), 1.0) => ('sge', 'a', 'b')
 *    ('sne', ('sge', 'a', 'b'), 1.0) => ('slt', 'a', 'b')
 *    ('fall_equal2', 'a', 'b') => ('fmin', ('seq', 'a.x', 'b.x'), ('seq', 'a.y', 'b.y'))
 *    ('fall_equal3', 'a', 'b') => ('seq', ('fany_nequal3', 'a', 'b'), 0.0)
 *    ('fall_equal4', 'a', 'b') => ('seq', ('fany_nequal4', 'a', 'b'), 0.0)
 *    ('fany_nequal2', 'a', 'b') => ('fmax', ('sne', 'a.x', 'b.x'), ('sne', 'a.y', 'b.y'))
 *    ('fany_nequal3', 'a', 'b') => ('fsat', ('fdot3', ('sne', 'a', 'b'), ('sne', 'a', 'b')))
 *    ('fany_nequal4', 'a', 'b') => ('fsat', ('fdot4', ('sne', 'a', 'b'), ('sne', 'a', 'b')))
 *    ('fne', ('fneg', 'a'), 'a') => ('fne', 'a', 0.0)
 *    ('feq', ('fneg', 'a'), 'a') => ('feq', 'a', 0.0)
 *    ('imul', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('iand', 'a', 'b'))
 *    ('fmul', ('b2f', 'a@1'), ('b2f', 'b@1')) => ('b2f', ('iand', 'a', 'b'))
 *    ('fsat', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))) => ('b2f', ('ior', 'a', 'b'))
 *    ('iand', 'a@bool32', 1.0) => ('b2f', 'a')
 *    ('ineg', ('b2i32', 'a@32')) => a
 *    ('flt', ('fneg', ('b2f', 'a@1')), 0) => a
 *    ('flt', ('fsub', 0.0, ('b2f', 'a@1')), 0) => a
 *    ('ilt', 'a', 'a') => False
 *    ('ige', 'a', 'a') => True
 *    ('ieq', 'a', 'a') => True
 *    ('ine', 'a', 'a') => False
 *    ('ult', 'a', 'a') => False
 *    ('uge', 'a', 'a') => True
 *    ('iand', 'a', 'a') => a
 *    ('iand', 'a', -1) => a
 *    ('iand', 'a', 0) => 0
 *    ('ior', 'a', 'a') => a
 *    ('ior', 'a', 0) => a
 *    ('ior', 'a', True) => True
 *    ('ixor', 'a', 'a') => 0
 *    ('ixor', 'a', 0) => a
 *    ('inot', ('inot', 'a')) => a
 *    ('ior', ('iand', 'a', 'b'), 'b') => b
 *    ('ior', ('ior', 'a', 'b'), 'b') => ('ior', 'a', 'b')
 *    ('iand', ('ior', 'a', 'b'), 'b') => b
 *    ('iand', ('iand', 'a', 'b'), 'b') => ('iand', 'a', 'b')
 *    ('iand', ('inot', 'a'), ('inot', 'b')) => ('inot', ('ior', 'a', 'b'))
 *    ('ior', ('inot', 'a'), ('inot', 'b')) => ('inot', ('iand', 'a', 'b'))
 *    ('ishl', 0, 'a') => 0
 *    ('ishl', 'a', 0) => a
 *    ('ishr', 0, 'a') => 0
 *    ('ishr', 'a', 0) => a
 *    ('ushr', 0, 'a') => 0
 *    ('ushr', 'a', 0) => a
 *    ('iand', 255, ('ushr@32', 'a', 24)) => ('ushr', 'a', 24)
 *    ('iand', 65535, ('ushr@32', 'a', 16)) => ('ushr', 'a', 16)
 *    ('ior', ('ishl@16', 'a', 'b'), ('ushr@16', 'a', ('iadd', 16, ('ineg', 'b')))) => ('urol', 'a', 'b')
 *    ('ior', ('ishl@16', 'a', 'b'), ('ushr@16', 'a', ('isub', 16, 'b'))) => ('urol', 'a', 'b')
 *    ('ior', ('ishl@32', 'a', 'b'), ('ushr@32', 'a', ('iadd', 32, ('ineg', 'b')))) => ('urol', 'a', 'b')
 *    ('ior', ('ishl@32', 'a', 'b'), ('ushr@32', 'a', ('isub', 32, 'b'))) => ('urol', 'a', 'b')
 *    ('ior', ('ushr@16', 'a', 'b'), ('ishl@16', 'a', ('iadd', 16, ('ineg', 'b')))) => ('uror', 'a', 'b')
 *    ('ior', ('ushr@16', 'a', 'b'), ('ishl@16', 'a', ('isub', 16, 'b'))) => ('uror', 'a', 'b')
 *    ('ior', ('ushr@32', 'a', 'b'), ('ishl@32', 'a', ('iadd', 32, ('ineg', 'b')))) => ('uror', 'a', 'b')
 *    ('ior', ('ushr@32', 'a', 'b'), ('ishl@32', 'a', ('isub', 32, 'b'))) => ('uror', 'a', 'b')
 *    ('urol@16', 'a', 'b') => ('ior', ('ishl', 'a', 'b'), ('ushr', 'a', ('isub', 16, 'b')))
 *    ('urol@32', 'a', 'b') => ('ior', ('ishl', 'a', 'b'), ('ushr', 'a', ('isub', 32, 'b')))
 *    ('uror@16', 'a', 'b') => ('ior', ('ushr', 'a', 'b'), ('ishl', 'a', ('isub', 16, 'b')))
 *    ('uror@32', 'a', 'b') => ('ior', ('ushr', 'a', 'b'), ('ishl', 'a', ('isub', 32, 'b')))
 *    ('~fexp2', ('flog2', 'a')) => a
 *    ('~flog2', ('fexp2', 'a')) => a
 *    ('fpow', 'a', 'b') => ('fexp2', ('fmul', ('flog2', 'a'), 'b'))
 *    ('~fexp2', ('fmul', ('flog2', 'a'), 'b')) => ('fpow', 'a', 'b')
 *    ('~fexp2', ('fadd', ('fmul', ('flog2', 'a'), 'b'), ('fmul', ('flog2', 'c'), 'd'))) => ('~fmul', ('fpow', 'a', 'b'), ('fpow', 'c', 'd'))
 *    ('~fexp2', ('fmul', ('flog2', 'a'), 2.0)) => ('fmul', 'a', 'a')
 *    ('~fexp2', ('fmul', ('flog2', 'a'), 4.0)) => ('fmul', ('fmul', 'a', 'a'), ('fmul', 'a', 'a'))
 *    ('~fpow', 'a', 1.0) => a
 *    ('~fpow', 'a', 2.0) => ('fmul', 'a', 'a')
 *    ('~fpow', 'a', 4.0) => ('fmul', ('fmul', 'a', 'a'), ('fmul', 'a', 'a'))
 *    ('~fpow', 2.0, 'a') => ('fexp2', 'a')
 *    ('~fpow', ('fpow', 'a', 2.2), 0.454545) => a
 *    ('~fpow', ('fabs', ('fpow', 'a', 2.2)), 0.454545) => ('fabs', 'a')
 *    ('~fsqrt', ('fexp2', 'a')) => ('fexp2', ('fmul', 0.5, 'a'))
 *    ('~frcp', ('fexp2', 'a')) => ('fexp2', ('fneg', 'a'))
 *    ('~frsq', ('fexp2', 'a')) => ('fexp2', ('fmul', -0.5, 'a'))
 *    ('~flog2', ('fsqrt', 'a')) => ('fmul', 0.5, ('flog2', 'a'))
 *    ('~flog2', ('frcp', 'a')) => ('fneg', ('flog2', 'a'))
 *    ('~flog2', ('frsq', 'a')) => ('fmul', -0.5, ('flog2', 'a'))
 *    ('~flog2', ('fpow', 'a', 'b')) => ('fmul', 'b', ('flog2', 'a'))
 *    ('~fmul', ('fexp2(is_used_once)', 'a'), ('fexp2(is_used_once)', 'b')) => ('fexp2', ('fadd', 'a', 'b'))
 *    ('bcsel', ('flt', 'a', 0.0), 0.0, ('fsqrt', 'a')) => ('fsqrt', ('fmax', 'a', 0.0))
 *    ('~fdiv', 1.0, 'a') => ('frcp', 'a')
 *    ('fdiv', 'a', 'b') => ('fmul', 'a', ('frcp', 'b'))
 *    ('~frcp', ('frcp', 'a')) => a
 *    ('~frcp', ('fsqrt', 'a')) => ('frsq', 'a')
 *    ('fsqrt', 'a') => ('frcp', ('frsq', 'a'))
 *    ('~frcp', ('frsq', 'a')) => ('fsqrt', 'a')
 *    ('fsin', 'a') => ('ffma', ('ffma', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0), ('fabs', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0)), ('fneg', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0))), 0.225, ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0))
 *    ('fcos', 'a') => ('ffma', ('ffma', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0), ('fabs', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0)), ('fneg', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0))), 0.225, ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0))
 *    ('i2b32(is_used_by_if)', 'a') => ('ine32', 'a', 0)
 *    ('i2b1(is_used_by_if)', 'a') => ('ine', 'a', 0)
 *    ('ieq', 'a', True) => a
 *    ('ine(is_not_used_by_if)', 'a', True) => ('inot', 'a')
 *    ('ine', 'a', False) => a
 *    ('ieq(is_not_used_by_if)', 'a', False) => ('inot', 'a')
 *    ('bcsel', 'a', True, False) => a
 *    ('bcsel', 'a', False, True) => ('inot', 'a')
 *    ('bcsel@32', 'a', 1.0, 0.0) => ('b2f', 'a')
 *    ('bcsel@32', 'a', 0.0, 1.0) => ('b2f', ('inot', 'a'))
 *    ('bcsel@32', 'a', -1.0, -0.0) => ('fneg', ('b2f', 'a'))
 *    ('bcsel@32', 'a', -0.0, -1.0) => ('fneg', ('b2f', ('inot', 'a')))
 *    ('bcsel', True, 'b', 'c') => b
 *    ('bcsel', False, 'b', 'c') => c
 *    ('bcsel', 'a', ('b2f(is_used_once)', 'b@32'), ('b2f', 'c@32')) => ('b2f', ('bcsel', 'a', 'b', 'c'))
 *    ('bcsel', 'a', 'b', 'b') => b
 *    ('fcsel', 'a', 'b', 'b') => b
 *    ('bcsel', 'a', -1, 0) => ('ineg', ('b2i', 'a@1'))
 *    ('bcsel', 'a', 0, -1) => ('ineg', ('b2i', ('inot', 'a')))
 *    ('iand', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('iand', 'a', 'b')))
 *    ('ior', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('ior', 'a', 'b')))
 *    ('ieq', ('ineg', ('b2i', 'a@1')), 0) => ('inot', 'a')
 *    ('ieq', ('ineg', ('b2i', 'a@1')), -1) => a
 *    ('ine', ('ineg', ('b2i', 'a@1')), 0) => a
 *    ('ine', ('ineg', ('b2i', 'a@1')), -1) => ('inot', 'a')
 *    ('iand', ('ineg', ('b2i', 'a')), 1.0) => ('b2f', 'a')
 *    ('ishl', 'a@32', ('iand', 31, 'b')) => ('ishl', 'a', 'b')
 *    ('ishr', 'a@32', ('iand', 31, 'b')) => ('ishr', 'a', 'b')
 *    ('ushr', 'a@32', ('iand', 31, 'b')) => ('ushr', 'a', 'b')
 *    ('i2b32', ('b2i', 'a@32')) => a
 *    ('f2i', ('ftrunc', 'a')) => ('f2i', 'a')
 *    ('f2u', ('ftrunc', 'a')) => ('f2u', 'a')
 *    ('i2b', ('ineg', 'a')) => ('i2b', 'a')
 *    ('i2b', ('iabs', 'a')) => ('i2b', 'a')
 *    ('inot', ('f2b1', 'a')) => ('feq', 'a', 0.0)
 *    ('~f2i32', ('i2f', 'a@32')) => a
 *    ('~f2i32', ('u2f', 'a@32')) => a
 *    ('~f2u32', ('i2f', 'a@32')) => a
 *    ('~f2u32', ('u2f', 'a@32')) => a
 *    ('ffloor', 'a(is_integral)') => a
 *    ('fceil', 'a(is_integral)') => a
 *    ('ftrunc', 'a(is_integral)') => a
 *    ('~ffract', 'a(is_integral)') => 0.0
 *    ('fabs', 'a(is_not_negative)') => a
 *    ('iabs', 'a(is_not_negative)') => a
 *    ('fsat', 'a(is_not_positive)') => 0.0
 *    ('ige', ('f2u', 'a'), 'b') => ('ige', ('f2i', 'a'), 'b')
 *    ('ige', 'b', ('f2u', 'a')) => ('ige', 'b', ('f2i', 'a'))
 *    ('ilt', ('f2u', 'a'), 'b') => ('ilt', ('f2i', 'a'), 'b')
 *    ('ilt', 'b', ('f2u', 'a')) => ('ilt', 'b', ('f2i', 'a'))
 *    ('~fmin', 'a(is_not_negative)', 1.0) => ('fsat', 'a')
 *    ('flt', ('fadd', ('fmul', ('fsat', 'a'), ('fneg', ('fsat', 'a'))), 1.0), 0.0) => False
 *    ('flt', ('fadd', ('fneg', ('fmul', ('fsat', 'a'), ('fsat', 'a'))), 1.0), 0.0) => False
 *    ('fmax', ('fadd', ('fmul', ('fsat', 'a'), ('fneg', ('fsat', 'a'))), 1.0), 0.0) => ('fadd', ('fmul', ('fsat', 'a'), ('fneg', ('fsat', 'a'))), 1.0)
 *    ('fmax', ('fadd', ('fneg', ('fmul', ('fsat', 'a'), ('fsat', 'a'))), 1.0), 0.0) => ('fadd', ('fneg', ('fmul', ('fsat', 'a'), ('fsat', 'a'))), 1.0)
 *    ('fne', 'a(is_not_zero)', 0.0) => True
 *    ('feq', 'a(is_not_zero)', 0.0) => False
 *    ('~fge', 'a(is_not_negative)', 'b(is_not_positive)') => True
 *    ('fge', 'b(is_not_positive)', 'a(is_gt_zero)') => False
 *    ('fge', 'a(is_lt_zero)', 'b(is_not_negative)') => False
 *    ('~fge', 'b(is_not_negative)', 'a(is_not_positive)') => True
 *    ('flt', 'a(is_not_negative)', 'b(is_not_positive)') => False
 *    ('~flt', 'b(is_not_positive)', 'a(is_gt_zero)') => True
 *    ('~flt', 'a(is_lt_zero)', 'b(is_not_negative)') => True
 *    ('flt', 'b(is_not_negative)', 'a(is_not_positive)') => False
 *    ('ine', 'a(is_not_zero)', 0) => True
 *    ('ieq', 'a(is_not_zero)', 0) => False
 *    ('ige', 'a(is_not_negative)', 'b(is_not_positive)') => True
 *    ('ige', 'b(is_not_positive)', 'a(is_gt_zero)') => False
 *    ('ige', 'a(is_lt_zero)', 'b(is_not_negative)') => False
 *    ('ige', 'b(is_not_negative)', 'a(is_not_positive)') => True
 *    ('ilt', 'a(is_not_negative)', 'b(is_not_positive)') => False
 *    ('ilt', 'b(is_not_positive)', 'a(is_gt_zero)') => True
 *    ('ilt', 'a(is_lt_zero)', 'b(is_not_negative)') => True
 *    ('ilt', 'b(is_not_negative)', 'a(is_not_positive)') => False
 *    ('ult', 0, 'a(is_gt_zero)') => True
 *    ('unpack_64_2x32_split_x', ('pack_64_2x32_split', 'a', 'b')) => a
 *    ('unpack_64_2x32_split_y', ('pack_64_2x32_split', 'a', 'b')) => b
 *    ('pack_64_2x32_split', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')) => a
 *    ('iand', ('ieq', ('unpack_32_2x16_split_x', 'a'), '#b'), ('ieq', ('unpack_32_2x16_split_y', 'a'), '#c')) => ('ieq', 'a', ('pack_32_2x16_split', 'b', 'c'))
 *    ('ushr', 'a@16', 8) => ('extract_u8', 'a', 1)
 *    ('ushr', 'a@32', 24) => ('extract_u8', 'a', 3)
 *    ('ushr', 'a@64', 56) => ('extract_u8', 'a', 7)
 *    ('ishr', 'a@16', 8) => ('extract_i8', 'a', 1)
 *    ('ishr', 'a@32', 24) => ('extract_i8', 'a', 3)
 *    ('ishr', 'a@64', 56) => ('extract_i8', 'a', 7)
 *    ('iand', 255, 'a') => ('extract_u8', 'a', 0)
 *    ('unpack_half_2x16_split_x', ('iand', 'a', 65535)) => ('unpack_half_2x16_split_x', 'a')
 *    ('unpack_32_2x16_split_x', ('iand', 'a', 65535)) => ('unpack_32_2x16_split_x', 'a')
 *    ('unpack_64_2x32_split_x', ('iand', 'a', 4294967295)) => ('unpack_64_2x32_split_x', 'a')
 *    ('unpack_half_2x16_split_y', ('iand', 'a', 4294901760)) => ('unpack_half_2x16_split_y', 'a')
 *    ('unpack_32_2x16_split_y', ('iand', 'a', 4294901760)) => ('unpack_32_2x16_split_y', 'a')
 *    ('unpack_64_2x32_split_y', ('iand', 'a', 18446744069414584320)) => ('unpack_64_2x32_split_y', 'a')
 *    ('extract_u8', ('ushr', 'a@16', 8), 0) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ushr', 'a@32', 8), 0) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ushr', 'a@32', 16), 0) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ushr', 'a@32', 24), 0) => ('extract_u8', 'a', 3)
 *    ('extract_u8', ('ushr', 'a@64', 8), 0) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ushr', 'a@64', 16), 0) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ushr', 'a@64', 24), 0) => ('extract_u8', 'a', 3)
 *    ('extract_u8', ('ushr', 'a@64', 32), 0) => ('extract_u8', 'a', 4)
 *    ('extract_u8', ('ushr', 'a@64', 40), 0) => ('extract_u8', 'a', 5)
 *    ('extract_u8', ('ushr', 'a@64', 48), 0) => ('extract_u8', 'a', 6)
 *    ('extract_u8', ('ushr', 'a@64', 56), 0) => ('extract_u8', 'a', 7)
 *    ('extract_u8', ('ishr', 'a@16', 8), 0) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ishr', 'a@32', 8), 0) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ishr', 'a@32', 16), 0) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ishr', 'a@32', 24), 0) => ('extract_u8', 'a', 3)
 *    ('extract_u8', ('ishr', 'a@64', 8), 0) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ishr', 'a@64', 16), 0) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ishr', 'a@64', 24), 0) => ('extract_u8', 'a', 3)
 *    ('extract_u8', ('ishr', 'a@64', 32), 0) => ('extract_u8', 'a', 4)
 *    ('extract_u8', ('ishr', 'a@64', 40), 0) => ('extract_u8', 'a', 5)
 *    ('extract_u8', ('ishr', 'a@64', 48), 0) => ('extract_u8', 'a', 6)
 *    ('extract_u8', ('ishr', 'a@64', 56), 0) => ('extract_u8', 'a', 7)
 *    ('extract_u8', ('extract_u16', 'a', 1), 0) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ishl', 'a@16', 8), 1) => ('extract_u8', 'a', 0)
 *    ('extract_u8', ('ishl', 'a@32', 8), 3) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ishl', 'a@32', 16), 3) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ishl', 'a@32', 24), 3) => ('extract_u8', 'a', 0)
 *    ('extract_u8', ('ishl', 'a@64', 8), 7) => ('extract_u8', 'a', 6)
 *    ('extract_u8', ('ishl', 'a@64', 16), 7) => ('extract_u8', 'a', 5)
 *    ('extract_u8', ('ishl', 'a@64', 24), 7) => ('extract_u8', 'a', 4)
 *    ('extract_u8', ('ishl', 'a@64', 32), 7) => ('extract_u8', 'a', 3)
 *    ('extract_u8', ('ishl', 'a@64', 40), 7) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ishl', 'a@64', 48), 7) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ishl', 'a@64', 56), 7) => ('extract_u8', 'a', 0)
 *    ('extract_i8', ('ishl', 'a@16', 8), 1) => ('extract_i8', 'a', 0)
 *    ('extract_i8', ('ishl', 'a@32', 8), 3) => ('extract_i8', 'a', 2)
 *    ('extract_i8', ('ishl', 'a@32', 16), 3) => ('extract_i8', 'a', 1)
 *    ('extract_i8', ('ishl', 'a@32', 24), 3) => ('extract_i8', 'a', 0)
 *    ('extract_i8', ('ishl', 'a@64', 8), 7) => ('extract_i8', 'a', 6)
 *    ('extract_i8', ('ishl', 'a@64', 16), 7) => ('extract_i8', 'a', 5)
 *    ('extract_i8', ('ishl', 'a@64', 24), 7) => ('extract_i8', 'a', 4)
 *    ('extract_i8', ('ishl', 'a@64', 32), 7) => ('extract_i8', 'a', 3)
 *    ('extract_i8', ('ishl', 'a@64', 40), 7) => ('extract_i8', 'a', 2)
 *    ('extract_i8', ('ishl', 'a@64', 48), 7) => ('extract_i8', 'a', 1)
 *    ('extract_i8', ('ishl', 'a@64', 56), 7) => ('extract_i8', 'a', 0)
 *    ('ushr', ('ishl', 'a@32', 16), 16) => ('extract_u16', 'a', 0)
 *    ('ushr', 'a@32', 16) => ('extract_u16', 'a', 1)
 *    ('ishr', ('ishl', 'a@32', 16), 16) => ('extract_i16', 'a', 0)
 *    ('ishr', 'a@32', 16) => ('extract_i16', 'a', 1)
 *    ('iand', 65535, 'a') => ('extract_u16', 'a', 0)
 *    ('~fsub', 'a', ('fsub', 0.0, 'b')) => ('fadd', 'a', 'b')
 *    ('isub', 'a', ('isub', 0, 'b')) => ('iadd', 'a', 'b')
 *    ('ussub_4x8', 'a', 0) => a
 *    ('ussub_4x8', 'a', -1) => 0
 *    ('fsub', 'a', 'b') => ('fadd', 'a', ('fneg', 'b'))
 *    ('isub', 'a', 'b') => ('iadd', 'a', ('ineg', 'b'))
 *    ('fneg', 'a') => ('fsub', 0.0, 'a')
 *    ('ineg', 'a') => ('isub', 0, 'a')
 *    ('~fadd', 'a', ('fsub', 0.0, 'b')) => ('fsub', 'a', 'b')
 *    ('iadd', 'a', ('isub', 0, 'b')) => ('isub', 'a', 'b')
 *    ('fabs', ('fsub', 0.0, 'a')) => ('fabs', 'a')
 *    ('iabs', ('isub', 0, 'a')) => ('iabs', 'a')
 *    ('fmul(is_used_by_non_fsat)', ('fneg', 'a'), 'b') => ('fneg', ('fmul', 'a', 'b'))
 *    ('imul', ('ineg', 'a'), 'b') => ('ineg', ('imul', 'a', 'b'))
 *    ('~fmul(is_used_once)', ('fmul(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('fmul', ('fmul', 'a', 'c'), 'b')
 *    ('imul(is_used_once)', ('imul(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('imul', ('imul', 'a', 'c'), 'b')
 *    ('~fadd(is_used_once)', ('fadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('fadd', ('fadd', 'a', 'c'), 'b')
 *    ('iadd(is_used_once)', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('iadd', ('iadd', 'a', 'c'), 'b')
 *    ('~fmul', '#a', ('fmul', 'b(is_not_const)', '#c')) => ('fmul', ('fmul', 'a', 'c'), 'b')
 *    ('imul', '#a', ('imul', 'b(is_not_const)', '#c')) => ('imul', ('imul', 'a', 'c'), 'b')
 *    ('~fadd', '#a', ('fadd', 'b(is_not_const)', '#c')) => ('fadd', ('fadd', 'a', 'c'), 'b')
 *    ('~fadd', '#a', ('fneg', ('fadd', 'b(is_not_const)', '#c'))) => ('fadd', ('fadd', 'a', ('fneg', 'c')), ('fneg', 'b'))
 *    ('iadd', '#a', ('iadd', 'b(is_not_const)', '#c')) => ('iadd', ('iadd', 'a', 'c'), 'b')
 *    ('idiv', ('imul(no_signed_wrap)', 'a', 'b'), 'b') => a
 *    ('bcsel', ('ige', ('find_lsb', 'a'), 0), ('find_lsb', 'a'), -1) => ('find_lsb', 'a')
 *    ('bcsel', ('ige', ('ifind_msb', 'a'), 0), ('ifind_msb', 'a'), -1) => ('ifind_msb', 'a')
 *    ('bcsel', ('ige', ('ufind_msb', 'a'), 0), ('ufind_msb', 'a'), -1) => ('ufind_msb', 'a')
 *    ('bcsel', ('ine', 'a', 0), ('find_lsb', 'a'), -1) => ('find_lsb', 'a')
 *    ('bcsel', ('ine', 'a', 0), ('ifind_msb', 'a'), -1) => ('ifind_msb', 'a')
 *    ('bcsel', ('ine', 'a', 0), ('ufind_msb', 'a'), -1) => ('ufind_msb', 'a')
 *    ('bcsel', ('ine', 'a', -1), ('ifind_msb', 'a'), -1) => ('ifind_msb', 'a')
 *    ('fmod@16', 'a', 'b') => ('fsub', 'a', ('fmul', 'b', ('ffloor', ('fdiv', 'a', 'b'))))
 *    ('fmod@32', 'a', 'b') => ('fsub', 'a', ('fmul', 'b', ('ffloor', ('fdiv', 'a', 'b'))))
 *    ('frem', 'a', 'b') => ('fsub', 'a', ('fmul', 'b', ('ftrunc', ('fdiv', 'a', 'b'))))
 *    ('uadd_carry@32', 'a', 'b') => ('b2i', ('ult', ('iadd', 'a', 'b'), 'a'))
 *    ('usub_borrow@32', 'a', 'b') => ('b2i', ('ult', 'a', 'b'))
 *    ('bitfield_insert', 'base', 'insert', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'insert', ('bfi', ('bfm', 'bits', 'offset'), 'insert', 'base'))
 *    ('ihadd', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1))
 *    ('uhadd', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1))
 *    ('irhadd', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1))
 *    ('urhadd', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1))
 *    ('uadd_sat', 'a', 'b') => ('bcsel', ('ult', ('iadd', 'a', 'b'), 'a'), -1, ('iadd', 'a', 'b'))
 *    ('usub_sat', 'a', 'b') => ('bcsel', ('ult', 'a', 'b'), 0, ('isub', 'a', 'b'))
 *    ('bitfield_insert', 'base', 'insert', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'insert', ('ior', ('iand', 'base', ('inot', ('ishl', ('isub', ('ishl', 1, 'bits'), 1), 'offset'))), ('iand', ('ishl', 'insert', 'offset'), ('ishl', ('isub', ('ishl', 1, 'bits'), 1), 'offset'))))
 *    ('bitfield_insert', 'base', 'insert', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'insert', ('bitfield_select', ('bfm', 'bits', 'offset'), ('ishl', 'insert', 'offset'), 'base'))
 *    ('ibitfield_extract', 'value', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'value', ('ibfe', 'value', 'offset', 'bits'))
 *    ('ubitfield_extract', 'value', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'value', ('ubfe', 'value', 'offset', 'bits'))
 *    ('ubfe', 'value', 'offset', ('iand', 31, 'bits')) => ('ubfe', 'value', 'offset', 'bits')
 *    ('ubfe', 'value', ('iand', 31, 'offset'), 'bits') => ('ubfe', 'value', 'offset', 'bits')
 *    ('ibfe', 'value', 'offset', ('iand', 31, 'bits')) => ('ibfe', 'value', 'offset', 'bits')
 *    ('ibfe', 'value', ('iand', 31, 'offset'), 'bits') => ('ibfe', 'value', 'offset', 'bits')
 *    ('bfm', 'bits', ('iand', 31, 'offset')) => ('bfm', 'bits', 'offset')
 *    ('bfm', ('iand', 31, 'bits'), 'offset') => ('bfm', 'bits', 'offset')
 *    ('ibitfield_extract', 'value', 'offset', 'bits') => ('bcsel', ('ieq', 0, 'bits'), 0, ('ishr', ('ishl', 'value', ('isub', ('isub', 32, 'bits'), 'offset')), ('isub', 32, 'bits')))
 *    ('ubitfield_extract', 'value', 'offset', 'bits') => ('iand', ('ushr', 'value', 'offset'), ('bcsel', ('ieq', 'bits', 32), 4294967295, ('isub', ('ishl', 1, 'bits'), 1)))
 *    ('ifind_msb', 'value') => ('ufind_msb', ('bcsel', ('ilt', 'value', 0), ('inot', 'value'), 'value'))
 *    ('find_lsb', 'value') => ('ufind_msb', ('iand', 'value', ('ineg', 'value')))
 *    ('extract_i8', 'a', 'b@32') => ('ishr', ('ishl', 'a', ('imul', ('isub', 3, 'b'), 8)), 24)
 *    ('extract_u8', 'a', 'b@32') => ('iand', ('ushr', 'a', ('imul', 'b', 8)), 255)
 *    ('extract_i16', 'a', 'b@32') => ('ishr', ('ishl', 'a', ('imul', ('isub', 1, 'b'), 16)), 16)
 *    ('extract_u16', 'a', 'b@32') => ('iand', ('ushr', 'a', ('imul', 'b', 16)), 65535)
 *    ('pack_unorm_2x16', 'v') => ('pack_uvec2_to_uint', ('f2u32', ('fround_even', ('fmul', ('fsat', 'v'), 65535.0))))
 *    ('pack_unorm_4x8', 'v') => ('pack_uvec4_to_uint', ('f2u32', ('fround_even', ('fmul', ('fsat', 'v'), 255.0))))
 *    ('pack_snorm_2x16', 'v') => ('pack_uvec2_to_uint', ('f2i32', ('fround_even', ('fmul', ('fmin', 1.0, ('fmax', -1.0, 'v')), 32767.0))))
 *    ('pack_snorm_4x8', 'v') => ('pack_uvec4_to_uint', ('f2i32', ('fround_even', ('fmul', ('fmin', 1.0, ('fmax', -1.0, 'v')), 127.0))))
 *    ('unpack_unorm_2x16', 'v') => ('fdiv', ('u2f32', ('vec2', ('extract_u16', 'v', 0), ('extract_u16', 'v', 1))), 65535.0)
 *    ('unpack_unorm_4x8', 'v') => ('fdiv', ('u2f32', ('vec4', ('extract_u8', 'v', 0), ('extract_u8', 'v', 1), ('extract_u8', 'v', 2), ('extract_u8', 'v', 3))), 255.0)
 *    ('unpack_snorm_2x16', 'v') => ('fmin', 1.0, ('fmax', -1.0, ('fdiv', ('i2f', ('vec2', ('extract_i16', 'v', 0), ('extract_i16', 'v', 1))), 32767.0)))
 *    ('unpack_snorm_4x8', 'v') => ('fmin', 1.0, ('fmax', -1.0, ('fdiv', ('i2f', ('vec4', ('extract_i8', 'v', 0), ('extract_i8', 'v', 1), ('extract_i8', 'v', 2), ('extract_i8', 'v', 3))), 127.0)))
 *    ('isign', 'a') => ('imin', ('imax', 'a', -1), 1)
 *    ('fsign', 'a') => ('fsub', ('b2f', ('flt', 0.0, 'a')), ('b2f', ('flt', 'a', 0.0)))
 *    ('iadd_sat@8', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 127, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 128, ('iadd', 'a', 'b')))
 *    ('isub_sat@8', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 127, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 128, ('isub', 'a', 'b')))
 *    ('iadd_sat@16', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 32767, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 32768, ('iadd', 'a', 'b')))
 *    ('isub_sat@16', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 32767, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 32768, ('isub', 'a', 'b')))
 *    ('iadd_sat@32', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 2147483647, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 2147483648, ('iadd', 'a', 'b')))
 *    ('isub_sat@32', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 2147483647, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 2147483648, ('isub', 'a', 'b')))
 *    ('iadd_sat@64', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 9223372036854775807, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 9223372036854775808, ('iadd', 'a', 'b')))
 *    ('isub_sat@64', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 9223372036854775807, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 9223372036854775808, ('isub', 'a', 'b')))
 *    ('inot', ('ior(is_used_once)', ('feq', 'a', 'b'), ('feq', 'c', 'd'))) => ('iand', ('fne', 'a', 'b'), ('fne', 'c', 'd'))
 *    ('inot', ('iand(is_used_once)', ('feq', 'a', 'b'), ('feq', 'c', 'd'))) => ('ior', ('fne', 'a', 'b'), ('fne', 'c', 'd'))
 *    ('inot', ('ior(is_used_once)', ('feq', 'a', 'b'), ('fne', 'c', 'd'))) => ('iand', ('fne', 'a', 'b'), ('feq', 'c', 'd'))
 *    ('inot', ('iand(is_used_once)', ('feq', 'a', 'b'), ('fne', 'c', 'd'))) => ('ior', ('fne', 'a', 'b'), ('feq', 'c', 'd'))
 *    ('inot', ('ior(is_used_once)', ('feq', 'a', 'b'), ('fge', 'c', 'd'))) => ('iand', ('fne', 'a', 'b'), ('flt', 'c', 'd'))
 *    ('inot', ('iand(is_used_once)', ('feq', 'a', 'b'), ('fge', 'c', 'd'))) => ('ior', ('fne', 'a', 'b'), ('flt', 'c', 'd'))
 *    ('inot', ('ior(is_used_once)', ('feq', 'a', 'b'), ('flt', 'c', 'd'))) => ('iand', ('fne', 'a', 'b'), ('fge', 'c', 'd'))
 *    ('inot', ('iand(is_used_once)', ('feq', 'a', 'b'), ('flt', 'c', 'd'))) => ('ior', ('fne', 'a', 'b'), ('fge', 'c', 'd'))
 *    ('inot', ('ior(is_used_once)', ('fne', 'a', 'b'), ('fne', 'c', 'd'))) => ('iand', ('feq', 'a', 'b'), ('feq', 'c', 'd'))
 *    ('inot', ('iand(is_used_once)', ('fne', 'a', 'b'), ('fne', 'c', 'd'))) => ('ior', ('feq', 'a', 'b'), ('feq', 'c', 'd'))
 *    ('inot', ('ior(is_used_once)', ('fne', 'a', 'b'), ('fge', 'c', 'd'))) => ('iand', ('feq', 'a', 'b'), ('flt', 'c', 'd'))
 *    ('inot', ('iand(is_used_once)', ('fne', 'a', 'b'), ('fge', 'c', 'd'))) => ('ior', ('feq', 'a', 'b'), ('flt', 'c', 'd'))
 *    ('inot', ('ior(is_used_once)', ('fne', 'a', 'b'), ('flt', 'c', 'd'))) => ('iand', ('feq', 'a', 'b'), ('fge', 'c', 'd'))
 *    ('inot', ('iand(is_used_once)', ('fne', 'a', 'b'), ('flt', 'c', 'd'))) => ('ior', ('feq', 'a', 'b'), ('fge', 'c', 'd'))
 *    ('inot', ('ior(is_used_once)', ('fge', 'a', 'b'), ('fge', 'c', 'd'))) => ('iand', ('flt', 'a', 'b'), ('flt', 'c', 'd'))
 *    ('inot', ('iand(is_used_once)', ('fge', 'a', 'b'), ('fge', 'c', 'd'))) => ('ior', ('flt', 'a', 'b'), ('flt', 'c', 'd'))
 *    ('inot', ('ior(is_used_once)', ('fge', 'a', 'b'), ('flt', 'c', 'd'))) => ('iand', ('flt', 'a', 'b'), ('fge', 'c', 'd'))
 *    ('inot', ('iand(is_used_once)', ('fge', 'a', 'b'), ('flt', 'c', 'd'))) => ('ior', ('flt', 'a', 'b'), ('fge', 'c', 'd'))
 *    ('inot', ('ior(is_used_once)', ('flt', 'a', 'b'), ('flt', 'c', 'd'))) => ('iand', ('fge', 'a', 'b'), ('fge', 'c', 'd'))
 *    ('inot', ('iand(is_used_once)', ('flt', 'a', 'b'), ('flt', 'c', 'd'))) => ('ior', ('fge', 'a', 'b'), ('fge', 'c', 'd'))
 *    ('f2b1', ('b2f', 'a@1')) => a
 *    ('i2b1', ('b2i', 'a@1')) => a
 *    ('f2b32', ('b2f', 'a@32')) => a
 *    ('i2b32', ('b2i', 'a@32')) => a
 *    ('f2f', ('b2f', 'a')) => ('b2f', 'a')
 *    ('f2u', ('b2f', 'a')) => ('b2i', 'a')
 *    ('f2i', ('b2f', 'a')) => ('b2i', 'a')
 *    ('u2f', ('b2i', 'a')) => ('b2f', 'a')
 *    ('u2u', ('b2i', 'a')) => ('b2i', 'a')
 *    ('i2f', ('b2i', 'a')) => ('b2f', 'a')
 *    ('i2i', ('b2i', 'a')) => ('b2i', 'a')
 *    ('i2i1', 'a@1') => a
 *    ('i2i8', 'a@8') => a
 *    ('i2i16', 'a@16') => a
 *    ('i2i32', 'a@32') => a
 *    ('i2i64', 'a@64') => a
 *    ('u2u1', 'a@1') => a
 *    ('u2u8', 'a@8') => a
 *    ('u2u16', 'a@16') => a
 *    ('u2u32', 'a@32') => a
 *    ('u2u64', 'a@64') => a
 *    ('f2f16', 'a@16') => a
 *    ('f2f32', 'a@32') => a
 *    ('f2f64', 'a@64') => a
 *    ('i2i1', ('i2i8', 'a')) => ('i2i1', 'a')
 *    ('i2i1', ('u2u8', 'a')) => ('u2u1', 'a')
 *    ('u2u1', ('i2i8', 'a')) => ('i2i1', 'a')
 *    ('u2u1', ('u2u8', 'a')) => ('u2u1', 'a')
 *    ('i2i1', ('i2i16', 'a')) => ('i2i1', 'a')
 *    ('i2i1', ('u2u16', 'a')) => ('u2u1', 'a')
 *    ('u2u1', ('i2i16', 'a')) => ('i2i1', 'a')
 *    ('u2u1', ('u2u16', 'a')) => ('u2u1', 'a')
 *    ('i2i1', ('i2i32', 'a')) => ('i2i1', 'a')
 *    ('i2i1', ('u2u32', 'a')) => ('u2u1', 'a')
 *    ('u2u1', ('i2i32', 'a')) => ('i2i1', 'a')
 *    ('u2u1', ('u2u32', 'a')) => ('u2u1', 'a')
 *    ('i2i1', ('i2i64', 'a')) => ('i2i1', 'a')
 *    ('i2i1', ('u2u64', 'a')) => ('u2u1', 'a')
 *    ('u2u1', ('i2i64', 'a')) => ('i2i1', 'a')
 *    ('u2u1', ('u2u64', 'a')) => ('u2u1', 'a')
 *    ('i2i8', ('i2i1', 'a@1')) => ('i2i8', 'a')
 *    ('u2u8', ('u2u1', 'a@1')) => ('u2u8', 'a')
 *    ('i2i8', ('i2i16', 'a')) => ('i2i8', 'a')
 *    ('i2i8', ('u2u16', 'a')) => ('u2u8', 'a')
 *    ('u2u8', ('i2i16', 'a')) => ('i2i8', 'a')
 *    ('u2u8', ('u2u16', 'a')) => ('u2u8', 'a')
 *    ('i2i8', ('i2i32', 'a')) => ('i2i8', 'a')
 *    ('i2i8', ('u2u32', 'a')) => ('u2u8', 'a')
 *    ('u2u8', ('i2i32', 'a')) => ('i2i8', 'a')
 *    ('u2u8', ('u2u32', 'a')) => ('u2u8', 'a')
 *    ('i2i8', ('i2i64', 'a')) => ('i2i8', 'a')
 *    ('i2i8', ('u2u64', 'a')) => ('u2u8', 'a')
 *    ('u2u8', ('i2i64', 'a')) => ('i2i8', 'a')
 *    ('u2u8', ('u2u64', 'a')) => ('u2u8', 'a')
 *    ('i2i16', ('i2i1', 'a@1')) => ('i2i16', 'a')
 *    ('u2u16', ('u2u1', 'a@1')) => ('u2u16', 'a')
 *    ('i2i16', ('i2i8', 'a@1')) => ('i2i16', 'a')
 *    ('u2u16', ('u2u8', 'a@1')) => ('u2u16', 'a')
 *    ('i2i16', ('i2i8', 'a@8')) => ('i2i16', 'a')
 *    ('u2u16', ('u2u8', 'a@8')) => ('u2u16', 'a')
 *    ('i2i16', ('i2i32', 'a')) => ('i2i16', 'a')
 *    ('i2i16', ('u2u32', 'a')) => ('u2u16', 'a')
 *    ('u2u16', ('i2i32', 'a')) => ('i2i16', 'a')
 *    ('u2u16', ('u2u32', 'a')) => ('u2u16', 'a')
 *    ('i2i16', ('i2i64', 'a')) => ('i2i16', 'a')
 *    ('i2i16', ('u2u64', 'a')) => ('u2u16', 'a')
 *    ('u2u16', ('i2i64', 'a')) => ('i2i16', 'a')
 *    ('u2u16', ('u2u64', 'a')) => ('u2u16', 'a')
 *    ('i2i32', ('i2i1', 'a@1')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u1', 'a@1')) => ('u2u32', 'a')
 *    ('i2i32', ('i2i8', 'a@1')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u8', 'a@1')) => ('u2u32', 'a')
 *    ('i2i32', ('i2i8', 'a@8')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u8', 'a@8')) => ('u2u32', 'a')
 *    ('i2i32', ('i2i16', 'a@1')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u16', 'a@1')) => ('u2u32', 'a')
 *    ('i2i32', ('i2i16', 'a@8')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u16', 'a@8')) => ('u2u32', 'a')
 *    ('i2i32', ('i2i16', 'a@16')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u16', 'a@16')) => ('u2u32', 'a')
 *    ('i2i32', ('i2i64', 'a')) => ('i2i32', 'a')
 *    ('i2i32', ('u2u64', 'a')) => ('u2u32', 'a')
 *    ('u2u32', ('i2i64', 'a')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u64', 'a')) => ('u2u32', 'a')
 *    ('i2i64', ('i2i1', 'a@1')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u1', 'a@1')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i8', 'a@1')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u8', 'a@1')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i8', 'a@8')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u8', 'a@8')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i16', 'a@1')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u16', 'a@1')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i16', 'a@8')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u16', 'a@8')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i16', 'a@16')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u16', 'a@16')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i32', 'a@1')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u32', 'a@1')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i32', 'a@8')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u32', 'a@8')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i32', 'a@16')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u32', 'a@16')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i32', 'a@32')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u32', 'a@32')) => ('u2u64', 'a')
 *    ('ieq', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ieq', 'a', ('i2i8', 'b'))
 *    ('ine', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ine', 'a', ('i2i8', 'b'))
 *    ('ige', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ige', 'a', ('i2i8', 'b'))
 *    ('ilt', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ilt', 'a', ('i2i8', 'b'))
 *    ('ige', ('i2i16', 'b@8'), ('i2i16', 'a@8')) => ('ige', ('i2i8', 'b'), 'a')
 *    ('ilt', ('i2i16', 'b@8'), ('i2i16', 'a@8')) => ('ilt', ('i2i8', 'b'), 'a')
 *    ('ieq', ('i2i16', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('i2i8', 'b')), ('ieq', ('i2i16', ('i2i8', 'b')), 'b'))
 *    ('ine', ('i2i16', 'a@8'), '#b') => ('ior', ('ine', 'a', ('i2i8', 'b')), ('ine', ('i2i16', ('i2i8', 'b')), 'b'))
 *    ('ilt', ('i2i16', 'a@8'), '#b') => ('iand', ('ilt', -128, 'b'), ('ior', ('ilt', 127, 'b'), ('ilt', 'a', ('i2i8', 'b'))))
 *    ('ilt', '#a', ('i2i16', 'b@8')) => ('iand', ('ilt', 'a', 127), ('ior', ('ilt', 'a', -128), ('ilt', ('i2i8', 'a'), 'b')))
 *    ('ige', ('i2i16', 'a@8'), '#b') => ('iand', ('ige', 127, 'b'), ('ior', ('ige', -128, 'b'), ('ige', 'a', ('i2i8', 'b'))))
 *    ('ige', '#a', ('i2i16', 'b@8')) => ('iand', ('ige', 'a', -128), ('ior', ('ige', 'a', 127), ('ige', ('i2i8', 'a'), 'b')))
 *    ('ieq', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ieq', 'a', ('i2i8', 'b'))
 *    ('ine', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ine', 'a', ('i2i8', 'b'))
 *    ('ige', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ige', 'a', ('i2i8', 'b'))
 *    ('ilt', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ilt', 'a', ('i2i8', 'b'))
 *    ('ige', ('i2i32', 'b@8'), ('i2i32', 'a@8')) => ('ige', ('i2i8', 'b'), 'a')
 *    ('ilt', ('i2i32', 'b@8'), ('i2i32', 'a@8')) => ('ilt', ('i2i8', 'b'), 'a')
 *    ('ieq', ('i2i32', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('i2i8', 'b')), ('ieq', ('i2i32', ('i2i8', 'b')), 'b'))
 *    ('ine', ('i2i32', 'a@8'), '#b') => ('ior', ('ine', 'a', ('i2i8', 'b')), ('ine', ('i2i32', ('i2i8', 'b')), 'b'))
 *    ('ilt', ('i2i32', 'a@8'), '#b') => ('iand', ('ilt', -128, 'b'), ('ior', ('ilt', 127, 'b'), ('ilt', 'a', ('i2i8', 'b'))))
 *    ('ilt', '#a', ('i2i32', 'b@8')) => ('iand', ('ilt', 'a', 127), ('ior', ('ilt', 'a', -128), ('ilt', ('i2i8', 'a'), 'b')))
 *    ('ige', ('i2i32', 'a@8'), '#b') => ('iand', ('ige', 127, 'b'), ('ior', ('ige', -128, 'b'), ('ige', 'a', ('i2i8', 'b'))))
 *    ('ige', '#a', ('i2i32', 'b@8')) => ('iand', ('ige', 'a', -128), ('ior', ('ige', 'a', 127), ('ige', ('i2i8', 'a'), 'b')))
 *    ('ieq', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ieq', 'a', ('i2i8', 'b'))
 *    ('ine', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ine', 'a', ('i2i8', 'b'))
 *    ('ige', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ige', 'a', ('i2i8', 'b'))
 *    ('ilt', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ilt', 'a', ('i2i8', 'b'))
 *    ('ige', ('i2i64', 'b@8'), ('i2i64', 'a@8')) => ('ige', ('i2i8', 'b'), 'a')
 *    ('ilt', ('i2i64', 'b@8'), ('i2i64', 'a@8')) => ('ilt', ('i2i8', 'b'), 'a')
 *    ('ieq', ('i2i64', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('i2i8', 'b')), ('ieq', ('i2i64', ('i2i8', 'b')), 'b'))
 *    ('ine', ('i2i64', 'a@8'), '#b') => ('ior', ('ine', 'a', ('i2i8', 'b')), ('ine', ('i2i64', ('i2i8', 'b')), 'b'))
 *    ('ilt', ('i2i64', 'a@8'), '#b') => ('iand', ('ilt', -128, 'b'), ('ior', ('ilt', 127, 'b'), ('ilt', 'a', ('i2i8', 'b'))))
 *    ('ilt', '#a', ('i2i64', 'b@8')) => ('iand', ('ilt', 'a', 127), ('ior', ('ilt', 'a', -128), ('ilt', ('i2i8', 'a'), 'b')))
 *    ('ige', ('i2i64', 'a@8'), '#b') => ('iand', ('ige', 127, 'b'), ('ior', ('ige', -128, 'b'), ('ige', 'a', ('i2i8', 'b'))))
 *    ('ige', '#a', ('i2i64', 'b@8')) => ('iand', ('ige', 'a', -128), ('ior', ('ige', 'a', 127), ('ige', ('i2i8', 'a'), 'b')))
 *    ('ieq', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ieq', 'a', ('i2i16', 'b'))
 *    ('ine', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ine', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ige', 'a', ('i2i16', 'b'))
 *    ('ilt', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ilt', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i32', 'b@8'), ('i2i32', 'a@16')) => ('ige', ('i2i16', 'b'), 'a')
 *    ('ilt', ('i2i32', 'b@8'), ('i2i32', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a')
 *    ('ieq', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ieq', 'a', ('i2i16', 'b'))
 *    ('ine', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ine', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ige', 'a', ('i2i16', 'b'))
 *    ('ilt', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ilt', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i32', 'b@16'), ('i2i32', 'a@16')) => ('ige', ('i2i16', 'b'), 'a')
 *    ('ilt', ('i2i32', 'b@16'), ('i2i32', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a')
 *    ('ieq', ('i2i32', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('i2i16', 'b')), ('ieq', ('i2i32', ('i2i16', 'b')), 'b'))
 *    ('ine', ('i2i32', 'a@16'), '#b') => ('ior', ('ine', 'a', ('i2i16', 'b')), ('ine', ('i2i32', ('i2i16', 'b')), 'b'))
 *    ('ilt', ('i2i32', 'a@16'), '#b') => ('iand', ('ilt', -32768, 'b'), ('ior', ('ilt', 32767, 'b'), ('ilt', 'a', ('i2i16', 'b'))))
 *    ('ilt', '#a', ('i2i32', 'b@16')) => ('iand', ('ilt', 'a', 32767), ('ior', ('ilt', 'a', -32768), ('ilt', ('i2i16', 'a'), 'b')))
 *    ('ige', ('i2i32', 'a@16'), '#b') => ('iand', ('ige', 32767, 'b'), ('ior', ('ige', -32768, 'b'), ('ige', 'a', ('i2i16', 'b'))))
 *    ('ige', '#a', ('i2i32', 'b@16')) => ('iand', ('ige', 'a', -32768), ('ior', ('ige', 'a', 32767), ('ige', ('i2i16', 'a'), 'b')))
 *    ('ieq', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ieq', 'a', ('i2i16', 'b'))
 *    ('ine', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ine', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ige', 'a', ('i2i16', 'b'))
 *    ('ilt', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ilt', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i64', 'b@8'), ('i2i64', 'a@16')) => ('ige', ('i2i16', 'b'), 'a')
 *    ('ilt', ('i2i64', 'b@8'), ('i2i64', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a')
 *    ('ieq', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ieq', 'a', ('i2i16', 'b'))
 *    ('ine', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ine', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ige', 'a', ('i2i16', 'b'))
 *    ('ilt', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ilt', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i64', 'b@16'), ('i2i64', 'a@16')) => ('ige', ('i2i16', 'b'), 'a')
 *    ('ilt', ('i2i64', 'b@16'), ('i2i64', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a')
 *    ('ieq', ('i2i64', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('i2i16', 'b')), ('ieq', ('i2i64', ('i2i16', 'b')), 'b'))
 *    ('ine', ('i2i64', 'a@16'), '#b') => ('ior', ('ine', 'a', ('i2i16', 'b')), ('ine', ('i2i64', ('i2i16', 'b')), 'b'))
 *    ('ilt', ('i2i64', 'a@16'), '#b') => ('iand', ('ilt', -32768, 'b'), ('ior', ('ilt', 32767, 'b'), ('ilt', 'a', ('i2i16', 'b'))))
 *    ('ilt', '#a', ('i2i64', 'b@16')) => ('iand', ('ilt', 'a', 32767), ('ior', ('ilt', 'a', -32768), ('ilt', ('i2i16', 'a'), 'b')))
 *    ('ige', ('i2i64', 'a@16'), '#b') => ('iand', ('ige', 32767, 'b'), ('ior', ('ige', -32768, 'b'), ('ige', 'a', ('i2i16', 'b'))))
 *    ('ige', '#a', ('i2i64', 'b@16')) => ('iand', ('ige', 'a', -32768), ('ior', ('ige', 'a', 32767), ('ige', ('i2i16', 'a'), 'b')))
 *    ('ieq', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ieq', 'a', ('i2i32', 'b'))
 *    ('ine', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ine', 'a', ('i2i32', 'b'))
 *    ('ige', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ige', 'a', ('i2i32', 'b'))
 *    ('ilt', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ilt', 'a', ('i2i32', 'b'))
 *    ('ige', ('i2i64', 'b@8'), ('i2i64', 'a@32')) => ('ige', ('i2i32', 'b'), 'a')
 *    ('ilt', ('i2i64', 'b@8'), ('i2i64', 'a@32')) => ('ilt', ('i2i32', 'b'), 'a')
 *    ('ieq', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ieq', 'a', ('i2i32', 'b'))
 *    ('ine', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ine', 'a', ('i2i32', 'b'))
 *    ('ige', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ige', 'a', ('i2i32', 'b'))
 *    ('ilt', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ilt', 'a', ('i2i32', 'b'))
 *    ('ige', ('i2i64', 'b@16'), ('i2i64', 'a@32')) => ('ige', ('i2i32', 'b'), 'a')
 *    ('ilt', ('i2i64', 'b@16'), ('i2i64', 'a@32')) => ('ilt', ('i2i32', 'b'), 'a')
 *    ('ieq', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ieq', 'a', ('i2i32', 'b'))
 *    ('ine', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ine', 'a', ('i2i32', 'b'))
 *    ('ige', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ige', 'a', ('i2i32', 'b'))
 *    ('ilt', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ilt', 'a', ('i2i32', 'b'))
 *    ('ige', ('i2i64', 'b@32'), ('i2i64', 'a@32')) => ('ige', ('i2i32', 'b'), 'a')
 *    ('ilt', ('i2i64', 'b@32'), ('i2i64', 'a@32')) => ('ilt', ('i2i32', 'b'), 'a')
 *    ('ieq', ('i2i64', 'a@32'), '#b') => ('iand', ('ieq', 'a', ('i2i32', 'b')), ('ieq', ('i2i64', ('i2i32', 'b')), 'b'))
 *    ('ine', ('i2i64', 'a@32'), '#b') => ('ior', ('ine', 'a', ('i2i32', 'b')), ('ine', ('i2i64', ('i2i32', 'b')), 'b'))
 *    ('ilt', ('i2i64', 'a@32'), '#b') => ('iand', ('ilt', -2147483648, 'b'), ('ior', ('ilt', 2147483647, 'b'), ('ilt', 'a', ('i2i32', 'b'))))
 *    ('ilt', '#a', ('i2i64', 'b@32')) => ('iand', ('ilt', 'a', 2147483647), ('ior', ('ilt', 'a', -2147483648), ('ilt', ('i2i32', 'a'), 'b')))
 *    ('ige', ('i2i64', 'a@32'), '#b') => ('iand', ('ige', 2147483647, 'b'), ('ior', ('ige', -2147483648, 'b'), ('ige', 'a', ('i2i32', 'b'))))
 *    ('ige', '#a', ('i2i64', 'b@32')) => ('iand', ('ige', 'a', -2147483648), ('ior', ('ige', 'a', 2147483647), ('ige', ('i2i32', 'a'), 'b')))
 *    ('ieq', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('ieq', 'a', ('u2u8', 'b'))
 *    ('ine', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('ine', 'a', ('u2u8', 'b'))
 *    ('uge', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('uge', 'a', ('u2u8', 'b'))
 *    ('ult', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('ult', 'a', ('u2u8', 'b'))
 *    ('uge', ('u2u16', 'b@8'), ('u2u16', 'a@8')) => ('uge', ('u2u8', 'b'), 'a')
 *    ('ult', ('u2u16', 'b@8'), ('u2u16', 'a@8')) => ('ult', ('u2u8', 'b'), 'a')
 *    ('ieq', ('u2u16', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('u2u8', 'b')), ('ieq', ('u2u16', ('u2u8', 'b')), 'b'))
 *    ('ine', ('u2u16', 'a@8'), '#b') => ('ior', ('ine', 'a', ('u2u8', 'b')), ('ine', ('u2u16', ('u2u8', 'b')), 'b'))
 *    ('ult', ('u2u16', 'a@8'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 255, 'b'), ('ult', 'a', ('u2u8', 'b'))))
 *    ('ult', '#a', ('u2u16', 'b@8')) => ('iand', ('ult', 'a', 255), ('ior', ('ult', 'a', 0), ('ult', ('u2u8', 'a'), 'b')))
 *    ('uge', ('u2u16', 'a@8'), '#b') => ('iand', ('uge', 255, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u8', 'b'))))
 *    ('uge', '#a', ('u2u16', 'b@8')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 255), ('uge', ('u2u8', 'a'), 'b')))
 *    ('ieq', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('ieq', 'a', ('u2u8', 'b'))
 *    ('ine', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('ine', 'a', ('u2u8', 'b'))
 *    ('uge', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('uge', 'a', ('u2u8', 'b'))
 *    ('ult', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('ult', 'a', ('u2u8', 'b'))
 *    ('uge', ('u2u32', 'b@8'), ('u2u32', 'a@8')) => ('uge', ('u2u8', 'b'), 'a')
 *    ('ult', ('u2u32', 'b@8'), ('u2u32', 'a@8')) => ('ult', ('u2u8', 'b'), 'a')
 *    ('ieq', ('u2u32', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('u2u8', 'b')), ('ieq', ('u2u32', ('u2u8', 'b')), 'b'))
 *    ('ine', ('u2u32', 'a@8'), '#b') => ('ior', ('ine', 'a', ('u2u8', 'b')), ('ine', ('u2u32', ('u2u8', 'b')), 'b'))
 *    ('ult', ('u2u32', 'a@8'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 255, 'b'), ('ult', 'a', ('u2u8', 'b'))))
 *    ('ult', '#a', ('u2u32', 'b@8')) => ('iand', ('ult', 'a', 255), ('ior', ('ult', 'a', 0), ('ult', ('u2u8', 'a'), 'b')))
 *    ('uge', ('u2u32', 'a@8'), '#b') => ('iand', ('uge', 255, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u8', 'b'))))
 *    ('uge', '#a', ('u2u32', 'b@8')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 255), ('uge', ('u2u8', 'a'), 'b')))
 *    ('ieq', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('ieq', 'a', ('u2u8', 'b'))
 *    ('ine', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('ine', 'a', ('u2u8', 'b'))
 *    ('uge', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('uge', 'a', ('u2u8', 'b'))
 *    ('ult', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('ult', 'a', ('u2u8', 'b'))
 *    ('uge', ('u2u64', 'b@8'), ('u2u64', 'a@8')) => ('uge', ('u2u8', 'b'), 'a')
 *    ('ult', ('u2u64', 'b@8'), ('u2u64', 'a@8')) => ('ult', ('u2u8', 'b'), 'a')
 *    ('ieq', ('u2u64', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('u2u8', 'b')), ('ieq', ('u2u64', ('u2u8', 'b')), 'b'))
 *    ('ine', ('u2u64', 'a@8'), '#b') => ('ior', ('ine', 'a', ('u2u8', 'b')), ('ine', ('u2u64', ('u2u8', 'b')), 'b'))
 *    ('ult', ('u2u64', 'a@8'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 255, 'b'), ('ult', 'a', ('u2u8', 'b'))))
 *    ('ult', '#a', ('u2u64', 'b@8')) => ('iand', ('ult', 'a', 255), ('ior', ('ult', 'a', 0), ('ult', ('u2u8', 'a'), 'b')))
 *    ('uge', ('u2u64', 'a@8'), '#b') => ('iand', ('uge', 255, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u8', 'b'))))
 *    ('uge', '#a', ('u2u64', 'b@8')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 255), ('uge', ('u2u8', 'a'), 'b')))
 *    ('ieq', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('ieq', 'a', ('u2u16', 'b'))
 *    ('ine', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('ine', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('uge', 'a', ('u2u16', 'b'))
 *    ('ult', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('ult', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u32', 'b@8'), ('u2u32', 'a@16')) => ('uge', ('u2u16', 'b'), 'a')
 *    ('ult', ('u2u32', 'b@8'), ('u2u32', 'a@16')) => ('ult', ('u2u16', 'b'), 'a')
 *    ('ieq', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('ieq', 'a', ('u2u16', 'b'))
 *    ('ine', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('ine', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('uge', 'a', ('u2u16', 'b'))
 *    ('ult', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('ult', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u32', 'b@16'), ('u2u32', 'a@16')) => ('uge', ('u2u16', 'b'), 'a')
 *    ('ult', ('u2u32', 'b@16'), ('u2u32', 'a@16')) => ('ult', ('u2u16', 'b'), 'a')
 *    ('ieq', ('u2u32', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('u2u16', 'b')), ('ieq', ('u2u32', ('u2u16', 'b')), 'b'))
 *    ('ine', ('u2u32', 'a@16'), '#b') => ('ior', ('ine', 'a', ('u2u16', 'b')), ('ine', ('u2u32', ('u2u16', 'b')), 'b'))
 *    ('ult', ('u2u32', 'a@16'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 65535, 'b'), ('ult', 'a', ('u2u16', 'b'))))
 *    ('ult', '#a', ('u2u32', 'b@16')) => ('iand', ('ult', 'a', 65535), ('ior', ('ult', 'a', 0), ('ult', ('u2u16', 'a'), 'b')))
 *    ('uge', ('u2u32', 'a@16'), '#b') => ('iand', ('uge', 65535, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u16', 'b'))))
 *    ('uge', '#a', ('u2u32', 'b@16')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 65535), ('uge', ('u2u16', 'a'), 'b')))
 *    ('ieq', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('ieq', 'a', ('u2u16', 'b'))
 *    ('ine', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('ine', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('uge', 'a', ('u2u16', 'b'))
 *    ('ult', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('ult', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u64', 'b@8'), ('u2u64', 'a@16')) => ('uge', ('u2u16', 'b'), 'a')
 *    ('ult', ('u2u64', 'b@8'), ('u2u64', 'a@16')) => ('ult', ('u2u16', 'b'), 'a')
 *    ('ieq', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('ieq', 'a', ('u2u16', 'b'))
 *    ('ine', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('ine', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('uge', 'a', ('u2u16', 'b'))
 *    ('ult', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('ult', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u64', 'b@16'), ('u2u64', 'a@16')) => ('uge', ('u2u16', 'b'), 'a')
 *    ('ult', ('u2u64', 'b@16'), ('u2u64', 'a@16')) => ('ult', ('u2u16', 'b'), 'a')
 *    ('ieq', ('u2u64', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('u2u16', 'b')), ('ieq', ('u2u64', ('u2u16', 'b')), 'b'))
 *    ('ine', ('u2u64', 'a@16'), '#b') => ('ior', ('ine', 'a', ('u2u16', 'b')), ('ine', ('u2u64', ('u2u16', 'b')), 'b'))
 *    ('ult', ('u2u64', 'a@16'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 65535, 'b'), ('ult', 'a', ('u2u16', 'b'))))
 *    ('ult', '#a', ('u2u64', 'b@16')) => ('iand', ('ult', 'a', 65535), ('ior', ('ult', 'a', 0), ('ult', ('u2u16', 'a'), 'b')))
 *    ('uge', ('u2u64', 'a@16'), '#b') => ('iand', ('uge', 65535, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u16', 'b'))))
 *    ('uge', '#a', ('u2u64', 'b@16')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 65535), ('uge', ('u2u16', 'a'), 'b')))
 *    ('ieq', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('ieq', 'a', ('u2u32', 'b'))
 *    ('ine', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('ine', 'a', ('u2u32', 'b'))
 *    ('uge', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('uge', 'a', ('u2u32', 'b'))
 *    ('ult', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('ult', 'a', ('u2u32', 'b'))
 *    ('uge', ('u2u64', 'b@8'), ('u2u64', 'a@32')) => ('uge', ('u2u32', 'b'), 'a')
 *    ('ult', ('u2u64', 'b@8'), ('u2u64', 'a@32')) => ('ult', ('u2u32', 'b'), 'a')
 *    ('ieq', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('ieq', 'a', ('u2u32', 'b'))
 *    ('ine', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('ine', 'a', ('u2u32', 'b'))
 *    ('uge', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('uge', 'a', ('u2u32', 'b'))
 *    ('ult', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('ult', 'a', ('u2u32', 'b'))
 *    ('uge', ('u2u64', 'b@16'), ('u2u64', 'a@32')) => ('uge', ('u2u32', 'b'), 'a')
 *    ('ult', ('u2u64', 'b@16'), ('u2u64', 'a@32')) => ('ult', ('u2u32', 'b'), 'a')
 *    ('ieq', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('ieq', 'a', ('u2u32', 'b'))
 *    ('ine', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('ine', 'a', ('u2u32', 'b'))
 *    ('uge', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('uge', 'a', ('u2u32', 'b'))
 *    ('ult', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('ult', 'a', ('u2u32', 'b'))
 *    ('uge', ('u2u64', 'b@32'), ('u2u64', 'a@32')) => ('uge', ('u2u32', 'b'), 'a')
 *    ('ult', ('u2u64', 'b@32'), ('u2u64', 'a@32')) => ('ult', ('u2u32', 'b'), 'a')
 *    ('ieq', ('u2u64', 'a@32'), '#b') => ('iand', ('ieq', 'a', ('u2u32', 'b')), ('ieq', ('u2u64', ('u2u32', 'b')), 'b'))
 *    ('ine', ('u2u64', 'a@32'), '#b') => ('ior', ('ine', 'a', ('u2u32', 'b')), ('ine', ('u2u64', ('u2u32', 'b')), 'b'))
 *    ('ult', ('u2u64', 'a@32'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 4294967295, 'b'), ('ult', 'a', ('u2u32', 'b'))))
 *    ('ult', '#a', ('u2u64', 'b@32')) => ('iand', ('ult', 'a', 4294967295), ('ior', ('ult', 'a', 0), ('ult', ('u2u32', 'a'), 'b')))
 *    ('uge', ('u2u64', 'a@32'), '#b') => ('iand', ('uge', 4294967295, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u32', 'b'))))
 *    ('uge', '#a', ('u2u64', 'b@32')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 4294967295), ('uge', ('u2u32', 'a'), 'b')))
 *    ('feq', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('feq', 'a', ('f2f16', 'b'))
 *    ('fne', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('fne', 'a', ('f2f16', 'b'))
 *    ('fge', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('fge', 'a', ('f2f16', 'b'))
 *    ('flt', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('flt', 'a', ('f2f16', 'b'))
 *    ('fge', ('f2f32', 'b@16'), ('f2f32', 'a@16')) => ('fge', ('f2f16', 'b'), 'a')
 *    ('flt', ('f2f32', 'b@16'), ('f2f32', 'a@16')) => ('flt', ('f2f16', 'b'), 'a')
 *    ('feq', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('feq', 'a', ('f2f16', 'b'))
 *    ('fne', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('fne', 'a', ('f2f16', 'b'))
 *    ('fge', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('fge', 'a', ('f2f16', 'b'))
 *    ('flt', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('flt', 'a', ('f2f16', 'b'))
 *    ('fge', ('f2f64', 'b@16'), ('f2f64', 'a@16')) => ('fge', ('f2f16', 'b'), 'a')
 *    ('flt', ('f2f64', 'b@16'), ('f2f64', 'a@16')) => ('flt', ('f2f16', 'b'), 'a')
 *    ('feq', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('feq', 'a', ('f2f32', 'b'))
 *    ('fne', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('fne', 'a', ('f2f32', 'b'))
 *    ('fge', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('fge', 'a', ('f2f32', 'b'))
 *    ('flt', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('flt', 'a', ('f2f32', 'b'))
 *    ('fge', ('f2f64', 'b@16'), ('f2f64', 'a@32')) => ('fge', ('f2f32', 'b'), 'a')
 *    ('flt', ('f2f64', 'b@16'), ('f2f64', 'a@32')) => ('flt', ('f2f32', 'b'), 'a')
 *    ('feq', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('feq', 'a', ('f2f32', 'b'))
 *    ('fne', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('fne', 'a', ('f2f32', 'b'))
 *    ('fge', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('fge', 'a', ('f2f32', 'b'))
 *    ('flt', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('flt', 'a', ('f2f32', 'b'))
 *    ('fge', ('f2f64', 'b@32'), ('f2f64', 'a@32')) => ('fge', ('f2f32', 'b'), 'a')
 *    ('flt', ('f2f64', 'b@32'), ('f2f64', 'a@32')) => ('flt', ('f2f32', 'b'), 'a')
 *    ('ldexp@16', 'x', 'exp') => ('fmul', ('fmul', 'x', ('i2i16', ('ishl', ('iadd', ('ishr', ('imin', ('imax', 'exp', -28), 30), 1), 15), 10))), ('i2i16', ('ishl', ('iadd', ('isub', ('imin', ('imax', 'exp', -28), 30), ('ishr', ('imin', ('imax', 'exp', -28), 30), 1)), 15), 10)))
 *    ('ldexp@32', 'x', 'exp') => ('fmul', ('fmul', 'x', ('ishl', ('iadd', ('ishr', ('imin', ('imax', 'exp', -252), 254), 1), 127), 23)), ('ishl', ('iadd', ('isub', ('imin', ('imax', 'exp', -252), 254), ('ishr', ('imin', ('imax', 'exp', -252), 254), 1)), 127), 23))
 *    ('ldexp@64', 'x', 'exp') => ('fmul', ('fmul', 'x', ('pack_64_2x32_split', 0, ('ishl', ('iadd', ('ishr', ('imin', ('imax', 'exp', -2044), 2046), 1), 1023), 20))), ('pack_64_2x32_split', 0, ('ishl', ('iadd', ('isub', ('imin', ('imax', 'exp', -2044), 2046), ('ishr', ('imin', ('imax', 'exp', -2044), 2046), 1)), 1023), 20)))
 *    ('ior(many-comm-expr)', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 858993459), 2), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 3435973836), 2)), 1431655765), 1), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 858993459), 2), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 3435973836), 2)), 2863311530), 1)) => ('bitfield_reverse', 'x')
 *    ('iand', ('feq', 'a', 'a'), ('flt', 'a', 'b')) => ('flt', 'a', 'b')
 *    ('iand', ('feq', 'a', 'a'), ('flt', 'b', 'a')) => ('flt', 'b', 'a')
 *    ('iand', ('feq', 'a', 'a'), ('fge', 'a', 'b')) => ('fge', 'a', 'b')
 *    ('iand', ('feq', 'a', 'a'), ('fge', 'b', 'a')) => ('fge', 'b', 'a')
 *    ('iand', ('feq', 'a', 'a'), ('feq', 'a', 'b')) => ('feq', 'a', 'b')
 *    ('iand', ('feq', 'a', 'a'), ('feq', 'b', 'a')) => ('feq', 'b', 'a')
 *    ('flt', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('flt', 'b', 'd'), ('flt', 'c', 'd'))
 *    ('flt', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('flt', 'd', 'b'), ('flt', 'd', 'c'))
 *    ('fge', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('fge', 'b', 'd'), ('fge', 'c', 'd'))
 *    ('fge', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('fge', 'd', 'b'), ('fge', 'd', 'c'))
 *    ('feq', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('feq', 'b', 'd'), ('feq', 'c', 'd'))
 *    ('feq', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('feq', 'd', 'b'), ('feq', 'd', 'c'))
 *    ('fne', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('fne', 'b', 'd'), ('fne', 'c', 'd'))
 *    ('fne', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('fne', 'd', 'b'), ('fne', 'd', 'c'))
 *    ('ilt', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ilt', 'b', 'd'), ('ilt', 'c', 'd'))
 *    ('ilt', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('ilt', 'd', 'b'), ('ilt', 'd', 'c'))
 *    ('ige', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ige', 'b', 'd'), ('ige', 'c', 'd'))
 *    ('ige', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('ige', 'd', 'b'), ('ige', 'd', 'c'))
 *    ('ieq', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ieq', 'b', 'd'), ('ieq', 'c', 'd'))
 *    ('ieq', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('ieq', 'd', 'b'), ('ieq', 'd', 'c'))
 *    ('ine', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ine', 'b', 'd'), ('ine', 'c', 'd'))
 *    ('ine', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('ine', 'd', 'b'), ('ine', 'd', 'c'))
 *    ('ult', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ult', 'b', 'd'), ('ult', 'c', 'd'))
 *    ('ult', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('ult', 'd', 'b'), ('ult', 'd', 'c'))
 *    ('uge', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('uge', 'b', 'd'), ('uge', 'c', 'd'))
 *    ('uge', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('uge', 'd', 'b'), ('uge', 'd', 'c'))
 *    ('fadd', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('fadd', 'b', 'd'), ('fadd', 'c', 'd'))
 *    ('fmul', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('fmul', 'b', 'd'), ('fmul', 'c', 'd'))
 *    ('iadd', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('iadd', 'b', 'd'), ('iadd', 'c', 'd'))
 *    ('imul', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('imul', 'b', 'd'), ('imul', 'c', 'd'))
 *    ('fddx', 'a') => 0.0
 *    ('fddx_fine', 'a') => 0.0
 *    ('fddx_coarse', 'a') => 0.0
 *    ('fddy', 'a') => 0.0
 *    ('fddy_fine', 'a') => 0.0
 *    ('fddy_coarse', 'a') => 0.0
 *    ('umul_low', '#a(is_lower_half_zero)', 'b') => 0
 *    ('imadsh_mix16', '#a@32(is_lower_half_zero)', 'b@32', 'c@32') => c
 *    ('imadsh_mix16', 'a@32', '#b@32(is_upper_half_zero)', 'c@32') => c
 */

#ifndef NIR_OPT_ALGEBRAIC_STRUCT_DEFS
#define NIR_OPT_ALGEBRAIC_STRUCT_DEFS

struct transform {
   const nir_search_expression *search;
   const nir_search_value *replace;
   unsigned condition_offset;
};

struct per_op_table {
   const uint16_t *filter;
   unsigned num_filtered_states;
   const uint16_t *table;
};

/* Note: these must match the start states created in
 * TreeAutomaton._build_table()
 */

/* WILDCARD_STATE = 0 is set by zeroing the state array */
static const uint16_t CONST_STATE = 1;

#endif


   static const nir_search_variable search0_0 = {
   { nir_search_value_variable, 32 },
   0, /* a */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

static const nir_search_variable search0_1 = {
   { nir_search_value_variable, 32 },
   1, /* b */
   true,
   nir_type_invalid,
   (is_pos_power_of_two),
   {0, 1, 2, 3},
};
static const nir_search_expression search0 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_imul,
   { &search0_0.value, &search0_1.value },
   NULL,
};

   /* replace0_0 -> search0_0 in the cache */

static const nir_search_variable replace0_1_0 = {
   { nir_search_value_variable, 32 },
   1, /* b */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression replace0_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_find_lsb,
   { &replace0_1_0.value },
   NULL,
};
static const nir_search_expression replace0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_ishl,
   { &search0_0.value, &replace0_1.value },
   NULL,
};

   /* search1_0 -> search0_0 in the cache */

static const nir_search_variable search1_1 = {
   { nir_search_value_variable, 32 },
   1, /* b */
   true,
   nir_type_invalid,
   (is_neg_power_of_two),
   {0, 1, 2, 3},
};
static const nir_search_expression search1 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_imul,
   { &search0_0.value, &search1_1.value },
   NULL,
};

   /* replace1_0_0 -> search0_0 in the cache */

/* replace1_0_1_0_0 -> replace0_1_0 in the cache */
static const nir_search_expression replace1_0_1_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_iabs,
   { &replace0_1_0.value },
   NULL,
};
static const nir_search_expression replace1_0_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_find_lsb,
   { &replace1_0_1_0.value },
   NULL,
};
static const nir_search_expression replace1_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_ishl,
   { &search0_0.value, &replace1_0_1.value },
   NULL,
};
static const nir_search_expression replace1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_ineg,
   { &replace1_0.value },
   NULL,
};

   static const nir_search_variable search2_0 = {
   { nir_search_value_variable, -1 },
   0, /* a */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

static const nir_search_variable search2_1 = {
   { nir_search_value_variable, 32 },
   1, /* b */
   true,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search2 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_ishl,
   { &search2_0.value, &search2_1.value },
   NULL,
};

   /* replace2_0 -> search2_0 in the cache */

static const nir_search_constant replace2_1_0 = {
   { nir_search_value_constant, -1 },
   nir_type_int, { 0x1 /* 1 */ },
};

/* replace2_1_1 -> replace0_1_0 in the cache */
static const nir_search_expression replace2_1 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_ishl,
   { &replace2_1_0.value, &replace0_1_0.value },
   NULL,
};
static const nir_search_expression replace2 = {
   { nir_search_value_expression, -1 },
   false,
   0, 1,
   nir_op_imul,
   { &search2_0.value, &replace2_1.value },
   NULL,
};

   /* search3_0_0 -> search0_0 in the cache */

/* search3_0_1 -> replace0_1_0 in the cache */
static const nir_search_expression search3_0 = {
   { nir_search_value_expression, 64 },
   false,
   0, 1,
   nir_op_imul_2x32_64,
   { &search0_0.value, &replace0_1_0.value },
   (is_used_once),
};
static const nir_search_expression search3 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_op_unpack_64_2x32_split_x,
   { &search3_0.value },
   NULL,
};

   /* replace3_0 -> search0_0 in the cache */

/* replace3_1 -> replace0_1_0 in the cache */
static const nir_search_expression replace3 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_imul,
   { &search0_0.value, &replace0_1_0.value },
   NULL,
};

   /* search4_0_0 -> search0_0 in the cache */

/* search4_0_1 -> replace0_1_0 in the cache */
static const nir_search_expression search4_0 = {
   { nir_search_value_expression, 64 },
   false,
   0, 1,
   nir_op_umul_2x32_64,
   { &search0_0.value, &replace0_1_0.value },
   (is_used_once),
};
static const nir_search_expression search4 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_op_unpack_64_2x32_split_x,
   { &search4_0.value },
   NULL,
};

   /* replace4_0 -> search0_0 in the cache */

/* replace4_1 -> replace0_1_0 in the cache */
/* replace4 -> replace3 in the cache */

   /* search5_0 -> search0_0 in the cache */

/* search5_1 -> replace0_1_0 in the cache */
static const nir_search_expression search5 = {
   { nir_search_value_expression, 64 },
   false,
   0, 1,
   nir_op_imul_2x32_64,
   { &search0_0.value, &replace0_1_0.value },
   NULL,
};

   /* replace5_0_0 -> search0_0 in the cache */

/* replace5_0_1 -> replace0_1_0 in the cache */
/* replace5_0 -> replace3 in the cache */

/* replace5_1_0 -> search0_0 in the cache */

/* replace5_1_1 -> replace0_1_0 in the cache */
static const nir_search_expression replace5_1 = {
   { nir_search_value_expression, 32 },
   false,
   1, 1,
   nir_op_imul_high,
   { &search0_0.value, &replace0_1_0.value },
   NULL,
};
static const nir_search_expression replace5 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 2,
   nir_op_pack_64_2x32_split,
   { &replace3.value, &replace5_1.value },
   NULL,
};

   /* search6_0 -> search0_0 in the cache */

/* search6_1 -> replace0_1_0 in the cache */
static const nir_search_expression search6 = {
   { nir_search_value_expression, 64 },
   false,
   0, 1,
   nir_op_umul_2x32_64,
   { &search0_0.value, &replace0_1_0.value },
   NULL,
};

   /* replace6_0_0 -> search0_0 in the cache */

/* replace6_0_1 -> replace0_1_0 in the cache */
/* replace6_0 -> replace3 in the cache */

/* replace6_1_0 -> search0_0 in the cache */

/* replace6_1_1 -> replace0_1_0 in the cache */
static const nir_search_expression replace6_1 = {
   { nir_search_value_expression, 32 },
   false,
   1, 1,
   nir_op_umul_high,
   { &search0_0.value, &replace0_1_0.value },
   NULL,
};
static const nir_search_expression replace6 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 2,
   nir_op_pack_64_2x32_split,
   { &replace3.value, &replace6_1.value },
   NULL,
};

   /* search7_0 -> search2_0 in the cache */

/* search7_1 -> replace2_1_0 in the cache */
static const nir_search_expression search7 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_udiv,
   { &search2_0.value, &replace2_1_0.value },
   NULL,
};

   /* replace7 -> search2_0 in the cache */

   /* search8_0 -> search2_0 in the cache */

/* search8_1 -> replace2_1_0 in the cache */
static const nir_search_expression search8 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_idiv,
   { &search2_0.value, &replace2_1_0.value },
   NULL,
};

   /* replace8 -> search2_0 in the cache */

   /* search9_0 -> search2_0 in the cache */

/* search9_1 -> replace2_1_0 in the cache */
static const nir_search_expression search9 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_umod,
   { &search2_0.value, &replace2_1_0.value },
   NULL,
};

   static const nir_search_constant replace9 = {
   { nir_search_value_constant, -1 },
   nir_type_int, { 0x0 /* 0 */ },
};

   /* search10_0 -> search2_0 in the cache */

/* search10_1 -> replace2_1_0 in the cache */
static const nir_search_expression search10 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_imod,
   { &search2_0.value, &replace2_1_0.value },
   NULL,
};

   /* replace10 -> replace9 in the cache */

   /* search11_0 -> search0_0 in the cache */

/* search11_1 -> search0_1 in the cache */
static const nir_search_expression search11 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_udiv,
   { &search0_0.value, &search0_1.value },
   NULL,
};

   /* replace11_0 -> search0_0 in the cache */

/* replace11_1_0 -> replace0_1_0 in the cache */
/* replace11_1 -> replace0_1 in the cache */
static const nir_search_expression replace11 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_ushr,
   { &search0_0.value, &replace0_1.value },
   NULL,
};

   /* search12_0 -> search0_0 in the cache */

/* search12_1 -> search0_1 in the cache */
static const nir_search_expression search12 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_idiv,
   { &search0_0.value, &search0_1.value },
   NULL,
};

   /* replace12_0_0 -> search0_0 in the cache */
static const nir_search_expression replace12_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_isign,
   { &search0_0.value },
   NULL,
};

/* replace12_1_0_0 -> search0_0 in the cache */
static const nir_search_expression replace12_1_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_iabs,
   { &search0_0.value },
   NULL,
};

/* replace12_1_1_0 -> replace0_1_0 in the cache */
/* replace12_1_1 -> replace0_1 in the cache */
static const nir_search_expression replace12_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_ushr,
   { &replace12_1_0.value, &replace0_1.value },
   NULL,
};
static const nir_search_expression replace12 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_imul,
   { &replace12_0.value, &replace12_1.value },
   NULL,
};

   /* search13_0 -> search0_0 in the cache */

/* search13_1 -> search1_1 in the cache */
static const nir_search_expression search13 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_idiv,
   { &search0_0.value, &search1_1.value },
   NULL,
};

   /* replace13_0_0_0 -> search0_0 in the cache */
/* replace13_0_0 -> replace12_0 in the cache */

/* replace13_0_1_0_0 -> search0_0 in the cache */
/* replace13_0_1_0 -> replace12_1_0 in the cache */

/* replace13_0_1_1_0_0 -> replace0_1_0 in the cache */
/* replace13_0_1_1_0 -> replace1_0_1_0 in the cache */
/* replace13_0_1_1 -> replace1_0_1 in the cache */
static const nir_search_expression replace13_0_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_ushr,
   { &replace12_1_0.value, &replace1_0_1.value },
   NULL,
};
static const nir_search_expression replace13_0 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_imul,
   { &replace12_0.value, &replace13_0_1.value },
   NULL,
};
static const nir_search_expression replace13 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_op_ineg,
   { &replace13_0.value },
   NULL,
};

   static const nir_search_variable search14_0 = {
   { nir_search_value_variable, -2 },
   0, /* a */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

static const nir_search_variable search14_1 = {
   { nir_search_value_variable, -2 },
   1, /* b */
   true,
   nir_type_invalid,
   (is_pos_power_of_two),
   {0, 1, 2, 3},
};
static const nir_search_expression search14 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_umod,
   { &search14_0.value, &search14_1.value },
   NULL,
};

   /* replace14_0 -> search14_0 in the cache */

static const nir_search_variable replace14_1_0 = {
   { nir_search_value_variable, -2 },
   1, /* b */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

static const nir_search_constant replace14_1_1 = {
   { nir_search_value_constant, -2 },
   nir_type_int, { 0x1 /* 1 */ },
};
static const nir_search_expression replace14_1 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_isub,
   { &replace14_1_0.value, &replace14_1_1.value },
   NULL,
};
static const nir_search_expression replace14 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_iand,
   { &search14_0.value, &replace14_1.value },
   NULL,
};

   /* search15_0_0 -> search2_0 in the cache */
static const nir_search_expression search15_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fneg,
   { &search2_0.value },
   NULL,
};
static const nir_search_expression search15 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fneg,
   { &search15_0.value },
   NULL,
};

   /* replace15 -> search2_0 in the cache */

   /* search16_0_0 -> search2_0 in the cache */
static const nir_search_expression search16_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_ineg,
   { &search2_0.value },
   NULL,
};
static const nir_search_expression search16 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_ineg,
   { &search16_0.value },
   NULL,
};

   /* replace16 -> search2_0 in the cache */

   /* search17_0_0 -> search2_0 in the cache */
static const nir_search_expression search17_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fabs,
   { &search2_0.value },
   NULL,
};
static const nir_search_expression search17 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fabs,
   { &search17_0.value },
   NULL,
};

   /* replace17_0 -> search2_0 in the cache */
/* replace17 -> search17_0 in the cache */

   /* search18_0_0 -> search2_0 in the cache */
/* search18_0 -> search15_0 in the cache */
static const nir_search_expression search18 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fabs,
   { &search15_0.value },
   NULL,
};

   /* replace18_0 -> search2_0 in the cache */
/* replace18 -> search17_0 in the cache */

   /* search19_0_0 -> search2_0 in the cache */
static const nir_search_expression search19_0 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_search_op_u2f,
   { &search2_0.value },
   NULL,
};
static const nir_search_expression search19 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_op_fabs,
   { &search19_0.value },
   NULL,
};

   /* replace19_0 -> search2_0 in the cache */
/* replace19 -> search19_0 in the cache */

   /* search20_0_0 -> search2_0 in the cache */
static const nir_search_expression search20_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_iabs,
   { &search2_0.value },
   NULL,
};
static const nir_search_expression search20 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_iabs,
   { &search20_0.value },
   NULL,
};

   /* replace20_0 -> search2_0 in the cache */
/* replace20 -> search20_0 in the cache */

   /* search21_0_0 -> search2_0 in the cache */
/* search21_0 -> search16_0 in the cache */
static const nir_search_expression search21 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_iabs,
   { &search16_0.value },
   NULL,
};

   /* replace21_0 -> search2_0 in the cache */
/* replace21 -> search20_0 in the cache */

   /* search22_0_0 -> search2_0 in the cache */
/* search22_0 -> search15_0 in the cache */
static const nir_search_expression search22 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_search_op_f2b,
   { &search15_0.value },
   NULL,
};

   /* replace22_0 -> search2_0 in the cache */
static const nir_search_expression replace22 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_search_op_f2b,
   { &search2_0.value },
   NULL,
};

   /* search23_0_0 -> search2_0 in the cache */
/* search23_0 -> search16_0 in the cache */
static const nir_search_expression search23 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_search_op_i2b,
   { &search16_0.value },
   NULL,
};

   /* replace23_0 -> search2_0 in the cache */
static const nir_search_expression replace23 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_search_op_i2b,
   { &search2_0.value },
   NULL,
};

   /* search24_0 -> search2_0 in the cache */

static const nir_search_constant search24_1 = {
   { nir_search_value_constant, -1 },
   nir_type_float, { 0x0 /* 0.0 */ },
};
static const nir_search_expression search24 = {
   { nir_search_value_expression, -1 },
   true,
   0, 1,
   nir_op_fadd,
   { &search2_0.value, &search24_1.value },
   NULL,
};

   /* replace24 -> search2_0 in the cache */

   /* search25_0 -> search2_0 in the cache */

/* search25_1 -> replace9 in the cache */
static const nir_search_expression search25 = {
   { nir_search_value_expression, -1 },
   false,
   0, 1,
   nir_op_iadd,
   { &search2_0.value, &replace9.value },
   NULL,
};

   /* replace25 -> search2_0 in the cache */

   /* search26_0 -> search0_0 in the cache */

static const nir_search_constant search26_1 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { 0x0 /* 0 */ },
};
static const nir_search_expression search26 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_usadd_4x8,
   { &search0_0.value, &search26_1.value },
   NULL,
};

   /* replace26 -> search0_0 in the cache */

   /* search27_0 -> search0_0 in the cache */

static const nir_search_constant search27_1 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { -0x1 /* -1 */ },
};
static const nir_search_expression search27 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_usadd_4x8,
   { &search0_0.value, &search27_1.value },
   NULL,
};

   /* replace27 -> search27_1 in the cache */

   static const nir_search_variable search28_0_0 = {
   { nir_search_value_variable, -3 },
   0, /* a */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

static const nir_search_variable search28_0_1 = {
   { nir_search_value_variable, -3 },
   1, /* b */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search28_0 = {
   { nir_search_value_expression, -3 },
   false,
   1, 1,
   nir_op_fmul,
   { &search28_0_0.value, &search28_0_1.value },
   NULL,
};

/* search28_1_0 -> search28_0_0 in the cache */

static const nir_search_variable search28_1_1 = {
   { nir_search_value_variable, -3 },
   2, /* c */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search28_1 = {
   { nir_search_value_expression, -3 },
   false,
   2, 1,
   nir_op_fmul,
   { &search28_0_0.value, &search28_1_1.value },
   NULL,
};
static const nir_search_expression search28 = {
   { nir_search_value_expression, -3 },
   true,
   0, 3,
   nir_op_fadd,
   { &search28_0.value, &search28_1.value },
   NULL,
};

   /* replace28_0 -> search28_0_0 in the cache */

/* replace28_1_0 -> search28_0_1 in the cache */

/* replace28_1_1 -> search28_1_1 in the cache */
static const nir_search_expression replace28_1 = {
   { nir_search_value_expression, -3 },
   false,
   1, 1,
   nir_op_fadd,
   { &search28_0_1.value, &search28_1_1.value },
   NULL,
};
static const nir_search_expression replace28 = {
   { nir_search_value_expression, -3 },
   false,
   0, 2,
   nir_op_fmul,
   { &search28_0_0.value, &replace28_1.value },
   NULL,
};

   /* search29_0_0 -> search28_0_0 in the cache */

/* search29_0_1 -> search28_0_1 in the cache */
static const nir_search_expression search29_0 = {
   { nir_search_value_expression, -3 },
   false,
   1, 1,
   nir_op_imul,
   { &search28_0_0.value, &search28_0_1.value },
   NULL,
};

/* search29_1_0 -> search28_0_0 in the cache */

/* search29_1_1 -> search28_1_1 in the cache */
static const nir_search_expression search29_1 = {
   { nir_search_value_expression, -3 },
   false,
   2, 1,
   nir_op_imul,
   { &search28_0_0.value, &search28_1_1.value },
   NULL,
};
static const nir_search_expression search29 = {
   { nir_search_value_expression, -3 },
   false,
   0, 3,
   nir_op_iadd,
   { &search29_0.value, &search29_1.value },
   NULL,
};

   /* replace29_0 -> search28_0_0 in the cache */

/* replace29_1_0 -> search28_0_1 in the cache */

/* replace29_1_1 -> search28_1_1 in the cache */
static const nir_search_expression replace29_1 = {
   { nir_search_value_expression, -3 },
   false,
   1, 1,
   nir_op_iadd,
   { &search28_0_1.value, &search28_1_1.value },
   NULL,
};
static const nir_search_expression replace29 = {
   { nir_search_value_expression, -3 },
   false,
   0, 2,
   nir_op_imul,
   { &search28_0_0.value, &replace29_1.value },
   NULL,
};

   /* search30_0_0 -> search2_0 in the cache */
/* search30_0 -> search15_0 in the cache */

/* search30_1 -> search2_0 in the cache */
static const nir_search_expression search30 = {
   { nir_search_value_expression, -1 },
   true,
   0, 1,
   nir_op_fadd,
   { &search15_0.value, &search2_0.value },
   NULL,
};

   /* replace30 -> search24_1 in the cache */

   /* search31_0_0 -> search2_0 in the cache */
/* search31_0 -> search16_0 in the cache */

/* search31_1 -> search2_0 in the cache */
static const nir_search_expression search31 = {
   { nir_search_value_expression, -1 },
   false,
   0, 1,
   nir_op_iadd,
   { &search16_0.value, &search2_0.value },
   NULL,
};

   /* replace31 -> replace9 in the cache */

   /* search32_0_0 -> search14_0 in the cache */
static const nir_search_expression search32_0 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_ineg,
   { &search14_0.value },
   NULL,
};

/* search32_1_0 -> search14_0 in the cache */

/* search32_1_1 -> replace14_1_0 in the cache */
static const nir_search_expression search32_1 = {
   { nir_search_value_expression, -2 },
   false,
   1, 1,
   nir_op_iadd,
   { &search14_0.value, &replace14_1_0.value },
   NULL,
};
static const nir_search_expression search32 = {
   { nir_search_value_expression, -2 },
   false,
   0, 2,
   nir_op_iadd,
   { &search32_0.value, &search32_1.value },
   NULL,
};

   /* replace32 -> replace14_1_0 in the cache */

   /* search33_0 -> search14_0 in the cache */

/* search33_1_0_0 -> search14_0 in the cache */
/* search33_1_0 -> search32_0 in the cache */

/* search33_1_1 -> replace14_1_0 in the cache */
static const nir_search_expression search33_1 = {
   { nir_search_value_expression, -2 },
   false,
   1, 1,
   nir_op_iadd,
   { &search32_0.value, &replace14_1_0.value },
   NULL,
};
static const nir_search_expression search33 = {
   { nir_search_value_expression, -2 },
   false,
   0, 2,
   nir_op_iadd,
   { &search14_0.value, &search33_1.value },
   NULL,
};

   /* replace33 -> replace14_1_0 in the cache */

   /* search34_0_0 -> search14_0 in the cache */
static const nir_search_expression search34_0 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_fneg,
   { &search14_0.value },
   NULL,
};

/* search34_1_0 -> search14_0 in the cache */

/* search34_1_1 -> replace14_1_0 in the cache */
static const nir_search_expression search34_1 = {
   { nir_search_value_expression, -2 },
   false,
   1, 1,
   nir_op_fadd,
   { &search14_0.value, &replace14_1_0.value },
   NULL,
};
static const nir_search_expression search34 = {
   { nir_search_value_expression, -2 },
   true,
   0, 2,
   nir_op_fadd,
   { &search34_0.value, &search34_1.value },
   NULL,
};

   /* replace34 -> replace14_1_0 in the cache */

   /* search35_0 -> search14_0 in the cache */

/* search35_1_0_0 -> search14_0 in the cache */
/* search35_1_0 -> search34_0 in the cache */

/* search35_1_1 -> replace14_1_0 in the cache */
static const nir_search_expression search35_1 = {
   { nir_search_value_expression, -2 },
   false,
   1, 1,
   nir_op_fadd,
   { &search34_0.value, &replace14_1_0.value },
   NULL,
};
static const nir_search_expression search35 = {
   { nir_search_value_expression, -2 },
   true,
   0, 2,
   nir_op_fadd,
   { &search14_0.value, &search35_1.value },
   NULL,
};

   /* replace35 -> replace14_1_0 in the cache */

   /* search36_0_0 -> search2_0 in the cache */
static const nir_search_expression search36_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fsat,
   { &search2_0.value },
   NULL,
};

/* search36_1_0_0 -> search2_0 in the cache */
/* search36_1_0 -> search15_0 in the cache */
static const nir_search_expression search36_1 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fsat,
   { &search15_0.value },
   NULL,
};
static const nir_search_expression search36 = {
   { nir_search_value_expression, -1 },
   false,
   0, 1,
   nir_op_fadd,
   { &search36_0.value, &search36_1.value },
   NULL,
};

   /* replace36_0_0 -> search2_0 in the cache */
/* replace36_0 -> search17_0 in the cache */
static const nir_search_expression replace36 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fsat,
   { &search17_0.value },
   NULL,
};

   /* search37_0 -> search2_0 in the cache */

/* search37_1 -> search24_1 in the cache */
static const nir_search_expression search37 = {
   { nir_search_value_expression, -1 },
   true,
   0, 1,
   nir_op_fmul,
   { &search2_0.value, &search24_1.value },
   NULL,
};

   /* replace37 -> search24_1 in the cache */

   /* search38_0 -> search2_0 in the cache */

/* search38_1 -> replace9 in the cache */
static const nir_search_expression search38 = {
   { nir_search_value_expression, -1 },
   false,
   0, 1,
   nir_op_imul,
   { &search2_0.value, &replace9.value },
   NULL,
};

   /* replace38 -> replace9 in the cache */

   /* search39_0 -> search0_0 in the cache */

/* search39_1 -> search26_1 in the cache */
static const nir_search_expression search39 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_umul_unorm_4x8,
   { &search0_0.value, &search26_1.value },
   NULL,
};

   /* replace39 -> search26_1 in the cache */

   /* search40_0 -> search0_0 in the cache */

/* search40_1 -> search27_1 in the cache */
static const nir_search_expression search40 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_umul_unorm_4x8,
   { &search0_0.value, &search27_1.value },
   NULL,
};

   /* replace40 -> search0_0 in the cache */

   /* search41_0 -> search2_0 in the cache */

static const nir_search_constant search41_1 = {
   { nir_search_value_constant, -1 },
   nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
};
static const nir_search_expression search41 = {
   { nir_search_value_expression, -1 },
   false,
   0, 1,
   nir_op_fmul,
   { &search2_0.value, &search41_1.value },
   NULL,
};

   /* replace41 -> search2_0 in the cache */

   /* search42_0 -> search2_0 in the cache */

/* search42_1 -> replace2_1_0 in the cache */
static const nir_search_expression search42 = {
   { nir_search_value_expression, -1 },
   false,
   0, 1,
   nir_op_imul,
   { &search2_0.value, &replace2_1_0.value },
   NULL,
};

   /* replace42 -> search2_0 in the cache */

   /* search43_0 -> search2_0 in the cache */

static const nir_search_constant search43_1 = {
   { nir_search_value_constant, -1 },
   nir_type_float, { 0xbff0000000000000L /* -1.0 */ },
};
static const nir_search_expression search43 = {
   { nir_search_value_expression, -1 },
   false,
   0, 1,
   nir_op_fmul,
   { &search2_0.value, &search43_1.value },
   NULL,
};

   /* replace43_0 -> search2_0 in the cache */
/* replace43 -> search15_0 in the cache */

   /* search44_0 -> search2_0 in the cache */

static const nir_search_constant search44_1 = {
   { nir_search_value_constant, -1 },
   nir_type_int, { -0x1 /* -1 */ },
};
static const nir_search_expression search44 = {
   { nir_search_value_expression, -1 },
   false,
   0, 1,
   nir_op_imul,
   { &search2_0.value, &search44_1.value },
   NULL,
};

   /* replace44_0 -> search2_0 in the cache */
/* replace44 -> search16_0 in the cache */

   /* search45_0_0 -> search2_0 in the cache */
static const nir_search_expression search45_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fsign,
   { &search2_0.value },
   NULL,
};

/* search45_1_0 -> search2_0 in the cache */

/* search45_1_1 -> search2_0 in the cache */
static const nir_search_expression search45_1 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fmul,
   { &search2_0.value, &search2_0.value },
   NULL,
};
static const nir_search_expression search45 = {
   { nir_search_value_expression, -1 },
   false,
   0, 1,
   nir_op_fmul,
   { &search45_0.value, &search45_1.value },
   NULL,
};

   /* replace45_0_0 -> search2_0 in the cache */
/* replace45_0 -> search17_0 in the cache */

/* replace45_1 -> search2_0 in the cache */
static const nir_search_expression replace45 = {
   { nir_search_value_expression, -1 },
   false,
   0, 1,
   nir_op_fmul,
   { &search17_0.value, &search2_0.value },
   NULL,
};

   /* search46_0_0_0 -> search2_0 in the cache */
/* search46_0_0 -> search45_0 in the cache */

/* search46_0_1 -> search2_0 in the cache */
static const nir_search_expression search46_0 = {
   { nir_search_value_expression, -1 },
   false,
   1, 1,
   nir_op_fmul,
   { &search45_0.value, &search2_0.value },
   NULL,
};

/* search46_1 -> search2_0 in the cache */
static const nir_search_expression search46 = {
   { nir_search_value_expression, -1 },
   false,
   0, 2,
   nir_op_fmul,
   { &search46_0.value, &search2_0.value },
   NULL,
};

   /* replace46_0_0 -> search2_0 in the cache */
/* replace46_0 -> search17_0 in the cache */

/* replace46_1 -> search2_0 in the cache */
/* replace46 -> replace45 in the cache */

   static const nir_search_constant search47_0 = {
   { nir_search_value_constant, -2 },
   nir_type_float, { 0x0 /* 0.0 */ },
};

/* search47_1 -> search14_0 in the cache */

/* search47_2 -> replace14_1_0 in the cache */
static const nir_search_expression search47 = {
   { nir_search_value_expression, -2 },
   true,
   0, 1,
   nir_op_ffma,
   { &search47_0.value, &search14_0.value, &replace14_1_0.value },
   NULL,
};

   /* replace47 -> replace14_1_0 in the cache */

   /* search48_0 -> search14_0 in the cache */

/* search48_1 -> replace14_1_0 in the cache */

/* search48_2 -> search47_0 in the cache */
static const nir_search_expression search48 = {
   { nir_search_value_expression, -2 },
   true,
   0, 1,
   nir_op_ffma,
   { &search14_0.value, &replace14_1_0.value, &search47_0.value },
   NULL,
};

   /* replace48_0 -> search14_0 in the cache */

/* replace48_1 -> replace14_1_0 in the cache */
static const nir_search_expression replace48 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_fmul,
   { &search14_0.value, &replace14_1_0.value },
   NULL,
};

   static const nir_search_constant search49_0 = {
   { nir_search_value_constant, -2 },
   nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
};

/* search49_1 -> search14_0 in the cache */

/* search49_2 -> replace14_1_0 in the cache */
static const nir_search_expression search49 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_ffma,
   { &search49_0.value, &search14_0.value, &replace14_1_0.value },
   NULL,
};

   /* replace49_0 -> search14_0 in the cache */

/* replace49_1 -> replace14_1_0 in the cache */
static const nir_search_expression replace49 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_fadd,
   { &search14_0.value, &replace14_1_0.value },
   NULL,
};

   static const nir_search_constant search50_0 = {
   { nir_search_value_constant, -2 },
   nir_type_float, { 0xbff0000000000000L /* -1.0 */ },
};

/* search50_1 -> search14_0 in the cache */

/* search50_2 -> replace14_1_0 in the cache */
static const nir_search_expression search50 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_ffma,
   { &search50_0.value, &search14_0.value, &replace14_1_0.value },
   NULL,
};

   /* replace50_0_0 -> search14_0 in the cache */
/* replace50_0 -> search34_0 in the cache */

/* replace50_1 -> replace14_1_0 in the cache */
static const nir_search_expression replace50 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_fadd,
   { &search34_0.value, &replace14_1_0.value },
   NULL,
};

   /* search51_0 -> search14_0 in the cache */

/* search51_1 -> replace14_1_0 in the cache */

/* search51_2 -> search47_0 in the cache */
static const nir_search_expression search51 = {
   { nir_search_value_expression, -2 },
   true,
   -1, 0,
   nir_op_flrp,
   { &search14_0.value, &replace14_1_0.value, &search47_0.value },
   NULL,
};

   /* replace51 -> search14_0 in the cache */

   /* search52_0 -> search14_0 in the cache */

/* search52_1 -> replace14_1_0 in the cache */

/* search52_2 -> search49_0 in the cache */
static const nir_search_expression search52 = {
   { nir_search_value_expression, -2 },
   true,
   -1, 0,
   nir_op_flrp,
   { &search14_0.value, &replace14_1_0.value, &search49_0.value },
   NULL,
};

   /* replace52 -> replace14_1_0 in the cache */

   /* search53_0 -> search14_0 in the cache */

/* search53_1 -> search14_0 in the cache */

/* search53_2 -> replace14_1_0 in the cache */
static const nir_search_expression search53 = {
   { nir_search_value_expression, -2 },
   true,
   -1, 0,
   nir_op_flrp,
   { &search14_0.value, &search14_0.value, &replace14_1_0.value },
   NULL,
};

   /* replace53 -> search14_0 in the cache */

   /* search54_0 -> search47_0 in the cache */

/* search54_1 -> search14_0 in the cache */

/* search54_2 -> replace14_1_0 in the cache */
static const nir_search_expression search54 = {
   { nir_search_value_expression, -2 },
   true,
   -1, 0,
   nir_op_flrp,
   { &search47_0.value, &search14_0.value, &replace14_1_0.value },
   NULL,
};

   /* replace54_0 -> search14_0 in the cache */

/* replace54_1 -> replace14_1_0 in the cache */
/* replace54 -> replace48 in the cache */

   /* search55_0 -> search28_0_0 in the cache */

/* search55_1_0 -> search28_0_0 in the cache */

/* search55_1_1 -> search28_0_1 in the cache */
static const nir_search_expression search55_1 = {
   { nir_search_value_expression, -3 },
   false,
   0, 1,
   nir_op_fadd,
   { &search28_0_0.value, &search28_0_1.value },
   (is_used_once),
};

/* search55_2 -> search28_1_1 in the cache */
static const nir_search_expression search55 = {
   { nir_search_value_expression, -3 },
   true,
   -1, 1,
   nir_op_flrp,
   { &search28_0_0.value, &search55_1.value, &search28_1_1.value },
   NULL,
};

   /* replace55_0_0 -> search28_0_1 in the cache */

/* replace55_0_1 -> search28_1_1 in the cache */
static const nir_search_expression replace55_0 = {
   { nir_search_value_expression, -3 },
   false,
   1, 1,
   nir_op_fmul,
   { &search28_0_1.value, &search28_1_1.value },
   NULL,
};

/* replace55_1 -> search28_0_0 in the cache */
static const nir_search_expression replace55 = {
   { nir_search_value_expression, -3 },
   false,
   0, 2,
   nir_op_fadd,
   { &replace55_0.value, &search28_0_0.value },
   NULL,
};

   /* search56_0 -> search0_0 in the cache */

/* search56_1_0 -> search0_0 in the cache */

/* search56_1_1 -> replace0_1_0 in the cache */
static const nir_search_expression search56_1 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_fadd,
   { &search0_0.value, &replace0_1_0.value },
   NULL,
};

static const nir_search_variable search56_2 = {
   { nir_search_value_variable, 32 },
   2, /* c */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search56 = {
   { nir_search_value_expression, 32 },
   true,
   -1, 1,
   nir_op_flrp,
   { &search0_0.value, &search56_1.value, &search56_2.value },
   NULL,
};

   /* replace56_0_0 -> replace0_1_0 in the cache */

/* replace56_0_1 -> search56_2 in the cache */
static const nir_search_expression replace56_0 = {
   { nir_search_value_expression, 32 },
   false,
   1, 1,
   nir_op_fmul,
   { &replace0_1_0.value, &search56_2.value },
   NULL,
};

/* replace56_1 -> search0_0 in the cache */
static const nir_search_expression replace56 = {
   { nir_search_value_expression, 32 },
   false,
   0, 2,
   nir_op_fadd,
   { &replace56_0.value, &search0_0.value },
   NULL,
};

   static const nir_search_variable search57_0 = {
   { nir_search_value_variable, 64 },
   0, /* a */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

/* search57_1_0 -> search57_0 in the cache */

static const nir_search_variable search57_1_1 = {
   { nir_search_value_variable, 64 },
   1, /* b */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search57_1 = {
   { nir_search_value_expression, 64 },
   false,
   0, 1,
   nir_op_fadd,
   { &search57_0.value, &search57_1_1.value },
   NULL,
};

static const nir_search_variable search57_2 = {
   { nir_search_value_variable, 64 },
   2, /* c */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search57 = {
   { nir_search_value_expression, 64 },
   true,
   -1, 1,
   nir_op_flrp,
   { &search57_0.value, &search57_1.value, &search57_2.value },
   NULL,
};

   /* replace57_0_0 -> search57_1_1 in the cache */

/* replace57_0_1 -> search57_2 in the cache */
static const nir_search_expression replace57_0 = {
   { nir_search_value_expression, 64 },
   false,
   1, 1,
   nir_op_fmul,
   { &search57_1_1.value, &search57_2.value },
   NULL,
};

/* replace57_1 -> search57_0 in the cache */
static const nir_search_expression replace57 = {
   { nir_search_value_expression, 64 },
   false,
   0, 2,
   nir_op_fadd,
   { &replace57_0.value, &search57_0.value },
   NULL,
};

   /* search58_0_0 -> search0_0 in the cache */

/* search58_0_1 -> replace0_1_0 in the cache */
/* search58_0 -> search56_1 in the cache */

/* search58_1_0 -> search0_0 in the cache */

/* search58_1_1 -> search56_2 in the cache */
static const nir_search_expression search58_1 = {
   { nir_search_value_expression, 32 },
   false,
   1, 1,
   nir_op_fadd,
   { &search0_0.value, &search56_2.value },
   NULL,
};

static const nir_search_variable search58_2 = {
   { nir_search_value_variable, 32 },
   3, /* d */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search58 = {
   { nir_search_value_expression, 32 },
   true,
   -1, 2,
   nir_op_flrp,
   { &search56_1.value, &search58_1.value, &search58_2.value },
   NULL,
};

   /* replace58_0_0 -> replace0_1_0 in the cache */

/* replace58_0_1 -> search56_2 in the cache */

/* replace58_0_2 -> search58_2 in the cache */
static const nir_search_expression replace58_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_flrp,
   { &replace0_1_0.value, &search56_2.value, &search58_2.value },
   NULL,
};

/* replace58_1 -> search0_0 in the cache */
static const nir_search_expression replace58 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_fadd,
   { &replace58_0.value, &search0_0.value },
   NULL,
};

   /* search59_0_0 -> search57_0 in the cache */

/* search59_0_1 -> search57_1_1 in the cache */
/* search59_0 -> search57_1 in the cache */

/* search59_1_0 -> search57_0 in the cache */

/* search59_1_1 -> search57_2 in the cache */
static const nir_search_expression search59_1 = {
   { nir_search_value_expression, 64 },
   false,
   1, 1,
   nir_op_fadd,
   { &search57_0.value, &search57_2.value },
   NULL,
};

static const nir_search_variable search59_2 = {
   { nir_search_value_variable, 64 },
   3, /* d */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search59 = {
   { nir_search_value_expression, 64 },
   true,
   -1, 2,
   nir_op_flrp,
   { &search57_1.value, &search59_1.value, &search59_2.value },
   NULL,
};

   /* replace59_0_0 -> search57_1_1 in the cache */

/* replace59_0_1 -> search57_2 in the cache */

/* replace59_0_2 -> search59_2 in the cache */
static const nir_search_expression replace59_0 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_flrp,
   { &search57_1_1.value, &search57_2.value, &search59_2.value },
   NULL,
};

/* replace59_1 -> search57_0 in the cache */
static const nir_search_expression replace59 = {
   { nir_search_value_expression, 64 },
   false,
   0, 1,
   nir_op_fadd,
   { &replace59_0.value, &search57_0.value },
   NULL,
};

   /* search60_0 -> search0_0 in the cache */

/* search60_1_0 -> search0_0 in the cache */

/* search60_1_1 -> replace0_1_0 in the cache */
static const nir_search_expression search60_1 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_fmul,
   { &search0_0.value, &replace0_1_0.value },
   (is_used_once),
};

/* search60_2 -> search56_2 in the cache */
static const nir_search_expression search60 = {
   { nir_search_value_expression, 32 },
   true,
   -1, 1,
   nir_op_flrp,
   { &search0_0.value, &search60_1.value, &search56_2.value },
   NULL,
};

   static const nir_search_constant replace60_0_0 = {
   { nir_search_value_constant, 32 },
   nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
};

/* replace60_0_1 -> replace0_1_0 in the cache */

/* replace60_0_2 -> search56_2 in the cache */
static const nir_search_expression replace60_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_flrp,
   { &replace60_0_0.value, &replace0_1_0.value, &search56_2.value },
   NULL,
};

/* replace60_1 -> search0_0 in the cache */
static const nir_search_expression replace60 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_fmul,
   { &replace60_0.value, &search0_0.value },
   NULL,
};

   /* search61_0 -> search57_0 in the cache */

/* search61_1_0 -> search57_0 in the cache */

/* search61_1_1 -> search57_1_1 in the cache */
static const nir_search_expression search61_1 = {
   { nir_search_value_expression, 64 },
   false,
   0, 1,
   nir_op_fmul,
   { &search57_0.value, &search57_1_1.value },
   (is_used_once),
};

/* search61_2 -> search57_2 in the cache */
static const nir_search_expression search61 = {
   { nir_search_value_expression, 64 },
   true,
   -1, 1,
   nir_op_flrp,
   { &search57_0.value, &search61_1.value, &search57_2.value },
   NULL,
};

   static const nir_search_constant replace61_0_0 = {
   { nir_search_value_constant, 64 },
   nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
};

/* replace61_0_1 -> search57_1_1 in the cache */

/* replace61_0_2 -> search57_2 in the cache */
static const nir_search_expression replace61_0 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_flrp,
   { &replace61_0_0.value, &search57_1_1.value, &search57_2.value },
   NULL,
};

/* replace61_1 -> search57_0 in the cache */
static const nir_search_expression replace61 = {
   { nir_search_value_expression, 64 },
   false,
   0, 1,
   nir_op_fmul,
   { &replace61_0.value, &search57_0.value },
   NULL,
};

   static const nir_search_variable search62_0_0 = {
   { nir_search_value_variable, -4 },
   0, /* a */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

static const nir_search_variable search62_0_1 = {
   { nir_search_value_variable, -4 },
   1, /* b */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search62_0 = {
   { nir_search_value_expression, -4 },
   false,
   0, 1,
   nir_op_fmul,
   { &search62_0_0.value, &search62_0_1.value },
   (is_used_once),
};

/* search62_1_0 -> search62_0_0 in the cache */

static const nir_search_variable search62_1_1 = {
   { nir_search_value_variable, -4 },
   2, /* c */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search62_1 = {
   { nir_search_value_expression, -4 },
   false,
   1, 1,
   nir_op_fmul,
   { &search62_0_0.value, &search62_1_1.value },
   (is_used_once),
};

static const nir_search_variable search62_2 = {
   { nir_search_value_variable, -4 },
   3, /* d */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search62 = {
   { nir_search_value_expression, -4 },
   true,
   -1, 2,
   nir_op_flrp,
   { &search62_0.value, &search62_1.value, &search62_2.value },
   NULL,
};

   /* replace62_0_0 -> search62_0_1 in the cache */

/* replace62_0_1 -> search62_1_1 in the cache */

/* replace62_0_2 -> search62_2 in the cache */
static const nir_search_expression replace62_0 = {
   { nir_search_value_expression, -4 },
   false,
   -1, 0,
   nir_op_flrp,
   { &search62_0_1.value, &search62_1_1.value, &search62_2.value },
   NULL,
};

/* replace62_1 -> search62_0_0 in the cache */
static const nir_search_expression replace62 = {
   { nir_search_value_expression, -4 },
   false,
   0, 1,
   nir_op_fmul,
   { &replace62_0.value, &search62_0_0.value },
   NULL,
};

   /* search63_0 -> search14_0 in the cache */

/* search63_1 -> replace14_1_0 in the cache */

static const nir_search_variable search63_2_0 = {
   { nir_search_value_variable, 1 },
   2, /* c */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search63_2 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_search_op_b2f,
   { &search63_2_0.value },
   NULL,
};
static const nir_search_expression search63 = {
   { nir_search_value_expression, -2 },
   true,
   -1, 0,
   nir_op_flrp,
   { &search14_0.value, &replace14_1_0.value, &search63_2.value },
   NULL,
};

   /* replace63_0 -> search63_2_0 in the cache */

/* replace63_1 -> replace14_1_0 in the cache */

/* replace63_2 -> search14_0 in the cache */
static const nir_search_expression replace63 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &search63_2_0.value, &replace14_1_0.value, &search14_0.value },
   NULL,
};

   /* search64_0 -> search14_0 in the cache */

/* search64_1 -> search47_0 in the cache */

static const nir_search_variable search64_2 = {
   { nir_search_value_variable, -2 },
   1, /* c */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search64 = {
   { nir_search_value_expression, -2 },
   true,
   -1, 0,
   nir_op_flrp,
   { &search14_0.value, &search47_0.value, &search64_2.value },
   NULL,
};

   /* replace64_0_0_0 -> search14_0 in the cache */
/* replace64_0_0 -> search34_0 in the cache */

/* replace64_0_1 -> search64_2 in the cache */
static const nir_search_expression replace64_0 = {
   { nir_search_value_expression, -2 },
   false,
   1, 1,
   nir_op_fmul,
   { &search34_0.value, &search64_2.value },
   NULL,
};

/* replace64_1 -> search14_0 in the cache */
static const nir_search_expression replace64 = {
   { nir_search_value_expression, -2 },
   false,
   0, 2,
   nir_op_fadd,
   { &replace64_0.value, &search14_0.value },
   NULL,
};

   /* search65_0 -> search2_0 in the cache */
static const nir_search_expression search65 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_ftrunc,
   { &search2_0.value },
   NULL,
};

   /* replace65_0_0 -> search2_0 in the cache */

/* replace65_0_1 -> search24_1 in the cache */
static const nir_search_expression replace65_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search2_0.value, &search24_1.value },
   NULL,
};

/* replace65_1_0_0_0 -> search2_0 in the cache */
/* replace65_1_0_0 -> search17_0 in the cache */
static const nir_search_expression replace65_1_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_ffloor,
   { &search17_0.value },
   NULL,
};
static const nir_search_expression replace65_1 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fneg,
   { &replace65_1_0.value },
   NULL,
};

/* replace65_2_0_0 -> search2_0 in the cache */
/* replace65_2_0 -> search17_0 in the cache */
/* replace65_2 -> replace65_1_0 in the cache */
static const nir_search_expression replace65 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace65_0.value, &replace65_1.value, &replace65_1_0.value },
   NULL,
};

   /* search66_0 -> search2_0 in the cache */
static const nir_search_expression search66 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_ffloor,
   { &search2_0.value },
   NULL,
};

   /* replace66_0 -> search2_0 in the cache */

/* replace66_1_0 -> search2_0 in the cache */
static const nir_search_expression replace66_1 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_ffract,
   { &search2_0.value },
   NULL,
};
static const nir_search_expression replace66 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fsub,
   { &search2_0.value, &replace66_1.value },
   NULL,
};

   /* search67_0 -> search2_0 in the cache */

/* search67_1_0_0 -> search2_0 in the cache */
/* search67_1_0 -> replace66_1 in the cache */
static const nir_search_expression search67_1 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fneg,
   { &replace66_1.value },
   NULL,
};
static const nir_search_expression search67 = {
   { nir_search_value_expression, -1 },
   false,
   0, 1,
   nir_op_fadd,
   { &search2_0.value, &search67_1.value },
   NULL,
};

   /* replace67_0 -> search2_0 in the cache */
/* replace67 -> search66 in the cache */

   /* search68_0 -> search2_0 in the cache */
/* search68 -> replace66_1 in the cache */

   /* replace68_0 -> search2_0 in the cache */

/* replace68_1_0 -> search2_0 in the cache */
/* replace68_1 -> search66 in the cache */
static const nir_search_expression replace68 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fsub,
   { &search2_0.value, &search66.value },
   NULL,
};

   /* search69_0 -> search2_0 in the cache */
static const nir_search_expression search69 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fceil,
   { &search2_0.value },
   NULL,
};

   /* replace69_0_0_0 -> search2_0 in the cache */
/* replace69_0_0 -> search15_0 in the cache */
static const nir_search_expression replace69_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_ffloor,
   { &search15_0.value },
   NULL,
};
static const nir_search_expression replace69 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fneg,
   { &replace69_0.value },
   NULL,
};

   /* search70_0_0 -> search28_0_0 in the cache */

static const nir_search_constant search70_0_1_0 = {
   { nir_search_value_constant, -3 },
   nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
};

static const nir_search_variable search70_0_1_1_0_0 = {
   { nir_search_value_variable, 1 },
   1, /* c */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search70_0_1_1_0 = {
   { nir_search_value_expression, -3 },
   false,
   -1, 0,
   nir_search_op_b2f,
   { &search70_0_1_1_0_0.value },
   NULL,
};
static const nir_search_expression search70_0_1_1 = {
   { nir_search_value_expression, -3 },
   false,
   -1, 0,
   nir_op_fneg,
   { &search70_0_1_1_0.value },
   NULL,
};
static const nir_search_expression search70_0_1 = {
   { nir_search_value_expression, -3 },
   false,
   2, 1,
   nir_op_fadd,
   { &search70_0_1_0.value, &search70_0_1_1.value },
   NULL,
};
static const nir_search_expression search70_0 = {
   { nir_search_value_expression, -3 },
   false,
   1, 2,
   nir_op_fmul,
   { &search28_0_0.value, &search70_0_1.value },
   NULL,
};

static const nir_search_variable search70_1_0 = {
   { nir_search_value_variable, -3 },
   2, /* b */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

/* search70_1_1_0 -> search70_0_1_1_0_0 in the cache */
/* search70_1_1 -> search70_0_1_1_0 in the cache */
static const nir_search_expression search70_1 = {
   { nir_search_value_expression, -3 },
   false,
   3, 1,
   nir_op_fmul,
   { &search70_1_0.value, &search70_0_1_1_0.value },
   NULL,
};
static const nir_search_expression search70 = {
   { nir_search_value_expression, -3 },
   true,
   0, 4,
   nir_op_fadd,
   { &search70_0.value, &search70_1.value },
   NULL,
};

   /* replace70_0 -> search70_0_1_1_0_0 in the cache */

/* replace70_1 -> search70_1_0 in the cache */

/* replace70_2 -> search28_0_0 in the cache */
static const nir_search_expression replace70 = {
   { nir_search_value_expression, -3 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &search70_0_1_1_0_0.value, &search70_1_0.value, &search28_0_0.value },
   NULL,
};

   /* search71_0_0 -> search0_0 in the cache */

/* search71_0_1_0 -> replace60_0_0 in the cache */

static const nir_search_variable search71_0_1_1_0 = {
   { nir_search_value_variable, 32 },
   1, /* c */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search71_0_1_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_fneg,
   { &search71_0_1_1_0.value },
   NULL,
};
static const nir_search_expression search71_0_1 = {
   { nir_search_value_expression, 32 },
   false,
   2, 1,
   nir_op_fadd,
   { &replace60_0_0.value, &search71_0_1_1.value },
   NULL,
};
static const nir_search_expression search71_0 = {
   { nir_search_value_expression, 32 },
   false,
   1, 2,
   nir_op_fmul,
   { &search0_0.value, &search71_0_1.value },
   NULL,
};

static const nir_search_variable search71_1_0 = {
   { nir_search_value_variable, 32 },
   2, /* b */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

/* search71_1_1 -> search71_0_1_1_0 in the cache */
static const nir_search_expression search71_1 = {
   { nir_search_value_expression, 32 },
   false,
   3, 1,
   nir_op_fmul,
   { &search71_1_0.value, &search71_0_1_1_0.value },
   NULL,
};
static const nir_search_expression search71 = {
   { nir_search_value_expression, 32 },
   true,
   0, 4,
   nir_op_fadd,
   { &search71_0.value, &search71_1.value },
   NULL,
};

   /* replace71_0 -> search0_0 in the cache */

/* replace71_1 -> search71_1_0 in the cache */

/* replace71_2 -> search71_0_1_1_0 in the cache */
static const nir_search_expression replace71 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_flrp,
   { &search0_0.value, &search71_1_0.value, &search71_0_1_1_0.value },
   NULL,
};

   /* search72_0_0 -> search57_0 in the cache */

/* search72_0_1_0 -> replace61_0_0 in the cache */

static const nir_search_variable search72_0_1_1_0 = {
   { nir_search_value_variable, 64 },
   1, /* c */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search72_0_1_1 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_fneg,
   { &search72_0_1_1_0.value },
   NULL,
};
static const nir_search_expression search72_0_1 = {
   { nir_search_value_expression, 64 },
   false,
   2, 1,
   nir_op_fadd,
   { &replace61_0_0.value, &search72_0_1_1.value },
   NULL,
};
static const nir_search_expression search72_0 = {
   { nir_search_value_expression, 64 },
   false,
   1, 2,
   nir_op_fmul,
   { &search57_0.value, &search72_0_1.value },
   NULL,
};

static const nir_search_variable search72_1_0 = {
   { nir_search_value_variable, 64 },
   2, /* b */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

/* search72_1_1 -> search72_0_1_1_0 in the cache */
static const nir_search_expression search72_1 = {
   { nir_search_value_expression, 64 },
   false,
   3, 1,
   nir_op_fmul,
   { &search72_1_0.value, &search72_0_1_1_0.value },
   NULL,
};
static const nir_search_expression search72 = {
   { nir_search_value_expression, 64 },
   true,
   0, 4,
   nir_op_fadd,
   { &search72_0.value, &search72_1.value },
   NULL,
};

   /* replace72_0 -> search57_0 in the cache */

/* replace72_1 -> search72_1_0 in the cache */

/* replace72_2 -> search72_0_1_1_0 in the cache */
static const nir_search_expression replace72 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_flrp,
   { &search57_0.value, &search72_1_0.value, &search72_0_1_1_0.value },
   NULL,
};

   /* search73_0_0 -> search0_0 in the cache */

/* search73_0_1_0_0 -> replace60_0_0 in the cache */

/* search73_0_1_0_1_0 -> search71_0_1_1_0 in the cache */
/* search73_0_1_0_1 -> search71_0_1_1 in the cache */
/* search73_0_1_0 -> search71_0_1 in the cache */
static const nir_search_expression search73_0_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_op_fsat,
   { &search71_0_1.value },
   NULL,
};
static const nir_search_expression search73_0 = {
   { nir_search_value_expression, 32 },
   false,
   1, 2,
   nir_op_fmul,
   { &search0_0.value, &search73_0_1.value },
   NULL,
};

/* search73_1_0 -> search71_1_0 in the cache */

/* search73_1_1_0 -> search71_0_1_1_0 in the cache */
static const nir_search_expression search73_1_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_fsat,
   { &search71_0_1_1_0.value },
   NULL,
};
static const nir_search_expression search73_1 = {
   { nir_search_value_expression, 32 },
   false,
   3, 1,
   nir_op_fmul,
   { &search71_1_0.value, &search73_1_1.value },
   NULL,
};
static const nir_search_expression search73 = {
   { nir_search_value_expression, 32 },
   true,
   0, 4,
   nir_op_fadd,
   { &search73_0.value, &search73_1.value },
   NULL,
};

   /* replace73_0 -> search0_0 in the cache */

/* replace73_1 -> search71_1_0 in the cache */

/* replace73_2_0 -> search71_0_1_1_0 in the cache */
/* replace73_2 -> search73_1_1 in the cache */
static const nir_search_expression replace73 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_flrp,
   { &search0_0.value, &search71_1_0.value, &search73_1_1.value },
   NULL,
};

   /* search74_0_0 -> search57_0 in the cache */

/* search74_0_1_0_0 -> replace61_0_0 in the cache */

/* search74_0_1_0_1_0 -> search72_0_1_1_0 in the cache */
/* search74_0_1_0_1 -> search72_0_1_1 in the cache */
/* search74_0_1_0 -> search72_0_1 in the cache */
static const nir_search_expression search74_0_1 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 1,
   nir_op_fsat,
   { &search72_0_1.value },
   NULL,
};
static const nir_search_expression search74_0 = {
   { nir_search_value_expression, 64 },
   false,
   1, 2,
   nir_op_fmul,
   { &search57_0.value, &search74_0_1.value },
   NULL,
};

/* search74_1_0 -> search72_1_0 in the cache */

/* search74_1_1_0 -> search72_0_1_1_0 in the cache */
static const nir_search_expression search74_1_1 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_fsat,
   { &search72_0_1_1_0.value },
   NULL,
};
static const nir_search_expression search74_1 = {
   { nir_search_value_expression, 64 },
   false,
   3, 1,
   nir_op_fmul,
   { &search72_1_0.value, &search74_1_1.value },
   NULL,
};
static const nir_search_expression search74 = {
   { nir_search_value_expression, 64 },
   true,
   0, 4,
   nir_op_fadd,
   { &search74_0.value, &search74_1.value },
   NULL,
};

   /* replace74_0 -> search57_0 in the cache */

/* replace74_1 -> search72_1_0 in the cache */

/* replace74_2_0 -> search72_0_1_1_0 in the cache */
/* replace74_2 -> search74_1_1 in the cache */
static const nir_search_expression replace74 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_flrp,
   { &search57_0.value, &search72_1_0.value, &search74_1_1.value },
   NULL,
};

   /* search75_0 -> search2_0 in the cache */

/* search75_1_0_0 -> search70_0_1_1_0_0 in the cache */
static const nir_search_expression search75_1_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_search_op_b2f,
   { &search70_0_1_1_0_0.value },
   NULL,
};

static const nir_search_variable search75_1_1_0 = {
   { nir_search_value_variable, -1 },
   2, /* b */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

/* search75_1_1_1_0 -> search2_0 in the cache */
/* search75_1_1_1 -> search15_0 in the cache */
static const nir_search_expression search75_1_1 = {
   { nir_search_value_expression, -1 },
   false,
   2, 1,
   nir_op_fadd,
   { &search75_1_1_0.value, &search15_0.value },
   NULL,
};
static const nir_search_expression search75_1 = {
   { nir_search_value_expression, -1 },
   false,
   1, 2,
   nir_op_fmul,
   { &search75_1_0.value, &search75_1_1.value },
   NULL,
};
static const nir_search_expression search75 = {
   { nir_search_value_expression, -1 },
   true,
   0, 3,
   nir_op_fadd,
   { &search2_0.value, &search75_1.value },
   NULL,
};

   /* replace75_0 -> search70_0_1_1_0_0 in the cache */

/* replace75_1 -> search75_1_1_0 in the cache */

/* replace75_2 -> search2_0 in the cache */
static const nir_search_expression replace75 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &search70_0_1_1_0_0.value, &search75_1_1_0.value, &search2_0.value },
   NULL,
};

   /* search76_0 -> search0_0 in the cache */

/* search76_1_0 -> search71_0_1_1_0 in the cache */

/* search76_1_1_0 -> search71_1_0 in the cache */

/* search76_1_1_1_0 -> search0_0 in the cache */
static const nir_search_expression search76_1_1_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_fneg,
   { &search0_0.value },
   NULL,
};
static const nir_search_expression search76_1_1 = {
   { nir_search_value_expression, 32 },
   false,
   2, 1,
   nir_op_fadd,
   { &search71_1_0.value, &search76_1_1_1.value },
   NULL,
};
static const nir_search_expression search76_1 = {
   { nir_search_value_expression, 32 },
   false,
   1, 2,
   nir_op_fmul,
   { &search71_0_1_1_0.value, &search76_1_1.value },
   NULL,
};
static const nir_search_expression search76 = {
   { nir_search_value_expression, 32 },
   true,
   0, 3,
   nir_op_fadd,
   { &search0_0.value, &search76_1.value },
   NULL,
};

   /* replace76_0 -> search0_0 in the cache */

/* replace76_1 -> search71_1_0 in the cache */

/* replace76_2 -> search71_0_1_1_0 in the cache */
/* replace76 -> replace71 in the cache */

   /* search77_0 -> search57_0 in the cache */

/* search77_1_0 -> search72_0_1_1_0 in the cache */

/* search77_1_1_0 -> search72_1_0 in the cache */

/* search77_1_1_1_0 -> search57_0 in the cache */
static const nir_search_expression search77_1_1_1 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_fneg,
   { &search57_0.value },
   NULL,
};
static const nir_search_expression search77_1_1 = {
   { nir_search_value_expression, 64 },
   false,
   2, 1,
   nir_op_fadd,
   { &search72_1_0.value, &search77_1_1_1.value },
   NULL,
};
static const nir_search_expression search77_1 = {
   { nir_search_value_expression, 64 },
   false,
   1, 2,
   nir_op_fmul,
   { &search72_0_1_1_0.value, &search77_1_1.value },
   NULL,
};
static const nir_search_expression search77 = {
   { nir_search_value_expression, 64 },
   true,
   0, 3,
   nir_op_fadd,
   { &search57_0.value, &search77_1.value },
   NULL,
};

   /* replace77_0 -> search57_0 in the cache */

/* replace77_1 -> search72_1_0 in the cache */

/* replace77_2 -> search72_0_1_1_0 in the cache */
/* replace77 -> replace72 in the cache */

   /* search78_0 -> search28_0_0 in the cache */

/* search78_1 -> search28_0_1 in the cache */

/* search78_2 -> search28_1_1 in the cache */
static const nir_search_expression search78 = {
   { nir_search_value_expression, -3 },
   false,
   0, 1,
   nir_op_ffma,
   { &search28_0_0.value, &search28_0_1.value, &search28_1_1.value },
   NULL,
};

   /* replace78_0_0 -> search28_0_0 in the cache */

/* replace78_0_1 -> search28_0_1 in the cache */
/* replace78_0 -> search28_0 in the cache */

/* replace78_1 -> search28_1_1 in the cache */
static const nir_search_expression replace78 = {
   { nir_search_value_expression, -3 },
   false,
   0, 2,
   nir_op_fadd,
   { &search28_0.value, &search28_1_1.value },
   NULL,
};

   /* search79_0_0 -> search28_0_0 in the cache */

/* search79_0_1 -> search28_0_1 in the cache */
/* search79_0 -> search28_0 in the cache */

/* search79_1 -> search28_1_1 in the cache */
static const nir_search_expression search79 = {
   { nir_search_value_expression, -3 },
   true,
   0, 2,
   nir_op_fadd,
   { &search28_0.value, &search28_1_1.value },
   NULL,
};

   /* replace79_0 -> search28_0_0 in the cache */

/* replace79_1 -> search28_0_1 in the cache */

/* replace79_2 -> search28_1_1 in the cache */
/* replace79 -> search78 in the cache */

   static const nir_search_variable search80_0_0_0_0_0 = {
   { nir_search_value_variable, 1 },
   0, /* a */
   false,
   nir_type_bool,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search80_0_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_b2i32,
   { &search80_0_0_0_0_0.value },
   NULL,
};
static const nir_search_expression search80_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_ineg,
   { &search80_0_0_0_0.value },
   NULL,
};

/* search80_0_0_1_0 -> replace0_1_0 in the cache */

/* search80_0_0_1_1 -> search56_2 in the cache */
static const nir_search_expression search80_0_0_1 = {
   { nir_search_value_expression, 32 },
   false,
   3, 1,
   nir_op_fmul,
   { &replace0_1_0.value, &search56_2.value },
   NULL,
};
static const nir_search_expression search80_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   2, 2,
   nir_op_iand,
   { &search80_0_0_0.value, &search80_0_0_1.value },
   NULL,
};

static const nir_search_variable search80_0_1 = {
   { nir_search_value_variable, 32 },
   3, /* d */
   true,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search80_0 = {
   { nir_search_value_expression, 32 },
   false,
   1, 3,
   nir_op_fadd,
   { &search80_0_0.value, &search80_0_1.value },
   NULL,
};

static const nir_search_variable search80_1 = {
   { nir_search_value_variable, 32 },
   4, /* e */
   true,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search80 = {
   { nir_search_value_expression, 32 },
   true,
   0, 4,
   nir_op_fmul,
   { &search80_0.value, &search80_1.value },
   NULL,
};

   static const nir_search_variable replace80_0 = {
   { nir_search_value_variable, 1 },
   0, /* a */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

/* replace80_1_0_0_0 -> replace0_1_0 in the cache */

/* replace80_1_0_0_1 -> search56_2 in the cache */
static const nir_search_expression replace80_1_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   2, 1,
   nir_op_fmul,
   { &replace0_1_0.value, &search56_2.value },
   NULL,
};

/* replace80_1_0_1 -> search58_2 in the cache */
static const nir_search_expression replace80_1_0 = {
   { nir_search_value_expression, 32 },
   false,
   1, 2,
   nir_op_fadd,
   { &replace80_1_0_0.value, &search58_2.value },
   NULL,
};

static const nir_search_variable replace80_1_1 = {
   { nir_search_value_variable, 32 },
   4, /* e */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression replace80_1 = {
   { nir_search_value_expression, 32 },
   false,
   0, 3,
   nir_op_fmul,
   { &replace80_1_0.value, &replace80_1_1.value },
   NULL,
};

/* replace80_2_0 -> search58_2 in the cache */

/* replace80_2_1 -> replace80_1_1 in the cache */
static const nir_search_expression replace80_2 = {
   { nir_search_value_expression, 32 },
   false,
   3, 1,
   nir_op_fmul,
   { &search58_2.value, &replace80_1_1.value },
   NULL,
};
static const nir_search_expression replace80 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 4,
   nir_op_bcsel,
   { &replace80_0.value, &replace80_1.value, &replace80_2.value },
   NULL,
};

   /* search81_0 -> search14_0 in the cache */

/* search81_1 -> replace14_1_0 in the cache */
static const nir_search_expression search81 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_fdph,
   { &search14_0.value, &replace14_1_0.value },
   NULL,
};

   static const nir_search_variable replace81_0_0 = {
   { nir_search_value_variable, -2 },
   0, /* a */
   false,
   nir_type_invalid,
   NULL,
   {0},
};

static const nir_search_variable replace81_0_1 = {
   { nir_search_value_variable, -2 },
   0, /* a */
   false,
   nir_type_invalid,
   NULL,
   {1},
};

static const nir_search_variable replace81_0_2 = {
   { nir_search_value_variable, -2 },
   0, /* a */
   false,
   nir_type_invalid,
   NULL,
   {2},
};

/* replace81_0_3 -> search49_0 in the cache */
static const nir_search_expression replace81_0 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_vec4,
   { &replace81_0_0.value, &replace81_0_1.value, &replace81_0_2.value, &search49_0.value },
   NULL,
};

/* replace81_1 -> replace14_1_0 in the cache */
static const nir_search_expression replace81 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_fdot4,
   { &replace81_0.value, &replace14_1_0.value },
   NULL,
};

   /* search82_0_0 -> search62_0_0 in the cache */

/* search82_0_1 -> search62_0_1 in the cache */

/* search82_0_2 -> search62_1_1 in the cache */

static const nir_search_constant search82_0_3 = {
   { nir_search_value_constant, -4 },
   nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
};
static const nir_search_expression search82_0 = {
   { nir_search_value_expression, -4 },
   false,
   -1, 0,
   nir_op_vec4,
   { &search62_0_0.value, &search62_0_1.value, &search62_1_1.value, &search82_0_3.value },
   NULL,
};

/* search82_1 -> search62_2 in the cache */
static const nir_search_expression search82 = {
   { nir_search_value_expression, -4 },
   false,
   0, 1,
   nir_op_fdot4,
   { &search82_0.value, &search62_2.value },
   NULL,
};

   /* replace82_0_0 -> search62_0_0 in the cache */

/* replace82_0_1 -> search62_0_1 in the cache */

/* replace82_0_2 -> search62_1_1 in the cache */
static const nir_search_expression replace82_0 = {
   { nir_search_value_expression, -4 },
   false,
   -1, 0,
   nir_op_vec3,
   { &search62_0_0.value, &search62_0_1.value, &search62_1_1.value },
   NULL,
};

/* replace82_1 -> search62_2 in the cache */
static const nir_search_expression replace82 = {
   { nir_search_value_expression, -4 },
   false,
   -1, 0,
   nir_op_fdph,
   { &replace82_0.value, &search62_2.value },
   NULL,
};

   /* search83_0_0 -> search14_0 in the cache */

/* search83_0_1 -> search47_0 in the cache */

/* search83_0_2 -> search47_0 in the cache */

/* search83_0_3 -> search47_0 in the cache */
static const nir_search_expression search83_0 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_vec4,
   { &search14_0.value, &search47_0.value, &search47_0.value, &search47_0.value },
   NULL,
};

/* search83_1 -> replace14_1_0 in the cache */
static const nir_search_expression search83 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_fdot4,
   { &search83_0.value, &replace14_1_0.value },
   NULL,
};

   /* replace83_0 -> search14_0 in the cache */

/* replace83_1 -> replace14_1_0 in the cache */
/* replace83 -> replace48 in the cache */

   /* search84_0_0 -> search28_0_0 in the cache */

/* search84_0_1 -> search28_0_1 in the cache */

static const nir_search_constant search84_0_2 = {
   { nir_search_value_constant, -3 },
   nir_type_float, { 0x0 /* 0.0 */ },
};

/* search84_0_3 -> search84_0_2 in the cache */
static const nir_search_expression search84_0 = {
   { nir_search_value_expression, -3 },
   false,
   -1, 0,
   nir_op_vec4,
   { &search28_0_0.value, &search28_0_1.value, &search84_0_2.value, &search84_0_2.value },
   NULL,
};

/* search84_1 -> search28_1_1 in the cache */
static const nir_search_expression search84 = {
   { nir_search_value_expression, -3 },
   false,
   0, 1,
   nir_op_fdot4,
   { &search84_0.value, &search28_1_1.value },
   NULL,
};

   /* replace84_0_0 -> search28_0_0 in the cache */

/* replace84_0_1 -> search28_0_1 in the cache */
static const nir_search_expression replace84_0 = {
   { nir_search_value_expression, -3 },
   false,
   -1, 0,
   nir_op_vec2,
   { &search28_0_0.value, &search28_0_1.value },
   NULL,
};

/* replace84_1 -> search28_1_1 in the cache */
static const nir_search_expression replace84 = {
   { nir_search_value_expression, -3 },
   false,
   0, 1,
   nir_op_fdot2,
   { &replace84_0.value, &search28_1_1.value },
   NULL,
};

   /* search85_0_0 -> search62_0_0 in the cache */

/* search85_0_1 -> search62_0_1 in the cache */

/* search85_0_2 -> search62_1_1 in the cache */

static const nir_search_constant search85_0_3 = {
   { nir_search_value_constant, -4 },
   nir_type_float, { 0x0 /* 0.0 */ },
};
static const nir_search_expression search85_0 = {
   { nir_search_value_expression, -4 },
   false,
   -1, 0,
   nir_op_vec4,
   { &search62_0_0.value, &search62_0_1.value, &search62_1_1.value, &search85_0_3.value },
   NULL,
};

/* search85_1 -> search62_2 in the cache */
static const nir_search_expression search85 = {
   { nir_search_value_expression, -4 },
   false,
   0, 1,
   nir_op_fdot4,
   { &search85_0.value, &search62_2.value },
   NULL,
};

   /* replace85_0_0 -> search62_0_0 in the cache */

/* replace85_0_1 -> search62_0_1 in the cache */

/* replace85_0_2 -> search62_1_1 in the cache */
/* replace85_0 -> replace82_0 in the cache */

/* replace85_1 -> search62_2 in the cache */
static const nir_search_expression replace85 = {
   { nir_search_value_expression, -4 },
   false,
   0, 1,
   nir_op_fdot3,
   { &replace82_0.value, &search62_2.value },
   NULL,
};

   /* search86_0_0 -> search14_0 in the cache */

/* search86_0_1 -> search47_0 in the cache */

/* search86_0_2 -> search47_0 in the cache */
static const nir_search_expression search86_0 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_vec3,
   { &search14_0.value, &search47_0.value, &search47_0.value },
   NULL,
};

/* search86_1 -> replace14_1_0 in the cache */
static const nir_search_expression search86 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_fdot3,
   { &search86_0.value, &replace14_1_0.value },
   NULL,
};

   /* replace86_0 -> search14_0 in the cache */

/* replace86_1 -> replace14_1_0 in the cache */
/* replace86 -> replace48 in the cache */

   /* search87_0_0 -> search28_0_0 in the cache */

/* search87_0_1 -> search28_0_1 in the cache */

/* search87_0_2 -> search84_0_2 in the cache */
static const nir_search_expression search87_0 = {
   { nir_search_value_expression, -3 },
   false,
   -1, 0,
   nir_op_vec3,
   { &search28_0_0.value, &search28_0_1.value, &search84_0_2.value },
   NULL,
};

/* search87_1 -> search28_1_1 in the cache */
static const nir_search_expression search87 = {
   { nir_search_value_expression, -3 },
   false,
   0, 1,
   nir_op_fdot3,
   { &search87_0.value, &search28_1_1.value },
   NULL,
};

   /* replace87_0_0 -> search28_0_0 in the cache */

/* replace87_0_1 -> search28_0_1 in the cache */
/* replace87_0 -> replace84_0 in the cache */

/* replace87_1 -> search28_1_1 in the cache */
/* replace87 -> replace84 in the cache */

   /* search88_0_0 -> search14_0 in the cache */

/* search88_0_1 -> search47_0 in the cache */
static const nir_search_expression search88_0 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_vec2,
   { &search14_0.value, &search47_0.value },
   NULL,
};

/* search88_1 -> replace14_1_0 in the cache */
static const nir_search_expression search88 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_fdot2,
   { &search88_0.value, &replace14_1_0.value },
   NULL,
};

   /* replace88_0 -> search14_0 in the cache */

/* replace88_1 -> replace14_1_0 in the cache */
/* replace88 -> replace48 in the cache */

   /* search89_0 -> search2_0 in the cache */

/* search89_1 -> search41_1 in the cache */
static const nir_search_expression search89 = {
   { nir_search_value_expression, -1 },
   false,
   0, 1,
   nir_op_fdot2,
   { &search2_0.value, &search41_1.value },
   NULL,
};

   static const nir_search_variable replace89_0 = {
   { nir_search_value_variable, -1 },
   0, /* a */
   false,
   nir_type_invalid,
   NULL,
   {0},
};

static const nir_search_variable replace89_1 = {
   { nir_search_value_variable, -1 },
   0, /* a */
   false,
   nir_type_invalid,
   NULL,
   {1},
};
static const nir_search_expression replace89 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fadd,
   { &replace89_0.value, &replace89_1.value },
   NULL,
};

   /* search90_0 -> search14_0 in the cache */

/* search90_1 -> replace14_1_0 in the cache */
static const nir_search_expression search90 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_fdot2,
   { &search14_0.value, &replace14_1_0.value },
   NULL,
};

   /* replace90_0_0 -> search14_0 in the cache */

/* replace90_0_1 -> replace14_1_0 in the cache */
/* replace90_0 -> replace48 in the cache */
static const nir_search_expression replace90 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 1,
   nir_op_fsum2,
   { &replace48.value },
   NULL,
};

   /* search91_0 -> search14_0 in the cache */

/* search91_1 -> replace14_1_0 in the cache */
static const nir_search_expression search91 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_fdot3,
   { &search14_0.value, &replace14_1_0.value },
   NULL,
};

   /* replace91_0_0 -> search14_0 in the cache */

/* replace91_0_1 -> replace14_1_0 in the cache */
/* replace91_0 -> replace48 in the cache */
static const nir_search_expression replace91 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 1,
   nir_op_fsum3,
   { &replace48.value },
   NULL,
};

   /* search92_0 -> search14_0 in the cache */

/* search92_1 -> replace14_1_0 in the cache */
static const nir_search_expression search92 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_fdot4,
   { &search14_0.value, &replace14_1_0.value },
   NULL,
};

   /* replace92_0_0 -> search14_0 in the cache */

/* replace92_0_1 -> replace14_1_0 in the cache */
/* replace92_0 -> replace48 in the cache */
static const nir_search_expression replace92 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 1,
   nir_op_fsum4,
   { &replace48.value },
   NULL,
};

   /* search93_0 -> search2_0 in the cache */
static const nir_search_expression search93 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fsum2,
   { &search2_0.value },
   NULL,
};

   /* replace93_0 -> replace89_0 in the cache */

/* replace93_1 -> replace89_1 in the cache */
/* replace93 -> replace89 in the cache */

   static const nir_search_variable search94_0_0_0 = {
   { nir_search_value_variable, -1 },
   0, /* a */
   false,
   nir_type_invalid,
   (is_not_fmul),
   {0, 1, 2, 3},
};
static const nir_search_expression search94_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fsat,
   { &search94_0_0_0.value },
   (is_used_once),
};
static const nir_search_expression search94_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fneg,
   { &search94_0_0.value },
   (is_used_once),
};

/* search94_1 -> search41_1 in the cache */
static const nir_search_expression search94 = {
   { nir_search_value_expression, -1 },
   true,
   0, 1,
   nir_op_fadd,
   { &search94_0.value, &search41_1.value },
   NULL,
};

   /* replace94_0_0 -> search41_1 in the cache */

/* replace94_0_1_0 -> search2_0 in the cache */
/* replace94_0_1 -> search15_0 in the cache */
static const nir_search_expression replace94_0 = {
   { nir_search_value_expression, -1 },
   false,
   0, 1,
   nir_op_fadd,
   { &search41_1.value, &search15_0.value },
   NULL,
};
static const nir_search_expression replace94 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 1,
   nir_op_fsat,
   { &replace94_0.value },
   NULL,
};

   /* search95_0 -> replace60_0_0 in the cache */

/* search95_1_0_0_0 -> replace60_0_0 in the cache */

/* search95_1_0_0_1_0 -> search0_0 in the cache */
/* search95_1_0_0_1 -> search76_1_1_1 in the cache */
static const nir_search_expression search95_1_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   2, 1,
   nir_op_fadd,
   { &replace60_0_0.value, &search76_1_1_1.value },
   NULL,
};

/* search95_1_0_1_0 -> replace60_0_0 in the cache */

/* search95_1_0_1_1_0 -> replace0_1_0 in the cache */
static const nir_search_expression search95_1_0_1_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_fneg,
   { &replace0_1_0.value },
   NULL,
};
static const nir_search_expression search95_1_0_1 = {
   { nir_search_value_expression, 32 },
   false,
   3, 1,
   nir_op_fadd,
   { &replace60_0_0.value, &search95_1_0_1_1.value },
   NULL,
};
static const nir_search_expression search95_1_0 = {
   { nir_search_value_expression, 32 },
   false,
   1, 3,
   nir_op_fmul,
   { &search95_1_0_0.value, &search95_1_0_1.value },
   NULL,
};
static const nir_search_expression search95_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 3,
   nir_op_fneg,
   { &search95_1_0.value },
   NULL,
};
static const nir_search_expression search95 = {
   { nir_search_value_expression, 32 },
   true,
   0, 4,
   nir_op_fadd,
   { &replace60_0_0.value, &search95_1.value },
   NULL,
};

   /* replace95_0 -> replace0_1_0 in the cache */

/* replace95_1 -> replace60_0_0 in the cache */

/* replace95_2 -> search0_0 in the cache */
static const nir_search_expression replace95 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_flrp,
   { &replace0_1_0.value, &replace60_0_0.value, &search0_0.value },
   NULL,
};

   /* search96_0_0_0 -> search28_0_0 in the cache */

static const nir_search_variable search96_0_0_1 = {
   { nir_search_value_variable, -3 },
   1, /* b */
   true,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search96_0_0 = {
   { nir_search_value_expression, -3 },
   false,
   1, 1,
   nir_op_imul,
   { &search28_0_0.value, &search96_0_0_1.value },
   NULL,
};

static const nir_search_variable search96_0_1 = {
   { nir_search_value_variable, -3 },
   2, /* c */
   true,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search96_0 = {
   { nir_search_value_expression, -3 },
   false,
   0, 2,
   nir_op_iadd,
   { &search96_0_0.value, &search96_0_1.value },
   NULL,
};

/* search96_1 -> search80_0_1 in the cache */
static const nir_search_expression search96 = {
   { nir_search_value_expression, -3 },
   false,
   -1, 2,
   nir_op_ishl,
   { &search96_0.value, &search80_0_1.value },
   NULL,
};

   /* replace96_0_0 -> search28_0_0 in the cache */

/* replace96_0_1_0 -> search28_0_1 in the cache */

/* replace96_0_1_1 -> search58_2 in the cache */
static const nir_search_expression replace96_0_1 = {
   { nir_search_value_expression, -3 },
   false,
   -1, 0,
   nir_op_ishl,
   { &search28_0_1.value, &search58_2.value },
   NULL,
};
static const nir_search_expression replace96_0 = {
   { nir_search_value_expression, -3 },
   false,
   1, 1,
   nir_op_imul,
   { &search28_0_0.value, &replace96_0_1.value },
   NULL,
};

/* replace96_1_0 -> search28_1_1 in the cache */

/* replace96_1_1 -> search58_2 in the cache */
static const nir_search_expression replace96_1 = {
   { nir_search_value_expression, -3 },
   false,
   -1, 0,
   nir_op_ishl,
   { &search28_1_1.value, &search58_2.value },
   NULL,
};
static const nir_search_expression replace96 = {
   { nir_search_value_expression, -3 },
   false,
   0, 2,
   nir_op_iadd,
   { &replace96_0.value, &replace96_1.value },
   NULL,
};

   /* search97_0_0 -> search14_0 in the cache */

static const nir_search_variable search97_0_1 = {
   { nir_search_value_variable, -2 },
   1, /* b */
   true,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search97_0 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_imul,
   { &search14_0.value, &search97_0_1.value },
   NULL,
};

static const nir_search_variable search97_1 = {
   { nir_search_value_variable, 32 },
   2, /* c */
   true,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search97 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 1,
   nir_op_ishl,
   { &search97_0.value, &search97_1.value },
   NULL,
};

   /* replace97_0 -> search14_0 in the cache */

/* replace97_1_0 -> replace14_1_0 in the cache */

/* replace97_1_1 -> search56_2 in the cache */
static const nir_search_expression replace97_1 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_ishl,
   { &replace14_1_0.value, &search56_2.value },
   NULL,
};
static const nir_search_expression replace97 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_imul,
   { &search14_0.value, &replace97_1.value },
   NULL,
};

   static const nir_search_variable search98_0_0 = {
   { nir_search_value_variable, 8 },
   0, /* a */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

/* search98_0_1 -> search2_1 in the cache */
static const nir_search_expression search98_0 = {
   { nir_search_value_expression, 8 },
   false,
   -1, 0,
   nir_op_ishl,
   { &search98_0_0.value, &search2_1.value },
   NULL,
};

/* search98_1 -> search97_1 in the cache */
static const nir_search_expression search98 = {
   { nir_search_value_expression, 8 },
   false,
   -1, 0,
   nir_op_ishl,
   { &search98_0.value, &search97_1.value },
   NULL,
};

   /* replace98_0_0_0_0 -> replace0_1_0 in the cache */

static const nir_search_constant replace98_0_0_0_1 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { 0xff /* 255 */ },
};
static const nir_search_expression replace98_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   1, 1,
   nir_op_iand,
   { &replace0_1_0.value, &replace98_0_0_0_1.value },
   NULL,
};

/* replace98_0_0_1_0 -> search56_2 in the cache */

/* replace98_0_0_1_1 -> replace98_0_0_0_1 in the cache */
static const nir_search_expression replace98_0_0_1 = {
   { nir_search_value_expression, 32 },
   false,
   2, 1,
   nir_op_iand,
   { &search56_2.value, &replace98_0_0_0_1.value },
   NULL,
};
static const nir_search_expression replace98_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   0, 3,
   nir_op_iadd,
   { &replace98_0_0_0.value, &replace98_0_0_1.value },
   NULL,
};

static const nir_search_constant replace98_0_1 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { 0x8 /* 8 */ },
};
static const nir_search_expression replace98_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 3,
   nir_op_ult,
   { &replace98_0_0.value, &replace98_0_1.value },
   NULL,
};

/* replace98_1_0 -> search98_0_0 in the cache */

/* replace98_1_1_0 -> replace0_1_0 in the cache */

/* replace98_1_1_1 -> search56_2 in the cache */
static const nir_search_expression replace98_1_1 = {
   { nir_search_value_expression, 32 },
   false,
   3, 1,
   nir_op_iadd,
   { &replace0_1_0.value, &search56_2.value },
   NULL,
};
static const nir_search_expression replace98_1 = {
   { nir_search_value_expression, 8 },
   false,
   -1, 1,
   nir_op_ishl,
   { &search98_0_0.value, &replace98_1_1.value },
   NULL,
};

static const nir_search_constant replace98_2 = {
   { nir_search_value_constant, 8 },
   nir_type_int, { 0x0 /* 0 */ },
};
static const nir_search_expression replace98 = {
   { nir_search_value_expression, 8 },
   false,
   -1, 4,
   nir_op_bcsel,
   { &replace98_0.value, &replace98_1.value, &replace98_2.value },
   NULL,
};

   /* search99_0_0 -> search98_0_0 in the cache */

/* search99_0_1 -> search2_1 in the cache */
static const nir_search_expression search99_0 = {
   { nir_search_value_expression, 8 },
   false,
   -1, 0,
   nir_op_ushr,
   { &search98_0_0.value, &search2_1.value },
   NULL,
};

/* search99_1 -> search97_1 in the cache */
static const nir_search_expression search99 = {
   { nir_search_value_expression, 8 },
   false,
   -1, 0,
   nir_op_ushr,
   { &search99_0.value, &search97_1.value },
   NULL,
};

   /* replace99_0_0_0_0 -> replace0_1_0 in the cache */

/* replace99_0_0_0_1 -> replace98_0_0_0_1 in the cache */
/* replace99_0_0_0 -> replace98_0_0_0 in the cache */

/* replace99_0_0_1_0 -> search56_2 in the cache */

/* replace99_0_0_1_1 -> replace98_0_0_0_1 in the cache */
/* replace99_0_0_1 -> replace98_0_0_1 in the cache */
/* replace99_0_0 -> replace98_0_0 in the cache */

/* replace99_0_1 -> replace98_0_1 in the cache */
/* replace99_0 -> replace98_0 in the cache */

/* replace99_1_0 -> search98_0_0 in the cache */

/* replace99_1_1_0 -> replace0_1_0 in the cache */

/* replace99_1_1_1 -> search56_2 in the cache */
/* replace99_1_1 -> replace98_1_1 in the cache */
static const nir_search_expression replace99_1 = {
   { nir_search_value_expression, 8 },
   false,
   -1, 1,
   nir_op_ushr,
   { &search98_0_0.value, &replace98_1_1.value },
   NULL,
};

/* replace99_2 -> replace98_2 in the cache */
static const nir_search_expression replace99 = {
   { nir_search_value_expression, 8 },
   false,
   -1, 4,
   nir_op_bcsel,
   { &replace98_0.value, &replace99_1.value, &replace98_2.value },
   NULL,
};

   /* search100_0_0 -> search98_0_0 in the cache */

/* search100_0_1 -> search2_1 in the cache */
static const nir_search_expression search100_0 = {
   { nir_search_value_expression, 8 },
   false,
   -1, 0,
   nir_op_ishr,
   { &search98_0_0.value, &search2_1.value },
   NULL,
};

/* search100_1 -> search97_1 in the cache */
static const nir_search_expression search100 = {
   { nir_search_value_expression, 8 },
   false,
   -1, 0,
   nir_op_ishr,
   { &search100_0.value, &search97_1.value },
   NULL,
};

   /* replace100_0 -> search98_0_0 in the cache */

/* replace100_1_0_0_0 -> replace0_1_0 in the cache */

/* replace100_1_0_0_1 -> replace98_0_0_0_1 in the cache */
static const nir_search_expression replace100_1_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   2, 1,
   nir_op_iand,
   { &replace0_1_0.value, &replace98_0_0_0_1.value },
   NULL,
};

/* replace100_1_0_1_0 -> search56_2 in the cache */

/* replace100_1_0_1_1 -> replace98_0_0_0_1 in the cache */
static const nir_search_expression replace100_1_0_1 = {
   { nir_search_value_expression, 32 },
   false,
   3, 1,
   nir_op_iand,
   { &search56_2.value, &replace98_0_0_0_1.value },
   NULL,
};
static const nir_search_expression replace100_1_0 = {
   { nir_search_value_expression, 32 },
   false,
   1, 3,
   nir_op_iadd,
   { &replace100_1_0_0.value, &replace100_1_0_1.value },
   NULL,
};

static const nir_search_constant replace100_1_1 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { 0x7 /* 7 */ },
};
static const nir_search_expression replace100_1 = {
   { nir_search_value_expression, 32 },
   false,
   0, 4,
   nir_op_imin,
   { &replace100_1_0.value, &replace100_1_1.value },
   NULL,
};
static const nir_search_expression replace100 = {
   { nir_search_value_expression, 8 },
   false,
   -1, 4,
   nir_op_ishr,
   { &search98_0_0.value, &replace100_1.value },
   NULL,
};

   static const nir_search_variable search101_0_0 = {
   { nir_search_value_variable, 16 },
   0, /* a */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

/* search101_0_1 -> search2_1 in the cache */
static const nir_search_expression search101_0 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_ishl,
   { &search101_0_0.value, &search2_1.value },
   NULL,
};

/* search101_1 -> search97_1 in the cache */
static const nir_search_expression search101 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_ishl,
   { &search101_0.value, &search97_1.value },
   NULL,
};

   /* replace101_0_0_0_0 -> replace0_1_0 in the cache */

static const nir_search_constant replace101_0_0_0_1 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { 0xffff /* 65535 */ },
};
static const nir_search_expression replace101_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   1, 1,
   nir_op_iand,
   { &replace0_1_0.value, &replace101_0_0_0_1.value },
   NULL,
};

/* replace101_0_0_1_0 -> search56_2 in the cache */

/* replace101_0_0_1_1 -> replace101_0_0_0_1 in the cache */
static const nir_search_expression replace101_0_0_1 = {
   { nir_search_value_expression, 32 },
   false,
   2, 1,
   nir_op_iand,
   { &search56_2.value, &replace101_0_0_0_1.value },
   NULL,
};
static const nir_search_expression replace101_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   0, 3,
   nir_op_iadd,
   { &replace101_0_0_0.value, &replace101_0_0_1.value },
   NULL,
};

static const nir_search_constant replace101_0_1 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { 0x10 /* 16 */ },
};
static const nir_search_expression replace101_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 3,
   nir_op_ult,
   { &replace101_0_0.value, &replace101_0_1.value },
   NULL,
};

/* replace101_1_0 -> search101_0_0 in the cache */

/* replace101_1_1_0 -> replace0_1_0 in the cache */

/* replace101_1_1_1 -> search56_2 in the cache */
/* replace101_1_1 -> replace98_1_1 in the cache */
static const nir_search_expression replace101_1 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 1,
   nir_op_ishl,
   { &search101_0_0.value, &replace98_1_1.value },
   NULL,
};

static const nir_search_constant replace101_2 = {
   { nir_search_value_constant, 16 },
   nir_type_int, { 0x0 /* 0 */ },
};
static const nir_search_expression replace101 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 4,
   nir_op_bcsel,
   { &replace101_0.value, &replace101_1.value, &replace101_2.value },
   NULL,
};

   /* search102_0_0 -> search101_0_0 in the cache */

/* search102_0_1 -> search2_1 in the cache */
static const nir_search_expression search102_0 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_ushr,
   { &search101_0_0.value, &search2_1.value },
   NULL,
};

/* search102_1 -> search97_1 in the cache */
static const nir_search_expression search102 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_ushr,
   { &search102_0.value, &search97_1.value },
   NULL,
};

   /* replace102_0_0_0_0 -> replace0_1_0 in the cache */

/* replace102_0_0_0_1 -> replace101_0_0_0_1 in the cache */
/* replace102_0_0_0 -> replace101_0_0_0 in the cache */

/* replace102_0_0_1_0 -> search56_2 in the cache */

/* replace102_0_0_1_1 -> replace101_0_0_0_1 in the cache */
/* replace102_0_0_1 -> replace101_0_0_1 in the cache */
/* replace102_0_0 -> replace101_0_0 in the cache */

/* replace102_0_1 -> replace101_0_1 in the cache */
/* replace102_0 -> replace101_0 in the cache */

/* replace102_1_0 -> search101_0_0 in the cache */

/* replace102_1_1_0 -> replace0_1_0 in the cache */

/* replace102_1_1_1 -> search56_2 in the cache */
/* replace102_1_1 -> replace98_1_1 in the cache */
static const nir_search_expression replace102_1 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 1,
   nir_op_ushr,
   { &search101_0_0.value, &replace98_1_1.value },
   NULL,
};

/* replace102_2 -> replace101_2 in the cache */
static const nir_search_expression replace102 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 4,
   nir_op_bcsel,
   { &replace101_0.value, &replace102_1.value, &replace101_2.value },
   NULL,
};

   /* search103_0_0 -> search101_0_0 in the cache */

/* search103_0_1 -> search2_1 in the cache */
static const nir_search_expression search103_0 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_ishr,
   { &search101_0_0.value, &search2_1.value },
   NULL,
};

/* search103_1 -> search97_1 in the cache */
static const nir_search_expression search103 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_ishr,
   { &search103_0.value, &search97_1.value },
   NULL,
};

   /* replace103_0 -> search101_0_0 in the cache */

/* replace103_1_0_0_0 -> replace0_1_0 in the cache */

/* replace103_1_0_0_1 -> replace101_0_0_0_1 in the cache */
static const nir_search_expression replace103_1_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   2, 1,
   nir_op_iand,
   { &replace0_1_0.value, &replace101_0_0_0_1.value },
   NULL,
};

/* replace103_1_0_1_0 -> search56_2 in the cache */

/* replace103_1_0_1_1 -> replace101_0_0_0_1 in the cache */
static const nir_search_expression replace103_1_0_1 = {
   { nir_search_value_expression, 32 },
   false,
   3, 1,
   nir_op_iand,
   { &search56_2.value, &replace101_0_0_0_1.value },
   NULL,
};
static const nir_search_expression replace103_1_0 = {
   { nir_search_value_expression, 32 },
   false,
   1, 3,
   nir_op_iadd,
   { &replace103_1_0_0.value, &replace103_1_0_1.value },
   NULL,
};

static const nir_search_constant replace103_1_1 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { 0xf /* 15 */ },
};
static const nir_search_expression replace103_1 = {
   { nir_search_value_expression, 32 },
   false,
   0, 4,
   nir_op_imin,
   { &replace103_1_0.value, &replace103_1_1.value },
   NULL,
};
static const nir_search_expression replace103 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 4,
   nir_op_ishr,
   { &search101_0_0.value, &replace103_1.value },
   NULL,
};

   /* search104_0_0 -> search0_0 in the cache */

/* search104_0_1 -> search2_1 in the cache */
static const nir_search_expression search104_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_ishl,
   { &search0_0.value, &search2_1.value },
   NULL,
};

/* search104_1 -> search97_1 in the cache */
static const nir_search_expression search104 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_ishl,
   { &search104_0.value, &search97_1.value },
   NULL,
};

   /* replace104_0_0_0_0 -> replace0_1_0 in the cache */

static const nir_search_constant replace104_0_0_0_1 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { 0xffffffff /* 4294967295 */ },
};
static const nir_search_expression replace104_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   1, 1,
   nir_op_iand,
   { &replace0_1_0.value, &replace104_0_0_0_1.value },
   NULL,
};

/* replace104_0_0_1_0 -> search56_2 in the cache */

/* replace104_0_0_1_1 -> replace104_0_0_0_1 in the cache */
static const nir_search_expression replace104_0_0_1 = {
   { nir_search_value_expression, 32 },
   false,
   2, 1,
   nir_op_iand,
   { &search56_2.value, &replace104_0_0_0_1.value },
   NULL,
};
static const nir_search_expression replace104_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   0, 3,
   nir_op_iadd,
   { &replace104_0_0_0.value, &replace104_0_0_1.value },
   NULL,
};

static const nir_search_constant replace104_0_1 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { 0x20 /* 32 */ },
};
static const nir_search_expression replace104_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 3,
   nir_op_ult,
   { &replace104_0_0.value, &replace104_0_1.value },
   NULL,
};

/* replace104_1_0 -> search0_0 in the cache */

/* replace104_1_1_0 -> replace0_1_0 in the cache */

/* replace104_1_1_1 -> search56_2 in the cache */
/* replace104_1_1 -> replace98_1_1 in the cache */
static const nir_search_expression replace104_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_op_ishl,
   { &search0_0.value, &replace98_1_1.value },
   NULL,
};

/* replace104_2 -> search26_1 in the cache */
static const nir_search_expression replace104 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 4,
   nir_op_bcsel,
   { &replace104_0.value, &replace104_1.value, &search26_1.value },
   NULL,
};

   /* search105_0_0 -> search0_0 in the cache */

/* search105_0_1 -> search2_1 in the cache */
static const nir_search_expression search105_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_ushr,
   { &search0_0.value, &search2_1.value },
   NULL,
};

/* search105_1 -> search97_1 in the cache */
static const nir_search_expression search105 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_ushr,
   { &search105_0.value, &search97_1.value },
   NULL,
};

   /* replace105_0_0_0_0 -> replace0_1_0 in the cache */

/* replace105_0_0_0_1 -> replace104_0_0_0_1 in the cache */
/* replace105_0_0_0 -> replace104_0_0_0 in the cache */

/* replace105_0_0_1_0 -> search56_2 in the cache */

/* replace105_0_0_1_1 -> replace104_0_0_0_1 in the cache */
/* replace105_0_0_1 -> replace104_0_0_1 in the cache */
/* replace105_0_0 -> replace104_0_0 in the cache */

/* replace105_0_1 -> replace104_0_1 in the cache */
/* replace105_0 -> replace104_0 in the cache */

/* replace105_1_0 -> search0_0 in the cache */

/* replace105_1_1_0 -> replace0_1_0 in the cache */

/* replace105_1_1_1 -> search56_2 in the cache */
/* replace105_1_1 -> replace98_1_1 in the cache */
static const nir_search_expression replace105_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_op_ushr,
   { &search0_0.value, &replace98_1_1.value },
   NULL,
};

/* replace105_2 -> search26_1 in the cache */
static const nir_search_expression replace105 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 4,
   nir_op_bcsel,
   { &replace104_0.value, &replace105_1.value, &search26_1.value },
   NULL,
};

   /* search106_0_0 -> search0_0 in the cache */

/* search106_0_1 -> search2_1 in the cache */
static const nir_search_expression search106_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_ishr,
   { &search0_0.value, &search2_1.value },
   NULL,
};

/* search106_1 -> search97_1 in the cache */
static const nir_search_expression search106 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_ishr,
   { &search106_0.value, &search97_1.value },
   NULL,
};

   /* replace106_0 -> search0_0 in the cache */

/* replace106_1_0_0_0 -> replace0_1_0 in the cache */

/* replace106_1_0_0_1 -> replace104_0_0_0_1 in the cache */
static const nir_search_expression replace106_1_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   2, 1,
   nir_op_iand,
   { &replace0_1_0.value, &replace104_0_0_0_1.value },
   NULL,
};

/* replace106_1_0_1_0 -> search56_2 in the cache */

/* replace106_1_0_1_1 -> replace104_0_0_0_1 in the cache */
static const nir_search_expression replace106_1_0_1 = {
   { nir_search_value_expression, 32 },
   false,
   3, 1,
   nir_op_iand,
   { &search56_2.value, &replace104_0_0_0_1.value },
   NULL,
};
static const nir_search_expression replace106_1_0 = {
   { nir_search_value_expression, 32 },
   false,
   1, 3,
   nir_op_iadd,
   { &replace106_1_0_0.value, &replace106_1_0_1.value },
   NULL,
};

static const nir_search_constant replace106_1_1 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { 0x1f /* 31 */ },
};
static const nir_search_expression replace106_1 = {
   { nir_search_value_expression, 32 },
   false,
   0, 4,
   nir_op_imin,
   { &replace106_1_0.value, &replace106_1_1.value },
   NULL,
};
static const nir_search_expression replace106 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 4,
   nir_op_ishr,
   { &search0_0.value, &replace106_1.value },
   NULL,
};

   /* search107_0_0 -> search57_0 in the cache */

/* search107_0_1 -> search2_1 in the cache */
static const nir_search_expression search107_0 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_ishl,
   { &search57_0.value, &search2_1.value },
   NULL,
};

/* search107_1 -> search97_1 in the cache */
static const nir_search_expression search107 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_ishl,
   { &search107_0.value, &search97_1.value },
   NULL,
};

   /* replace107_0_0_0_0 -> replace0_1_0 in the cache */

static const nir_search_constant replace107_0_0_0_1 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { 0xffffffffffffffff /* 18446744073709551615 */ },
};
static const nir_search_expression replace107_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   1, 1,
   nir_op_iand,
   { &replace0_1_0.value, &replace107_0_0_0_1.value },
   NULL,
};

/* replace107_0_0_1_0 -> search56_2 in the cache */

/* replace107_0_0_1_1 -> replace107_0_0_0_1 in the cache */
static const nir_search_expression replace107_0_0_1 = {
   { nir_search_value_expression, 32 },
   false,
   2, 1,
   nir_op_iand,
   { &search56_2.value, &replace107_0_0_0_1.value },
   NULL,
};
static const nir_search_expression replace107_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   0, 3,
   nir_op_iadd,
   { &replace107_0_0_0.value, &replace107_0_0_1.value },
   NULL,
};

static const nir_search_constant replace107_0_1 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { 0x40 /* 64 */ },
};
static const nir_search_expression replace107_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 3,
   nir_op_ult,
   { &replace107_0_0.value, &replace107_0_1.value },
   NULL,
};

/* replace107_1_0 -> search57_0 in the cache */

/* replace107_1_1_0 -> replace0_1_0 in the cache */

/* replace107_1_1_1 -> search56_2 in the cache */
/* replace107_1_1 -> replace98_1_1 in the cache */
static const nir_search_expression replace107_1 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 1,
   nir_op_ishl,
   { &search57_0.value, &replace98_1_1.value },
   NULL,
};

static const nir_search_constant replace107_2 = {
   { nir_search_value_constant, 64 },
   nir_type_int, { 0x0 /* 0 */ },
};
static const nir_search_expression replace107 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 4,
   nir_op_bcsel,
   { &replace107_0.value, &replace107_1.value, &replace107_2.value },
   NULL,
};

   /* search108_0_0 -> search57_0 in the cache */

/* search108_0_1 -> search2_1 in the cache */
static const nir_search_expression search108_0 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_ushr,
   { &search57_0.value, &search2_1.value },
   NULL,
};

/* search108_1 -> search97_1 in the cache */
static const nir_search_expression search108 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_ushr,
   { &search108_0.value, &search97_1.value },
   NULL,
};

   /* replace108_0_0_0_0 -> replace0_1_0 in the cache */

/* replace108_0_0_0_1 -> replace107_0_0_0_1 in the cache */
/* replace108_0_0_0 -> replace107_0_0_0 in the cache */

/* replace108_0_0_1_0 -> search56_2 in the cache */

/* replace108_0_0_1_1 -> replace107_0_0_0_1 in the cache */
/* replace108_0_0_1 -> replace107_0_0_1 in the cache */
/* replace108_0_0 -> replace107_0_0 in the cache */

/* replace108_0_1 -> replace107_0_1 in the cache */
/* replace108_0 -> replace107_0 in the cache */

/* replace108_1_0 -> search57_0 in the cache */

/* replace108_1_1_0 -> replace0_1_0 in the cache */

/* replace108_1_1_1 -> search56_2 in the cache */
/* replace108_1_1 -> replace98_1_1 in the cache */
static const nir_search_expression replace108_1 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 1,
   nir_op_ushr,
   { &search57_0.value, &replace98_1_1.value },
   NULL,
};

/* replace108_2 -> replace107_2 in the cache */
static const nir_search_expression replace108 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 4,
   nir_op_bcsel,
   { &replace107_0.value, &replace108_1.value, &replace107_2.value },
   NULL,
};

   /* search109_0_0 -> search57_0 in the cache */

/* search109_0_1 -> search2_1 in the cache */
static const nir_search_expression search109_0 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_ishr,
   { &search57_0.value, &search2_1.value },
   NULL,
};

/* search109_1 -> search97_1 in the cache */
static const nir_search_expression search109 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_ishr,
   { &search109_0.value, &search97_1.value },
   NULL,
};

   /* replace109_0 -> search57_0 in the cache */

/* replace109_1_0_0_0 -> replace0_1_0 in the cache */

/* replace109_1_0_0_1 -> replace107_0_0_0_1 in the cache */
static const nir_search_expression replace109_1_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   2, 1,
   nir_op_iand,
   { &replace0_1_0.value, &replace107_0_0_0_1.value },
   NULL,
};

/* replace109_1_0_1_0 -> search56_2 in the cache */

/* replace109_1_0_1_1 -> replace107_0_0_0_1 in the cache */
static const nir_search_expression replace109_1_0_1 = {
   { nir_search_value_expression, 32 },
   false,
   3, 1,
   nir_op_iand,
   { &search56_2.value, &replace107_0_0_0_1.value },
   NULL,
};
static const nir_search_expression replace109_1_0 = {
   { nir_search_value_expression, 32 },
   false,
   1, 3,
   nir_op_iadd,
   { &replace109_1_0_0.value, &replace109_1_0_1.value },
   NULL,
};

static const nir_search_constant replace109_1_1 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { 0x3f /* 63 */ },
};
static const nir_search_expression replace109_1 = {
   { nir_search_value_expression, 32 },
   false,
   0, 4,
   nir_op_imin,
   { &replace109_1_0.value, &replace109_1_1.value },
   NULL,
};
static const nir_search_expression replace109 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 4,
   nir_op_ishr,
   { &search57_0.value, &replace109_1.value },
   NULL,
};

   /* search110_0_0 -> search14_0 in the cache */

/* search110_0_1 -> search97_0_1 in the cache */
static const nir_search_expression search110_0 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_iadd,
   { &search14_0.value, &search97_0_1.value },
   NULL,
};

/* search110_1 -> search97_1 in the cache */
static const nir_search_expression search110 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 1,
   nir_op_ishl,
   { &search110_0.value, &search97_1.value },
   NULL,
};

   /* replace110_0_0 -> search14_0 in the cache */

/* replace110_0_1 -> search56_2 in the cache */
static const nir_search_expression replace110_0 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_ishl,
   { &search14_0.value, &search56_2.value },
   NULL,
};

/* replace110_1_0 -> replace14_1_0 in the cache */

/* replace110_1_1 -> search56_2 in the cache */
/* replace110_1 -> replace97_1 in the cache */
static const nir_search_expression replace110 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_iadd,
   { &replace110_0.value, &replace97_1.value },
   NULL,
};

   /* search111_0_0 -> search14_0 in the cache */

/* search111_0_1 -> replace14_1_0 in the cache */
static const nir_search_expression search111_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search14_0.value, &replace14_1_0.value },
   NULL,
};
static const nir_search_expression search111 = {
   { nir_search_value_expression, 1 },
   true,
   -1, 0,
   nir_op_inot,
   { &search111_0.value },
   NULL,
};

   /* replace111_0 -> search14_0 in the cache */

/* replace111_1 -> replace14_1_0 in the cache */
static const nir_search_expression replace111 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search14_0.value, &replace14_1_0.value },
   NULL,
};

   /* search112_0_0 -> search14_0 in the cache */

/* search112_0_1 -> replace14_1_0 in the cache */
/* search112_0 -> replace111 in the cache */
static const nir_search_expression search112 = {
   { nir_search_value_expression, 1 },
   true,
   -1, 0,
   nir_op_inot,
   { &replace111.value },
   NULL,
};

   /* replace112_0 -> search14_0 in the cache */

/* replace112_1 -> replace14_1_0 in the cache */
/* replace112 -> search111_0 in the cache */

   /* search113_0_0 -> search14_0 in the cache */

/* search113_0_1 -> replace14_1_0 in the cache */
static const nir_search_expression search113_0 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_feq,
   { &search14_0.value, &replace14_1_0.value },
   NULL,
};
static const nir_search_expression search113 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_inot,
   { &search113_0.value },
   NULL,
};

   /* replace113_0 -> search14_0 in the cache */

/* replace113_1 -> replace14_1_0 in the cache */
static const nir_search_expression replace113 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_fne,
   { &search14_0.value, &replace14_1_0.value },
   NULL,
};

   /* search114_0_0 -> search14_0 in the cache */

/* search114_0_1 -> replace14_1_0 in the cache */
/* search114_0 -> replace113 in the cache */
static const nir_search_expression search114 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_inot,
   { &replace113.value },
   NULL,
};

   /* replace114_0 -> search14_0 in the cache */

/* replace114_1 -> replace14_1_0 in the cache */
/* replace114 -> search113_0 in the cache */

   /* search115_0_0 -> search14_0 in the cache */

/* search115_0_1 -> replace14_1_0 in the cache */
static const nir_search_expression search115_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search14_0.value, &replace14_1_0.value },
   NULL,
};
static const nir_search_expression search115 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_inot,
   { &search115_0.value },
   NULL,
};

   /* replace115_0 -> search14_0 in the cache */

/* replace115_1 -> replace14_1_0 in the cache */
static const nir_search_expression replace115 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search14_0.value, &replace14_1_0.value },
   NULL,
};

   /* search116_0_0 -> search14_0 in the cache */

/* search116_0_1 -> replace14_1_0 in the cache */
static const nir_search_expression search116_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search14_0.value, &replace14_1_0.value },
   NULL,
};
static const nir_search_expression search116 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_inot,
   { &search116_0.value },
   NULL,
};

   /* replace116_0 -> search14_0 in the cache */

/* replace116_1 -> replace14_1_0 in the cache */
static const nir_search_expression replace116 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search14_0.value, &replace14_1_0.value },
   NULL,
};

   /* search117_0_0 -> search14_0 in the cache */

/* search117_0_1 -> replace14_1_0 in the cache */
/* search117_0 -> replace115 in the cache */
static const nir_search_expression search117 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_inot,
   { &replace115.value },
   NULL,
};

   /* replace117_0 -> search14_0 in the cache */

/* replace117_1 -> replace14_1_0 in the cache */
/* replace117 -> search115_0 in the cache */

   /* search118_0_0 -> search14_0 in the cache */

/* search118_0_1 -> replace14_1_0 in the cache */
/* search118_0 -> replace116 in the cache */
static const nir_search_expression search118 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_inot,
   { &replace116.value },
   NULL,
};

   /* replace118_0 -> search14_0 in the cache */

/* replace118_1 -> replace14_1_0 in the cache */
/* replace118 -> search116_0 in the cache */

   /* search119_0_0 -> search14_0 in the cache */

/* search119_0_1 -> replace14_1_0 in the cache */
static const nir_search_expression search119_0 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &search14_0.value, &replace14_1_0.value },
   NULL,
};
static const nir_search_expression search119 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_inot,
   { &search119_0.value },
   NULL,
};

   /* replace119_0 -> search14_0 in the cache */

/* replace119_1 -> replace14_1_0 in the cache */
static const nir_search_expression replace119 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &search14_0.value, &replace14_1_0.value },
   NULL,
};

   /* search120_0_0 -> search14_0 in the cache */

/* search120_0_1 -> replace14_1_0 in the cache */
/* search120_0 -> replace119 in the cache */
static const nir_search_expression search120 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_inot,
   { &replace119.value },
   NULL,
};

   /* replace120_0 -> search14_0 in the cache */

/* replace120_1 -> replace14_1_0 in the cache */
/* replace120 -> search119_0 in the cache */

   /* search121_0_0 -> search14_0 in the cache */

/* search121_0_1 -> replace14_1_0 in the cache */
static const nir_search_expression search121_0 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_feq,
   { &search14_0.value, &replace14_1_0.value },
   NULL,
};

/* search121_1_0 -> search14_0 in the cache */

/* search121_1_1 -> replace14_1_0 in the cache */
static const nir_search_expression search121_1 = {
   { nir_search_value_expression, 1 },
   false,
   2, 1,
   nir_op_fne,
   { &search14_0.value, &replace14_1_0.value },
   NULL,
};
static const nir_search_expression search121 = {
   { nir_search_value_expression, 1 },
   false,
   0, 3,
   nir_op_iand,
   { &search121_0.value, &search121_1.value },
   NULL,
};

   static const nir_search_constant replace121 = {
   { nir_search_value_constant, 1 },
   nir_type_bool, { NIR_FALSE /* False */ },
};

   /* search122_0_0 -> search14_0 in the cache */

/* search122_0_1 -> replace14_1_0 in the cache */
/* search122_0 -> search111_0 in the cache */

/* search122_1_0 -> replace14_1_0 in the cache */

/* search122_1_1 -> search14_0 in the cache */
static const nir_search_expression search122_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &replace14_1_0.value, &search14_0.value },
   NULL,
};
static const nir_search_expression search122 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_iand,
   { &search111_0.value, &search122_1.value },
   NULL,
};

   /* replace122 -> replace121 in the cache */

   /* search123_0_0 -> search14_0 in the cache */

/* search123_0_1 -> replace14_1_0 in the cache */
static const nir_search_expression search123_0 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ieq,
   { &search14_0.value, &replace14_1_0.value },
   NULL,
};

/* search123_1_0 -> search14_0 in the cache */

/* search123_1_1 -> replace14_1_0 in the cache */
static const nir_search_expression search123_1 = {
   { nir_search_value_expression, 1 },
   false,
   2, 1,
   nir_op_ine,
   { &search14_0.value, &replace14_1_0.value },
   NULL,
};
static const nir_search_expression search123 = {
   { nir_search_value_expression, 1 },
   false,
   0, 3,
   nir_op_iand,
   { &search123_0.value, &search123_1.value },
   NULL,
};

   /* replace123 -> replace121 in the cache */

   /* search124_0_0 -> search14_0 in the cache */

/* search124_0_1 -> replace14_1_0 in the cache */
/* search124_0 -> search115_0 in the cache */

/* search124_1_0 -> replace14_1_0 in the cache */

/* search124_1_1 -> search14_0 in the cache */
static const nir_search_expression search124_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &replace14_1_0.value, &search14_0.value },
   NULL,
};
static const nir_search_expression search124 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_iand,
   { &search115_0.value, &search124_1.value },
   NULL,
};

   /* replace124 -> replace121 in the cache */

   /* search125_0_0 -> search14_0 in the cache */

/* search125_0_1 -> replace14_1_0 in the cache */
/* search125_0 -> search116_0 in the cache */

/* search125_1_0 -> replace14_1_0 in the cache */

/* search125_1_1 -> search14_0 in the cache */
static const nir_search_expression search125_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &replace14_1_0.value, &search14_0.value },
   NULL,
};
static const nir_search_expression search125 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_iand,
   { &search116_0.value, &search125_1.value },
   NULL,
};

   /* replace125 -> replace121 in the cache */

   /* search126_0_0 -> search14_0 in the cache */
/* search126_0 -> search34_0 in the cache */

/* search126_1_0 -> replace14_1_0 in the cache */
static const nir_search_expression search126_1 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_fneg,
   { &replace14_1_0.value },
   NULL,
};
static const nir_search_expression search126 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search34_0.value, &search126_1.value },
   NULL,
};

   /* replace126_0 -> replace14_1_0 in the cache */

/* replace126_1 -> search14_0 in the cache */
/* replace126 -> search122_1 in the cache */

   /* search127_0_0 -> search14_0 in the cache */
/* search127_0 -> search34_0 in the cache */

/* search127_1_0 -> replace14_1_0 in the cache */
/* search127_1 -> search126_1 in the cache */
static const nir_search_expression search127 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search34_0.value, &search126_1.value },
   NULL,
};

   /* replace127_0 -> replace14_1_0 in the cache */

/* replace127_1 -> search14_0 in the cache */
static const nir_search_expression replace127 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &replace14_1_0.value, &search14_0.value },
   NULL,
};

   /* search128_0_0 -> search14_0 in the cache */
/* search128_0 -> search34_0 in the cache */

/* search128_1_0 -> replace14_1_0 in the cache */
/* search128_1 -> search126_1 in the cache */
static const nir_search_expression search128 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_feq,
   { &search34_0.value, &search126_1.value },
   NULL,
};

   /* replace128_0 -> replace14_1_0 in the cache */

/* replace128_1 -> search14_0 in the cache */
static const nir_search_expression replace128 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_feq,
   { &replace14_1_0.value, &search14_0.value },
   NULL,
};

   /* search129_0_0 -> search14_0 in the cache */
/* search129_0 -> search34_0 in the cache */

/* search129_1_0 -> replace14_1_0 in the cache */
/* search129_1 -> search126_1 in the cache */
static const nir_search_expression search129 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_fne,
   { &search34_0.value, &search126_1.value },
   NULL,
};

   /* replace129_0 -> replace14_1_0 in the cache */

/* replace129_1 -> search14_0 in the cache */
static const nir_search_expression replace129 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_fne,
   { &replace14_1_0.value, &search14_0.value },
   NULL,
};

   /* search130_0_0 -> search2_0 in the cache */
/* search130_0 -> search15_0 in the cache */

/* search130_1 -> search43_1 in the cache */
static const nir_search_expression search130 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search15_0.value, &search43_1.value },
   NULL,
};

   /* replace130_0 -> search41_1 in the cache */

/* replace130_1 -> search2_0 in the cache */
static const nir_search_expression replace130 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search41_1.value, &search2_0.value },
   NULL,
};

   /* search131_0 -> search43_1 in the cache */

/* search131_1_0 -> search2_0 in the cache */
/* search131_1 -> search15_0 in the cache */
static const nir_search_expression search131 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search43_1.value, &search15_0.value },
   NULL,
};

   /* replace131_0 -> search2_0 in the cache */

/* replace131_1 -> search41_1 in the cache */
static const nir_search_expression replace131 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search2_0.value, &search41_1.value },
   NULL,
};

   /* search132_0_0 -> search2_0 in the cache */
/* search132_0 -> search15_0 in the cache */

/* search132_1 -> search43_1 in the cache */
static const nir_search_expression search132 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search15_0.value, &search43_1.value },
   NULL,
};

   /* replace132_0 -> search41_1 in the cache */

/* replace132_1 -> search2_0 in the cache */
static const nir_search_expression replace132 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search41_1.value, &search2_0.value },
   NULL,
};

   /* search133_0 -> search43_1 in the cache */

/* search133_1_0 -> search2_0 in the cache */
/* search133_1 -> search15_0 in the cache */
static const nir_search_expression search133 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search43_1.value, &search15_0.value },
   NULL,
};

   /* replace133_0 -> search2_0 in the cache */

/* replace133_1 -> search41_1 in the cache */
static const nir_search_expression replace133 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search2_0.value, &search41_1.value },
   NULL,
};

   /* search134_0_0 -> search2_0 in the cache */
/* search134_0 -> search15_0 in the cache */

/* search134_1 -> search43_1 in the cache */
static const nir_search_expression search134 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_fne,
   { &search15_0.value, &search43_1.value },
   NULL,
};

   /* replace134_0 -> search41_1 in the cache */

/* replace134_1 -> search2_0 in the cache */
static const nir_search_expression replace134 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_fne,
   { &search41_1.value, &search2_0.value },
   NULL,
};

   /* search135_0 -> search43_1 in the cache */

/* search135_1_0 -> search2_0 in the cache */
/* search135_1 -> search15_0 in the cache */
static const nir_search_expression search135 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_feq,
   { &search43_1.value, &search15_0.value },
   NULL,
};

   /* replace135_0 -> search2_0 in the cache */

/* replace135_1 -> search41_1 in the cache */
static const nir_search_expression replace135 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_feq,
   { &search2_0.value, &search41_1.value },
   NULL,
};

   /* search136_0_0 -> search14_0 in the cache */
static const nir_search_expression search136_0 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_fsat,
   { &search14_0.value },
   (is_used_once),
};

static const nir_search_variable search136_1 = {
   { nir_search_value_variable, -2 },
   1, /* b */
   true,
   nir_type_invalid,
   (is_gt_0_and_lt_1),
   {0, 1, 2, 3},
};
static const nir_search_expression search136 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search136_0.value, &search136_1.value },
   NULL,
};

   /* replace136_0 -> search14_0 in the cache */

/* replace136_1 -> replace14_1_0 in the cache */
/* replace136 -> search111_0 in the cache */

   static const nir_search_variable search137_0 = {
   { nir_search_value_variable, -2 },
   0, /* b */
   true,
   nir_type_invalid,
   (is_gt_0_and_lt_1),
   {0, 1, 2, 3},
};

static const nir_search_variable search137_1_0 = {
   { nir_search_value_variable, -2 },
   1, /* a */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search137_1 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_fsat,
   { &search137_1_0.value },
   (is_used_once),
};
static const nir_search_expression search137 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search137_0.value, &search137_1.value },
   NULL,
};

   static const nir_search_variable replace137_0 = {
   { nir_search_value_variable, -2 },
   0, /* b */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

/* replace137_1 -> search137_1_0 in the cache */
static const nir_search_expression replace137 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &replace137_0.value, &search137_1_0.value },
   NULL,
};

   /* search138_0_0 -> search14_0 in the cache */
/* search138_0 -> search136_0 in the cache */

/* search138_1 -> search136_1 in the cache */
static const nir_search_expression search138 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search136_0.value, &search136_1.value },
   NULL,
};

   /* replace138_0 -> search14_0 in the cache */

/* replace138_1 -> replace14_1_0 in the cache */
/* replace138 -> replace111 in the cache */

   /* search139_0 -> search137_0 in the cache */

/* search139_1_0 -> search137_1_0 in the cache */
/* search139_1 -> search137_1 in the cache */
static const nir_search_expression search139 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search137_0.value, &search137_1.value },
   NULL,
};

   /* replace139_0 -> replace137_0 in the cache */

/* replace139_1 -> search137_1_0 in the cache */
static const nir_search_expression replace139 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &replace137_0.value, &search137_1_0.value },
   NULL,
};

   /* search140_0_0 -> search14_0 in the cache */
/* search140_0 -> search136_0 in the cache */

/* search140_1 -> search136_1 in the cache */
static const nir_search_expression search140 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_feq,
   { &search136_0.value, &search136_1.value },
   NULL,
};

   /* replace140_0 -> search14_0 in the cache */

/* replace140_1 -> replace14_1_0 in the cache */
/* replace140 -> search113_0 in the cache */

   /* search141_0_0 -> search14_0 in the cache */
/* search141_0 -> search136_0 in the cache */

/* search141_1 -> search136_1 in the cache */
static const nir_search_expression search141 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_fne,
   { &search136_0.value, &search136_1.value },
   NULL,
};

   /* replace141_0 -> search14_0 in the cache */

/* replace141_1 -> replace14_1_0 in the cache */
/* replace141 -> replace113 in the cache */

   /* search142_0_0 -> search2_0 in the cache */
static const nir_search_expression search142_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fsat,
   { &search2_0.value },
   (is_used_once),
};

/* search142_1 -> search41_1 in the cache */
static const nir_search_expression search142 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search142_0.value, &search41_1.value },
   NULL,
};

   /* replace142_0 -> search2_0 in the cache */

/* replace142_1 -> search41_1 in the cache */
/* replace142 -> replace133 in the cache */

   /* search143_0_0 -> search2_0 in the cache */
/* search143_0 -> search142_0 in the cache */

/* search143_1 -> search41_1 in the cache */
static const nir_search_expression search143 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search142_0.value, &search41_1.value },
   NULL,
};

   /* replace143_0 -> search2_0 in the cache */

/* replace143_1 -> search41_1 in the cache */
/* replace143 -> replace131 in the cache */

   /* search144_0 -> search24_1 in the cache */

/* search144_1_0 -> search2_0 in the cache */
/* search144_1 -> search142_0 in the cache */
static const nir_search_expression search144 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search24_1.value, &search142_0.value },
   NULL,
};

   /* replace144_0 -> search24_1 in the cache */

/* replace144_1 -> search2_0 in the cache */
static const nir_search_expression replace144 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search24_1.value, &search2_0.value },
   NULL,
};

   /* search145_0 -> search24_1 in the cache */

/* search145_1_0 -> search2_0 in the cache */
/* search145_1 -> search142_0 in the cache */
static const nir_search_expression search145 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search24_1.value, &search142_0.value },
   NULL,
};

   /* replace145_0 -> search24_1 in the cache */

/* replace145_1 -> search2_0 in the cache */
static const nir_search_expression replace145 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search24_1.value, &search2_0.value },
   NULL,
};

   static const nir_search_constant search146_0 = {
   { nir_search_value_constant, 0 },
   nir_type_float, { 0x0 /* 0.0 */ },
};

/* search146_1_0 -> replace80_0 in the cache */
static const nir_search_expression search146_1 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_search_op_b2f,
   { &replace80_0.value },
   NULL,
};
static const nir_search_expression search146 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search146_0.value, &search146_1.value },
   NULL,
};

   /* replace146_0 -> replace80_0 in the cache */
static const nir_search_expression replace146 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_inot,
   { &replace80_0.value },
   NULL,
};

   /* search147_0_0_0 -> replace80_0 in the cache */
/* search147_0_0 -> search146_1 in the cache */
static const nir_search_expression search147_0 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_op_fneg,
   { &search146_1.value },
   NULL,
};

/* search147_1 -> search146_0 in the cache */
static const nir_search_expression search147 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search147_0.value, &search146_0.value },
   NULL,
};

   /* replace147_0 -> replace80_0 in the cache */
/* replace147 -> replace146 in the cache */

   /* search148_0_0_0 -> replace80_0 in the cache */
/* search148_0_0 -> search146_1 in the cache */

static const nir_search_variable search148_0_1_0 = {
   { nir_search_value_variable, 1 },
   1, /* b */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search148_0_1 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_search_op_b2f,
   { &search148_0_1_0.value },
   NULL,
};
static const nir_search_expression search148_0 = {
   { nir_search_value_expression, 0 },
   false,
   1, 1,
   nir_op_fadd,
   { &search146_1.value, &search148_0_1.value },
   NULL,
};

/* search148_1 -> search146_0 in the cache */
static const nir_search_expression search148 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_fne,
   { &search148_0.value, &search146_0.value },
   NULL,
};

   /* replace148_0 -> replace80_0 in the cache */

/* replace148_1 -> search148_0_1_0 in the cache */
static const nir_search_expression replace148 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ior,
   { &replace80_0.value, &search148_0_1_0.value },
   NULL,
};

   /* search149_0_0_0 -> replace80_0 in the cache */
/* search149_0_0 -> search146_1 in the cache */

/* search149_0_1_0 -> search148_0_1_0 in the cache */
/* search149_0_1 -> search148_0_1 in the cache */
static const nir_search_expression search149_0 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_op_fmax,
   { &search146_1.value, &search148_0_1.value },
   NULL,
};

/* search149_1 -> search146_0 in the cache */
static const nir_search_expression search149 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_fne,
   { &search149_0.value, &search146_0.value },
   NULL,
};

   /* replace149_0 -> replace80_0 in the cache */

/* replace149_1 -> search148_0_1_0 in the cache */
/* replace149 -> replace148 in the cache */

   /* search150_0_0 -> replace80_0 in the cache */

static const nir_search_constant search150_0_1 = {
   { nir_search_value_constant, 0 },
   nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
};

/* search150_0_2_0 -> search148_0_1_0 in the cache */
/* search150_0_2 -> search148_0_1 in the cache */
static const nir_search_expression search150_0 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace80_0.value, &search150_0_1.value, &search148_0_1.value },
   NULL,
};

/* search150_1 -> search146_0 in the cache */
static const nir_search_expression search150 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_fne,
   { &search150_0.value, &search146_0.value },
   NULL,
};

   /* replace150_0 -> replace80_0 in the cache */

/* replace150_1 -> search148_0_1_0 in the cache */
/* replace150 -> replace148 in the cache */

   /* search151_0_0 -> replace80_0 in the cache */
/* search151_0 -> search146_1 in the cache */

/* search151_1_0_0 -> search148_0_1_0 in the cache */
/* search151_1_0 -> search148_0_1 in the cache */
static const nir_search_expression search151_1 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_op_fneg,
   { &search148_0_1.value },
   NULL,
};
static const nir_search_expression search151 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_fne,
   { &search146_1.value, &search151_1.value },
   NULL,
};

   /* replace151_0 -> replace80_0 in the cache */

/* replace151_1 -> search148_0_1_0 in the cache */
/* replace151 -> replace148 in the cache */

   /* search152_0_0_0 -> replace80_0 in the cache */
/* search152_0_0 -> search146_1 in the cache */

/* search152_0_1_0 -> search148_0_1_0 in the cache */
/* search152_0_1 -> search148_0_1 in the cache */
static const nir_search_expression search152_0 = {
   { nir_search_value_expression, 0 },
   false,
   1, 1,
   nir_op_fmul,
   { &search146_1.value, &search148_0_1.value },
   NULL,
};

/* search152_1 -> search146_0 in the cache */
static const nir_search_expression search152 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_fne,
   { &search152_0.value, &search146_0.value },
   NULL,
};

   /* replace152_0 -> replace80_0 in the cache */

/* replace152_1 -> search148_0_1_0 in the cache */
static const nir_search_expression replace152 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_iand,
   { &replace80_0.value, &search148_0_1_0.value },
   NULL,
};

   /* search153_0_0_0 -> replace80_0 in the cache */
/* search153_0_0 -> search146_1 in the cache */

/* search153_0_1_0 -> search148_0_1_0 in the cache */
/* search153_0_1 -> search148_0_1 in the cache */
static const nir_search_expression search153_0 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_op_fmin,
   { &search146_1.value, &search148_0_1.value },
   NULL,
};

/* search153_1 -> search146_0 in the cache */
static const nir_search_expression search153 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_fne,
   { &search153_0.value, &search146_0.value },
   NULL,
};

   /* replace153_0 -> replace80_0 in the cache */

/* replace153_1 -> search148_0_1_0 in the cache */
/* replace153 -> replace152 in the cache */

   /* search154_0_0 -> replace80_0 in the cache */

/* search154_0_1_0 -> search148_0_1_0 in the cache */
/* search154_0_1 -> search148_0_1 in the cache */

/* search154_0_2 -> search146_0 in the cache */
static const nir_search_expression search154_0 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace80_0.value, &search148_0_1.value, &search146_0.value },
   NULL,
};

/* search154_1 -> search146_0 in the cache */
static const nir_search_expression search154 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_fne,
   { &search154_0.value, &search146_0.value },
   NULL,
};

   /* replace154_0 -> replace80_0 in the cache */

/* replace154_1 -> search148_0_1_0 in the cache */
/* replace154 -> replace152 in the cache */

   /* search155_0_0_0 -> replace80_0 in the cache */
/* search155_0_0 -> search146_1 in the cache */

/* search155_0_1_0_0 -> search148_0_1_0 in the cache */
/* search155_0_1_0 -> search148_0_1 in the cache */
/* search155_0_1 -> search151_1 in the cache */
static const nir_search_expression search155_0 = {
   { nir_search_value_expression, 0 },
   false,
   1, 1,
   nir_op_fadd,
   { &search146_1.value, &search151_1.value },
   NULL,
};

/* search155_1 -> search146_0 in the cache */
static const nir_search_expression search155 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_fne,
   { &search155_0.value, &search146_0.value },
   NULL,
};

   /* replace155_0 -> replace80_0 in the cache */

/* replace155_1 -> search148_0_1_0 in the cache */
static const nir_search_expression replace155 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ixor,
   { &replace80_0.value, &search148_0_1_0.value },
   NULL,
};

   /* search156_0_0 -> replace80_0 in the cache */
/* search156_0 -> search146_1 in the cache */

/* search156_1_0 -> search148_0_1_0 in the cache */
/* search156_1 -> search148_0_1 in the cache */
static const nir_search_expression search156 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_fne,
   { &search146_1.value, &search148_0_1.value },
   NULL,
};

   /* replace156_0 -> replace80_0 in the cache */

/* replace156_1 -> search148_0_1_0 in the cache */
/* replace156 -> replace155 in the cache */

   /* search157_0_0_0 -> replace80_0 in the cache */
/* search157_0_0 -> search146_1 in the cache */
/* search157_0 -> search147_0 in the cache */

/* search157_1_0_0 -> search148_0_1_0 in the cache */
/* search157_1_0 -> search148_0_1 in the cache */
/* search157_1 -> search151_1 in the cache */
static const nir_search_expression search157 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_fne,
   { &search147_0.value, &search151_1.value },
   NULL,
};

   /* replace157_0 -> replace80_0 in the cache */

/* replace157_1 -> search148_0_1_0 in the cache */
/* replace157 -> replace155 in the cache */

   /* search158_0_0_0 -> replace80_0 in the cache */
/* search158_0_0 -> search146_1 in the cache */

/* search158_0_1_0 -> search148_0_1_0 in the cache */
/* search158_0_1 -> search148_0_1 in the cache */
/* search158_0 -> search148_0 in the cache */

/* search158_1 -> search146_0 in the cache */
static const nir_search_expression search158 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_feq,
   { &search148_0.value, &search146_0.value },
   NULL,
};

   /* replace158_0_0 -> replace80_0 in the cache */

/* replace158_0_1 -> search148_0_1_0 in the cache */
/* replace158_0 -> replace148 in the cache */
static const nir_search_expression replace158 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_inot,
   { &replace148.value },
   NULL,
};

   /* search159_0_0_0 -> replace80_0 in the cache */
/* search159_0_0 -> search146_1 in the cache */

/* search159_0_1_0 -> search148_0_1_0 in the cache */
/* search159_0_1 -> search148_0_1 in the cache */
/* search159_0 -> search149_0 in the cache */

/* search159_1 -> search146_0 in the cache */
static const nir_search_expression search159 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_feq,
   { &search149_0.value, &search146_0.value },
   NULL,
};

   /* replace159_0_0 -> replace80_0 in the cache */

/* replace159_0_1 -> search148_0_1_0 in the cache */
/* replace159_0 -> replace148 in the cache */
/* replace159 -> replace158 in the cache */

   /* search160_0_0 -> replace80_0 in the cache */

/* search160_0_1 -> search150_0_1 in the cache */

/* search160_0_2_0 -> search148_0_1_0 in the cache */
/* search160_0_2 -> search148_0_1 in the cache */
/* search160_0 -> search150_0 in the cache */

/* search160_1 -> search146_0 in the cache */
static const nir_search_expression search160 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_feq,
   { &search150_0.value, &search146_0.value },
   NULL,
};

   /* replace160_0_0 -> replace80_0 in the cache */

/* replace160_0_1 -> search148_0_1_0 in the cache */
/* replace160_0 -> replace148 in the cache */
/* replace160 -> replace158 in the cache */

   /* search161_0_0 -> replace80_0 in the cache */
/* search161_0 -> search146_1 in the cache */

/* search161_1_0_0 -> search148_0_1_0 in the cache */
/* search161_1_0 -> search148_0_1 in the cache */
/* search161_1 -> search151_1 in the cache */
static const nir_search_expression search161 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_feq,
   { &search146_1.value, &search151_1.value },
   NULL,
};

   /* replace161_0_0 -> replace80_0 in the cache */

/* replace161_0_1 -> search148_0_1_0 in the cache */
/* replace161_0 -> replace148 in the cache */
/* replace161 -> replace158 in the cache */

   /* search162_0_0_0 -> replace80_0 in the cache */
/* search162_0_0 -> search146_1 in the cache */

/* search162_0_1_0 -> search148_0_1_0 in the cache */
/* search162_0_1 -> search148_0_1 in the cache */
/* search162_0 -> search152_0 in the cache */

/* search162_1 -> search146_0 in the cache */
static const nir_search_expression search162 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_feq,
   { &search152_0.value, &search146_0.value },
   NULL,
};

   /* replace162_0_0 -> replace80_0 in the cache */

/* replace162_0_1 -> search148_0_1_0 in the cache */
/* replace162_0 -> replace152 in the cache */
static const nir_search_expression replace162 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_inot,
   { &replace152.value },
   NULL,
};

   /* search163_0_0_0 -> replace80_0 in the cache */
/* search163_0_0 -> search146_1 in the cache */

/* search163_0_1_0 -> search148_0_1_0 in the cache */
/* search163_0_1 -> search148_0_1 in the cache */
/* search163_0 -> search153_0 in the cache */

/* search163_1 -> search146_0 in the cache */
static const nir_search_expression search163 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_feq,
   { &search153_0.value, &search146_0.value },
   NULL,
};

   /* replace163_0_0 -> replace80_0 in the cache */

/* replace163_0_1 -> search148_0_1_0 in the cache */
/* replace163_0 -> replace152 in the cache */
/* replace163 -> replace162 in the cache */

   /* search164_0_0 -> replace80_0 in the cache */

/* search164_0_1_0 -> search148_0_1_0 in the cache */
/* search164_0_1 -> search148_0_1 in the cache */

/* search164_0_2 -> search146_0 in the cache */
/* search164_0 -> search154_0 in the cache */

/* search164_1 -> search146_0 in the cache */
static const nir_search_expression search164 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_feq,
   { &search154_0.value, &search146_0.value },
   NULL,
};

   /* replace164_0_0 -> replace80_0 in the cache */

/* replace164_0_1 -> search148_0_1_0 in the cache */
/* replace164_0 -> replace152 in the cache */
/* replace164 -> replace162 in the cache */

   /* search165_0_0_0 -> replace80_0 in the cache */
/* search165_0_0 -> search146_1 in the cache */

/* search165_0_1_0_0 -> search148_0_1_0 in the cache */
/* search165_0_1_0 -> search148_0_1 in the cache */
/* search165_0_1 -> search151_1 in the cache */
/* search165_0 -> search155_0 in the cache */

/* search165_1 -> search146_0 in the cache */
static const nir_search_expression search165 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_feq,
   { &search155_0.value, &search146_0.value },
   NULL,
};

   /* replace165_0 -> replace80_0 in the cache */

/* replace165_1 -> search148_0_1_0 in the cache */
static const nir_search_expression replace165 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &replace80_0.value, &search148_0_1_0.value },
   NULL,
};

   /* search166_0_0 -> replace80_0 in the cache */
/* search166_0 -> search146_1 in the cache */

/* search166_1_0 -> search148_0_1_0 in the cache */
/* search166_1 -> search148_0_1 in the cache */
static const nir_search_expression search166 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_feq,
   { &search146_1.value, &search148_0_1.value },
   NULL,
};

   /* replace166_0 -> replace80_0 in the cache */

/* replace166_1 -> search148_0_1_0 in the cache */
/* replace166 -> replace165 in the cache */

   /* search167_0_0_0 -> replace80_0 in the cache */
/* search167_0_0 -> search146_1 in the cache */
/* search167_0 -> search147_0 in the cache */

/* search167_1_0_0 -> search148_0_1_0 in the cache */
/* search167_1_0 -> search148_0_1 in the cache */
/* search167_1 -> search151_1 in the cache */
static const nir_search_expression search167 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_feq,
   { &search147_0.value, &search151_1.value },
   NULL,
};

   /* replace167_0 -> replace80_0 in the cache */

/* replace167_1 -> search148_0_1_0 in the cache */
/* replace167 -> replace165 in the cache */

   /* search168_0_0_0_0 -> replace80_0 in the cache */
/* search168_0_0_0 -> search146_1 in the cache */

/* search168_0_0_1_0 -> search148_0_1_0 in the cache */
/* search168_0_0_1 -> search148_0_1 in the cache */
static const nir_search_expression search168_0_0 = {
   { nir_search_value_expression, 0 },
   false,
   0, 1,
   nir_op_fadd,
   { &search146_1.value, &search148_0_1.value },
   NULL,
};
static const nir_search_expression search168_0 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 1,
   nir_op_fneg,
   { &search168_0_0.value },
   NULL,
};

/* search168_1 -> search146_0 in the cache */
static const nir_search_expression search168 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_flt,
   { &search168_0.value, &search146_0.value },
   NULL,
};

   /* replace168_0 -> replace80_0 in the cache */

/* replace168_1 -> search148_0_1_0 in the cache */
/* replace168 -> replace148 in the cache */

   /* search169_0 -> search146_0 in the cache */

/* search169_1_0_0 -> replace80_0 in the cache */
/* search169_1_0 -> search146_1 in the cache */

/* search169_1_1_0 -> search148_0_1_0 in the cache */
/* search169_1_1 -> search148_0_1 in the cache */
/* search169_1 -> search168_0_0 in the cache */
static const nir_search_expression search169 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_flt,
   { &search146_0.value, &search168_0_0.value },
   NULL,
};

   /* replace169_0 -> replace80_0 in the cache */

/* replace169_1 -> search148_0_1_0 in the cache */
/* replace169 -> replace148 in the cache */

   /* search170_0_0_0_0 -> replace80_0 in the cache */
/* search170_0_0_0 -> search146_1 in the cache */

/* search170_0_0_1_0 -> search148_0_1_0 in the cache */
/* search170_0_0_1 -> search148_0_1 in the cache */
/* search170_0_0 -> search168_0_0 in the cache */
/* search170_0 -> search168_0 in the cache */

/* search170_1 -> search146_0 in the cache */
static const nir_search_expression search170 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_fge,
   { &search168_0.value, &search146_0.value },
   NULL,
};

   /* replace170_0_0 -> replace80_0 in the cache */

/* replace170_0_1 -> search148_0_1_0 in the cache */
/* replace170_0 -> replace148 in the cache */
/* replace170 -> replace158 in the cache */

   /* search171_0 -> search146_0 in the cache */

/* search171_1_0_0 -> replace80_0 in the cache */
/* search171_1_0 -> search146_1 in the cache */

/* search171_1_1_0 -> search148_0_1_0 in the cache */
/* search171_1_1 -> search148_0_1 in the cache */
/* search171_1 -> search168_0_0 in the cache */
static const nir_search_expression search171 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_fge,
   { &search146_0.value, &search168_0_0.value },
   NULL,
};

   /* replace171_0_0 -> replace80_0 in the cache */

/* replace171_0_1 -> search148_0_1_0 in the cache */
/* replace171_0 -> replace148 in the cache */
/* replace171 -> replace158 in the cache */

   /* search172_0 -> search2_0 in the cache */

/* search172_1_0 -> search2_0 in the cache */
/* search172_1 -> search15_0 in the cache */
static const nir_search_expression search172 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search2_0.value, &search15_0.value },
   NULL,
};

   /* replace172_0 -> search2_0 in the cache */

/* replace172_1 -> search24_1 in the cache */
/* replace172 -> replace65_0 in the cache */

   /* search173_0 -> search2_0 in the cache */

/* search173_1_0 -> search2_0 in the cache */
/* search173_1 -> search15_0 in the cache */
static const nir_search_expression search173 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search2_0.value, &search15_0.value },
   NULL,
};

   /* replace173_0 -> search2_0 in the cache */

/* replace173_1 -> search24_1 in the cache */
static const nir_search_expression replace173 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search2_0.value, &search24_1.value },
   NULL,
};

   static const nir_search_variable search174_0_0 = {
   { nir_search_value_variable, -1 },
   0, /* c */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

static const nir_search_variable search174_0_1_0_0_0 = {
   { nir_search_value_variable, 1 },
   1, /* a */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search174_0_1_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_search_op_b2f,
   { &search174_0_1_0_0_0.value },
   NULL,
};

static const nir_search_variable search174_0_1_0_1_0 = {
   { nir_search_value_variable, 1 },
   2, /* b */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search174_0_1_0_1 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_search_op_b2f,
   { &search174_0_1_0_1_0.value },
   NULL,
};
static const nir_search_expression search174_0_1_0 = {
   { nir_search_value_expression, -1 },
   false,
   0, 1,
   nir_op_fadd,
   { &search174_0_1_0_0.value, &search174_0_1_0_1.value },
   NULL,
};
static const nir_search_expression search174_0_1 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 1,
   nir_op_fneg,
   { &search174_0_1_0.value },
   NULL,
};
static const nir_search_expression search174_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 1,
   nir_op_fmin,
   { &search174_0_0.value, &search174_0_1.value },
   NULL,
};

/* search174_1 -> search24_1 in the cache */
static const nir_search_expression search174 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_flt,
   { &search174_0.value, &search24_1.value },
   NULL,
};

   /* replace174_0_0 -> search174_0_0 in the cache */

/* replace174_0_1 -> search24_1 in the cache */
static const nir_search_expression replace174_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search174_0_0.value, &search24_1.value },
   NULL,
};

/* replace174_1_0 -> search174_0_1_0_0_0 in the cache */

/* replace174_1_1 -> search174_0_1_0_1_0 in the cache */
static const nir_search_expression replace174_1 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ior,
   { &search174_0_1_0_0_0.value, &search174_0_1_0_1_0.value },
   NULL,
};
static const nir_search_expression replace174 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_ior,
   { &replace174_0.value, &replace174_1.value },
   NULL,
};

   /* search175_0_0 -> search14_0 in the cache */

/* search175_0_1 -> replace14_1_0 in the cache */
/* search175_0 -> replace49 in the cache */

/* search175_1 -> search14_0 in the cache */
static const nir_search_expression search175 = {
   { nir_search_value_expression, 1 },
   true,
   -1, 1,
   nir_op_flt,
   { &replace49.value, &search14_0.value },
   NULL,
};

   /* replace175_0 -> replace14_1_0 in the cache */

/* replace175_1 -> search47_0 in the cache */
static const nir_search_expression replace175 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &replace14_1_0.value, &search47_0.value },
   NULL,
};

   /* search176_0_0 -> search14_0 in the cache */

/* search176_0_1 -> replace14_1_0 in the cache */
/* search176_0 -> replace49 in the cache */

/* search176_1 -> search14_0 in the cache */
static const nir_search_expression search176 = {
   { nir_search_value_expression, 1 },
   true,
   -1, 1,
   nir_op_fge,
   { &replace49.value, &search14_0.value },
   NULL,
};

   /* replace176_0 -> replace14_1_0 in the cache */

/* replace176_1 -> search47_0 in the cache */
static const nir_search_expression replace176 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &replace14_1_0.value, &search47_0.value },
   NULL,
};

   /* search177_0_0 -> search14_0 in the cache */

/* search177_0_1 -> replace14_1_0 in the cache */
/* search177_0 -> search34_1 in the cache */

/* search177_1 -> search14_0 in the cache */
static const nir_search_expression search177 = {
   { nir_search_value_expression, 1 },
   true,
   0, 2,
   nir_op_feq,
   { &search34_1.value, &search14_0.value },
   NULL,
};

   /* replace177_0 -> replace14_1_0 in the cache */

/* replace177_1 -> search47_0 in the cache */
static const nir_search_expression replace177 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_feq,
   { &replace14_1_0.value, &search47_0.value },
   NULL,
};

   /* search178_0_0 -> search14_0 in the cache */

/* search178_0_1 -> replace14_1_0 in the cache */
/* search178_0 -> search34_1 in the cache */

/* search178_1 -> search14_0 in the cache */
static const nir_search_expression search178 = {
   { nir_search_value_expression, 1 },
   true,
   0, 2,
   nir_op_fne,
   { &search34_1.value, &search14_0.value },
   NULL,
};

   /* replace178_0 -> replace14_1_0 in the cache */

/* replace178_1 -> search47_0 in the cache */
static const nir_search_expression replace178 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_fne,
   { &replace14_1_0.value, &search47_0.value },
   NULL,
};

   /* search179_0_0 -> search28_0_0 in the cache */

/* search179_0_1 -> search96_0_0_1 in the cache */
static const nir_search_expression search179_0 = {
   { nir_search_value_expression, -3 },
   false,
   0, 1,
   nir_op_fadd,
   { &search28_0_0.value, &search96_0_0_1.value },
   (is_used_once),
};

/* search179_1 -> search96_0_1 in the cache */
static const nir_search_expression search179 = {
   { nir_search_value_expression, 1 },
   true,
   -1, 1,
   nir_op_flt,
   { &search179_0.value, &search96_0_1.value },
   NULL,
};

   /* replace179_0 -> search28_0_0 in the cache */

/* replace179_1_0 -> search28_1_1 in the cache */

/* replace179_1_1_0 -> search28_0_1 in the cache */
static const nir_search_expression replace179_1_1 = {
   { nir_search_value_expression, -3 },
   false,
   -1, 0,
   nir_op_fneg,
   { &search28_0_1.value },
   NULL,
};
static const nir_search_expression replace179_1 = {
   { nir_search_value_expression, -3 },
   false,
   0, 1,
   nir_op_fadd,
   { &search28_1_1.value, &replace179_1_1.value },
   NULL,
};
static const nir_search_expression replace179 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_flt,
   { &search28_0_0.value, &replace179_1.value },
   NULL,
};

   /* search180_0_0_0 -> search28_0_0 in the cache */

/* search180_0_0_1 -> search96_0_0_1 in the cache */
/* search180_0_0 -> search179_0 in the cache */
static const nir_search_expression search180_0 = {
   { nir_search_value_expression, -3 },
   false,
   -1, 1,
   nir_op_fneg,
   { &search179_0.value },
   (is_used_once),
};

/* search180_1 -> search96_0_1 in the cache */
static const nir_search_expression search180 = {
   { nir_search_value_expression, 1 },
   true,
   -1, 1,
   nir_op_flt,
   { &search180_0.value, &search96_0_1.value },
   NULL,
};

   /* replace180_0_0_0 -> search28_1_1 in the cache */

/* replace180_0_0_1 -> search28_0_1 in the cache */
static const nir_search_expression replace180_0_0 = {
   { nir_search_value_expression, -3 },
   false,
   0, 1,
   nir_op_fadd,
   { &search28_1_1.value, &search28_0_1.value },
   NULL,
};
static const nir_search_expression replace180_0 = {
   { nir_search_value_expression, -3 },
   false,
   -1, 1,
   nir_op_fneg,
   { &replace180_0_0.value },
   NULL,
};

/* replace180_1 -> search28_0_0 in the cache */
static const nir_search_expression replace180 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_flt,
   { &replace180_0.value, &search28_0_0.value },
   NULL,
};

   /* search181_0_0 -> search28_0_0 in the cache */

/* search181_0_1 -> search96_0_0_1 in the cache */
/* search181_0 -> search179_0 in the cache */

/* search181_1 -> search96_0_1 in the cache */
static const nir_search_expression search181 = {
   { nir_search_value_expression, 1 },
   true,
   -1, 1,
   nir_op_fge,
   { &search179_0.value, &search96_0_1.value },
   NULL,
};

   /* replace181_0 -> search28_0_0 in the cache */

/* replace181_1_0 -> search28_1_1 in the cache */

/* replace181_1_1_0 -> search28_0_1 in the cache */
/* replace181_1_1 -> replace179_1_1 in the cache */
/* replace181_1 -> replace179_1 in the cache */
static const nir_search_expression replace181 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_fge,
   { &search28_0_0.value, &replace179_1.value },
   NULL,
};

   /* search182_0_0_0 -> search28_0_0 in the cache */

/* search182_0_0_1 -> search96_0_0_1 in the cache */
/* search182_0_0 -> search179_0 in the cache */
/* search182_0 -> search180_0 in the cache */

/* search182_1 -> search96_0_1 in the cache */
static const nir_search_expression search182 = {
   { nir_search_value_expression, 1 },
   true,
   -1, 1,
   nir_op_fge,
   { &search180_0.value, &search96_0_1.value },
   NULL,
};

   /* replace182_0_0_0 -> search28_1_1 in the cache */

/* replace182_0_0_1 -> search28_0_1 in the cache */
/* replace182_0_0 -> replace180_0_0 in the cache */
/* replace182_0 -> replace180_0 in the cache */

/* replace182_1 -> search28_0_0 in the cache */
static const nir_search_expression replace182 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_fge,
   { &replace180_0.value, &search28_0_0.value },
   NULL,
};

   /* search183_0_0 -> search28_0_0 in the cache */

/* search183_0_1 -> search96_0_0_1 in the cache */
static const nir_search_expression search183_0 = {
   { nir_search_value_expression, -3 },
   false,
   1, 1,
   nir_op_fadd,
   { &search28_0_0.value, &search96_0_0_1.value },
   (is_used_once),
};

/* search183_1 -> search96_0_1 in the cache */
static const nir_search_expression search183 = {
   { nir_search_value_expression, 1 },
   true,
   0, 2,
   nir_op_feq,
   { &search183_0.value, &search96_0_1.value },
   NULL,
};

   /* replace183_0 -> search28_0_0 in the cache */

/* replace183_1_0 -> search28_1_1 in the cache */

/* replace183_1_1_0 -> search28_0_1 in the cache */
/* replace183_1_1 -> replace179_1_1 in the cache */
static const nir_search_expression replace183_1 = {
   { nir_search_value_expression, -3 },
   false,
   1, 1,
   nir_op_fadd,
   { &search28_1_1.value, &replace179_1_1.value },
   NULL,
};
static const nir_search_expression replace183 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_feq,
   { &search28_0_0.value, &replace183_1.value },
   NULL,
};

   /* search184_0_0_0 -> search28_0_0 in the cache */

/* search184_0_0_1 -> search96_0_0_1 in the cache */
/* search184_0_0 -> search183_0 in the cache */
static const nir_search_expression search184_0 = {
   { nir_search_value_expression, -3 },
   false,
   -1, 1,
   nir_op_fneg,
   { &search183_0.value },
   (is_used_once),
};

/* search184_1 -> search96_0_1 in the cache */
static const nir_search_expression search184 = {
   { nir_search_value_expression, 1 },
   true,
   0, 2,
   nir_op_feq,
   { &search184_0.value, &search96_0_1.value },
   NULL,
};

   /* replace184_0_0_0 -> search28_1_1 in the cache */

/* replace184_0_0_1 -> search28_0_1 in the cache */
static const nir_search_expression replace184_0_0 = {
   { nir_search_value_expression, -3 },
   false,
   1, 1,
   nir_op_fadd,
   { &search28_1_1.value, &search28_0_1.value },
   NULL,
};
static const nir_search_expression replace184_0 = {
   { nir_search_value_expression, -3 },
   false,
   -1, 1,
   nir_op_fneg,
   { &replace184_0_0.value },
   NULL,
};

/* replace184_1 -> search28_0_0 in the cache */
static const nir_search_expression replace184 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_feq,
   { &replace184_0.value, &search28_0_0.value },
   NULL,
};

   /* search185_0_0 -> search28_0_0 in the cache */

/* search185_0_1 -> search96_0_0_1 in the cache */
/* search185_0 -> search183_0 in the cache */

/* search185_1 -> search96_0_1 in the cache */
static const nir_search_expression search185 = {
   { nir_search_value_expression, 1 },
   true,
   0, 2,
   nir_op_fne,
   { &search183_0.value, &search96_0_1.value },
   NULL,
};

   /* replace185_0 -> search28_0_0 in the cache */

/* replace185_1_0 -> search28_1_1 in the cache */

/* replace185_1_1_0 -> search28_0_1 in the cache */
/* replace185_1_1 -> replace179_1_1 in the cache */
/* replace185_1 -> replace183_1 in the cache */
static const nir_search_expression replace185 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_fne,
   { &search28_0_0.value, &replace183_1.value },
   NULL,
};

   /* search186_0_0_0 -> search28_0_0 in the cache */

/* search186_0_0_1 -> search96_0_0_1 in the cache */
/* search186_0_0 -> search183_0 in the cache */
/* search186_0 -> search184_0 in the cache */

/* search186_1 -> search96_0_1 in the cache */
static const nir_search_expression search186 = {
   { nir_search_value_expression, 1 },
   true,
   0, 2,
   nir_op_fne,
   { &search184_0.value, &search96_0_1.value },
   NULL,
};

   /* replace186_0_0_0 -> search28_1_1 in the cache */

/* replace186_0_0_1 -> search28_0_1 in the cache */
/* replace186_0_0 -> replace184_0_0 in the cache */
/* replace186_0 -> replace184_0 in the cache */

/* replace186_1 -> search28_0_0 in the cache */
static const nir_search_expression replace186 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_fne,
   { &replace184_0.value, &search28_0_0.value },
   NULL,
};

   /* search187_0_0 -> search14_0 in the cache */

/* search187_0_1 -> replace14_1_0 in the cache */
/* search187_0 -> search32_1 in the cache */

/* search187_1 -> search14_0 in the cache */
static const nir_search_expression search187 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_ieq,
   { &search32_1.value, &search14_0.value },
   NULL,
};

   /* replace187_0 -> replace14_1_0 in the cache */

static const nir_search_constant replace187_1 = {
   { nir_search_value_constant, -2 },
   nir_type_int, { 0x0 /* 0 */ },
};
static const nir_search_expression replace187 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &replace14_1_0.value, &replace187_1.value },
   NULL,
};

   /* search188_0_0 -> search14_0 in the cache */

/* search188_0_1 -> replace14_1_0 in the cache */
/* search188_0 -> search32_1 in the cache */

/* search188_1 -> search14_0 in the cache */
static const nir_search_expression search188 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_ine,
   { &search32_1.value, &search14_0.value },
   NULL,
};

   /* replace188_0 -> replace14_1_0 in the cache */

/* replace188_1 -> replace187_1 in the cache */
static const nir_search_expression replace188 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &replace14_1_0.value, &replace187_1.value },
   NULL,
};

   /* search189_0_0_0_0 -> replace80_0 in the cache */
static const nir_search_expression search189_0_0_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_search_op_b2f,
   { &replace80_0.value },
   NULL,
};
static const nir_search_expression search189_0_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fneg,
   { &search189_0_0_0.value },
   NULL,
};

/* search189_0_1 -> search148_0_1_0 in the cache */
static const nir_search_expression search189_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fmin,
   { &search189_0_0.value, &search148_0_1_0.value },
   NULL,
};

static const nir_search_constant search189_1 = {
   { nir_search_value_constant, 1 },
   nir_type_float, { 0x0 /* 0.0 */ },
};
static const nir_search_expression search189 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search189_0.value, &search189_1.value },
   NULL,
};

   /* replace189_0_0 -> replace80_0 in the cache */
/* replace189_0 -> replace146 in the cache */

/* replace189_1_0 -> search148_0_1_0 in the cache */

/* replace189_1_1 -> search189_1 in the cache */
static const nir_search_expression replace189_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search148_0_1_0.value, &search189_1.value },
   NULL,
};
static const nir_search_expression replace189 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_iand,
   { &replace146.value, &replace189_1.value },
   NULL,
};

   /* search190_0_0_0_0 -> replace80_0 in the cache */
/* search190_0_0_0 -> search189_0_0_0 in the cache */
/* search190_0_0 -> search189_0_0 in the cache */

/* search190_0_1 -> search148_0_1_0 in the cache */
/* search190_0 -> search189_0 in the cache */

/* search190_1 -> search189_1 in the cache */
static const nir_search_expression search190 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_feq,
   { &search189_0.value, &search189_1.value },
   NULL,
};

   /* replace190_0_0 -> replace80_0 in the cache */
/* replace190_0 -> replace146 in the cache */

/* replace190_1_0 -> search148_0_1_0 in the cache */

/* replace190_1_1 -> search189_1 in the cache */
/* replace190_1 -> replace189_1 in the cache */
/* replace190 -> replace189 in the cache */

   /* search191_0_0 -> replace80_0 in the cache */
/* search191_0 -> search146_1 in the cache */

/* search191_1 -> search146_0 in the cache */
static const nir_search_expression search191 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_feq,
   { &search146_1.value, &search146_0.value },
   NULL,
};

   /* replace191_0 -> replace80_0 in the cache */
/* replace191 -> replace146 in the cache */

   /* search192_0_0 -> replace80_0 in the cache */
/* search192_0 -> search146_1 in the cache */

/* search192_1 -> search146_0 in the cache */
static const nir_search_expression search192 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_fne,
   { &search146_1.value, &search146_0.value },
   NULL,
};

   /* replace192 -> replace80_0 in the cache */

   /* search193_0_0 -> replace80_0 in the cache */
static const nir_search_expression search193_0 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_search_op_b2i,
   { &replace80_0.value },
   NULL,
};

static const nir_search_constant search193_1 = {
   { nir_search_value_constant, 0 },
   nir_type_int, { 0x0 /* 0 */ },
};
static const nir_search_expression search193 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &search193_0.value, &search193_1.value },
   NULL,
};

   /* replace193_0 -> replace80_0 in the cache */
/* replace193 -> replace146 in the cache */

   /* search194_0_0 -> replace80_0 in the cache */
/* search194_0 -> search193_0 in the cache */

/* search194_1 -> search193_1 in the cache */
static const nir_search_expression search194 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &search193_0.value, &search193_1.value },
   NULL,
};

   /* replace194 -> replace80_0 in the cache */

   /* search195_0_0 -> search2_0 in the cache */
/* search195_0 -> search19_0 in the cache */

/* search195_1 -> search146_0 in the cache */
static const nir_search_expression search195 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_fne,
   { &search19_0.value, &search146_0.value },
   NULL,
};

   /* replace195_0 -> search2_0 in the cache */

/* replace195_1 -> replace9 in the cache */
static const nir_search_expression replace195 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &search2_0.value, &replace9.value },
   NULL,
};

   /* search196_0_0 -> search2_0 in the cache */
/* search196_0 -> search19_0 in the cache */

/* search196_1 -> search146_0 in the cache */
static const nir_search_expression search196 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_feq,
   { &search19_0.value, &search146_0.value },
   NULL,
};

   /* replace196_0 -> search2_0 in the cache */

/* replace196_1 -> replace9 in the cache */
static const nir_search_expression replace196 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &search2_0.value, &replace9.value },
   NULL,
};

   /* search197_0_0 -> search2_0 in the cache */
/* search197_0 -> search19_0 in the cache */

/* search197_1 -> search146_0 in the cache */
static const nir_search_expression search197 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search19_0.value, &search146_0.value },
   NULL,
};

   static const nir_search_constant replace197 = {
   { nir_search_value_constant, 1 },
   nir_type_bool, { NIR_TRUE /* True */ },
};

   /* search198_0 -> search146_0 in the cache */

/* search198_1_0 -> search2_0 in the cache */
/* search198_1 -> search19_0 in the cache */
static const nir_search_expression search198 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search146_0.value, &search19_0.value },
   NULL,
};

   /* replace198_0 -> replace9 in the cache */

/* replace198_1 -> search2_0 in the cache */
static const nir_search_expression replace198 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &replace9.value, &search2_0.value },
   NULL,
};

   /* search199_0_0 -> search2_0 in the cache */
/* search199_0 -> search19_0 in the cache */

/* search199_1 -> search146_0 in the cache */
static const nir_search_expression search199 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search19_0.value, &search146_0.value },
   NULL,
};

   /* replace199 -> replace121 in the cache */

   /* search200_0 -> search146_0 in the cache */

/* search200_1_0 -> search2_0 in the cache */
/* search200_1 -> search19_0 in the cache */
static const nir_search_expression search200 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search146_0.value, &search19_0.value },
   NULL,
};

   /* replace200_0 -> replace9 in the cache */

/* replace200_1 -> search2_0 in the cache */
static const nir_search_expression replace200 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &replace9.value, &search2_0.value },
   NULL,
};

   /* search201_0_0 -> search2_0 in the cache */
static const nir_search_expression search201_0 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_search_op_i2f,
   { &search2_0.value },
   NULL,
};

/* search201_1 -> search146_0 in the cache */
static const nir_search_expression search201 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_fne,
   { &search201_0.value, &search146_0.value },
   NULL,
};

   /* replace201_0 -> search2_0 in the cache */

/* replace201_1 -> replace9 in the cache */
/* replace201 -> replace195 in the cache */

   /* search202_0_0 -> search2_0 in the cache */
/* search202_0 -> search201_0 in the cache */

/* search202_1 -> search146_0 in the cache */
static const nir_search_expression search202 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_feq,
   { &search201_0.value, &search146_0.value },
   NULL,
};

   /* replace202_0 -> search2_0 in the cache */

/* replace202_1 -> replace9 in the cache */
/* replace202 -> replace196 in the cache */

   /* search203_0_0 -> search2_0 in the cache */
/* search203_0 -> search201_0 in the cache */

/* search203_1 -> search146_0 in the cache */
static const nir_search_expression search203 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search201_0.value, &search146_0.value },
   NULL,
};

   /* replace203_0 -> search2_0 in the cache */

/* replace203_1 -> replace9 in the cache */
static const nir_search_expression replace203 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search2_0.value, &replace9.value },
   NULL,
};

   /* search204_0 -> search146_0 in the cache */

/* search204_1_0 -> search2_0 in the cache */
/* search204_1 -> search201_0 in the cache */
static const nir_search_expression search204 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search146_0.value, &search201_0.value },
   NULL,
};

   /* replace204_0 -> replace9 in the cache */

/* replace204_1 -> search2_0 in the cache */
static const nir_search_expression replace204 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &replace9.value, &search2_0.value },
   NULL,
};

   /* search205_0_0 -> search2_0 in the cache */
/* search205_0 -> search201_0 in the cache */

/* search205_1 -> search146_0 in the cache */
static const nir_search_expression search205 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search201_0.value, &search146_0.value },
   NULL,
};

   /* replace205_0 -> search2_0 in the cache */

/* replace205_1 -> replace9 in the cache */
static const nir_search_expression replace205 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search2_0.value, &replace9.value },
   NULL,
};

   /* search206_0 -> search146_0 in the cache */

/* search206_1_0 -> search2_0 in the cache */
/* search206_1 -> search201_0 in the cache */
static const nir_search_expression search206 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search146_0.value, &search201_0.value },
   NULL,
};

   /* replace206_0 -> replace9 in the cache */

/* replace206_1 -> search2_0 in the cache */
static const nir_search_expression replace206 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &replace9.value, &search2_0.value },
   NULL,
};

   /* search207_0 -> search24_1 in the cache */

/* search207_1_0 -> search2_0 in the cache */
/* search207_1 -> search17_0 in the cache */
static const nir_search_expression search207 = {
   { nir_search_value_expression, 1 },
   true,
   -1, 0,
   nir_op_flt,
   { &search24_1.value, &search17_0.value },
   NULL,
};

   /* replace207_0 -> search2_0 in the cache */

/* replace207_1 -> search24_1 in the cache */
static const nir_search_expression replace207 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_fne,
   { &search2_0.value, &search24_1.value },
   NULL,
};

   /* search208_0_0_0 -> search2_0 in the cache */
/* search208_0_0 -> search17_0 in the cache */
static const nir_search_expression search208_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fneg,
   { &search17_0.value },
   NULL,
};

/* search208_1 -> search24_1 in the cache */
static const nir_search_expression search208 = {
   { nir_search_value_expression, 1 },
   true,
   -1, 0,
   nir_op_flt,
   { &search208_0.value, &search24_1.value },
   NULL,
};

   /* replace208_0 -> search2_0 in the cache */

/* replace208_1 -> search24_1 in the cache */
/* replace208 -> replace207 in the cache */

   /* search209_0 -> search24_1 in the cache */

/* search209_1_0 -> search2_0 in the cache */
/* search209_1 -> search17_0 in the cache */
static const nir_search_expression search209 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search24_1.value, &search17_0.value },
   NULL,
};

   /* replace209_0 -> search2_0 in the cache */

/* replace209_1 -> search24_1 in the cache */
static const nir_search_expression replace209 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_feq,
   { &search2_0.value, &search24_1.value },
   NULL,
};

   /* search210_0_0_0 -> search2_0 in the cache */
/* search210_0_0 -> search17_0 in the cache */
/* search210_0 -> search208_0 in the cache */

/* search210_1 -> search24_1 in the cache */
static const nir_search_expression search210 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search208_0.value, &search24_1.value },
   NULL,
};

   /* replace210_0 -> search2_0 in the cache */

/* replace210_1 -> search24_1 in the cache */
/* replace210 -> replace209 in the cache */

   /* search211_0_0 -> search2_0 in the cache */

/* search211_0_1 -> search24_1 in the cache */
/* search211_0 -> replace173 in the cache */

/* search211_1_0 -> search41_1 in the cache */

/* search211_1_1 -> search2_0 in the cache */
/* search211_1 -> replace132 in the cache */
static const nir_search_expression search211 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_iand,
   { &replace173.value, &replace132.value },
   NULL,
};

   /* replace211_0 -> search2_0 in the cache */

/* replace211_1_0 -> search2_0 in the cache */
/* replace211_1 -> search36_0 in the cache */
static const nir_search_expression replace211 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_feq,
   { &search2_0.value, &search36_0.value },
   NULL,
};

   /* search212_0_0 -> search2_0 in the cache */

/* search212_0_1 -> search24_1 in the cache */
/* search212_0 -> replace65_0 in the cache */

/* search212_1_0 -> search41_1 in the cache */

/* search212_1_1 -> search2_0 in the cache */
/* search212_1 -> replace130 in the cache */
static const nir_search_expression search212 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ior,
   { &replace65_0.value, &replace130.value },
   NULL,
};

   /* replace212_0 -> search2_0 in the cache */

/* replace212_1_0 -> search2_0 in the cache */
/* replace212_1 -> search36_0 in the cache */
static const nir_search_expression replace212 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_fne,
   { &search2_0.value, &search36_0.value },
   NULL,
};

   /* search213_0_0 -> replace80_0 in the cache */
static const nir_search_expression search213_0 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_search_op_b2f,
   { &replace80_0.value },
   (is_used_once),
};

/* search213_1_0 -> search148_0_1_0 in the cache */
/* search213_1 -> search148_0_1 in the cache */
static const nir_search_expression search213 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_op_fmax,
   { &search213_0.value, &search148_0_1.value },
   NULL,
};

   /* replace213_0_0 -> replace80_0 in the cache */

/* replace213_0_1 -> search148_0_1_0 in the cache */
/* replace213_0 -> replace148 in the cache */
static const nir_search_expression replace213 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 1,
   nir_search_op_b2f,
   { &replace148.value },
   NULL,
};

   /* search214_0_0_0 -> replace80_0 in the cache */
/* search214_0_0 -> search213_0 in the cache */
static const nir_search_expression search214_0 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_op_fneg,
   { &search213_0.value },
   (is_used_once),
};

/* search214_1_0_0 -> search148_0_1_0 in the cache */
/* search214_1_0 -> search148_0_1 in the cache */
/* search214_1 -> search151_1 in the cache */
static const nir_search_expression search214 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_op_fmax,
   { &search214_0.value, &search151_1.value },
   NULL,
};

   /* replace214_0_0_0 -> replace80_0 in the cache */

/* replace214_0_0_1 -> search148_0_1_0 in the cache */
/* replace214_0_0 -> replace148 in the cache */
/* replace214_0 -> replace213 in the cache */
static const nir_search_expression replace214 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 1,
   nir_op_fneg,
   { &replace213.value },
   NULL,
};

   /* search215_0_0 -> replace80_0 in the cache */
/* search215_0 -> search213_0 in the cache */

/* search215_1_0 -> search148_0_1_0 in the cache */
/* search215_1 -> search148_0_1 in the cache */
static const nir_search_expression search215 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_op_fmin,
   { &search213_0.value, &search148_0_1.value },
   NULL,
};

   /* replace215_0_0 -> replace80_0 in the cache */

/* replace215_0_1 -> search148_0_1_0 in the cache */
/* replace215_0 -> replace152 in the cache */
static const nir_search_expression replace215 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 1,
   nir_search_op_b2f,
   { &replace152.value },
   NULL,
};

   /* search216_0_0_0 -> replace80_0 in the cache */
/* search216_0_0 -> search213_0 in the cache */
/* search216_0 -> search214_0 in the cache */

/* search216_1_0_0 -> search148_0_1_0 in the cache */
/* search216_1_0 -> search148_0_1 in the cache */
/* search216_1 -> search151_1 in the cache */
static const nir_search_expression search216 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_op_fmin,
   { &search214_0.value, &search151_1.value },
   NULL,
};

   /* replace216_0_0_0 -> replace80_0 in the cache */

/* replace216_0_0_1 -> search148_0_1_0 in the cache */
/* replace216_0_0 -> replace152 in the cache */
/* replace216_0 -> replace215 in the cache */
static const nir_search_expression replace216 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 1,
   nir_op_fneg,
   { &replace215.value },
   NULL,
};

   /* search217_0_0 -> replace80_0 in the cache */
static const nir_search_expression search217_0 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_search_op_b2f,
   { &replace80_0.value },
   NULL,
};

/* search217_1 -> search97_0_1 in the cache */
static const nir_search_expression search217 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_fmin,
   { &search217_0.value, &search97_0_1.value },
   NULL,
};

   /* replace217_0 -> replace80_0 in the cache */

/* replace217_1_0 -> replace14_1_0 in the cache */

/* replace217_1_1 -> search49_0 in the cache */
static const nir_search_expression replace217_1 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_fmin,
   { &replace14_1_0.value, &search49_0.value },
   NULL,
};

/* replace217_2_0 -> replace14_1_0 in the cache */

/* replace217_2_1 -> search47_0 in the cache */
static const nir_search_expression replace217_2 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_fmin,
   { &replace14_1_0.value, &search47_0.value },
   NULL,
};
static const nir_search_expression replace217 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace80_0.value, &replace217_1.value, &replace217_2.value },
   NULL,
};

   /* search218_0_0 -> search14_0 in the cache */

/* search218_0_1_0 -> replace14_1_0 in the cache */
/* search218_0_1 -> search126_1 in the cache */
static const nir_search_expression search218_0 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_fadd,
   { &search14_0.value, &search126_1.value },
   (is_used_once),
};

/* search218_1 -> search47_0 in the cache */
static const nir_search_expression search218 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_flt,
   { &search218_0.value, &search47_0.value },
   NULL,
};

   /* replace218_0 -> search14_0 in the cache */

/* replace218_1 -> replace14_1_0 in the cache */
/* replace218 -> search111_0 in the cache */

   /* search219_0_0_0 -> search2_0 in the cache */
/* search219_0_0 -> search17_0 in the cache */
/* search219_0 -> search208_0 in the cache */

/* search219_1 -> search24_1 in the cache */
/* search219 -> search210 in the cache */

   /* replace219_0 -> search2_0 in the cache */

/* replace219_1 -> search24_1 in the cache */
/* replace219 -> replace209 in the cache */

   /* search220_0_0 -> replace137_0 in the cache */

/* search220_0_1 -> search137_1_0 in the cache */
/* search220_0 -> replace137 in the cache */

/* search220_1 -> replace137_0 in the cache */

/* search220_2 -> search137_1_0 in the cache */
static const nir_search_expression search220 = {
   { nir_search_value_expression, -2 },
   true,
   -1, 0,
   nir_op_bcsel,
   { &replace137.value, &replace137_0.value, &search137_1_0.value },
   NULL,
};

   /* replace220_0 -> search137_1_0 in the cache */

/* replace220_1 -> replace137_0 in the cache */
static const nir_search_expression replace220 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_fmin,
   { &search137_1_0.value, &replace137_0.value },
   NULL,
};

   /* search221_0_0 -> search14_0 in the cache */

/* search221_0_1 -> replace14_1_0 in the cache */
/* search221_0 -> search111_0 in the cache */

/* search221_1 -> replace14_1_0 in the cache */

/* search221_2 -> search14_0 in the cache */
static const nir_search_expression search221 = {
   { nir_search_value_expression, -2 },
   true,
   -1, 0,
   nir_op_bcsel,
   { &search111_0.value, &replace14_1_0.value, &search14_0.value },
   NULL,
};

   /* replace221_0 -> search14_0 in the cache */

/* replace221_1 -> replace14_1_0 in the cache */
static const nir_search_expression replace221 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_fmax,
   { &search14_0.value, &replace14_1_0.value },
   NULL,
};

   /* search222_0_0 -> search14_0 in the cache */

/* search222_0_1 -> replace14_1_0 in the cache */
/* search222_0 -> replace111 in the cache */

/* search222_1 -> replace14_1_0 in the cache */

/* search222_2 -> search14_0 in the cache */
static const nir_search_expression search222 = {
   { nir_search_value_expression, -2 },
   true,
   -1, 0,
   nir_op_bcsel,
   { &replace111.value, &replace14_1_0.value, &search14_0.value },
   NULL,
};

   /* replace222_0 -> search14_0 in the cache */

/* replace222_1 -> replace14_1_0 in the cache */
static const nir_search_expression replace222 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_fmin,
   { &search14_0.value, &replace14_1_0.value },
   NULL,
};

   /* search223_0_0 -> replace137_0 in the cache */

/* search223_0_1 -> search137_1_0 in the cache */
/* search223_0 -> replace139 in the cache */

/* search223_1 -> replace137_0 in the cache */

/* search223_2 -> search137_1_0 in the cache */
static const nir_search_expression search223 = {
   { nir_search_value_expression, -2 },
   true,
   -1, 0,
   nir_op_bcsel,
   { &replace139.value, &replace137_0.value, &search137_1_0.value },
   NULL,
};

   /* replace223_0 -> search137_1_0 in the cache */

/* replace223_1 -> replace137_0 in the cache */
static const nir_search_expression replace223 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_fmax,
   { &search137_1_0.value, &replace137_0.value },
   NULL,
};

   /* search224_0_0 -> search2_0 in the cache */
static const nir_search_expression search224_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_search_op_i2b,
   { &search2_0.value },
   NULL,
};

/* search224_1 -> search28_0_1 in the cache */

/* search224_2 -> search28_1_1 in the cache */
static const nir_search_expression search224 = {
   { nir_search_value_expression, -3 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &search224_0.value, &search28_0_1.value, &search28_1_1.value },
   NULL,
};

   /* replace224_0_0 -> search2_0 in the cache */

/* replace224_0_1 -> replace9 in the cache */
/* replace224_0 -> replace195 in the cache */

/* replace224_1 -> search28_0_1 in the cache */

/* replace224_2 -> search28_1_1 in the cache */
static const nir_search_expression replace224 = {
   { nir_search_value_expression, -3 },
   false,
   -1, 1,
   nir_op_bcsel,
   { &replace195.value, &search28_0_1.value, &search28_1_1.value },
   NULL,
};

   /* search225_0_0 -> replace80_0 in the cache */
/* search225_0 -> replace146 in the cache */

/* search225_1 -> search28_0_1 in the cache */

/* search225_2 -> search28_1_1 in the cache */
static const nir_search_expression search225 = {
   { nir_search_value_expression, -3 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace146.value, &search28_0_1.value, &search28_1_1.value },
   NULL,
};

   /* replace225_0 -> replace80_0 in the cache */

/* replace225_1 -> search28_1_1 in the cache */

/* replace225_2 -> search28_0_1 in the cache */
static const nir_search_expression replace225 = {
   { nir_search_value_expression, -3 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace80_0.value, &search28_1_1.value, &search28_0_1.value },
   NULL,
};

   /* search226_0 -> replace80_0 in the cache */

/* search226_1_0 -> replace80_0 in the cache */

/* search226_1_1 -> search62_0_1 in the cache */

/* search226_1_2 -> search62_1_1 in the cache */
static const nir_search_expression search226_1 = {
   { nir_search_value_expression, -4 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace80_0.value, &search62_0_1.value, &search62_1_1.value },
   NULL,
};

/* search226_2 -> search62_2 in the cache */
static const nir_search_expression search226 = {
   { nir_search_value_expression, -4 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace80_0.value, &search226_1.value, &search62_2.value },
   NULL,
};

   /* replace226_0 -> replace80_0 in the cache */

/* replace226_1 -> search62_0_1 in the cache */

/* replace226_2 -> search62_2 in the cache */
static const nir_search_expression replace226 = {
   { nir_search_value_expression, -4 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace80_0.value, &search62_0_1.value, &search62_2.value },
   NULL,
};

   /* search227_0 -> replace80_0 in the cache */

/* search227_1 -> search62_0_1 in the cache */

/* search227_2_0 -> replace80_0 in the cache */

/* search227_2_1 -> search62_1_1 in the cache */

/* search227_2_2 -> search62_2 in the cache */
static const nir_search_expression search227_2 = {
   { nir_search_value_expression, -4 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace80_0.value, &search62_1_1.value, &search62_2.value },
   NULL,
};
static const nir_search_expression search227 = {
   { nir_search_value_expression, -4 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace80_0.value, &search62_0_1.value, &search227_2.value },
   NULL,
};

   /* replace227_0 -> replace80_0 in the cache */

/* replace227_1 -> search62_0_1 in the cache */

/* replace227_2 -> search62_2 in the cache */
/* replace227 -> replace226 in the cache */

   /* search228_0 -> replace80_0 in the cache */

/* search228_1_0 -> search148_0_1_0 in the cache */

static const nir_search_variable search228_1_1 = {
   { nir_search_value_variable, -5 },
   2, /* c */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

static const nir_search_variable search228_1_2 = {
   { nir_search_value_variable, -5 },
   3, /* d */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search228_1 = {
   { nir_search_value_expression, -5 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &search148_0_1_0.value, &search228_1_1.value, &search228_1_2.value },
   NULL,
};

/* search228_2_0 -> search148_0_1_0 in the cache */

/* search228_2_1 -> search228_1_1 in the cache */

static const nir_search_variable search228_2_2 = {
   { nir_search_value_variable, -5 },
   4, /* e */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search228_2 = {
   { nir_search_value_expression, -5 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &search148_0_1_0.value, &search228_1_1.value, &search228_2_2.value },
   (is_used_once),
};
static const nir_search_expression search228 = {
   { nir_search_value_expression, -5 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace80_0.value, &search228_1.value, &search228_2.value },
   NULL,
};

   /* replace228_0 -> search148_0_1_0 in the cache */

/* replace228_1 -> search228_1_1 in the cache */

/* replace228_2_0 -> replace80_0 in the cache */

/* replace228_2_1 -> search228_1_2 in the cache */

/* replace228_2_2 -> search228_2_2 in the cache */
static const nir_search_expression replace228_2 = {
   { nir_search_value_expression, -5 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace80_0.value, &search228_1_2.value, &search228_2_2.value },
   NULL,
};
static const nir_search_expression replace228 = {
   { nir_search_value_expression, -5 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &search148_0_1_0.value, &search228_1_1.value, &replace228_2.value },
   NULL,
};

   /* search229_0 -> replace80_0 in the cache */

/* search229_1_0 -> search148_0_1_0 in the cache */

/* search229_1_1 -> search228_1_1 in the cache */

/* search229_1_2 -> search228_1_2 in the cache */
static const nir_search_expression search229_1 = {
   { nir_search_value_expression, -5 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &search148_0_1_0.value, &search228_1_1.value, &search228_1_2.value },
   (is_used_once),
};

/* search229_2_0 -> search148_0_1_0 in the cache */

/* search229_2_1 -> search228_1_1 in the cache */

/* search229_2_2 -> search228_2_2 in the cache */
static const nir_search_expression search229_2 = {
   { nir_search_value_expression, -5 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &search148_0_1_0.value, &search228_1_1.value, &search228_2_2.value },
   NULL,
};
static const nir_search_expression search229 = {
   { nir_search_value_expression, -5 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace80_0.value, &search229_1.value, &search229_2.value },
   NULL,
};

   /* replace229_0 -> search148_0_1_0 in the cache */

/* replace229_1 -> search228_1_1 in the cache */

/* replace229_2_0 -> replace80_0 in the cache */

/* replace229_2_1 -> search228_1_2 in the cache */

/* replace229_2_2 -> search228_2_2 in the cache */
/* replace229_2 -> replace228_2 in the cache */
/* replace229 -> replace228 in the cache */

   /* search230_0 -> replace80_0 in the cache */

/* search230_1_0 -> search148_0_1_0 in the cache */

/* search230_1_1 -> search62_1_1 in the cache */

/* search230_1_2 -> search62_2 in the cache */
static const nir_search_expression search230_1 = {
   { nir_search_value_expression, -4 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &search148_0_1_0.value, &search62_1_1.value, &search62_2.value },
   NULL,
};

/* search230_2_0 -> search148_0_1_0 in the cache */

static const nir_search_variable search230_2_1 = {
   { nir_search_value_variable, -4 },
   4, /* e */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

/* search230_2_2 -> search62_2 in the cache */
static const nir_search_expression search230_2 = {
   { nir_search_value_expression, -4 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &search148_0_1_0.value, &search230_2_1.value, &search62_2.value },
   (is_used_once),
};
static const nir_search_expression search230 = {
   { nir_search_value_expression, -4 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace80_0.value, &search230_1.value, &search230_2.value },
   NULL,
};

   /* replace230_0 -> search148_0_1_0 in the cache */

/* replace230_1_0 -> replace80_0 in the cache */

/* replace230_1_1 -> search62_1_1 in the cache */

/* replace230_1_2 -> search230_2_1 in the cache */
static const nir_search_expression replace230_1 = {
   { nir_search_value_expression, -4 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace80_0.value, &search62_1_1.value, &search230_2_1.value },
   NULL,
};

/* replace230_2 -> search62_2 in the cache */
static const nir_search_expression replace230 = {
   { nir_search_value_expression, -4 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &search148_0_1_0.value, &replace230_1.value, &search62_2.value },
   NULL,
};

   /* search231_0 -> replace80_0 in the cache */

/* search231_1_0 -> search148_0_1_0 in the cache */

/* search231_1_1 -> search62_1_1 in the cache */

/* search231_1_2 -> search62_2 in the cache */
static const nir_search_expression search231_1 = {
   { nir_search_value_expression, -4 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &search148_0_1_0.value, &search62_1_1.value, &search62_2.value },
   (is_used_once),
};

/* search231_2_0 -> search148_0_1_0 in the cache */

/* search231_2_1 -> search230_2_1 in the cache */

/* search231_2_2 -> search62_2 in the cache */
static const nir_search_expression search231_2 = {
   { nir_search_value_expression, -4 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &search148_0_1_0.value, &search230_2_1.value, &search62_2.value },
   NULL,
};
static const nir_search_expression search231 = {
   { nir_search_value_expression, -4 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace80_0.value, &search231_1.value, &search231_2.value },
   NULL,
};

   /* replace231_0 -> search148_0_1_0 in the cache */

/* replace231_1_0 -> replace80_0 in the cache */

/* replace231_1_1 -> search62_1_1 in the cache */

/* replace231_1_2 -> search230_2_1 in the cache */
/* replace231_1 -> replace230_1 in the cache */

/* replace231_2 -> search62_2 in the cache */
/* replace231 -> replace230 in the cache */

   /* search232_0 -> replace80_0 in the cache */

/* search232_1 -> replace197 in the cache */

/* search232_2 -> search148_0_1_0 in the cache */
static const nir_search_expression search232 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace80_0.value, &replace197.value, &search148_0_1_0.value },
   NULL,
};

   /* replace232_0 -> replace80_0 in the cache */

/* replace232_1 -> search148_0_1_0 in the cache */
/* replace232 -> replace148 in the cache */

   /* search233_0 -> replace80_0 in the cache */

/* search233_1 -> replace80_0 in the cache */

/* search233_2 -> search148_0_1_0 in the cache */
static const nir_search_expression search233 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace80_0.value, &replace80_0.value, &search148_0_1_0.value },
   NULL,
};

   /* replace233_0 -> replace80_0 in the cache */

/* replace233_1 -> search148_0_1_0 in the cache */
/* replace233 -> replace148 in the cache */

   /* search234_0 -> replace80_0 in the cache */

/* search234_1 -> search148_0_1_0 in the cache */

/* search234_2 -> replace121 in the cache */
static const nir_search_expression search234 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace80_0.value, &search148_0_1_0.value, &replace121.value },
   NULL,
};

   /* replace234_0 -> replace80_0 in the cache */

/* replace234_1 -> search148_0_1_0 in the cache */
/* replace234 -> replace152 in the cache */

   /* search235_0 -> replace80_0 in the cache */

/* search235_1 -> search148_0_1_0 in the cache */

/* search235_2 -> replace80_0 in the cache */
static const nir_search_expression search235 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace80_0.value, &search148_0_1_0.value, &replace80_0.value },
   NULL,
};

   /* replace235_0 -> replace80_0 in the cache */

/* replace235_1 -> search148_0_1_0 in the cache */
/* replace235 -> replace152 in the cache */

   /* search236_0 -> search2_0 in the cache */

/* search236_1 -> search2_0 in the cache */
static const nir_search_expression search236 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fmin,
   { &search2_0.value, &search2_0.value },
   NULL,
};

   /* replace236 -> search2_0 in the cache */

   /* search237_0 -> search2_0 in the cache */

/* search237_1 -> search2_0 in the cache */
static const nir_search_expression search237 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fmax,
   { &search2_0.value, &search2_0.value },
   NULL,
};

   /* replace237 -> search2_0 in the cache */

   /* search238_0 -> search2_0 in the cache */

/* search238_1 -> search2_0 in the cache */
static const nir_search_expression search238 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_imin,
   { &search2_0.value, &search2_0.value },
   NULL,
};

   /* replace238 -> search2_0 in the cache */

   /* search239_0 -> search2_0 in the cache */

/* search239_1 -> search2_0 in the cache */
static const nir_search_expression search239 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_imax,
   { &search2_0.value, &search2_0.value },
   NULL,
};

   /* replace239 -> search2_0 in the cache */

   /* search240_0 -> search2_0 in the cache */

/* search240_1 -> search2_0 in the cache */
static const nir_search_expression search240 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_umin,
   { &search2_0.value, &search2_0.value },
   NULL,
};

   /* replace240 -> search2_0 in the cache */

   /* search241_0 -> search2_0 in the cache */

/* search241_1 -> search2_0 in the cache */
static const nir_search_expression search241 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_umax,
   { &search2_0.value, &search2_0.value },
   NULL,
};

   /* replace241 -> search2_0 in the cache */

   /* search242_0_0 -> search14_0 in the cache */

/* search242_0_1 -> replace14_1_0 in the cache */
/* search242_0 -> replace221 in the cache */

/* search242_1 -> replace14_1_0 in the cache */
static const nir_search_expression search242 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_fmax,
   { &replace221.value, &replace14_1_0.value },
   NULL,
};

   /* replace242_0 -> search14_0 in the cache */

/* replace242_1 -> replace14_1_0 in the cache */
/* replace242 -> replace221 in the cache */

   /* search243_0_0 -> search14_0 in the cache */

/* search243_0_1 -> replace14_1_0 in the cache */
static const nir_search_expression search243_0 = {
   { nir_search_value_expression, -2 },
   false,
   1, 1,
   nir_op_umax,
   { &search14_0.value, &replace14_1_0.value },
   NULL,
};

/* search243_1 -> replace14_1_0 in the cache */
static const nir_search_expression search243 = {
   { nir_search_value_expression, -2 },
   false,
   0, 2,
   nir_op_umax,
   { &search243_0.value, &replace14_1_0.value },
   NULL,
};

   /* replace243_0 -> search14_0 in the cache */

/* replace243_1 -> replace14_1_0 in the cache */
static const nir_search_expression replace243 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_umax,
   { &search14_0.value, &replace14_1_0.value },
   NULL,
};

   /* search244_0_0 -> search14_0 in the cache */

/* search244_0_1 -> replace14_1_0 in the cache */
static const nir_search_expression search244_0 = {
   { nir_search_value_expression, -2 },
   false,
   1, 1,
   nir_op_imax,
   { &search14_0.value, &replace14_1_0.value },
   NULL,
};

/* search244_1 -> replace14_1_0 in the cache */
static const nir_search_expression search244 = {
   { nir_search_value_expression, -2 },
   false,
   0, 2,
   nir_op_imax,
   { &search244_0.value, &replace14_1_0.value },
   NULL,
};

   /* replace244_0 -> search14_0 in the cache */

/* replace244_1 -> replace14_1_0 in the cache */
static const nir_search_expression replace244 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_imax,
   { &search14_0.value, &replace14_1_0.value },
   NULL,
};

   /* search245_0_0 -> search14_0 in the cache */

/* search245_0_1 -> replace14_1_0 in the cache */
/* search245_0 -> replace222 in the cache */

/* search245_1 -> replace14_1_0 in the cache */
static const nir_search_expression search245 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_fmin,
   { &replace222.value, &replace14_1_0.value },
   NULL,
};

   /* replace245_0 -> search14_0 in the cache */

/* replace245_1 -> replace14_1_0 in the cache */
/* replace245 -> replace222 in the cache */

   /* search246_0_0 -> search14_0 in the cache */

/* search246_0_1 -> replace14_1_0 in the cache */
static const nir_search_expression search246_0 = {
   { nir_search_value_expression, -2 },
   false,
   1, 1,
   nir_op_umin,
   { &search14_0.value, &replace14_1_0.value },
   NULL,
};

/* search246_1 -> replace14_1_0 in the cache */
static const nir_search_expression search246 = {
   { nir_search_value_expression, -2 },
   false,
   0, 2,
   nir_op_umin,
   { &search246_0.value, &replace14_1_0.value },
   NULL,
};

   /* replace246_0 -> search14_0 in the cache */

/* replace246_1 -> replace14_1_0 in the cache */
static const nir_search_expression replace246 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_umin,
   { &search14_0.value, &replace14_1_0.value },
   NULL,
};

   /* search247_0_0 -> search14_0 in the cache */

/* search247_0_1 -> replace14_1_0 in the cache */
static const nir_search_expression search247_0 = {
   { nir_search_value_expression, -2 },
   false,
   1, 1,
   nir_op_imin,
   { &search14_0.value, &replace14_1_0.value },
   NULL,
};

/* search247_1 -> replace14_1_0 in the cache */
static const nir_search_expression search247 = {
   { nir_search_value_expression, -2 },
   false,
   0, 2,
   nir_op_imin,
   { &search247_0.value, &replace14_1_0.value },
   NULL,
};

   /* replace247_0 -> search14_0 in the cache */

/* replace247_1 -> replace14_1_0 in the cache */
static const nir_search_expression replace247 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_imin,
   { &search14_0.value, &replace14_1_0.value },
   NULL,
};

   /* search248_0 -> search2_0 in the cache */

/* search248_1_0 -> search2_0 in the cache */
/* search248_1 -> search15_0 in the cache */
static const nir_search_expression search248 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fmax,
   { &search2_0.value, &search15_0.value },
   NULL,
};

   /* replace248_0 -> search2_0 in the cache */
/* replace248 -> search17_0 in the cache */

   /* search249_0 -> search2_0 in the cache */

/* search249_1_0 -> search2_0 in the cache */
/* search249_1 -> search16_0 in the cache */
static const nir_search_expression search249 = {
   { nir_search_value_expression, -1 },
   false,
   0, 1,
   nir_op_imax,
   { &search2_0.value, &search16_0.value },
   NULL,
};

   /* replace249_0 -> search2_0 in the cache */
/* replace249 -> search20_0 in the cache */

   /* search250_0 -> search2_0 in the cache */

/* search250_1_0 -> search2_0 in the cache */
/* search250_1 -> search15_0 in the cache */
static const nir_search_expression search250 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fmin,
   { &search2_0.value, &search15_0.value },
   NULL,
};

   /* replace250_0_0 -> search2_0 in the cache */
/* replace250_0 -> search17_0 in the cache */
/* replace250 -> search208_0 in the cache */

   /* search251_0 -> search2_0 in the cache */

/* search251_1_0 -> search2_0 in the cache */
/* search251_1 -> search16_0 in the cache */
static const nir_search_expression search251 = {
   { nir_search_value_expression, -1 },
   false,
   0, 1,
   nir_op_imin,
   { &search2_0.value, &search16_0.value },
   NULL,
};

   /* replace251_0_0 -> search2_0 in the cache */
/* replace251_0 -> search20_0 in the cache */
static const nir_search_expression replace251 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_ineg,
   { &search20_0.value },
   NULL,
};

   /* search252_0 -> search2_0 in the cache */

/* search252_1_0_0 -> search2_0 in the cache */
/* search252_1_0 -> search17_0 in the cache */
/* search252_1 -> search208_0 in the cache */
static const nir_search_expression search252 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fmin,
   { &search2_0.value, &search208_0.value },
   NULL,
};

   /* replace252_0_0 -> search2_0 in the cache */
/* replace252_0 -> search17_0 in the cache */
/* replace252 -> search208_0 in the cache */

   /* search253_0 -> search2_0 in the cache */

/* search253_1_0_0 -> search2_0 in the cache */
/* search253_1_0 -> search20_0 in the cache */
/* search253_1 -> replace251 in the cache */
static const nir_search_expression search253 = {
   { nir_search_value_expression, -1 },
   false,
   0, 1,
   nir_op_imin,
   { &search2_0.value, &replace251.value },
   NULL,
};

   /* replace253_0_0 -> search2_0 in the cache */
/* replace253_0 -> search20_0 in the cache */
/* replace253 -> replace251 in the cache */

   /* search254_0 -> search2_0 in the cache */

/* search254_1_0 -> search2_0 in the cache */
/* search254_1 -> search17_0 in the cache */
static const nir_search_expression search254 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fmin,
   { &search2_0.value, &search17_0.value },
   NULL,
};

   /* replace254 -> search2_0 in the cache */

   /* search255_0 -> search2_0 in the cache */

/* search255_1_0 -> search2_0 in the cache */
/* search255_1 -> search20_0 in the cache */
static const nir_search_expression search255 = {
   { nir_search_value_expression, -1 },
   false,
   0, 1,
   nir_op_imin,
   { &search2_0.value, &search20_0.value },
   NULL,
};

   /* replace255 -> search2_0 in the cache */

   /* search256_0 -> search2_0 in the cache */

/* search256_1_0_0 -> search2_0 in the cache */
/* search256_1_0 -> search17_0 in the cache */
/* search256_1 -> search208_0 in the cache */
static const nir_search_expression search256 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fmax,
   { &search2_0.value, &search208_0.value },
   NULL,
};

   /* replace256 -> search2_0 in the cache */

   /* search257_0 -> search2_0 in the cache */

/* search257_1_0_0 -> search2_0 in the cache */
/* search257_1_0 -> search20_0 in the cache */
/* search257_1 -> replace251 in the cache */
static const nir_search_expression search257 = {
   { nir_search_value_expression, -1 },
   false,
   0, 1,
   nir_op_imax,
   { &search2_0.value, &replace251.value },
   NULL,
};

   /* replace257 -> search2_0 in the cache */

   /* search258_0 -> search2_0 in the cache */

/* search258_1_0 -> search2_0 in the cache */
/* search258_1 -> search17_0 in the cache */
static const nir_search_expression search258 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fmax,
   { &search2_0.value, &search17_0.value },
   NULL,
};

   /* replace258_0 -> search2_0 in the cache */
/* replace258 -> search17_0 in the cache */

   /* search259_0 -> search2_0 in the cache */

/* search259_1_0 -> search2_0 in the cache */
/* search259_1 -> search20_0 in the cache */
static const nir_search_expression search259 = {
   { nir_search_value_expression, -1 },
   false,
   0, 1,
   nir_op_imax,
   { &search2_0.value, &search20_0.value },
   NULL,
};

   /* replace259_0 -> search2_0 in the cache */
/* replace259 -> search20_0 in the cache */

   /* search260_0 -> search2_0 in the cache */

/* search260_1_0 -> search2_0 in the cache */
/* search260_1 -> search15_0 in the cache */
/* search260 -> search248 in the cache */

   /* replace260_0 -> search2_0 in the cache */
/* replace260 -> search17_0 in the cache */

   /* search261_0 -> search2_0 in the cache */

/* search261_1_0 -> search2_0 in the cache */
/* search261_1 -> search16_0 in the cache */
/* search261 -> search249 in the cache */

   /* replace261_0 -> search2_0 in the cache */
/* replace261 -> search20_0 in the cache */

   /* search262_0_0 -> search2_0 in the cache */
/* search262_0 -> search17_0 in the cache */

/* search262_1 -> search24_1 in the cache */
static const nir_search_expression search262 = {
   { nir_search_value_expression, -1 },
   true,
   -1, 0,
   nir_op_fmax,
   { &search17_0.value, &search24_1.value },
   NULL,
};

   /* replace262_0 -> search2_0 in the cache */
/* replace262 -> search17_0 in the cache */

   /* search263_0_0 -> search2_0 in the cache */

/* search263_0_1 -> search24_1 in the cache */
static const nir_search_expression search263_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fmax,
   { &search2_0.value, &search24_1.value },
   NULL,
};

/* search263_1 -> search41_1 in the cache */
static const nir_search_expression search263 = {
   { nir_search_value_expression, -1 },
   true,
   -1, 0,
   nir_op_fmin,
   { &search263_0.value, &search41_1.value },
   NULL,
};

   /* replace263_0 -> search2_0 in the cache */
/* replace263 -> search36_0 in the cache */

   /* search264_0_0 -> search2_0 in the cache */

/* search264_0_1 -> search41_1 in the cache */
static const nir_search_expression search264_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fmin,
   { &search2_0.value, &search41_1.value },
   NULL,
};

/* search264_1 -> search24_1 in the cache */
static const nir_search_expression search264 = {
   { nir_search_value_expression, -1 },
   true,
   -1, 0,
   nir_op_fmax,
   { &search264_0.value, &search24_1.value },
   NULL,
};

   /* replace264_0 -> search2_0 in the cache */
/* replace264 -> search36_0 in the cache */

   /* search265_0_0 -> search2_0 in the cache */

/* search265_0_1 -> search43_1 in the cache */
static const nir_search_expression search265_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fmax,
   { &search2_0.value, &search43_1.value },
   NULL,
};

/* search265_1 -> search24_1 in the cache */
static const nir_search_expression search265 = {
   { nir_search_value_expression, -1 },
   true,
   -1, 0,
   nir_op_fmin,
   { &search265_0.value, &search24_1.value },
   NULL,
};

   /* replace265_0_0_0 -> search2_0 in the cache */
/* replace265_0_0 -> search15_0 in the cache */
/* replace265_0 -> search36_1 in the cache */
static const nir_search_expression replace265 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fneg,
   { &search36_1.value },
   NULL,
};

   /* search266_0_0 -> search2_0 in the cache */

/* search266_0_1 -> search24_1 in the cache */
static const nir_search_expression search266_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fmin,
   { &search2_0.value, &search24_1.value },
   NULL,
};

/* search266_1 -> search43_1 in the cache */
static const nir_search_expression search266 = {
   { nir_search_value_expression, -1 },
   true,
   -1, 0,
   nir_op_fmax,
   { &search266_0.value, &search43_1.value },
   NULL,
};

   /* replace266_0_0_0 -> search2_0 in the cache */
/* replace266_0_0 -> search15_0 in the cache */
/* replace266_0 -> search36_1 in the cache */
/* replace266 -> replace265 in the cache */

   /* search267_0_0 -> search2_0 in the cache */
/* search267_0 -> search45_0 in the cache */
static const nir_search_expression search267 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fsat,
   { &search45_0.value },
   NULL,
};

   /* replace267_0_0 -> search24_1 in the cache */

/* replace267_0_1 -> search2_0 in the cache */
/* replace267_0 -> replace145 in the cache */
static const nir_search_expression replace267 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_search_op_b2f,
   { &replace145.value },
   NULL,
};

   /* search268_0_0 -> search2_0 in the cache */
static const nir_search_expression search268_0 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_search_op_b2f,
   { &search2_0.value },
   NULL,
};
static const nir_search_expression search268 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_op_fsat,
   { &search268_0.value },
   NULL,
};

   /* replace268_0 -> search2_0 in the cache */
/* replace268 -> search268_0 in the cache */

   /* search269_0 -> search2_0 in the cache */
/* search269 -> search36_0 in the cache */

   /* replace269_0_0 -> search2_0 in the cache */

/* replace269_0_1 -> search24_1 in the cache */
/* replace269_0 -> search263_0 in the cache */

/* replace269_1 -> search41_1 in the cache */
static const nir_search_expression replace269 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fmin,
   { &search263_0.value, &search41_1.value },
   NULL,
};

   /* search270_0_0 -> search2_0 in the cache */
/* search270_0 -> search36_0 in the cache */
static const nir_search_expression search270 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fsat,
   { &search36_0.value },
   NULL,
};

   /* replace270_0 -> search2_0 in the cache */
/* replace270 -> search36_0 in the cache */

   /* search271_0_0_0 -> search14_0 in the cache */

/* search271_0_0_1 -> replace14_1_0 in the cache */
static const nir_search_expression search271_0_0 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_fadd,
   { &search14_0.value, &replace14_1_0.value },
   (is_used_once),
};
static const nir_search_expression search271_0 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 1,
   nir_op_fneg,
   { &search271_0_0.value },
   (is_used_once),
};
static const nir_search_expression search271 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 1,
   nir_op_fsat,
   { &search271_0.value },
   NULL,
};

   /* replace271_0_0_0 -> search14_0 in the cache */
/* replace271_0_0 -> search34_0 in the cache */

/* replace271_0_1_0 -> replace14_1_0 in the cache */
/* replace271_0_1 -> search126_1 in the cache */
static const nir_search_expression replace271_0 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_fadd,
   { &search34_0.value, &search126_1.value },
   NULL,
};
static const nir_search_expression replace271 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 1,
   nir_op_fsat,
   { &replace271_0.value },
   NULL,
};

   /* search272_0_0_0 -> search14_0 in the cache */

/* search272_0_0_1 -> replace14_1_0 in the cache */
static const nir_search_expression search272_0_0 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_fmul,
   { &search14_0.value, &replace14_1_0.value },
   (is_used_once),
};
static const nir_search_expression search272_0 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 1,
   nir_op_fneg,
   { &search272_0_0.value },
   (is_used_once),
};
static const nir_search_expression search272 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 1,
   nir_op_fsat,
   { &search272_0.value },
   NULL,
};

   /* replace272_0_0_0 -> search14_0 in the cache */
/* replace272_0_0 -> search34_0 in the cache */

/* replace272_0_1 -> replace14_1_0 in the cache */
static const nir_search_expression replace272_0 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_fmul,
   { &search34_0.value, &replace14_1_0.value },
   NULL,
};
static const nir_search_expression replace272 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 1,
   nir_op_fsat,
   { &replace272_0.value },
   NULL,
};

   /* search273_0_0_0 -> search14_0 in the cache */

/* search273_0_0_1 -> replace14_1_0 in the cache */
/* search273_0_0 -> search272_0_0 in the cache */
static const nir_search_expression search273_0 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 1,
   nir_op_fabs,
   { &search272_0_0.value },
   (is_used_once),
};
static const nir_search_expression search273 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 1,
   nir_op_fsat,
   { &search273_0.value },
   NULL,
};

   /* replace273_0_0_0 -> search14_0 in the cache */
static const nir_search_expression replace273_0_0 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_fabs,
   { &search14_0.value },
   NULL,
};

/* replace273_0_1_0 -> replace14_1_0 in the cache */
static const nir_search_expression replace273_0_1 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_fabs,
   { &replace14_1_0.value },
   NULL,
};
static const nir_search_expression replace273_0 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_fmul,
   { &replace273_0_0.value, &replace273_0_1.value },
   NULL,
};
static const nir_search_expression replace273 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 1,
   nir_op_fsat,
   { &replace273_0.value },
   NULL,
};

   /* search274_0_0_0_0 -> search28_0_0 in the cache */

/* search274_0_0_0_1 -> search28_0_1 in the cache */
static const nir_search_expression search274_0_0_0 = {
   { nir_search_value_expression, -3 },
   false,
   -1, 0,
   nir_op_fmax,
   { &search28_0_0.value, &search28_0_1.value },
   NULL,
};

/* search274_0_0_1 -> search28_1_1 in the cache */
static const nir_search_expression search274_0_0 = {
   { nir_search_value_expression, -3 },
   false,
   -1, 0,
   nir_op_fmin,
   { &search274_0_0_0.value, &search28_1_1.value },
   NULL,
};

/* search274_0_1 -> search28_0_1 in the cache */
static const nir_search_expression search274_0 = {
   { nir_search_value_expression, -3 },
   false,
   -1, 0,
   nir_op_fmax,
   { &search274_0_0.value, &search28_0_1.value },
   NULL,
};

/* search274_1 -> search28_1_1 in the cache */
static const nir_search_expression search274 = {
   { nir_search_value_expression, -3 },
   false,
   -1, 0,
   nir_op_fmin,
   { &search274_0.value, &search28_1_1.value },
   NULL,
};

   /* replace274_0_0 -> search28_0_0 in the cache */

/* replace274_0_1 -> search28_0_1 in the cache */
/* replace274_0 -> search274_0_0_0 in the cache */

/* replace274_1 -> search28_1_1 in the cache */
/* replace274 -> search274_0_0 in the cache */

   /* search275_0_0_0_0 -> search28_0_0 in the cache */

/* search275_0_0_0_1 -> search28_0_1 in the cache */
static const nir_search_expression search275_0_0_0 = {
   { nir_search_value_expression, -3 },
   false,
   3, 1,
   nir_op_imax,
   { &search28_0_0.value, &search28_0_1.value },
   NULL,
};

/* search275_0_0_1 -> search28_1_1 in the cache */
static const nir_search_expression search275_0_0 = {
   { nir_search_value_expression, -3 },
   false,
   2, 2,
   nir_op_imin,
   { &search275_0_0_0.value, &search28_1_1.value },
   NULL,
};

/* search275_0_1 -> search28_0_1 in the cache */
static const nir_search_expression search275_0 = {
   { nir_search_value_expression, -3 },
   false,
   1, 3,
   nir_op_imax,
   { &search275_0_0.value, &search28_0_1.value },
   NULL,
};

/* search275_1 -> search28_1_1 in the cache */
static const nir_search_expression search275 = {
   { nir_search_value_expression, -3 },
   false,
   0, 4,
   nir_op_imin,
   { &search275_0.value, &search28_1_1.value },
   NULL,
};

   /* replace275_0_0 -> search28_0_0 in the cache */

/* replace275_0_1 -> search28_0_1 in the cache */
static const nir_search_expression replace275_0 = {
   { nir_search_value_expression, -3 },
   false,
   1, 1,
   nir_op_imax,
   { &search28_0_0.value, &search28_0_1.value },
   NULL,
};

/* replace275_1 -> search28_1_1 in the cache */
static const nir_search_expression replace275 = {
   { nir_search_value_expression, -3 },
   false,
   0, 2,
   nir_op_imin,
   { &replace275_0.value, &search28_1_1.value },
   NULL,
};

   /* search276_0_0_0_0 -> search28_0_0 in the cache */

/* search276_0_0_0_1 -> search28_0_1 in the cache */
static const nir_search_expression search276_0_0_0 = {
   { nir_search_value_expression, -3 },
   false,
   3, 1,
   nir_op_umax,
   { &search28_0_0.value, &search28_0_1.value },
   NULL,
};

/* search276_0_0_1 -> search28_1_1 in the cache */
static const nir_search_expression search276_0_0 = {
   { nir_search_value_expression, -3 },
   false,
   2, 2,
   nir_op_umin,
   { &search276_0_0_0.value, &search28_1_1.value },
   NULL,
};

/* search276_0_1 -> search28_0_1 in the cache */
static const nir_search_expression search276_0 = {
   { nir_search_value_expression, -3 },
   false,
   1, 3,
   nir_op_umax,
   { &search276_0_0.value, &search28_0_1.value },
   NULL,
};

/* search276_1 -> search28_1_1 in the cache */
static const nir_search_expression search276 = {
   { nir_search_value_expression, -3 },
   false,
   0, 4,
   nir_op_umin,
   { &search276_0.value, &search28_1_1.value },
   NULL,
};

   /* replace276_0_0 -> search28_0_0 in the cache */

/* replace276_0_1 -> search28_0_1 in the cache */
static const nir_search_expression replace276_0 = {
   { nir_search_value_expression, -3 },
   false,
   1, 1,
   nir_op_umax,
   { &search28_0_0.value, &search28_0_1.value },
   NULL,
};

/* replace276_1 -> search28_1_1 in the cache */
static const nir_search_expression replace276 = {
   { nir_search_value_expression, -3 },
   false,
   0, 2,
   nir_op_umin,
   { &replace276_0.value, &search28_1_1.value },
   NULL,
};

   /* search277_0_0 -> search0_0 in the cache */
static const nir_search_expression search277_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_fsat,
   { &search0_0.value },
   NULL,
};

static const nir_search_variable search277_1 = {
   { nir_search_value_variable, 32 },
   1, /* b */
   true,
   nir_type_invalid,
   (is_zero_to_one),
   {0, 1, 2, 3},
};
static const nir_search_expression search277 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_fmax,
   { &search277_0.value, &search277_1.value },
   NULL,
};

   /* replace277_0_0 -> search0_0 in the cache */

/* replace277_0_1 -> replace0_1_0 in the cache */
static const nir_search_expression replace277_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_fmax,
   { &search0_0.value, &replace0_1_0.value },
   NULL,
};
static const nir_search_expression replace277 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_fsat,
   { &replace277_0.value },
   NULL,
};

   /* search278_0_0 -> search0_0 in the cache */
/* search278_0 -> search277_0 in the cache */

/* search278_1 -> search277_1 in the cache */
static const nir_search_expression search278 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_fmin,
   { &search277_0.value, &search277_1.value },
   NULL,
};

   /* replace278_0_0 -> search0_0 in the cache */

/* replace278_0_1 -> replace0_1_0 in the cache */
static const nir_search_expression replace278_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_fmin,
   { &search0_0.value, &replace0_1_0.value },
   NULL,
};
static const nir_search_expression replace278 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_fsat,
   { &replace278_0.value },
   NULL,
};

   /* search279_0_0_0 -> search2_0 in the cache */

/* search279_0_0_1 -> replace9 in the cache */
static const nir_search_expression search279_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   1, 1,
   nir_op_imax,
   { &search2_0.value, &replace9.value },
   NULL,
};

static const nir_search_constant search279_0_1 = {
   { nir_search_value_constant, -1 },
   nir_type_int, { 0xff /* 255 */ },
};
static const nir_search_expression search279_0 = {
   { nir_search_value_expression, -1 },
   false,
   0, 2,
   nir_op_imin,
   { &search279_0_0.value, &search279_0_1.value },
   NULL,
};

/* search279_1 -> replace9 in the cache */
static const nir_search_expression search279 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 2,
   nir_op_extract_u8,
   { &search279_0.value, &replace9.value },
   NULL,
};

   /* replace279_0_0 -> search2_0 in the cache */

/* replace279_0_1 -> replace9 in the cache */
/* replace279_0 -> search279_0_0 in the cache */

/* replace279_1 -> search279_0_1 in the cache */
/* replace279 -> search279_0 in the cache */

   /* search280_0_0 -> search28_0_0 in the cache */

/* search280_0_1 -> search28_0_1 in the cache */
static const nir_search_expression search280_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search28_0_0.value, &search28_0_1.value },
   (is_used_once),
};

/* search280_1_0 -> search28_0_0 in the cache */

/* search280_1_1 -> search28_1_1 in the cache */
static const nir_search_expression search280_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search28_0_0.value, &search28_1_1.value },
   NULL,
};
static const nir_search_expression search280 = {
   { nir_search_value_expression, 1 },
   true,
   0, 1,
   nir_op_ior,
   { &search280_0.value, &search280_1.value },
   NULL,
};

   /* replace280_0 -> search28_0_0 in the cache */

/* replace280_1_0 -> search28_0_1 in the cache */

/* replace280_1_1 -> search28_1_1 in the cache */
static const nir_search_expression replace280_1 = {
   { nir_search_value_expression, -3 },
   false,
   -1, 0,
   nir_op_fmax,
   { &search28_0_1.value, &search28_1_1.value },
   NULL,
};
static const nir_search_expression replace280 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search28_0_0.value, &replace280_1.value },
   NULL,
};

   /* search281_0_0 -> search14_0 in the cache */

/* search281_0_1 -> search64_2 in the cache */
static const nir_search_expression search281_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search14_0.value, &search64_2.value },
   (is_used_once),
};

static const nir_search_variable search281_1_0 = {
   { nir_search_value_variable, -2 },
   2, /* b */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

/* search281_1_1 -> search64_2 in the cache */
static const nir_search_expression search281_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search281_1_0.value, &search64_2.value },
   NULL,
};
static const nir_search_expression search281 = {
   { nir_search_value_expression, 1 },
   true,
   0, 1,
   nir_op_ior,
   { &search281_0.value, &search281_1.value },
   NULL,
};

   /* replace281_0_0 -> search14_0 in the cache */

/* replace281_0_1 -> search281_1_0 in the cache */
static const nir_search_expression replace281_0 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_fmin,
   { &search14_0.value, &search281_1_0.value },
   NULL,
};

/* replace281_1 -> search64_2 in the cache */
static const nir_search_expression replace281 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &replace281_0.value, &search64_2.value },
   NULL,
};

   /* search282_0_0 -> search28_0_0 in the cache */

/* search282_0_1 -> search28_0_1 in the cache */
static const nir_search_expression search282_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search28_0_0.value, &search28_0_1.value },
   (is_used_once),
};

/* search282_1_0 -> search28_0_0 in the cache */

/* search282_1_1 -> search28_1_1 in the cache */
static const nir_search_expression search282_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search28_0_0.value, &search28_1_1.value },
   NULL,
};
static const nir_search_expression search282 = {
   { nir_search_value_expression, 1 },
   true,
   0, 1,
   nir_op_ior,
   { &search282_0.value, &search282_1.value },
   NULL,
};

   /* replace282_0 -> search28_0_0 in the cache */

/* replace282_1_0 -> search28_0_1 in the cache */

/* replace282_1_1 -> search28_1_1 in the cache */
static const nir_search_expression replace282_1 = {
   { nir_search_value_expression, -3 },
   false,
   -1, 0,
   nir_op_fmin,
   { &search28_0_1.value, &search28_1_1.value },
   NULL,
};
static const nir_search_expression replace282 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search28_0_0.value, &replace282_1.value },
   NULL,
};

   /* search283_0_0 -> search14_0 in the cache */

/* search283_0_1 -> search64_2 in the cache */
static const nir_search_expression search283_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search14_0.value, &search64_2.value },
   (is_used_once),
};

/* search283_1_0 -> search281_1_0 in the cache */

/* search283_1_1 -> search64_2 in the cache */
static const nir_search_expression search283_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search281_1_0.value, &search64_2.value },
   NULL,
};
static const nir_search_expression search283 = {
   { nir_search_value_expression, 1 },
   true,
   0, 1,
   nir_op_ior,
   { &search283_0.value, &search283_1.value },
   NULL,
};

   /* replace283_0_0 -> search14_0 in the cache */

/* replace283_0_1 -> search281_1_0 in the cache */
static const nir_search_expression replace283_0 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_fmax,
   { &search14_0.value, &search281_1_0.value },
   NULL,
};

/* replace283_1 -> search64_2 in the cache */
static const nir_search_expression replace283 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &replace283_0.value, &search64_2.value },
   NULL,
};

   /* search284_0_0 -> search28_0_0 in the cache */

/* search284_0_1 -> search96_0_0_1 in the cache */
static const nir_search_expression search284_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search28_0_0.value, &search96_0_0_1.value },
   NULL,
};

/* search284_1_0 -> search28_0_0 in the cache */

/* search284_1_1 -> search96_0_1 in the cache */
static const nir_search_expression search284_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search28_0_0.value, &search96_0_1.value },
   NULL,
};
static const nir_search_expression search284 = {
   { nir_search_value_expression, 1 },
   true,
   0, 1,
   nir_op_ior,
   { &search284_0.value, &search284_1.value },
   NULL,
};

   /* replace284_0 -> search28_0_0 in the cache */

/* replace284_1_0 -> search28_0_1 in the cache */

/* replace284_1_1 -> search28_1_1 in the cache */
/* replace284_1 -> replace280_1 in the cache */
/* replace284 -> replace280 in the cache */

   static const nir_search_variable search285_0_0 = {
   { nir_search_value_variable, -2 },
   0, /* a */
   true,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

/* search285_0_1 -> search64_2 in the cache */
static const nir_search_expression search285_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search285_0_0.value, &search64_2.value },
   NULL,
};

static const nir_search_variable search285_1_0 = {
   { nir_search_value_variable, -2 },
   2, /* b */
   true,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

/* search285_1_1 -> search64_2 in the cache */
static const nir_search_expression search285_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search285_1_0.value, &search64_2.value },
   NULL,
};
static const nir_search_expression search285 = {
   { nir_search_value_expression, 1 },
   true,
   0, 1,
   nir_op_ior,
   { &search285_0.value, &search285_1.value },
   NULL,
};

   /* replace285_0_0 -> search14_0 in the cache */

/* replace285_0_1 -> search281_1_0 in the cache */
/* replace285_0 -> replace281_0 in the cache */

/* replace285_1 -> search64_2 in the cache */
/* replace285 -> replace281 in the cache */

   /* search286_0_0 -> search28_0_0 in the cache */

/* search286_0_1 -> search96_0_0_1 in the cache */
static const nir_search_expression search286_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search28_0_0.value, &search96_0_0_1.value },
   NULL,
};

/* search286_1_0 -> search28_0_0 in the cache */

/* search286_1_1 -> search96_0_1 in the cache */
static const nir_search_expression search286_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search28_0_0.value, &search96_0_1.value },
   NULL,
};
static const nir_search_expression search286 = {
   { nir_search_value_expression, 1 },
   true,
   0, 1,
   nir_op_ior,
   { &search286_0.value, &search286_1.value },
   NULL,
};

   /* replace286_0 -> search28_0_0 in the cache */

/* replace286_1_0 -> search28_0_1 in the cache */

/* replace286_1_1 -> search28_1_1 in the cache */
/* replace286_1 -> replace282_1 in the cache */
/* replace286 -> replace282 in the cache */

   /* search287_0_0 -> search285_0_0 in the cache */

/* search287_0_1 -> search64_2 in the cache */
static const nir_search_expression search287_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search285_0_0.value, &search64_2.value },
   NULL,
};

/* search287_1_0 -> search285_1_0 in the cache */

/* search287_1_1 -> search64_2 in the cache */
static const nir_search_expression search287_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search285_1_0.value, &search64_2.value },
   NULL,
};
static const nir_search_expression search287 = {
   { nir_search_value_expression, 1 },
   true,
   0, 1,
   nir_op_ior,
   { &search287_0.value, &search287_1.value },
   NULL,
};

   /* replace287_0_0 -> search14_0 in the cache */

/* replace287_0_1 -> search281_1_0 in the cache */
/* replace287_0 -> replace283_0 in the cache */

/* replace287_1 -> search64_2 in the cache */
/* replace287 -> replace283 in the cache */

   /* search288_0_0 -> search28_0_0 in the cache */

/* search288_0_1 -> search28_0_1 in the cache */
/* search288_0 -> search280_0 in the cache */

/* search288_1_0 -> search28_0_0 in the cache */

/* search288_1_1 -> search28_1_1 in the cache */
/* search288_1 -> search280_1 in the cache */
static const nir_search_expression search288 = {
   { nir_search_value_expression, 1 },
   true,
   0, 1,
   nir_op_iand,
   { &search280_0.value, &search280_1.value },
   NULL,
};

   /* replace288_0 -> search28_0_0 in the cache */

/* replace288_1_0 -> search28_0_1 in the cache */

/* replace288_1_1 -> search28_1_1 in the cache */
/* replace288_1 -> replace282_1 in the cache */
static const nir_search_expression replace288 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search28_0_0.value, &replace282_1.value },
   NULL,
};

   /* search289_0_0 -> search14_0 in the cache */

/* search289_0_1 -> search64_2 in the cache */
/* search289_0 -> search281_0 in the cache */

/* search289_1_0 -> search281_1_0 in the cache */

/* search289_1_1 -> search64_2 in the cache */
/* search289_1 -> search281_1 in the cache */
static const nir_search_expression search289 = {
   { nir_search_value_expression, 1 },
   true,
   0, 1,
   nir_op_iand,
   { &search281_0.value, &search281_1.value },
   NULL,
};

   /* replace289_0_0 -> search14_0 in the cache */

/* replace289_0_1 -> search281_1_0 in the cache */
/* replace289_0 -> replace283_0 in the cache */

/* replace289_1 -> search64_2 in the cache */
static const nir_search_expression replace289 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &replace283_0.value, &search64_2.value },
   NULL,
};

   /* search290_0_0 -> search28_0_0 in the cache */

/* search290_0_1 -> search28_0_1 in the cache */
/* search290_0 -> search282_0 in the cache */

/* search290_1_0 -> search28_0_0 in the cache */

/* search290_1_1 -> search28_1_1 in the cache */
/* search290_1 -> search282_1 in the cache */
static const nir_search_expression search290 = {
   { nir_search_value_expression, 1 },
   true,
   0, 1,
   nir_op_iand,
   { &search282_0.value, &search282_1.value },
   NULL,
};

   /* replace290_0 -> search28_0_0 in the cache */

/* replace290_1_0 -> search28_0_1 in the cache */

/* replace290_1_1 -> search28_1_1 in the cache */
/* replace290_1 -> replace280_1 in the cache */
static const nir_search_expression replace290 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search28_0_0.value, &replace280_1.value },
   NULL,
};

   /* search291_0_0 -> search14_0 in the cache */

/* search291_0_1 -> search64_2 in the cache */
/* search291_0 -> search283_0 in the cache */

/* search291_1_0 -> search281_1_0 in the cache */

/* search291_1_1 -> search64_2 in the cache */
/* search291_1 -> search283_1 in the cache */
static const nir_search_expression search291 = {
   { nir_search_value_expression, 1 },
   true,
   0, 1,
   nir_op_iand,
   { &search283_0.value, &search283_1.value },
   NULL,
};

   /* replace291_0_0 -> search14_0 in the cache */

/* replace291_0_1 -> search281_1_0 in the cache */
/* replace291_0 -> replace281_0 in the cache */

/* replace291_1 -> search64_2 in the cache */
static const nir_search_expression replace291 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &replace281_0.value, &search64_2.value },
   NULL,
};

   /* search292_0_0 -> search28_0_0 in the cache */

/* search292_0_1 -> search96_0_0_1 in the cache */
/* search292_0 -> search284_0 in the cache */

/* search292_1_0 -> search28_0_0 in the cache */

/* search292_1_1 -> search96_0_1 in the cache */
/* search292_1 -> search284_1 in the cache */
static const nir_search_expression search292 = {
   { nir_search_value_expression, 1 },
   true,
   0, 1,
   nir_op_iand,
   { &search284_0.value, &search284_1.value },
   NULL,
};

   /* replace292_0 -> search28_0_0 in the cache */

/* replace292_1_0 -> search28_0_1 in the cache */

/* replace292_1_1 -> search28_1_1 in the cache */
/* replace292_1 -> replace282_1 in the cache */
/* replace292 -> replace288 in the cache */

   /* search293_0_0 -> search285_0_0 in the cache */

/* search293_0_1 -> search64_2 in the cache */
/* search293_0 -> search285_0 in the cache */

/* search293_1_0 -> search285_1_0 in the cache */

/* search293_1_1 -> search64_2 in the cache */
/* search293_1 -> search285_1 in the cache */
static const nir_search_expression search293 = {
   { nir_search_value_expression, 1 },
   true,
   0, 1,
   nir_op_iand,
   { &search285_0.value, &search285_1.value },
   NULL,
};

   /* replace293_0_0 -> search14_0 in the cache */

/* replace293_0_1 -> search281_1_0 in the cache */
/* replace293_0 -> replace283_0 in the cache */

/* replace293_1 -> search64_2 in the cache */
/* replace293 -> replace289 in the cache */

   /* search294_0_0 -> search28_0_0 in the cache */

/* search294_0_1 -> search96_0_0_1 in the cache */
/* search294_0 -> search286_0 in the cache */

/* search294_1_0 -> search28_0_0 in the cache */

/* search294_1_1 -> search96_0_1 in the cache */
/* search294_1 -> search286_1 in the cache */
static const nir_search_expression search294 = {
   { nir_search_value_expression, 1 },
   true,
   0, 1,
   nir_op_iand,
   { &search286_0.value, &search286_1.value },
   NULL,
};

   /* replace294_0 -> search28_0_0 in the cache */

/* replace294_1_0 -> search28_0_1 in the cache */

/* replace294_1_1 -> search28_1_1 in the cache */
/* replace294_1 -> replace280_1 in the cache */
/* replace294 -> replace290 in the cache */

   /* search295_0_0 -> search285_0_0 in the cache */

/* search295_0_1 -> search64_2 in the cache */
/* search295_0 -> search287_0 in the cache */

/* search295_1_0 -> search285_1_0 in the cache */

/* search295_1_1 -> search64_2 in the cache */
/* search295_1 -> search287_1 in the cache */
static const nir_search_expression search295 = {
   { nir_search_value_expression, 1 },
   true,
   0, 1,
   nir_op_iand,
   { &search287_0.value, &search287_1.value },
   NULL,
};

   /* replace295_0_0 -> search14_0 in the cache */

/* replace295_0_1 -> search281_1_0 in the cache */
/* replace295_0 -> replace281_0 in the cache */

/* replace295_1 -> search64_2 in the cache */
/* replace295 -> replace291 in the cache */

   /* search296_0_0 -> search28_0_0 in the cache */

/* search296_0_1 -> search28_0_1 in the cache */
static const nir_search_expression search296_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search28_0_0.value, &search28_0_1.value },
   (is_used_once),
};

/* search296_1_0 -> search28_0_0 in the cache */

/* search296_1_1 -> search28_1_1 in the cache */
static const nir_search_expression search296_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search28_0_0.value, &search28_1_1.value },
   NULL,
};
static const nir_search_expression search296 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ior,
   { &search296_0.value, &search296_1.value },
   NULL,
};

   /* replace296_0 -> search28_0_0 in the cache */

/* replace296_1_0 -> search28_0_1 in the cache */

/* replace296_1_1 -> search28_1_1 in the cache */
static const nir_search_expression replace296_1 = {
   { nir_search_value_expression, -3 },
   false,
   0, 1,
   nir_op_imax,
   { &search28_0_1.value, &search28_1_1.value },
   NULL,
};
static const nir_search_expression replace296 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_ilt,
   { &search28_0_0.value, &replace296_1.value },
   NULL,
};

   /* search297_0_0 -> search14_0 in the cache */

/* search297_0_1 -> search64_2 in the cache */
static const nir_search_expression search297_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search14_0.value, &search64_2.value },
   (is_used_once),
};

/* search297_1_0 -> search281_1_0 in the cache */

/* search297_1_1 -> search64_2 in the cache */
static const nir_search_expression search297_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search281_1_0.value, &search64_2.value },
   NULL,
};
static const nir_search_expression search297 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ior,
   { &search297_0.value, &search297_1.value },
   NULL,
};

   /* replace297_0_0 -> search14_0 in the cache */

/* replace297_0_1 -> search281_1_0 in the cache */
static const nir_search_expression replace297_0 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_imin,
   { &search14_0.value, &search281_1_0.value },
   NULL,
};

/* replace297_1 -> search64_2 in the cache */
static const nir_search_expression replace297 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_ilt,
   { &replace297_0.value, &search64_2.value },
   NULL,
};

   /* search298_0_0 -> search28_0_0 in the cache */

/* search298_0_1 -> search28_0_1 in the cache */
static const nir_search_expression search298_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search28_0_0.value, &search28_0_1.value },
   (is_used_once),
};

/* search298_1_0 -> search28_0_0 in the cache */

/* search298_1_1 -> search28_1_1 in the cache */
static const nir_search_expression search298_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search28_0_0.value, &search28_1_1.value },
   NULL,
};
static const nir_search_expression search298 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ior,
   { &search298_0.value, &search298_1.value },
   NULL,
};

   /* replace298_0 -> search28_0_0 in the cache */

/* replace298_1_0 -> search28_0_1 in the cache */

/* replace298_1_1 -> search28_1_1 in the cache */
static const nir_search_expression replace298_1 = {
   { nir_search_value_expression, -3 },
   false,
   0, 1,
   nir_op_imin,
   { &search28_0_1.value, &search28_1_1.value },
   NULL,
};
static const nir_search_expression replace298 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_ige,
   { &search28_0_0.value, &replace298_1.value },
   NULL,
};

   /* search299_0_0 -> search14_0 in the cache */

/* search299_0_1 -> search64_2 in the cache */
static const nir_search_expression search299_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search14_0.value, &search64_2.value },
   (is_used_once),
};

/* search299_1_0 -> search281_1_0 in the cache */

/* search299_1_1 -> search64_2 in the cache */
static const nir_search_expression search299_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search281_1_0.value, &search64_2.value },
   NULL,
};
static const nir_search_expression search299 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ior,
   { &search299_0.value, &search299_1.value },
   NULL,
};

   /* replace299_0_0 -> search14_0 in the cache */

/* replace299_0_1 -> search281_1_0 in the cache */
static const nir_search_expression replace299_0 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_imax,
   { &search14_0.value, &search281_1_0.value },
   NULL,
};

/* replace299_1 -> search64_2 in the cache */
static const nir_search_expression replace299 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_ige,
   { &replace299_0.value, &search64_2.value },
   NULL,
};

   /* search300_0_0 -> search28_0_0 in the cache */

/* search300_0_1 -> search28_0_1 in the cache */
static const nir_search_expression search300_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search28_0_0.value, &search28_0_1.value },
   (is_used_once),
};

/* search300_1_0 -> search28_0_0 in the cache */

/* search300_1_1 -> search28_1_1 in the cache */
static const nir_search_expression search300_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search28_0_0.value, &search28_1_1.value },
   NULL,
};
static const nir_search_expression search300 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ior,
   { &search300_0.value, &search300_1.value },
   NULL,
};

   /* replace300_0 -> search28_0_0 in the cache */

/* replace300_1_0 -> search28_0_1 in the cache */

/* replace300_1_1 -> search28_1_1 in the cache */
static const nir_search_expression replace300_1 = {
   { nir_search_value_expression, -3 },
   false,
   0, 1,
   nir_op_umax,
   { &search28_0_1.value, &search28_1_1.value },
   NULL,
};
static const nir_search_expression replace300 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_ult,
   { &search28_0_0.value, &replace300_1.value },
   NULL,
};

   /* search301_0_0 -> search14_0 in the cache */

/* search301_0_1 -> search64_2 in the cache */
static const nir_search_expression search301_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search14_0.value, &search64_2.value },
   (is_used_once),
};

/* search301_1_0 -> search281_1_0 in the cache */

/* search301_1_1 -> search64_2 in the cache */
static const nir_search_expression search301_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search281_1_0.value, &search64_2.value },
   NULL,
};
static const nir_search_expression search301 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ior,
   { &search301_0.value, &search301_1.value },
   NULL,
};

   /* replace301_0_0 -> search14_0 in the cache */

/* replace301_0_1 -> search281_1_0 in the cache */
static const nir_search_expression replace301_0 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_umin,
   { &search14_0.value, &search281_1_0.value },
   NULL,
};

/* replace301_1 -> search64_2 in the cache */
static const nir_search_expression replace301 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_ult,
   { &replace301_0.value, &search64_2.value },
   NULL,
};

   /* search302_0_0 -> search28_0_0 in the cache */

/* search302_0_1 -> search28_0_1 in the cache */
static const nir_search_expression search302_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search28_0_0.value, &search28_0_1.value },
   (is_used_once),
};

/* search302_1_0 -> search28_0_0 in the cache */

/* search302_1_1 -> search28_1_1 in the cache */
static const nir_search_expression search302_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search28_0_0.value, &search28_1_1.value },
   NULL,
};
static const nir_search_expression search302 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ior,
   { &search302_0.value, &search302_1.value },
   NULL,
};

   /* replace302_0 -> search28_0_0 in the cache */

/* replace302_1_0 -> search28_0_1 in the cache */

/* replace302_1_1 -> search28_1_1 in the cache */
static const nir_search_expression replace302_1 = {
   { nir_search_value_expression, -3 },
   false,
   0, 1,
   nir_op_umin,
   { &search28_0_1.value, &search28_1_1.value },
   NULL,
};
static const nir_search_expression replace302 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_uge,
   { &search28_0_0.value, &replace302_1.value },
   NULL,
};

   /* search303_0_0 -> search14_0 in the cache */

/* search303_0_1 -> search64_2 in the cache */
static const nir_search_expression search303_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search14_0.value, &search64_2.value },
   (is_used_once),
};

/* search303_1_0 -> search281_1_0 in the cache */

/* search303_1_1 -> search64_2 in the cache */
static const nir_search_expression search303_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search281_1_0.value, &search64_2.value },
   NULL,
};
static const nir_search_expression search303 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ior,
   { &search303_0.value, &search303_1.value },
   NULL,
};

   /* replace303_0_0 -> search14_0 in the cache */

/* replace303_0_1 -> search281_1_0 in the cache */
static const nir_search_expression replace303_0 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_umax,
   { &search14_0.value, &search281_1_0.value },
   NULL,
};

/* replace303_1 -> search64_2 in the cache */
static const nir_search_expression replace303 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_uge,
   { &replace303_0.value, &search64_2.value },
   NULL,
};

   /* search304_0_0 -> search28_0_0 in the cache */

/* search304_0_1 -> search28_0_1 in the cache */
/* search304_0 -> search296_0 in the cache */

/* search304_1_0 -> search28_0_0 in the cache */

/* search304_1_1 -> search28_1_1 in the cache */
/* search304_1 -> search296_1 in the cache */
static const nir_search_expression search304 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_iand,
   { &search296_0.value, &search296_1.value },
   NULL,
};

   /* replace304_0 -> search28_0_0 in the cache */

/* replace304_1_0 -> search28_0_1 in the cache */

/* replace304_1_1 -> search28_1_1 in the cache */
/* replace304_1 -> replace298_1 in the cache */
static const nir_search_expression replace304 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_ilt,
   { &search28_0_0.value, &replace298_1.value },
   NULL,
};

   /* search305_0_0 -> search14_0 in the cache */

/* search305_0_1 -> search64_2 in the cache */
/* search305_0 -> search297_0 in the cache */

/* search305_1_0 -> search281_1_0 in the cache */

/* search305_1_1 -> search64_2 in the cache */
/* search305_1 -> search297_1 in the cache */
static const nir_search_expression search305 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_iand,
   { &search297_0.value, &search297_1.value },
   NULL,
};

   /* replace305_0_0 -> search14_0 in the cache */

/* replace305_0_1 -> search281_1_0 in the cache */
/* replace305_0 -> replace299_0 in the cache */

/* replace305_1 -> search64_2 in the cache */
static const nir_search_expression replace305 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_ilt,
   { &replace299_0.value, &search64_2.value },
   NULL,
};

   /* search306_0_0 -> search28_0_0 in the cache */

/* search306_0_1 -> search28_0_1 in the cache */
/* search306_0 -> search298_0 in the cache */

/* search306_1_0 -> search28_0_0 in the cache */

/* search306_1_1 -> search28_1_1 in the cache */
/* search306_1 -> search298_1 in the cache */
static const nir_search_expression search306 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_iand,
   { &search298_0.value, &search298_1.value },
   NULL,
};

   /* replace306_0 -> search28_0_0 in the cache */

/* replace306_1_0 -> search28_0_1 in the cache */

/* replace306_1_1 -> search28_1_1 in the cache */
/* replace306_1 -> replace296_1 in the cache */
static const nir_search_expression replace306 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_ige,
   { &search28_0_0.value, &replace296_1.value },
   NULL,
};

   /* search307_0_0 -> search14_0 in the cache */

/* search307_0_1 -> search64_2 in the cache */
/* search307_0 -> search299_0 in the cache */

/* search307_1_0 -> search281_1_0 in the cache */

/* search307_1_1 -> search64_2 in the cache */
/* search307_1 -> search299_1 in the cache */
static const nir_search_expression search307 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_iand,
   { &search299_0.value, &search299_1.value },
   NULL,
};

   /* replace307_0_0 -> search14_0 in the cache */

/* replace307_0_1 -> search281_1_0 in the cache */
/* replace307_0 -> replace297_0 in the cache */

/* replace307_1 -> search64_2 in the cache */
static const nir_search_expression replace307 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_ige,
   { &replace297_0.value, &search64_2.value },
   NULL,
};

   /* search308_0_0 -> search28_0_0 in the cache */

/* search308_0_1 -> search28_0_1 in the cache */
/* search308_0 -> search300_0 in the cache */

/* search308_1_0 -> search28_0_0 in the cache */

/* search308_1_1 -> search28_1_1 in the cache */
/* search308_1 -> search300_1 in the cache */
static const nir_search_expression search308 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_iand,
   { &search300_0.value, &search300_1.value },
   NULL,
};

   /* replace308_0 -> search28_0_0 in the cache */

/* replace308_1_0 -> search28_0_1 in the cache */

/* replace308_1_1 -> search28_1_1 in the cache */
/* replace308_1 -> replace302_1 in the cache */
static const nir_search_expression replace308 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_ult,
   { &search28_0_0.value, &replace302_1.value },
   NULL,
};

   /* search309_0_0 -> search14_0 in the cache */

/* search309_0_1 -> search64_2 in the cache */
/* search309_0 -> search301_0 in the cache */

/* search309_1_0 -> search281_1_0 in the cache */

/* search309_1_1 -> search64_2 in the cache */
/* search309_1 -> search301_1 in the cache */
static const nir_search_expression search309 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_iand,
   { &search301_0.value, &search301_1.value },
   NULL,
};

   /* replace309_0_0 -> search14_0 in the cache */

/* replace309_0_1 -> search281_1_0 in the cache */
/* replace309_0 -> replace303_0 in the cache */

/* replace309_1 -> search64_2 in the cache */
static const nir_search_expression replace309 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_ult,
   { &replace303_0.value, &search64_2.value },
   NULL,
};

   /* search310_0_0 -> search28_0_0 in the cache */

/* search310_0_1 -> search28_0_1 in the cache */
/* search310_0 -> search302_0 in the cache */

/* search310_1_0 -> search28_0_0 in the cache */

/* search310_1_1 -> search28_1_1 in the cache */
/* search310_1 -> search302_1 in the cache */
static const nir_search_expression search310 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_iand,
   { &search302_0.value, &search302_1.value },
   NULL,
};

   /* replace310_0 -> search28_0_0 in the cache */

/* replace310_1_0 -> search28_0_1 in the cache */

/* replace310_1_1 -> search28_1_1 in the cache */
/* replace310_1 -> replace300_1 in the cache */
static const nir_search_expression replace310 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_uge,
   { &search28_0_0.value, &replace300_1.value },
   NULL,
};

   /* search311_0_0 -> search14_0 in the cache */

/* search311_0_1 -> search64_2 in the cache */
/* search311_0 -> search303_0 in the cache */

/* search311_1_0 -> search281_1_0 in the cache */

/* search311_1_1 -> search64_2 in the cache */
/* search311_1 -> search303_1 in the cache */
static const nir_search_expression search311 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_iand,
   { &search303_0.value, &search303_1.value },
   NULL,
};

   /* replace311_0_0 -> search14_0 in the cache */

/* replace311_0_1 -> search281_1_0 in the cache */
/* replace311_0 -> replace301_0 in the cache */

/* replace311_1 -> search64_2 in the cache */
static const nir_search_expression replace311 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_uge,
   { &replace301_0.value, &search64_2.value },
   NULL,
};

   static const nir_search_constant search312_0_0 = {
   { nir_search_value_constant, 32 },
   nir_type_float, { 0x0 /* 0.0 */ },
};

/* search312_0_1 -> search0_0 in the cache */
static const nir_search_expression search312_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search312_0_0.value, &search0_0.value },
   (is_used_once),
};

/* search312_1_0 -> replace0_1_0 in the cache */

/* search312_1_1 -> search312_0_0 in the cache */
static const nir_search_expression search312_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &replace0_1_0.value, &search312_0_0.value },
   NULL,
};
static const nir_search_expression search312 = {
   { nir_search_value_expression, 1 },
   true,
   0, 1,
   nir_op_ior,
   { &search312_0.value, &search312_1.value },
   NULL,
};

   /* replace312_0 -> search312_0_0 in the cache */

/* replace312_1_0 -> search0_0 in the cache */

/* replace312_1_1_0 -> replace0_1_0 in the cache */
/* replace312_1_1 -> search95_1_0_1_1 in the cache */
static const nir_search_expression replace312_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_fmax,
   { &search0_0.value, &search95_1_0_1_1.value },
   NULL,
};
static const nir_search_expression replace312 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search312_0_0.value, &replace312_1.value },
   NULL,
};

   /* search313_0_0 -> search312_0_0 in the cache */

/* search313_0_1 -> search0_0 in the cache */
static const nir_search_expression search313_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search312_0_0.value, &search0_0.value },
   NULL,
};

/* search313_1_0 -> replace0_1_0 in the cache */

/* search313_1_1 -> search312_0_0 in the cache */
static const nir_search_expression search313_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &replace0_1_0.value, &search312_0_0.value },
   (is_used_once),
};
static const nir_search_expression search313 = {
   { nir_search_value_expression, 1 },
   true,
   0, 1,
   nir_op_ior,
   { &search313_0.value, &search313_1.value },
   NULL,
};

   /* replace313_0 -> search312_0_0 in the cache */

/* replace313_1_0 -> search0_0 in the cache */

/* replace313_1_1_0 -> replace0_1_0 in the cache */
/* replace313_1_1 -> search95_1_0_1_1 in the cache */
/* replace313_1 -> replace312_1 in the cache */
/* replace313 -> replace312 in the cache */

   /* search314_0_0 -> search312_0_0 in the cache */

/* search314_0_1 -> search0_0 in the cache */
static const nir_search_expression search314_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search312_0_0.value, &search0_0.value },
   (is_used_once),
};

/* search314_1_0 -> replace0_1_0 in the cache */

/* search314_1_1 -> search312_0_0 in the cache */
static const nir_search_expression search314_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &replace0_1_0.value, &search312_0_0.value },
   NULL,
};
static const nir_search_expression search314 = {
   { nir_search_value_expression, 1 },
   true,
   0, 1,
   nir_op_ior,
   { &search314_0.value, &search314_1.value },
   NULL,
};

   /* replace314_0 -> search312_0_0 in the cache */

/* replace314_1_0 -> search0_0 in the cache */

/* replace314_1_1_0 -> replace0_1_0 in the cache */
/* replace314_1_1 -> search95_1_0_1_1 in the cache */
static const nir_search_expression replace314_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_fmin,
   { &search0_0.value, &search95_1_0_1_1.value },
   NULL,
};
static const nir_search_expression replace314 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search312_0_0.value, &replace314_1.value },
   NULL,
};

   /* search315_0_0 -> search312_0_0 in the cache */

/* search315_0_1 -> search0_0 in the cache */
static const nir_search_expression search315_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search312_0_0.value, &search0_0.value },
   NULL,
};

/* search315_1_0 -> replace0_1_0 in the cache */

/* search315_1_1 -> search312_0_0 in the cache */
static const nir_search_expression search315_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &replace0_1_0.value, &search312_0_0.value },
   (is_used_once),
};
static const nir_search_expression search315 = {
   { nir_search_value_expression, 1 },
   true,
   0, 1,
   nir_op_ior,
   { &search315_0.value, &search315_1.value },
   NULL,
};

   /* replace315_0 -> search312_0_0 in the cache */

/* replace315_1_0 -> search0_0 in the cache */

/* replace315_1_1_0 -> replace0_1_0 in the cache */
/* replace315_1_1 -> search95_1_0_1_1 in the cache */
/* replace315_1 -> replace314_1 in the cache */
/* replace315 -> replace314 in the cache */

   /* search316_0_0 -> search312_0_0 in the cache */

/* search316_0_1 -> search0_0 in the cache */
/* search316_0 -> search312_0 in the cache */

/* search316_1_0 -> replace0_1_0 in the cache */

/* search316_1_1 -> search312_0_0 in the cache */
/* search316_1 -> search312_1 in the cache */
static const nir_search_expression search316 = {
   { nir_search_value_expression, 1 },
   true,
   0, 1,
   nir_op_iand,
   { &search312_0.value, &search312_1.value },
   NULL,
};

   /* replace316_0 -> search312_0_0 in the cache */

/* replace316_1_0 -> search0_0 in the cache */

/* replace316_1_1_0 -> replace0_1_0 in the cache */
/* replace316_1_1 -> search95_1_0_1_1 in the cache */
/* replace316_1 -> replace314_1 in the cache */
static const nir_search_expression replace316 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search312_0_0.value, &replace314_1.value },
   NULL,
};

   /* search317_0_0 -> search312_0_0 in the cache */

/* search317_0_1 -> search0_0 in the cache */
/* search317_0 -> search313_0 in the cache */

/* search317_1_0 -> replace0_1_0 in the cache */

/* search317_1_1 -> search312_0_0 in the cache */
/* search317_1 -> search313_1 in the cache */
static const nir_search_expression search317 = {
   { nir_search_value_expression, 1 },
   true,
   0, 1,
   nir_op_iand,
   { &search313_0.value, &search313_1.value },
   NULL,
};

   /* replace317_0 -> search312_0_0 in the cache */

/* replace317_1_0 -> search0_0 in the cache */

/* replace317_1_1_0 -> replace0_1_0 in the cache */
/* replace317_1_1 -> search95_1_0_1_1 in the cache */
/* replace317_1 -> replace314_1 in the cache */
/* replace317 -> replace316 in the cache */

   /* search318_0_0 -> search312_0_0 in the cache */

/* search318_0_1 -> search0_0 in the cache */
/* search318_0 -> search314_0 in the cache */

/* search318_1_0 -> replace0_1_0 in the cache */

/* search318_1_1 -> search312_0_0 in the cache */
/* search318_1 -> search314_1 in the cache */
static const nir_search_expression search318 = {
   { nir_search_value_expression, 1 },
   true,
   0, 1,
   nir_op_iand,
   { &search314_0.value, &search314_1.value },
   NULL,
};

   /* replace318_0 -> search312_0_0 in the cache */

/* replace318_1_0 -> search0_0 in the cache */

/* replace318_1_1_0 -> replace0_1_0 in the cache */
/* replace318_1_1 -> search95_1_0_1_1 in the cache */
/* replace318_1 -> replace312_1 in the cache */
static const nir_search_expression replace318 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search312_0_0.value, &replace312_1.value },
   NULL,
};

   /* search319_0_0 -> search312_0_0 in the cache */

/* search319_0_1 -> search0_0 in the cache */
/* search319_0 -> search315_0 in the cache */

/* search319_1_0 -> replace0_1_0 in the cache */

/* search319_1_1 -> search312_0_0 in the cache */
/* search319_1 -> search315_1 in the cache */
static const nir_search_expression search319 = {
   { nir_search_value_expression, 1 },
   true,
   0, 1,
   nir_op_iand,
   { &search315_0.value, &search315_1.value },
   NULL,
};

   /* replace319_0 -> search312_0_0 in the cache */

/* replace319_1_0 -> search0_0 in the cache */

/* replace319_1_1_0 -> replace0_1_0 in the cache */
/* replace319_1_1 -> search95_1_0_1_1 in the cache */
/* replace319_1 -> replace312_1 in the cache */
/* replace319 -> replace318 in the cache */

   /* search320_0_0 -> search2_0 in the cache */

/* search320_0_1 -> replace9 in the cache */
static const nir_search_expression search320_0 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ieq,
   { &search2_0.value, &replace9.value },
   NULL,
};

/* search320_1_0 -> search2_0 in the cache */

/* search320_1_1 -> replace2_1_0 in the cache */
static const nir_search_expression search320_1 = {
   { nir_search_value_expression, 1 },
   false,
   2, 1,
   nir_op_ieq,
   { &search2_0.value, &replace2_1_0.value },
   NULL,
};
static const nir_search_expression search320 = {
   { nir_search_value_expression, 1 },
   false,
   0, 3,
   nir_op_ior,
   { &search320_0.value, &search320_1.value },
   NULL,
};

   /* replace320_0 -> replace2_1_0 in the cache */

/* replace320_1 -> search2_0 in the cache */
static const nir_search_expression replace320 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &replace2_1_0.value, &search2_0.value },
   NULL,
};

   /* search321_0_0 -> replace2_1_0 in the cache */

/* search321_0_1 -> search2_0 in the cache */
/* search321_0 -> replace320 in the cache */

/* search321_1_0 -> search2_0 in the cache */

static const nir_search_constant search321_1_1 = {
   { nir_search_value_constant, -1 },
   nir_type_int, { 0x2 /* 2 */ },
};
static const nir_search_expression search321_1 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ieq,
   { &search2_0.value, &search321_1_1.value },
   NULL,
};
static const nir_search_expression search321 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_ior,
   { &replace320.value, &search321_1.value },
   NULL,
};

   /* replace321_0 -> search321_1_1 in the cache */

/* replace321_1 -> search2_0 in the cache */
static const nir_search_expression replace321 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search321_1_1.value, &search2_0.value },
   NULL,
};

   /* search322_0_0 -> search321_1_1 in the cache */

/* search322_0_1 -> search2_0 in the cache */
/* search322_0 -> replace321 in the cache */

/* search322_1_0 -> search2_0 in the cache */

static const nir_search_constant search322_1_1 = {
   { nir_search_value_constant, -1 },
   nir_type_int, { 0x3 /* 3 */ },
};
static const nir_search_expression search322_1 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ieq,
   { &search2_0.value, &search322_1_1.value },
   NULL,
};
static const nir_search_expression search322 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_ior,
   { &replace321.value, &search322_1.value },
   NULL,
};

   /* replace322_0 -> search322_1_1 in the cache */

/* replace322_1 -> search2_0 in the cache */
static const nir_search_expression replace322 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search322_1_1.value, &search2_0.value },
   NULL,
};

   /* search323_0_0 -> search0_0 in the cache */

/* search323_0_1 -> search312_0_0 in the cache */
static const nir_search_expression search323_0 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_feq,
   { &search0_0.value, &search312_0_0.value },
   NULL,
};

/* search323_1 -> replace60_0_0 in the cache */

/* search323_2_0_0_0_0 -> search312_0_0 in the cache */

/* search323_2_0_0_0_1 -> search0_0 in the cache */
/* search323_2_0_0_0 -> search313_0 in the cache */
static const nir_search_expression search323_2_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_b2i32,
   { &search313_0.value },
   NULL,
};

/* search323_2_0_1_0_0_0 -> search0_0 in the cache */

/* search323_2_0_1_0_0_1 -> search312_0_0 in the cache */
static const nir_search_expression search323_2_0_1_0_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search0_0.value, &search312_0_0.value },
   NULL,
};
static const nir_search_expression search323_2_0_1_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_b2i32,
   { &search323_2_0_1_0_0.value },
   NULL,
};
static const nir_search_expression search323_2_0_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_ineg,
   { &search323_2_0_1_0.value },
   NULL,
};
static const nir_search_expression search323_2_0 = {
   { nir_search_value_expression, 32 },
   false,
   1, 1,
   nir_op_iadd,
   { &search323_2_0_0.value, &search323_2_0_1.value },
   NULL,
};
static const nir_search_expression search323_2 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_op_i2f32,
   { &search323_2_0.value },
   NULL,
};
static const nir_search_expression search323 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 2,
   nir_op_bcsel,
   { &search323_0.value, &replace60_0_0.value, &search323_2.value },
   NULL,
};

   static const nir_search_constant replace323_0 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { 0x3f800000 /* 1065353216 */ },
};

/* replace323_1_0 -> search0_0 in the cache */

static const nir_search_constant replace323_1_1 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { 0x80000000 /* 2147483648 */ },
};
static const nir_search_expression replace323_1 = {
   { nir_search_value_expression, 32 },
   false,
   1, 1,
   nir_op_iand,
   { &search0_0.value, &replace323_1_1.value },
   NULL,
};
static const nir_search_expression replace323 = {
   { nir_search_value_expression, 32 },
   false,
   0, 2,
   nir_op_ior,
   { &replace323_0.value, &replace323_1.value },
   NULL,
};

   /* search324_0 -> replace80_0 in the cache */

/* search324_1_0 -> replace80_0 in the cache */

/* search324_1_1 -> replace121 in the cache */
static const nir_search_expression search324_1 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ieq,
   { &replace80_0.value, &replace121.value },
   NULL,
};
static const nir_search_expression search324 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_ior,
   { &replace80_0.value, &search324_1.value },
   NULL,
};

   /* replace324 -> replace197 in the cache */

   /* search325_0 -> search2_0 in the cache */

/* search325_1_0 -> search2_0 in the cache */
static const nir_search_expression search325_1 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_inot,
   { &search2_0.value },
   NULL,
};
static const nir_search_expression search325 = {
   { nir_search_value_expression, -1 },
   false,
   0, 1,
   nir_op_ior,
   { &search2_0.value, &search325_1.value },
   NULL,
};

   /* replace325 -> search44_1 in the cache */

   /* search326_0_0_0 -> replace80_0 in the cache */
static const nir_search_expression search326_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_b2i32,
   { &replace80_0.value },
   NULL,
};
static const nir_search_expression search326_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_ineg,
   { &search326_0_0.value },
   NULL,
};

/* search326_1_0_0 -> search148_0_1_0 in the cache */
static const nir_search_expression search326_1_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_b2i32,
   { &search148_0_1_0.value },
   NULL,
};
static const nir_search_expression search326_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_ineg,
   { &search326_1_0.value },
   NULL,
};
static const nir_search_expression search326 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &search326_0.value, &search326_1.value },
   NULL,
};

   /* replace326_0 -> replace80_0 in the cache */

/* replace326_1 -> search148_0_1_0 in the cache */
static const nir_search_expression replace326 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &replace80_0.value, &search148_0_1_0.value },
   NULL,
};

   /* search327_0_0 -> replace80_0 in the cache */

/* search327_0_1 -> search148_0_1_0 in the cache */
/* search327_0 -> replace326 in the cache */
static const nir_search_expression search327 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_op_b2i32,
   { &replace326.value },
   NULL,
};

   /* replace327_0_0 -> replace80_0 in the cache */

/* replace327_0_1 -> search148_0_1_0 in the cache */
/* replace327_0 -> replace155 in the cache */
static const nir_search_expression replace327 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_op_b2i32,
   { &replace155.value },
   NULL,
};

   /* search328_0_0 -> search0_0 in the cache */

/* search328_0_1 -> search26_1 in the cache */
static const nir_search_expression search328_0 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ieq,
   { &search0_0.value, &search26_1.value },
   NULL,
};

/* search328_1_0 -> replace0_1_0 in the cache */

/* search328_1_1 -> search26_1 in the cache */
static const nir_search_expression search328_1 = {
   { nir_search_value_expression, 1 },
   false,
   2, 1,
   nir_op_ieq,
   { &replace0_1_0.value, &search26_1.value },
   NULL,
};
static const nir_search_expression search328 = {
   { nir_search_value_expression, 1 },
   false,
   0, 3,
   nir_op_iand,
   { &search328_0.value, &search328_1.value },
   NULL,
};

   /* replace328_0_0 -> search0_0 in the cache */

/* replace328_0_1 -> replace0_1_0 in the cache */
static const nir_search_expression replace328_0 = {
   { nir_search_value_expression, 32 },
   false,
   1, 1,
   nir_op_ior,
   { &search0_0.value, &replace0_1_0.value },
   NULL,
};

/* replace328_1 -> search26_1 in the cache */
static const nir_search_expression replace328 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_ieq,
   { &replace328_0.value, &search26_1.value },
   NULL,
};

   /* search329_0 -> search2_0 in the cache */

static const nir_search_variable search329_1_0 = {
   { nir_search_value_variable, -1 },
   1, /* b */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

/* search329_1_1 -> search2_0 in the cache */
static const nir_search_expression search329_1 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fmax,
   { &search329_1_0.value, &search2_0.value },
   NULL,
};
static const nir_search_expression search329 = {
   { nir_search_value_expression, 1 },
   true,
   -1, 0,
   nir_op_flt,
   { &search2_0.value, &search329_1.value },
   NULL,
};

   /* replace329_0 -> search2_0 in the cache */

/* replace329_1 -> search329_1_0 in the cache */
static const nir_search_expression replace329 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search2_0.value, &search329_1_0.value },
   NULL,
};

   /* search330_0_0 -> search14_0 in the cache */

/* search330_0_1 -> replace14_1_0 in the cache */
/* search330_0 -> replace222 in the cache */

/* search330_1 -> search14_0 in the cache */
static const nir_search_expression search330 = {
   { nir_search_value_expression, 1 },
   true,
   -1, 0,
   nir_op_flt,
   { &replace222.value, &search14_0.value },
   NULL,
};

   /* replace330_0 -> replace14_1_0 in the cache */

/* replace330_1 -> search14_0 in the cache */
/* replace330 -> search122_1 in the cache */

   /* search331_0 -> search2_0 in the cache */

/* search331_1_0 -> search329_1_0 in the cache */

/* search331_1_1 -> search2_0 in the cache */
static const nir_search_expression search331_1 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fmin,
   { &search329_1_0.value, &search2_0.value },
   NULL,
};
static const nir_search_expression search331 = {
   { nir_search_value_expression, 1 },
   true,
   -1, 0,
   nir_op_fge,
   { &search2_0.value, &search331_1.value },
   NULL,
};

   /* replace331 -> replace197 in the cache */

   /* search332_0_0 -> search14_0 in the cache */

/* search332_0_1 -> replace14_1_0 in the cache */
/* search332_0 -> replace221 in the cache */

/* search332_1 -> search14_0 in the cache */
static const nir_search_expression search332 = {
   { nir_search_value_expression, 1 },
   true,
   -1, 0,
   nir_op_fge,
   { &replace221.value, &search14_0.value },
   NULL,
};

   /* replace332 -> replace197 in the cache */

   /* search333_0 -> search2_0 in the cache */

/* search333_1_0 -> search329_1_0 in the cache */

/* search333_1_1 -> search2_0 in the cache */
/* search333_1 -> search331_1 in the cache */
static const nir_search_expression search333 = {
   { nir_search_value_expression, 1 },
   true,
   -1, 0,
   nir_op_flt,
   { &search2_0.value, &search331_1.value },
   NULL,
};

   /* replace333 -> replace121 in the cache */

   /* search334_0_0 -> search14_0 in the cache */

/* search334_0_1 -> replace14_1_0 in the cache */
/* search334_0 -> replace221 in the cache */

/* search334_1 -> search14_0 in the cache */
static const nir_search_expression search334 = {
   { nir_search_value_expression, 1 },
   true,
   -1, 0,
   nir_op_flt,
   { &replace221.value, &search14_0.value },
   NULL,
};

   /* replace334 -> replace121 in the cache */

   /* search335_0 -> search2_0 in the cache */

/* search335_1_0 -> search329_1_0 in the cache */

/* search335_1_1 -> search2_0 in the cache */
/* search335_1 -> search329_1 in the cache */
static const nir_search_expression search335 = {
   { nir_search_value_expression, 1 },
   true,
   -1, 0,
   nir_op_fge,
   { &search2_0.value, &search329_1.value },
   NULL,
};

   /* replace335_0 -> search2_0 in the cache */

/* replace335_1 -> search329_1_0 in the cache */
static const nir_search_expression replace335 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search2_0.value, &search329_1_0.value },
   NULL,
};

   /* search336_0_0 -> search14_0 in the cache */

/* search336_0_1 -> replace14_1_0 in the cache */
/* search336_0 -> replace222 in the cache */

/* search336_1 -> search14_0 in the cache */
static const nir_search_expression search336 = {
   { nir_search_value_expression, 1 },
   true,
   -1, 0,
   nir_op_fge,
   { &replace222.value, &search14_0.value },
   NULL,
};

   /* replace336_0 -> replace14_1_0 in the cache */

/* replace336_1 -> search14_0 in the cache */
/* replace336 -> replace127 in the cache */

   /* search337_0 -> search2_0 in the cache */

/* search337_1_0 -> search329_1_0 in the cache */

/* search337_1_1 -> search2_0 in the cache */
static const nir_search_expression search337_1 = {
   { nir_search_value_expression, -1 },
   false,
   0, 1,
   nir_op_imax,
   { &search329_1_0.value, &search2_0.value },
   NULL,
};
static const nir_search_expression search337 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_ilt,
   { &search2_0.value, &search337_1.value },
   NULL,
};

   /* replace337_0 -> search2_0 in the cache */

/* replace337_1 -> search329_1_0 in the cache */
static const nir_search_expression replace337 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search2_0.value, &search329_1_0.value },
   NULL,
};

   /* search338_0_0 -> search14_0 in the cache */

/* search338_0_1 -> replace14_1_0 in the cache */
/* search338_0 -> replace247 in the cache */

/* search338_1 -> search14_0 in the cache */
static const nir_search_expression search338 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_ilt,
   { &replace247.value, &search14_0.value },
   NULL,
};

   /* replace338_0 -> replace14_1_0 in the cache */

/* replace338_1 -> search14_0 in the cache */
/* replace338 -> search124_1 in the cache */

   /* search339_0 -> search2_0 in the cache */

/* search339_1_0 -> search329_1_0 in the cache */

/* search339_1_1 -> search2_0 in the cache */
static const nir_search_expression search339_1 = {
   { nir_search_value_expression, -1 },
   false,
   0, 1,
   nir_op_imin,
   { &search329_1_0.value, &search2_0.value },
   NULL,
};
static const nir_search_expression search339 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_ige,
   { &search2_0.value, &search339_1.value },
   NULL,
};

   /* replace339 -> replace197 in the cache */

   /* search340_0_0 -> search14_0 in the cache */

/* search340_0_1 -> replace14_1_0 in the cache */
/* search340_0 -> replace244 in the cache */

/* search340_1 -> search14_0 in the cache */
static const nir_search_expression search340 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_ige,
   { &replace244.value, &search14_0.value },
   NULL,
};

   /* replace340 -> replace197 in the cache */

   /* search341_0 -> search2_0 in the cache */

/* search341_1_0 -> search329_1_0 in the cache */

/* search341_1_1 -> search2_0 in the cache */
static const nir_search_expression search341_1 = {
   { nir_search_value_expression, -1 },
   false,
   0, 1,
   nir_op_umax,
   { &search329_1_0.value, &search2_0.value },
   NULL,
};
static const nir_search_expression search341 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_ult,
   { &search2_0.value, &search341_1.value },
   NULL,
};

   /* replace341_0 -> search2_0 in the cache */

/* replace341_1 -> search329_1_0 in the cache */
static const nir_search_expression replace341 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search2_0.value, &search329_1_0.value },
   NULL,
};

   /* search342_0_0 -> search14_0 in the cache */

/* search342_0_1 -> replace14_1_0 in the cache */
/* search342_0 -> replace246 in the cache */

/* search342_1 -> search14_0 in the cache */
static const nir_search_expression search342 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_ult,
   { &replace246.value, &search14_0.value },
   NULL,
};

   /* replace342_0 -> replace14_1_0 in the cache */

/* replace342_1 -> search14_0 in the cache */
/* replace342 -> search125_1 in the cache */

   /* search343_0 -> search2_0 in the cache */

/* search343_1_0 -> search329_1_0 in the cache */

/* search343_1_1 -> search2_0 in the cache */
static const nir_search_expression search343_1 = {
   { nir_search_value_expression, -1 },
   false,
   0, 1,
   nir_op_umin,
   { &search329_1_0.value, &search2_0.value },
   NULL,
};
static const nir_search_expression search343 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_uge,
   { &search2_0.value, &search343_1.value },
   NULL,
};

   /* replace343 -> replace197 in the cache */

   /* search344_0_0 -> search14_0 in the cache */

/* search344_0_1 -> replace14_1_0 in the cache */
/* search344_0 -> replace243 in the cache */

/* search344_1 -> search14_0 in the cache */
static const nir_search_expression search344 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_uge,
   { &replace243.value, &search14_0.value },
   NULL,
};

   /* replace344 -> replace197 in the cache */

   /* search345_0 -> search2_0 in the cache */

/* search345_1_0 -> search329_1_0 in the cache */

/* search345_1_1 -> search2_0 in the cache */
/* search345_1 -> search339_1 in the cache */
static const nir_search_expression search345 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_ilt,
   { &search2_0.value, &search339_1.value },
   NULL,
};

   /* replace345 -> replace121 in the cache */

   /* search346_0_0 -> search14_0 in the cache */

/* search346_0_1 -> replace14_1_0 in the cache */
/* search346_0 -> replace244 in the cache */

/* search346_1 -> search14_0 in the cache */
static const nir_search_expression search346 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_ilt,
   { &replace244.value, &search14_0.value },
   NULL,
};

   /* replace346 -> replace121 in the cache */

   /* search347_0 -> search2_0 in the cache */

/* search347_1_0 -> search329_1_0 in the cache */

/* search347_1_1 -> search2_0 in the cache */
/* search347_1 -> search337_1 in the cache */
static const nir_search_expression search347 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_ige,
   { &search2_0.value, &search337_1.value },
   NULL,
};

   /* replace347_0 -> search2_0 in the cache */

/* replace347_1 -> search329_1_0 in the cache */
static const nir_search_expression replace347 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search2_0.value, &search329_1_0.value },
   NULL,
};

   /* search348_0_0 -> search14_0 in the cache */

/* search348_0_1 -> replace14_1_0 in the cache */
/* search348_0 -> replace247 in the cache */

/* search348_1 -> search14_0 in the cache */
static const nir_search_expression search348 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_ige,
   { &replace247.value, &search14_0.value },
   NULL,
};

   /* replace348_0 -> replace14_1_0 in the cache */

/* replace348_1 -> search14_0 in the cache */
static const nir_search_expression replace348 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &replace14_1_0.value, &search14_0.value },
   NULL,
};

   /* search349_0 -> search2_0 in the cache */

/* search349_1_0 -> search329_1_0 in the cache */

/* search349_1_1 -> search2_0 in the cache */
/* search349_1 -> search343_1 in the cache */
static const nir_search_expression search349 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_ult,
   { &search2_0.value, &search343_1.value },
   NULL,
};

   /* replace349 -> replace121 in the cache */

   /* search350_0_0 -> search14_0 in the cache */

/* search350_0_1 -> replace14_1_0 in the cache */
/* search350_0 -> replace243 in the cache */

/* search350_1 -> search14_0 in the cache */
static const nir_search_expression search350 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_ult,
   { &replace243.value, &search14_0.value },
   NULL,
};

   /* replace350 -> replace121 in the cache */

   /* search351_0 -> search2_0 in the cache */

/* search351_1_0 -> search329_1_0 in the cache */

/* search351_1_1 -> search2_0 in the cache */
/* search351_1 -> search341_1 in the cache */
static const nir_search_expression search351 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_uge,
   { &search2_0.value, &search341_1.value },
   NULL,
};

   /* replace351_0 -> search2_0 in the cache */

/* replace351_1 -> search329_1_0 in the cache */
static const nir_search_expression replace351 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search2_0.value, &search329_1_0.value },
   NULL,
};

   /* search352_0_0 -> search14_0 in the cache */

/* search352_0_1 -> replace14_1_0 in the cache */
/* search352_0 -> replace246 in the cache */

/* search352_1 -> search14_0 in the cache */
static const nir_search_expression search352 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_uge,
   { &replace246.value, &search14_0.value },
   NULL,
};

   /* replace352_0 -> replace14_1_0 in the cache */

/* replace352_1 -> search14_0 in the cache */
static const nir_search_expression replace352 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &replace14_1_0.value, &search14_0.value },
   NULL,
};

   /* search353_0 -> search2_0 in the cache */

/* search353_1_0 -> search329_1_0 in the cache */

/* search353_1_1 -> search2_0 in the cache */
static const nir_search_expression search353_1 = {
   { nir_search_value_expression, -1 },
   false,
   0, 1,
   nir_op_iand,
   { &search329_1_0.value, &search2_0.value },
   NULL,
};
static const nir_search_expression search353 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_ult,
   { &search2_0.value, &search353_1.value },
   NULL,
};

   /* replace353 -> replace121 in the cache */

   /* search354_0_0 -> search14_0 in the cache */

/* search354_0_1 -> replace14_1_0 in the cache */
static const nir_search_expression search354_0 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_ior,
   { &search14_0.value, &replace14_1_0.value },
   NULL,
};

/* search354_1 -> search14_0 in the cache */
static const nir_search_expression search354 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_ult,
   { &search354_0.value, &search14_0.value },
   NULL,
};

   /* replace354 -> replace121 in the cache */

   /* search355_0 -> search2_0 in the cache */

/* search355_1_0 -> search329_1_0 in the cache */

/* search355_1_1 -> search2_0 in the cache */
/* search355_1 -> search353_1 in the cache */
static const nir_search_expression search355 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_uge,
   { &search2_0.value, &search353_1.value },
   NULL,
};

   /* replace355 -> replace197 in the cache */

   /* search356_0_0 -> search14_0 in the cache */

/* search356_0_1 -> replace14_1_0 in the cache */
/* search356_0 -> search354_0 in the cache */

/* search356_1 -> search14_0 in the cache */
static const nir_search_expression search356 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_uge,
   { &search354_0.value, &search14_0.value },
   NULL,
};

   /* replace356 -> replace197 in the cache */

   static const nir_search_variable search357_0 = {
   { nir_search_value_variable, -3 },
   0, /* a */
   true,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

/* search357_1_0 -> search96_0_0_1 in the cache */

/* search357_1_1 -> search28_1_1 in the cache */
static const nir_search_expression search357_1 = {
   { nir_search_value_expression, -3 },
   false,
   0, 1,
   nir_op_imax,
   { &search96_0_0_1.value, &search28_1_1.value },
   NULL,
};
static const nir_search_expression search357 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_ilt,
   { &search357_0.value, &search357_1.value },
   NULL,
};

   /* replace357_0_0 -> search28_0_0 in the cache */

/* replace357_0_1 -> search28_0_1 in the cache */
static const nir_search_expression replace357_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search28_0_0.value, &search28_0_1.value },
   NULL,
};

/* replace357_1_0 -> search28_0_0 in the cache */

/* replace357_1_1 -> search28_1_1 in the cache */
/* replace357_1 -> search296_1 in the cache */
static const nir_search_expression replace357 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ior,
   { &replace357_0.value, &search296_1.value },
   NULL,
};

   /* search358_0_0 -> search357_0 in the cache */

/* search358_0_1 -> search28_0_1 in the cache */
static const nir_search_expression search358_0 = {
   { nir_search_value_expression, -3 },
   false,
   0, 1,
   nir_op_imin,
   { &search357_0.value, &search28_0_1.value },
   NULL,
};

/* search358_1 -> search96_0_1 in the cache */
static const nir_search_expression search358 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_ilt,
   { &search358_0.value, &search96_0_1.value },
   NULL,
};

   /* replace358_0_0 -> search28_0_0 in the cache */

/* replace358_0_1 -> search28_1_1 in the cache */
/* replace358_0 -> search296_1 in the cache */

/* replace358_1_0 -> search28_0_1 in the cache */

/* replace358_1_1 -> search28_1_1 in the cache */
static const nir_search_expression replace358_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search28_0_1.value, &search28_1_1.value },
   NULL,
};
static const nir_search_expression replace358 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ior,
   { &search296_1.value, &replace358_1.value },
   NULL,
};

   /* search359_0 -> search357_0 in the cache */

/* search359_1_0 -> search96_0_0_1 in the cache */

/* search359_1_1 -> search28_1_1 in the cache */
static const nir_search_expression search359_1 = {
   { nir_search_value_expression, -3 },
   false,
   0, 1,
   nir_op_imin,
   { &search96_0_0_1.value, &search28_1_1.value },
   NULL,
};
static const nir_search_expression search359 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_ige,
   { &search357_0.value, &search359_1.value },
   NULL,
};

   /* replace359_0_0 -> search28_0_0 in the cache */

/* replace359_0_1 -> search28_0_1 in the cache */
static const nir_search_expression replace359_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search28_0_0.value, &search28_0_1.value },
   NULL,
};

/* replace359_1_0 -> search28_0_0 in the cache */

/* replace359_1_1 -> search28_1_1 in the cache */
/* replace359_1 -> search298_1 in the cache */
static const nir_search_expression replace359 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ior,
   { &replace359_0.value, &search298_1.value },
   NULL,
};

   /* search360_0_0 -> search357_0 in the cache */

/* search360_0_1 -> search28_0_1 in the cache */
static const nir_search_expression search360_0 = {
   { nir_search_value_expression, -3 },
   false,
   0, 1,
   nir_op_imax,
   { &search357_0.value, &search28_0_1.value },
   NULL,
};

/* search360_1 -> search96_0_1 in the cache */
static const nir_search_expression search360 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_ige,
   { &search360_0.value, &search96_0_1.value },
   NULL,
};

   /* replace360_0_0 -> search28_0_0 in the cache */

/* replace360_0_1 -> search28_1_1 in the cache */
/* replace360_0 -> search298_1 in the cache */

/* replace360_1_0 -> search28_0_1 in the cache */

/* replace360_1_1 -> search28_1_1 in the cache */
static const nir_search_expression replace360_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search28_0_1.value, &search28_1_1.value },
   NULL,
};
static const nir_search_expression replace360 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ior,
   { &search298_1.value, &replace360_1.value },
   NULL,
};

   /* search361_0 -> search357_0 in the cache */

/* search361_1_0 -> search96_0_0_1 in the cache */

/* search361_1_1 -> search28_1_1 in the cache */
static const nir_search_expression search361_1 = {
   { nir_search_value_expression, -3 },
   false,
   0, 1,
   nir_op_umax,
   { &search96_0_0_1.value, &search28_1_1.value },
   NULL,
};
static const nir_search_expression search361 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_ult,
   { &search357_0.value, &search361_1.value },
   NULL,
};

   /* replace361_0_0 -> search28_0_0 in the cache */

/* replace361_0_1 -> search28_0_1 in the cache */
static const nir_search_expression replace361_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search28_0_0.value, &search28_0_1.value },
   NULL,
};

/* replace361_1_0 -> search28_0_0 in the cache */

/* replace361_1_1 -> search28_1_1 in the cache */
/* replace361_1 -> search300_1 in the cache */
static const nir_search_expression replace361 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ior,
   { &replace361_0.value, &search300_1.value },
   NULL,
};

   /* search362_0_0 -> search357_0 in the cache */

/* search362_0_1 -> search28_0_1 in the cache */
static const nir_search_expression search362_0 = {
   { nir_search_value_expression, -3 },
   false,
   0, 1,
   nir_op_umin,
   { &search357_0.value, &search28_0_1.value },
   NULL,
};

/* search362_1 -> search96_0_1 in the cache */
static const nir_search_expression search362 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_ult,
   { &search362_0.value, &search96_0_1.value },
   NULL,
};

   /* replace362_0_0 -> search28_0_0 in the cache */

/* replace362_0_1 -> search28_1_1 in the cache */
/* replace362_0 -> search300_1 in the cache */

/* replace362_1_0 -> search28_0_1 in the cache */

/* replace362_1_1 -> search28_1_1 in the cache */
static const nir_search_expression replace362_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search28_0_1.value, &search28_1_1.value },
   NULL,
};
static const nir_search_expression replace362 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ior,
   { &search300_1.value, &replace362_1.value },
   NULL,
};

   /* search363_0 -> search357_0 in the cache */

/* search363_1_0 -> search96_0_0_1 in the cache */

/* search363_1_1 -> search28_1_1 in the cache */
static const nir_search_expression search363_1 = {
   { nir_search_value_expression, -3 },
   false,
   0, 1,
   nir_op_umin,
   { &search96_0_0_1.value, &search28_1_1.value },
   NULL,
};
static const nir_search_expression search363 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_uge,
   { &search357_0.value, &search363_1.value },
   NULL,
};

   /* replace363_0_0 -> search28_0_0 in the cache */

/* replace363_0_1 -> search28_0_1 in the cache */
static const nir_search_expression replace363_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search28_0_0.value, &search28_0_1.value },
   NULL,
};

/* replace363_1_0 -> search28_0_0 in the cache */

/* replace363_1_1 -> search28_1_1 in the cache */
/* replace363_1 -> search302_1 in the cache */
static const nir_search_expression replace363 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ior,
   { &replace363_0.value, &search302_1.value },
   NULL,
};

   /* search364_0_0 -> search357_0 in the cache */

/* search364_0_1 -> search28_0_1 in the cache */
static const nir_search_expression search364_0 = {
   { nir_search_value_expression, -3 },
   false,
   0, 1,
   nir_op_umax,
   { &search357_0.value, &search28_0_1.value },
   NULL,
};

/* search364_1 -> search96_0_1 in the cache */
static const nir_search_expression search364 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_uge,
   { &search364_0.value, &search96_0_1.value },
   NULL,
};

   /* replace364_0_0 -> search28_0_0 in the cache */

/* replace364_0_1 -> search28_1_1 in the cache */
/* replace364_0 -> search302_1 in the cache */

/* replace364_1_0 -> search28_0_1 in the cache */

/* replace364_1_1 -> search28_1_1 in the cache */
static const nir_search_expression replace364_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search28_0_1.value, &search28_1_1.value },
   NULL,
};
static const nir_search_expression replace364 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ior,
   { &search302_1.value, &replace364_1.value },
   NULL,
};

   /* search365_0 -> search357_0 in the cache */

/* search365_1_0 -> search96_0_0_1 in the cache */

/* search365_1_1 -> search28_1_1 in the cache */
/* search365_1 -> search359_1 in the cache */
static const nir_search_expression search365 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_ilt,
   { &search357_0.value, &search359_1.value },
   NULL,
};

   /* replace365_0_0 -> search28_0_0 in the cache */

/* replace365_0_1 -> search28_0_1 in the cache */
/* replace365_0 -> replace357_0 in the cache */

/* replace365_1_0 -> search28_0_0 in the cache */

/* replace365_1_1 -> search28_1_1 in the cache */
/* replace365_1 -> search296_1 in the cache */
static const nir_search_expression replace365 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_iand,
   { &replace357_0.value, &search296_1.value },
   NULL,
};

   /* search366_0_0 -> search357_0 in the cache */

/* search366_0_1 -> search28_0_1 in the cache */
/* search366_0 -> search360_0 in the cache */

/* search366_1 -> search96_0_1 in the cache */
static const nir_search_expression search366 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_ilt,
   { &search360_0.value, &search96_0_1.value },
   NULL,
};

   /* replace366_0_0 -> search28_0_0 in the cache */

/* replace366_0_1 -> search28_1_1 in the cache */
/* replace366_0 -> search296_1 in the cache */

/* replace366_1_0 -> search28_0_1 in the cache */

/* replace366_1_1 -> search28_1_1 in the cache */
/* replace366_1 -> replace358_1 in the cache */
static const nir_search_expression replace366 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_iand,
   { &search296_1.value, &replace358_1.value },
   NULL,
};

   /* search367_0 -> search357_0 in the cache */

/* search367_1_0 -> search96_0_0_1 in the cache */

/* search367_1_1 -> search28_1_1 in the cache */
/* search367_1 -> search357_1 in the cache */
static const nir_search_expression search367 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_ige,
   { &search357_0.value, &search357_1.value },
   NULL,
};

   /* replace367_0_0 -> search28_0_0 in the cache */

/* replace367_0_1 -> search28_0_1 in the cache */
/* replace367_0 -> replace359_0 in the cache */

/* replace367_1_0 -> search28_0_0 in the cache */

/* replace367_1_1 -> search28_1_1 in the cache */
/* replace367_1 -> search298_1 in the cache */
static const nir_search_expression replace367 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_iand,
   { &replace359_0.value, &search298_1.value },
   NULL,
};

   /* search368_0_0 -> search357_0 in the cache */

/* search368_0_1 -> search28_0_1 in the cache */
/* search368_0 -> search358_0 in the cache */

/* search368_1 -> search96_0_1 in the cache */
static const nir_search_expression search368 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_ige,
   { &search358_0.value, &search96_0_1.value },
   NULL,
};

   /* replace368_0_0 -> search28_0_0 in the cache */

/* replace368_0_1 -> search28_1_1 in the cache */
/* replace368_0 -> search298_1 in the cache */

/* replace368_1_0 -> search28_0_1 in the cache */

/* replace368_1_1 -> search28_1_1 in the cache */
/* replace368_1 -> replace360_1 in the cache */
static const nir_search_expression replace368 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_iand,
   { &search298_1.value, &replace360_1.value },
   NULL,
};

   /* search369_0 -> search357_0 in the cache */

/* search369_1_0 -> search96_0_0_1 in the cache */

/* search369_1_1 -> search28_1_1 in the cache */
/* search369_1 -> search363_1 in the cache */
static const nir_search_expression search369 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_ult,
   { &search357_0.value, &search363_1.value },
   NULL,
};

   /* replace369_0_0 -> search28_0_0 in the cache */

/* replace369_0_1 -> search28_0_1 in the cache */
/* replace369_0 -> replace361_0 in the cache */

/* replace369_1_0 -> search28_0_0 in the cache */

/* replace369_1_1 -> search28_1_1 in the cache */
/* replace369_1 -> search300_1 in the cache */
static const nir_search_expression replace369 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_iand,
   { &replace361_0.value, &search300_1.value },
   NULL,
};

   /* search370_0_0 -> search357_0 in the cache */

/* search370_0_1 -> search28_0_1 in the cache */
/* search370_0 -> search364_0 in the cache */

/* search370_1 -> search96_0_1 in the cache */
static const nir_search_expression search370 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_ult,
   { &search364_0.value, &search96_0_1.value },
   NULL,
};

   /* replace370_0_0 -> search28_0_0 in the cache */

/* replace370_0_1 -> search28_1_1 in the cache */
/* replace370_0 -> search300_1 in the cache */

/* replace370_1_0 -> search28_0_1 in the cache */

/* replace370_1_1 -> search28_1_1 in the cache */
/* replace370_1 -> replace362_1 in the cache */
static const nir_search_expression replace370 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_iand,
   { &search300_1.value, &replace362_1.value },
   NULL,
};

   /* search371_0 -> search357_0 in the cache */

/* search371_1_0 -> search96_0_0_1 in the cache */

/* search371_1_1 -> search28_1_1 in the cache */
/* search371_1 -> search361_1 in the cache */
static const nir_search_expression search371 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_uge,
   { &search357_0.value, &search361_1.value },
   NULL,
};

   /* replace371_0_0 -> search28_0_0 in the cache */

/* replace371_0_1 -> search28_0_1 in the cache */
/* replace371_0 -> replace363_0 in the cache */

/* replace371_1_0 -> search28_0_0 in the cache */

/* replace371_1_1 -> search28_1_1 in the cache */
/* replace371_1 -> search302_1 in the cache */
static const nir_search_expression replace371 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_iand,
   { &replace363_0.value, &search302_1.value },
   NULL,
};

   /* search372_0_0 -> search357_0 in the cache */

/* search372_0_1 -> search28_0_1 in the cache */
/* search372_0 -> search362_0 in the cache */

/* search372_1 -> search96_0_1 in the cache */
static const nir_search_expression search372 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_uge,
   { &search362_0.value, &search96_0_1.value },
   NULL,
};

   /* replace372_0_0 -> search28_0_0 in the cache */

/* replace372_0_1 -> search28_1_1 in the cache */
/* replace372_0 -> search302_1 in the cache */

/* replace372_1_0 -> search28_0_1 in the cache */

/* replace372_1_1 -> search28_1_1 in the cache */
/* replace372_1 -> replace364_1 in the cache */
static const nir_search_expression replace372 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_iand,
   { &search302_1.value, &replace364_1.value },
   NULL,
};

   /* search373_0_0 -> search2_0 in the cache */

/* search373_0_1 -> replace9 in the cache */
/* search373_0 -> replace205 in the cache */

/* search373_1_0_0 -> search2_0 in the cache */

/* search373_1_0_1 -> replace0_1_0 in the cache */
static const nir_search_expression search373_1_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_ishr,
   { &search2_0.value, &replace0_1_0.value },
   NULL,
};
static const nir_search_expression search373_1 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_ineg,
   { &search373_1_0.value },
   NULL,
};

/* search373_2_0 -> search2_0 in the cache */

/* search373_2_1 -> replace0_1_0 in the cache */
/* search373_2 -> search373_1_0 in the cache */
static const nir_search_expression search373 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace205.value, &search373_1.value, &search373_1_0.value },
   NULL,
};

   /* replace373_0_0 -> search2_0 in the cache */

/* replace373_0_1 -> replace0_1_0 in the cache */
/* replace373_0 -> search373_1_0 in the cache */
static const nir_search_expression replace373 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_iabs,
   { &search373_1_0.value },
   NULL,
};

   /* search374_0_0_0 -> search2_0 in the cache */
/* search374_0_0 -> search20_0 in the cache */

/* search374_0_1 -> replace0_1_0 in the cache */
static const nir_search_expression search374_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_ishr,
   { &search20_0.value, &replace0_1_0.value },
   NULL,
};
static const nir_search_expression search374 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_iabs,
   { &search374_0.value },
   NULL,
};

   /* replace374_0_0 -> search2_0 in the cache */
/* replace374_0 -> search20_0 in the cache */

/* replace374_1 -> replace0_1_0 in the cache */
/* replace374 -> search374_0 in the cache */

   /* search375_0_0 -> search0_0 in the cache */

/* search375_0_1 -> replace0_1_0 in the cache */
static const nir_search_expression search375_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_slt,
   { &search0_0.value, &replace0_1_0.value },
   NULL,
};
static const nir_search_expression search375 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_fabs,
   { &search375_0.value },
   NULL,
};

   /* replace375_0 -> search0_0 in the cache */

/* replace375_1 -> replace0_1_0 in the cache */
/* replace375 -> search375_0 in the cache */

   /* search376_0_0 -> search14_0 in the cache */

/* search376_0_1 -> replace14_1_0 in the cache */
static const nir_search_expression search376_0 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_sge,
   { &search14_0.value, &replace14_1_0.value },
   NULL,
};
static const nir_search_expression search376 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_fabs,
   { &search376_0.value },
   NULL,
};

   /* replace376_0 -> search14_0 in the cache */

/* replace376_1 -> replace14_1_0 in the cache */
/* replace376 -> search376_0 in the cache */

   /* search377_0_0 -> search0_0 in the cache */

/* search377_0_1 -> replace0_1_0 in the cache */
static const nir_search_expression search377_0 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_seq,
   { &search0_0.value, &replace0_1_0.value },
   NULL,
};
static const nir_search_expression search377 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_op_fabs,
   { &search377_0.value },
   NULL,
};

   /* replace377_0 -> search0_0 in the cache */

/* replace377_1 -> replace0_1_0 in the cache */
/* replace377 -> search377_0 in the cache */

   /* search378_0_0 -> search0_0 in the cache */

/* search378_0_1 -> replace0_1_0 in the cache */
static const nir_search_expression search378_0 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_sne,
   { &search0_0.value, &replace0_1_0.value },
   NULL,
};
static const nir_search_expression search378 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_op_fabs,
   { &search378_0.value },
   NULL,
};

   /* replace378_0 -> search0_0 in the cache */

/* replace378_1 -> replace0_1_0 in the cache */
/* replace378 -> search378_0 in the cache */

   /* search379_0 -> search0_0 in the cache */

/* search379_1 -> replace0_1_0 in the cache */
/* search379 -> search375_0 in the cache */

   /* replace379_0_0 -> search0_0 in the cache */

/* replace379_0_1 -> replace0_1_0 in the cache */
static const nir_search_expression replace379_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search0_0.value, &replace0_1_0.value },
   NULL,
};
static const nir_search_expression replace379 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_search_op_b2f,
   { &replace379_0.value },
   NULL,
};

   /* search380_0 -> search14_0 in the cache */

/* search380_1 -> replace14_1_0 in the cache */
/* search380 -> search376_0 in the cache */

   /* replace380_0_0 -> search14_0 in the cache */

/* replace380_0_1 -> replace14_1_0 in the cache */
/* replace380_0 -> replace111 in the cache */
static const nir_search_expression replace380 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_search_op_b2f,
   { &replace111.value },
   NULL,
};

   /* search381_0 -> search0_0 in the cache */

/* search381_1 -> replace0_1_0 in the cache */
/* search381 -> search377_0 in the cache */

   /* replace381_0_0 -> search0_0 in the cache */

/* replace381_0_1 -> replace0_1_0 in the cache */
static const nir_search_expression replace381_0 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_feq,
   { &search0_0.value, &replace0_1_0.value },
   NULL,
};
static const nir_search_expression replace381 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_search_op_b2f,
   { &replace381_0.value },
   NULL,
};

   /* search382_0 -> search0_0 in the cache */

/* search382_1 -> replace0_1_0 in the cache */
/* search382 -> search378_0 in the cache */

   /* replace382_0_0 -> search0_0 in the cache */

/* replace382_0_1 -> replace0_1_0 in the cache */
static const nir_search_expression replace382_0 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_fne,
   { &search0_0.value, &replace0_1_0.value },
   NULL,
};
static const nir_search_expression replace382 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_search_op_b2f,
   { &replace382_0.value },
   NULL,
};

   /* search383_0_0 -> search0_0 in the cache */

/* search383_0_1 -> replace0_1_0 in the cache */
static const nir_search_expression search383_0 = {
   { nir_search_value_expression, 32 },
   false,
   1, 1,
   nir_op_seq,
   { &search0_0.value, &replace0_1_0.value },
   NULL,
};

/* search383_1 -> replace60_0_0 in the cache */
static const nir_search_expression search383 = {
   { nir_search_value_expression, 32 },
   false,
   0, 2,
   nir_op_seq,
   { &search383_0.value, &replace60_0_0.value },
   NULL,
};

   /* replace383_0 -> search0_0 in the cache */

/* replace383_1 -> replace0_1_0 in the cache */
/* replace383 -> search377_0 in the cache */

   /* search384_0_0 -> search0_0 in the cache */

/* search384_0_1 -> replace0_1_0 in the cache */
static const nir_search_expression search384_0 = {
   { nir_search_value_expression, 32 },
   false,
   1, 1,
   nir_op_sne,
   { &search0_0.value, &replace0_1_0.value },
   NULL,
};

/* search384_1 -> replace60_0_0 in the cache */
static const nir_search_expression search384 = {
   { nir_search_value_expression, 32 },
   false,
   0, 2,
   nir_op_seq,
   { &search384_0.value, &replace60_0_0.value },
   NULL,
};

   /* replace384_0 -> search0_0 in the cache */

/* replace384_1 -> replace0_1_0 in the cache */
/* replace384 -> search378_0 in the cache */

   /* search385_0_0 -> search0_0 in the cache */

/* search385_0_1 -> replace0_1_0 in the cache */
/* search385_0 -> search375_0 in the cache */

/* search385_1 -> replace60_0_0 in the cache */
static const nir_search_expression search385 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_seq,
   { &search375_0.value, &replace60_0_0.value },
   NULL,
};

   /* replace385_0 -> search0_0 in the cache */

/* replace385_1 -> replace0_1_0 in the cache */
/* replace385 -> search375_0 in the cache */

   /* search386_0_0 -> search0_0 in the cache */

/* search386_0_1 -> replace0_1_0 in the cache */
static const nir_search_expression search386_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_sge,
   { &search0_0.value, &replace0_1_0.value },
   NULL,
};

/* search386_1 -> replace60_0_0 in the cache */
static const nir_search_expression search386 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_seq,
   { &search386_0.value, &replace60_0_0.value },
   NULL,
};

   /* replace386_0 -> search0_0 in the cache */

/* replace386_1 -> replace0_1_0 in the cache */
/* replace386 -> search386_0 in the cache */

   /* search387_0_0 -> search0_0 in the cache */

/* search387_0_1 -> replace0_1_0 in the cache */
/* search387_0 -> search383_0 in the cache */

/* search387_1 -> search312_0_0 in the cache */
static const nir_search_expression search387 = {
   { nir_search_value_expression, 32 },
   false,
   0, 2,
   nir_op_sne,
   { &search383_0.value, &search312_0_0.value },
   NULL,
};

   /* replace387_0 -> search0_0 in the cache */

/* replace387_1 -> replace0_1_0 in the cache */
/* replace387 -> search377_0 in the cache */

   /* search388_0_0 -> search0_0 in the cache */

/* search388_0_1 -> replace0_1_0 in the cache */
/* search388_0 -> search384_0 in the cache */

/* search388_1 -> search312_0_0 in the cache */
static const nir_search_expression search388 = {
   { nir_search_value_expression, 32 },
   false,
   0, 2,
   nir_op_sne,
   { &search384_0.value, &search312_0_0.value },
   NULL,
};

   /* replace388_0 -> search0_0 in the cache */

/* replace388_1 -> replace0_1_0 in the cache */
/* replace388 -> search378_0 in the cache */

   /* search389_0_0 -> search0_0 in the cache */

/* search389_0_1 -> replace0_1_0 in the cache */
/* search389_0 -> search375_0 in the cache */

/* search389_1 -> search312_0_0 in the cache */
static const nir_search_expression search389 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_sne,
   { &search375_0.value, &search312_0_0.value },
   NULL,
};

   /* replace389_0 -> search0_0 in the cache */

/* replace389_1 -> replace0_1_0 in the cache */
/* replace389 -> search375_0 in the cache */

   /* search390_0_0 -> search0_0 in the cache */

/* search390_0_1 -> replace0_1_0 in the cache */
/* search390_0 -> search386_0 in the cache */

/* search390_1 -> search312_0_0 in the cache */
static const nir_search_expression search390 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_sne,
   { &search386_0.value, &search312_0_0.value },
   NULL,
};

   /* replace390_0 -> search0_0 in the cache */

/* replace390_1 -> replace0_1_0 in the cache */
/* replace390 -> search386_0 in the cache */

   /* search391_0_0 -> search0_0 in the cache */

/* search391_0_1 -> replace0_1_0 in the cache */
/* search391_0 -> search383_0 in the cache */

/* search391_1 -> search312_0_0 in the cache */
static const nir_search_expression search391 = {
   { nir_search_value_expression, 32 },
   false,
   0, 2,
   nir_op_seq,
   { &search383_0.value, &search312_0_0.value },
   NULL,
};

   /* replace391_0 -> search0_0 in the cache */

/* replace391_1 -> replace0_1_0 in the cache */
/* replace391 -> search378_0 in the cache */

   /* search392_0_0 -> search0_0 in the cache */

/* search392_0_1 -> replace0_1_0 in the cache */
/* search392_0 -> search384_0 in the cache */

/* search392_1 -> search312_0_0 in the cache */
static const nir_search_expression search392 = {
   { nir_search_value_expression, 32 },
   false,
   0, 2,
   nir_op_seq,
   { &search384_0.value, &search312_0_0.value },
   NULL,
};

   /* replace392_0 -> search0_0 in the cache */

/* replace392_1 -> replace0_1_0 in the cache */
/* replace392 -> search377_0 in the cache */

   /* search393_0_0 -> search0_0 in the cache */

/* search393_0_1 -> replace0_1_0 in the cache */
/* search393_0 -> search375_0 in the cache */

/* search393_1 -> search312_0_0 in the cache */
static const nir_search_expression search393 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_seq,
   { &search375_0.value, &search312_0_0.value },
   NULL,
};

   /* replace393_0 -> search0_0 in the cache */

/* replace393_1 -> replace0_1_0 in the cache */
/* replace393 -> search386_0 in the cache */

   /* search394_0_0 -> search0_0 in the cache */

/* search394_0_1 -> replace0_1_0 in the cache */
/* search394_0 -> search386_0 in the cache */

/* search394_1 -> search312_0_0 in the cache */
static const nir_search_expression search394 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_seq,
   { &search386_0.value, &search312_0_0.value },
   NULL,
};

   /* replace394_0 -> search0_0 in the cache */

/* replace394_1 -> replace0_1_0 in the cache */
/* replace394 -> search375_0 in the cache */

   /* search395_0_0 -> search0_0 in the cache */

/* search395_0_1 -> replace0_1_0 in the cache */
/* search395_0 -> search383_0 in the cache */

/* search395_1 -> replace60_0_0 in the cache */
static const nir_search_expression search395 = {
   { nir_search_value_expression, 32 },
   false,
   0, 2,
   nir_op_sne,
   { &search383_0.value, &replace60_0_0.value },
   NULL,
};

   /* replace395_0 -> search0_0 in the cache */

/* replace395_1 -> replace0_1_0 in the cache */
/* replace395 -> search378_0 in the cache */

   /* search396_0_0 -> search0_0 in the cache */

/* search396_0_1 -> replace0_1_0 in the cache */
/* search396_0 -> search384_0 in the cache */

/* search396_1 -> replace60_0_0 in the cache */
static const nir_search_expression search396 = {
   { nir_search_value_expression, 32 },
   false,
   0, 2,
   nir_op_sne,
   { &search384_0.value, &replace60_0_0.value },
   NULL,
};

   /* replace396_0 -> search0_0 in the cache */

/* replace396_1 -> replace0_1_0 in the cache */
/* replace396 -> search377_0 in the cache */

   /* search397_0_0 -> search0_0 in the cache */

/* search397_0_1 -> replace0_1_0 in the cache */
/* search397_0 -> search375_0 in the cache */

/* search397_1 -> replace60_0_0 in the cache */
static const nir_search_expression search397 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_sne,
   { &search375_0.value, &replace60_0_0.value },
   NULL,
};

   /* replace397_0 -> search0_0 in the cache */

/* replace397_1 -> replace0_1_0 in the cache */
/* replace397 -> search386_0 in the cache */

   /* search398_0_0 -> search0_0 in the cache */

/* search398_0_1 -> replace0_1_0 in the cache */
/* search398_0 -> search386_0 in the cache */

/* search398_1 -> replace60_0_0 in the cache */
static const nir_search_expression search398 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_sne,
   { &search386_0.value, &replace60_0_0.value },
   NULL,
};

   /* replace398_0 -> search0_0 in the cache */

/* replace398_1 -> replace0_1_0 in the cache */
/* replace398 -> search375_0 in the cache */

   /* search399_0 -> search0_0 in the cache */

/* search399_1 -> replace0_1_0 in the cache */
static const nir_search_expression search399 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_fall_equal2,
   { &search0_0.value, &replace0_1_0.value },
   NULL,
};

   static const nir_search_variable replace399_0_0 = {
   { nir_search_value_variable, 32 },
   0, /* a */
   false,
   nir_type_invalid,
   NULL,
   {0},
};

static const nir_search_variable replace399_0_1 = {
   { nir_search_value_variable, 32 },
   1, /* b */
   false,
   nir_type_invalid,
   NULL,
   {0},
};
static const nir_search_expression replace399_0 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_seq,
   { &replace399_0_0.value, &replace399_0_1.value },
   NULL,
};

static const nir_search_variable replace399_1_0 = {
   { nir_search_value_variable, 32 },
   0, /* a */
   false,
   nir_type_invalid,
   NULL,
   {1},
};

static const nir_search_variable replace399_1_1 = {
   { nir_search_value_variable, 32 },
   1, /* b */
   false,
   nir_type_invalid,
   NULL,
   {1},
};
static const nir_search_expression replace399_1 = {
   { nir_search_value_expression, 32 },
   false,
   1, 1,
   nir_op_seq,
   { &replace399_1_0.value, &replace399_1_1.value },
   NULL,
};
static const nir_search_expression replace399 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 2,
   nir_op_fmin,
   { &replace399_0.value, &replace399_1.value },
   NULL,
};

   /* search400_0 -> search0_0 in the cache */

/* search400_1 -> replace0_1_0 in the cache */
static const nir_search_expression search400 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_fall_equal3,
   { &search0_0.value, &replace0_1_0.value },
   NULL,
};

   /* replace400_0_0 -> search0_0 in the cache */

/* replace400_0_1 -> replace0_1_0 in the cache */
static const nir_search_expression replace400_0 = {
   { nir_search_value_expression, 32 },
   false,
   1, 1,
   nir_op_fany_nequal3,
   { &search0_0.value, &replace0_1_0.value },
   NULL,
};

/* replace400_1 -> search312_0_0 in the cache */
static const nir_search_expression replace400 = {
   { nir_search_value_expression, 32 },
   false,
   0, 2,
   nir_op_seq,
   { &replace400_0.value, &search312_0_0.value },
   NULL,
};

   /* search401_0 -> search0_0 in the cache */

/* search401_1 -> replace0_1_0 in the cache */
static const nir_search_expression search401 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_fall_equal4,
   { &search0_0.value, &replace0_1_0.value },
   NULL,
};

   /* replace401_0_0 -> search0_0 in the cache */

/* replace401_0_1 -> replace0_1_0 in the cache */
static const nir_search_expression replace401_0 = {
   { nir_search_value_expression, 32 },
   false,
   1, 1,
   nir_op_fany_nequal4,
   { &search0_0.value, &replace0_1_0.value },
   NULL,
};

/* replace401_1 -> search312_0_0 in the cache */
static const nir_search_expression replace401 = {
   { nir_search_value_expression, 32 },
   false,
   0, 2,
   nir_op_seq,
   { &replace401_0.value, &search312_0_0.value },
   NULL,
};

   /* search402_0 -> search0_0 in the cache */

/* search402_1 -> replace0_1_0 in the cache */
static const nir_search_expression search402 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_fany_nequal2,
   { &search0_0.value, &replace0_1_0.value },
   NULL,
};

   /* replace402_0_0 -> replace399_0_0 in the cache */

/* replace402_0_1 -> replace399_0_1 in the cache */
static const nir_search_expression replace402_0 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_sne,
   { &replace399_0_0.value, &replace399_0_1.value },
   NULL,
};

/* replace402_1_0 -> replace399_1_0 in the cache */

/* replace402_1_1 -> replace399_1_1 in the cache */
static const nir_search_expression replace402_1 = {
   { nir_search_value_expression, 32 },
   false,
   1, 1,
   nir_op_sne,
   { &replace399_1_0.value, &replace399_1_1.value },
   NULL,
};
static const nir_search_expression replace402 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 2,
   nir_op_fmax,
   { &replace402_0.value, &replace402_1.value },
   NULL,
};

   /* search403_0 -> search0_0 in the cache */

/* search403_1 -> replace0_1_0 in the cache */
static const nir_search_expression search403 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_fany_nequal3,
   { &search0_0.value, &replace0_1_0.value },
   NULL,
};

   /* replace403_0_0_0 -> search0_0 in the cache */

/* replace403_0_0_1 -> replace0_1_0 in the cache */
/* replace403_0_0 -> search378_0 in the cache */

/* replace403_0_1_0 -> search0_0 in the cache */

/* replace403_0_1_1 -> replace0_1_0 in the cache */
/* replace403_0_1 -> search384_0 in the cache */
static const nir_search_expression replace403_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 2,
   nir_op_fdot3,
   { &search378_0.value, &search384_0.value },
   NULL,
};
static const nir_search_expression replace403 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 2,
   nir_op_fsat,
   { &replace403_0.value },
   NULL,
};

   /* search404_0 -> search0_0 in the cache */

/* search404_1 -> replace0_1_0 in the cache */
static const nir_search_expression search404 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_fany_nequal4,
   { &search0_0.value, &replace0_1_0.value },
   NULL,
};

   /* replace404_0_0_0 -> search0_0 in the cache */

/* replace404_0_0_1 -> replace0_1_0 in the cache */
/* replace404_0_0 -> search378_0 in the cache */

/* replace404_0_1_0 -> search0_0 in the cache */

/* replace404_0_1_1 -> replace0_1_0 in the cache */
/* replace404_0_1 -> search384_0 in the cache */
static const nir_search_expression replace404_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 2,
   nir_op_fdot4,
   { &search378_0.value, &search384_0.value },
   NULL,
};
static const nir_search_expression replace404 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 2,
   nir_op_fsat,
   { &replace404_0.value },
   NULL,
};

   /* search405_0_0 -> search2_0 in the cache */
/* search405_0 -> search15_0 in the cache */

/* search405_1 -> search2_0 in the cache */
static const nir_search_expression search405 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_fne,
   { &search15_0.value, &search2_0.value },
   NULL,
};

   /* replace405_0 -> search2_0 in the cache */

/* replace405_1 -> search24_1 in the cache */
/* replace405 -> replace207 in the cache */

   /* search406_0_0 -> search2_0 in the cache */
/* search406_0 -> search15_0 in the cache */

/* search406_1 -> search2_0 in the cache */
static const nir_search_expression search406 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_feq,
   { &search15_0.value, &search2_0.value },
   NULL,
};

   /* replace406_0 -> search2_0 in the cache */

/* replace406_1 -> search24_1 in the cache */
/* replace406 -> replace209 in the cache */

   /* search407_0_0 -> replace80_0 in the cache */
/* search407_0 -> search193_0 in the cache */

/* search407_1_0 -> search148_0_1_0 in the cache */
static const nir_search_expression search407_1 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_search_op_b2i,
   { &search148_0_1_0.value },
   NULL,
};
static const nir_search_expression search407 = {
   { nir_search_value_expression, 0 },
   false,
   0, 1,
   nir_op_imul,
   { &search193_0.value, &search407_1.value },
   NULL,
};

   /* replace407_0_0 -> replace80_0 in the cache */

/* replace407_0_1 -> search148_0_1_0 in the cache */
/* replace407_0 -> replace152 in the cache */
static const nir_search_expression replace407 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 1,
   nir_search_op_b2i,
   { &replace152.value },
   NULL,
};

   /* search408_0_0 -> replace80_0 in the cache */
/* search408_0 -> search146_1 in the cache */

/* search408_1_0 -> search148_0_1_0 in the cache */
/* search408_1 -> search148_0_1 in the cache */
static const nir_search_expression search408 = {
   { nir_search_value_expression, 0 },
   false,
   0, 1,
   nir_op_fmul,
   { &search146_1.value, &search148_0_1.value },
   NULL,
};

   /* replace408_0_0 -> replace80_0 in the cache */

/* replace408_0_1 -> search148_0_1_0 in the cache */
/* replace408_0 -> replace152 in the cache */
/* replace408 -> replace215 in the cache */

   /* search409_0_0_0 -> replace80_0 in the cache */
/* search409_0_0 -> search146_1 in the cache */

/* search409_0_1_0 -> search148_0_1_0 in the cache */
/* search409_0_1 -> search148_0_1 in the cache */
/* search409_0 -> search168_0_0 in the cache */
static const nir_search_expression search409 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 1,
   nir_op_fsat,
   { &search168_0_0.value },
   NULL,
};

   /* replace409_0_0 -> replace80_0 in the cache */

/* replace409_0_1 -> search148_0_1_0 in the cache */
/* replace409_0 -> replace148 in the cache */
/* replace409 -> replace213 in the cache */

   static const nir_search_variable search410_0 = {
   { nir_search_value_variable, 32 },
   0, /* a */
   false,
   nir_type_bool,
   NULL,
   {0, 1, 2, 3},
};

/* search410_1 -> replace60_0_0 in the cache */
static const nir_search_expression search410 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_iand,
   { &search410_0.value, &replace60_0_0.value },
   NULL,
};

   /* replace410_0 -> search0_0 in the cache */
static const nir_search_expression replace410 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_search_op_b2f,
   { &search0_0.value },
   NULL,
};

   /* search411_0_0 -> search0_0 in the cache */
static const nir_search_expression search411_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_b2i32,
   { &search0_0.value },
   NULL,
};
static const nir_search_expression search411 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_ineg,
   { &search411_0.value },
   NULL,
};

   /* replace411 -> search0_0 in the cache */

   /* search412_0_0_0 -> replace80_0 in the cache */
/* search412_0_0 -> search146_1 in the cache */
/* search412_0 -> search147_0 in the cache */

/* search412_1 -> search193_1 in the cache */
static const nir_search_expression search412 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search147_0.value, &search193_1.value },
   NULL,
};

   /* replace412 -> replace80_0 in the cache */

   /* search413_0_0 -> search146_0 in the cache */

/* search413_0_1_0 -> replace80_0 in the cache */
/* search413_0_1 -> search146_1 in the cache */
static const nir_search_expression search413_0 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_op_fsub,
   { &search146_0.value, &search146_1.value },
   NULL,
};

/* search413_1 -> search193_1 in the cache */
static const nir_search_expression search413 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search413_0.value, &search193_1.value },
   NULL,
};

   /* replace413 -> replace80_0 in the cache */

   /* search414_0 -> search2_0 in the cache */

/* search414_1 -> search2_0 in the cache */
static const nir_search_expression search414 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search2_0.value, &search2_0.value },
   NULL,
};

   /* replace414 -> replace121 in the cache */

   /* search415_0 -> search2_0 in the cache */

/* search415_1 -> search2_0 in the cache */
static const nir_search_expression search415 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search2_0.value, &search2_0.value },
   NULL,
};

   /* replace415 -> replace197 in the cache */

   /* search416_0 -> search2_0 in the cache */

/* search416_1 -> search2_0 in the cache */
static const nir_search_expression search416 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ieq,
   { &search2_0.value, &search2_0.value },
   NULL,
};

   /* replace416 -> replace197 in the cache */

   /* search417_0 -> search2_0 in the cache */

/* search417_1 -> search2_0 in the cache */
static const nir_search_expression search417 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ine,
   { &search2_0.value, &search2_0.value },
   NULL,
};

   /* replace417 -> replace121 in the cache */

   /* search418_0 -> search2_0 in the cache */

/* search418_1 -> search2_0 in the cache */
static const nir_search_expression search418 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search2_0.value, &search2_0.value },
   NULL,
};

   /* replace418 -> replace121 in the cache */

   /* search419_0 -> search2_0 in the cache */

/* search419_1 -> search2_0 in the cache */
static const nir_search_expression search419 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search2_0.value, &search2_0.value },
   NULL,
};

   /* replace419 -> replace197 in the cache */

   /* search420_0 -> search2_0 in the cache */

/* search420_1 -> search2_0 in the cache */
static const nir_search_expression search420 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_iand,
   { &search2_0.value, &search2_0.value },
   NULL,
};

   /* replace420 -> search2_0 in the cache */

   /* search421_0 -> search2_0 in the cache */

/* search421_1 -> search44_1 in the cache */
static const nir_search_expression search421 = {
   { nir_search_value_expression, -1 },
   false,
   0, 1,
   nir_op_iand,
   { &search2_0.value, &search44_1.value },
   NULL,
};

   /* replace421 -> search2_0 in the cache */

   /* search422_0 -> search2_0 in the cache */

/* search422_1 -> replace9 in the cache */
static const nir_search_expression search422 = {
   { nir_search_value_expression, -1 },
   false,
   0, 1,
   nir_op_iand,
   { &search2_0.value, &replace9.value },
   NULL,
};

   /* replace422 -> replace9 in the cache */

   /* search423_0 -> search2_0 in the cache */

/* search423_1 -> search2_0 in the cache */
static const nir_search_expression search423 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_ior,
   { &search2_0.value, &search2_0.value },
   NULL,
};

   /* replace423 -> search2_0 in the cache */

   /* search424_0 -> search2_0 in the cache */

/* search424_1 -> replace9 in the cache */
static const nir_search_expression search424 = {
   { nir_search_value_expression, -1 },
   false,
   0, 1,
   nir_op_ior,
   { &search2_0.value, &replace9.value },
   NULL,
};

   /* replace424 -> search2_0 in the cache */

   /* search425_0 -> replace80_0 in the cache */

/* search425_1 -> replace197 in the cache */
static const nir_search_expression search425 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ior,
   { &replace80_0.value, &replace197.value },
   NULL,
};

   /* replace425 -> replace197 in the cache */

   /* search426_0 -> search2_0 in the cache */

/* search426_1 -> search2_0 in the cache */
static const nir_search_expression search426 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_ixor,
   { &search2_0.value, &search2_0.value },
   NULL,
};

   /* replace426 -> replace9 in the cache */

   /* search427_0 -> search2_0 in the cache */

/* search427_1 -> replace9 in the cache */
static const nir_search_expression search427 = {
   { nir_search_value_expression, -1 },
   false,
   0, 1,
   nir_op_ixor,
   { &search2_0.value, &replace9.value },
   NULL,
};

   /* replace427 -> search2_0 in the cache */

   /* search428_0_0 -> search2_0 in the cache */
/* search428_0 -> search325_1 in the cache */
static const nir_search_expression search428 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_inot,
   { &search325_1.value },
   NULL,
};

   /* replace428 -> search2_0 in the cache */

   /* search429_0_0 -> search14_0 in the cache */

/* search429_0_1 -> replace14_1_0 in the cache */
static const nir_search_expression search429_0 = {
   { nir_search_value_expression, -2 },
   false,
   1, 1,
   nir_op_iand,
   { &search14_0.value, &replace14_1_0.value },
   NULL,
};

/* search429_1 -> replace14_1_0 in the cache */
static const nir_search_expression search429 = {
   { nir_search_value_expression, -2 },
   false,
   0, 2,
   nir_op_ior,
   { &search429_0.value, &replace14_1_0.value },
   NULL,
};

   /* replace429 -> replace14_1_0 in the cache */

   /* search430_0_0 -> search14_0 in the cache */

/* search430_0_1 -> replace14_1_0 in the cache */
static const nir_search_expression search430_0 = {
   { nir_search_value_expression, -2 },
   false,
   1, 1,
   nir_op_ior,
   { &search14_0.value, &replace14_1_0.value },
   NULL,
};

/* search430_1 -> replace14_1_0 in the cache */
static const nir_search_expression search430 = {
   { nir_search_value_expression, -2 },
   false,
   0, 2,
   nir_op_ior,
   { &search430_0.value, &replace14_1_0.value },
   NULL,
};

   /* replace430_0 -> search14_0 in the cache */

/* replace430_1 -> replace14_1_0 in the cache */
/* replace430 -> search354_0 in the cache */

   /* search431_0_0 -> search14_0 in the cache */

/* search431_0_1 -> replace14_1_0 in the cache */
/* search431_0 -> search430_0 in the cache */

/* search431_1 -> replace14_1_0 in the cache */
static const nir_search_expression search431 = {
   { nir_search_value_expression, -2 },
   false,
   0, 2,
   nir_op_iand,
   { &search430_0.value, &replace14_1_0.value },
   NULL,
};

   /* replace431 -> replace14_1_0 in the cache */

   /* search432_0_0 -> search14_0 in the cache */

/* search432_0_1 -> replace14_1_0 in the cache */
/* search432_0 -> search429_0 in the cache */

/* search432_1 -> replace14_1_0 in the cache */
static const nir_search_expression search432 = {
   { nir_search_value_expression, -2 },
   false,
   0, 2,
   nir_op_iand,
   { &search429_0.value, &replace14_1_0.value },
   NULL,
};

   /* replace432_0 -> search14_0 in the cache */

/* replace432_1 -> replace14_1_0 in the cache */
static const nir_search_expression replace432 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_iand,
   { &search14_0.value, &replace14_1_0.value },
   NULL,
};

   /* search433_0_0 -> search14_0 in the cache */
static const nir_search_expression search433_0 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_inot,
   { &search14_0.value },
   NULL,
};

/* search433_1_0 -> replace14_1_0 in the cache */
static const nir_search_expression search433_1 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_inot,
   { &replace14_1_0.value },
   NULL,
};
static const nir_search_expression search433 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_iand,
   { &search433_0.value, &search433_1.value },
   NULL,
};

   /* replace433_0_0 -> search14_0 in the cache */

/* replace433_0_1 -> replace14_1_0 in the cache */
/* replace433_0 -> search354_0 in the cache */
static const nir_search_expression replace433 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 1,
   nir_op_inot,
   { &search354_0.value },
   NULL,
};

   /* search434_0_0 -> search14_0 in the cache */
/* search434_0 -> search433_0 in the cache */

/* search434_1_0 -> replace14_1_0 in the cache */
/* search434_1 -> search433_1 in the cache */
static const nir_search_expression search434 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_ior,
   { &search433_0.value, &search433_1.value },
   NULL,
};

   /* replace434_0_0 -> search14_0 in the cache */

/* replace434_0_1 -> replace14_1_0 in the cache */
/* replace434_0 -> replace432 in the cache */
static const nir_search_expression replace434 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 1,
   nir_op_inot,
   { &replace432.value },
   NULL,
};

   /* search435_0 -> search193_1 in the cache */

/* search435_1 -> search0_0 in the cache */
static const nir_search_expression search435 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_op_ishl,
   { &search193_1.value, &search0_0.value },
   NULL,
};

   /* replace435 -> search193_1 in the cache */

   /* search436_0 -> search2_0 in the cache */

/* search436_1 -> search26_1 in the cache */
static const nir_search_expression search436 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_ishl,
   { &search2_0.value, &search26_1.value },
   NULL,
};

   /* replace436 -> search2_0 in the cache */

   /* search437_0 -> search193_1 in the cache */

/* search437_1 -> search0_0 in the cache */
static const nir_search_expression search437 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_op_ishr,
   { &search193_1.value, &search0_0.value },
   NULL,
};

   /* replace437 -> search193_1 in the cache */

   /* search438_0 -> search2_0 in the cache */

/* search438_1 -> search26_1 in the cache */
static const nir_search_expression search438 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_ishr,
   { &search2_0.value, &search26_1.value },
   NULL,
};

   /* replace438 -> search2_0 in the cache */

   /* search439_0 -> search193_1 in the cache */

/* search439_1 -> search0_0 in the cache */
static const nir_search_expression search439 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_op_ushr,
   { &search193_1.value, &search0_0.value },
   NULL,
};

   /* replace439 -> search193_1 in the cache */

   /* search440_0 -> search2_0 in the cache */

/* search440_1 -> search26_1 in the cache */
static const nir_search_expression search440 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_ushr,
   { &search2_0.value, &search26_1.value },
   NULL,
};

   /* replace440 -> search2_0 in the cache */

   /* search441_0 -> replace98_0_0_0_1 in the cache */

/* search441_1_0 -> search0_0 in the cache */

static const nir_search_constant search441_1_1 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { 0x18 /* 24 */ },
};
static const nir_search_expression search441_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_ushr,
   { &search0_0.value, &search441_1_1.value },
   NULL,
};
static const nir_search_expression search441 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_iand,
   { &replace98_0_0_0_1.value, &search441_1.value },
   NULL,
};

   /* replace441_0 -> search0_0 in the cache */

/* replace441_1 -> search441_1_1 in the cache */
/* replace441 -> search441_1 in the cache */

   /* search442_0 -> replace101_0_0_0_1 in the cache */

/* search442_1_0 -> search0_0 in the cache */

/* search442_1_1 -> replace101_0_1 in the cache */
static const nir_search_expression search442_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_ushr,
   { &search0_0.value, &replace101_0_1.value },
   NULL,
};
static const nir_search_expression search442 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_iand,
   { &replace101_0_0_0_1.value, &search442_1.value },
   NULL,
};

   /* replace442_0 -> search0_0 in the cache */

/* replace442_1 -> replace101_0_1 in the cache */
/* replace442 -> search442_1 in the cache */

   /* search443_0_0 -> search101_0_0 in the cache */

/* search443_0_1 -> replace0_1_0 in the cache */
static const nir_search_expression search443_0 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_ishl,
   { &search101_0_0.value, &replace0_1_0.value },
   NULL,
};

/* search443_1_0 -> search101_0_0 in the cache */

/* search443_1_1_0 -> replace101_0_1 in the cache */

/* search443_1_1_1_0 -> replace0_1_0 in the cache */
static const nir_search_expression search443_1_1_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_ineg,
   { &replace0_1_0.value },
   NULL,
};
static const nir_search_expression search443_1_1 = {
   { nir_search_value_expression, 32 },
   false,
   1, 1,
   nir_op_iadd,
   { &replace101_0_1.value, &search443_1_1_1.value },
   NULL,
};
static const nir_search_expression search443_1 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 1,
   nir_op_ushr,
   { &search101_0_0.value, &search443_1_1.value },
   NULL,
};
static const nir_search_expression search443 = {
   { nir_search_value_expression, 16 },
   false,
   0, 2,
   nir_op_ior,
   { &search443_0.value, &search443_1.value },
   NULL,
};

   /* replace443_0 -> search101_0_0 in the cache */

/* replace443_1 -> replace0_1_0 in the cache */
static const nir_search_expression replace443 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_urol,
   { &search101_0_0.value, &replace0_1_0.value },
   NULL,
};

   /* search444_0_0 -> search101_0_0 in the cache */

/* search444_0_1 -> replace0_1_0 in the cache */
/* search444_0 -> search443_0 in the cache */

/* search444_1_0 -> search101_0_0 in the cache */

/* search444_1_1_0 -> replace101_0_1 in the cache */

/* search444_1_1_1 -> replace0_1_0 in the cache */
static const nir_search_expression search444_1_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_isub,
   { &replace101_0_1.value, &replace0_1_0.value },
   NULL,
};
static const nir_search_expression search444_1 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_ushr,
   { &search101_0_0.value, &search444_1_1.value },
   NULL,
};
static const nir_search_expression search444 = {
   { nir_search_value_expression, 16 },
   false,
   0, 1,
   nir_op_ior,
   { &search443_0.value, &search444_1.value },
   NULL,
};

   /* replace444_0 -> search101_0_0 in the cache */

/* replace444_1 -> replace0_1_0 in the cache */
/* replace444 -> replace443 in the cache */

   /* search445_0_0 -> search0_0 in the cache */

/* search445_0_1 -> replace0_1_0 in the cache */
static const nir_search_expression search445_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_ishl,
   { &search0_0.value, &replace0_1_0.value },
   NULL,
};

/* search445_1_0 -> search0_0 in the cache */

/* search445_1_1_0 -> replace104_0_1 in the cache */

/* search445_1_1_1_0 -> replace0_1_0 in the cache */
/* search445_1_1_1 -> search443_1_1_1 in the cache */
static const nir_search_expression search445_1_1 = {
   { nir_search_value_expression, 32 },
   false,
   1, 1,
   nir_op_iadd,
   { &replace104_0_1.value, &search443_1_1_1.value },
   NULL,
};
static const nir_search_expression search445_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_op_ushr,
   { &search0_0.value, &search445_1_1.value },
   NULL,
};
static const nir_search_expression search445 = {
   { nir_search_value_expression, 32 },
   false,
   0, 2,
   nir_op_ior,
   { &search445_0.value, &search445_1.value },
   NULL,
};

   /* replace445_0 -> search0_0 in the cache */

/* replace445_1 -> replace0_1_0 in the cache */
static const nir_search_expression replace445 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_urol,
   { &search0_0.value, &replace0_1_0.value },
   NULL,
};

   /* search446_0_0 -> search0_0 in the cache */

/* search446_0_1 -> replace0_1_0 in the cache */
/* search446_0 -> search445_0 in the cache */

/* search446_1_0 -> search0_0 in the cache */

/* search446_1_1_0 -> replace104_0_1 in the cache */

/* search446_1_1_1 -> replace0_1_0 in the cache */
static const nir_search_expression search446_1_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_isub,
   { &replace104_0_1.value, &replace0_1_0.value },
   NULL,
};
static const nir_search_expression search446_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_ushr,
   { &search0_0.value, &search446_1_1.value },
   NULL,
};
static const nir_search_expression search446 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_ior,
   { &search445_0.value, &search446_1.value },
   NULL,
};

   /* replace446_0 -> search0_0 in the cache */

/* replace446_1 -> replace0_1_0 in the cache */
/* replace446 -> replace445 in the cache */

   /* search447_0_0 -> search101_0_0 in the cache */

/* search447_0_1 -> replace0_1_0 in the cache */
static const nir_search_expression search447_0 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_ushr,
   { &search101_0_0.value, &replace0_1_0.value },
   NULL,
};

/* search447_1_0 -> search101_0_0 in the cache */

/* search447_1_1_0 -> replace101_0_1 in the cache */

/* search447_1_1_1_0 -> replace0_1_0 in the cache */
/* search447_1_1_1 -> search443_1_1_1 in the cache */
/* search447_1_1 -> search443_1_1 in the cache */
static const nir_search_expression search447_1 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 1,
   nir_op_ishl,
   { &search101_0_0.value, &search443_1_1.value },
   NULL,
};
static const nir_search_expression search447 = {
   { nir_search_value_expression, 16 },
   false,
   0, 2,
   nir_op_ior,
   { &search447_0.value, &search447_1.value },
   NULL,
};

   /* replace447_0 -> search101_0_0 in the cache */

/* replace447_1 -> replace0_1_0 in the cache */
static const nir_search_expression replace447 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_uror,
   { &search101_0_0.value, &replace0_1_0.value },
   NULL,
};

   /* search448_0_0 -> search101_0_0 in the cache */

/* search448_0_1 -> replace0_1_0 in the cache */
/* search448_0 -> search447_0 in the cache */

/* search448_1_0 -> search101_0_0 in the cache */

/* search448_1_1_0 -> replace101_0_1 in the cache */

/* search448_1_1_1 -> replace0_1_0 in the cache */
/* search448_1_1 -> search444_1_1 in the cache */
static const nir_search_expression search448_1 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_ishl,
   { &search101_0_0.value, &search444_1_1.value },
   NULL,
};
static const nir_search_expression search448 = {
   { nir_search_value_expression, 16 },
   false,
   0, 1,
   nir_op_ior,
   { &search447_0.value, &search448_1.value },
   NULL,
};

   /* replace448_0 -> search101_0_0 in the cache */

/* replace448_1 -> replace0_1_0 in the cache */
/* replace448 -> replace447 in the cache */

   /* search449_0_0 -> search0_0 in the cache */

/* search449_0_1 -> replace0_1_0 in the cache */
static const nir_search_expression search449_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_ushr,
   { &search0_0.value, &replace0_1_0.value },
   NULL,
};

/* search449_1_0 -> search0_0 in the cache */

/* search449_1_1_0 -> replace104_0_1 in the cache */

/* search449_1_1_1_0 -> replace0_1_0 in the cache */
/* search449_1_1_1 -> search443_1_1_1 in the cache */
/* search449_1_1 -> search445_1_1 in the cache */
static const nir_search_expression search449_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_op_ishl,
   { &search0_0.value, &search445_1_1.value },
   NULL,
};
static const nir_search_expression search449 = {
   { nir_search_value_expression, 32 },
   false,
   0, 2,
   nir_op_ior,
   { &search449_0.value, &search449_1.value },
   NULL,
};

   /* replace449_0 -> search0_0 in the cache */

/* replace449_1 -> replace0_1_0 in the cache */
static const nir_search_expression replace449 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_uror,
   { &search0_0.value, &replace0_1_0.value },
   NULL,
};

   /* search450_0_0 -> search0_0 in the cache */

/* search450_0_1 -> replace0_1_0 in the cache */
/* search450_0 -> search449_0 in the cache */

/* search450_1_0 -> search0_0 in the cache */

/* search450_1_1_0 -> replace104_0_1 in the cache */

/* search450_1_1_1 -> replace0_1_0 in the cache */
/* search450_1_1 -> search446_1_1 in the cache */
static const nir_search_expression search450_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_ishl,
   { &search0_0.value, &search446_1_1.value },
   NULL,
};
static const nir_search_expression search450 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_ior,
   { &search449_0.value, &search450_1.value },
   NULL,
};

   /* replace450_0 -> search0_0 in the cache */

/* replace450_1 -> replace0_1_0 in the cache */
/* replace450 -> replace449 in the cache */

   /* search451_0 -> search101_0_0 in the cache */

/* search451_1 -> replace0_1_0 in the cache */
/* search451 -> replace443 in the cache */

   /* replace451_0_0 -> search101_0_0 in the cache */

/* replace451_0_1 -> replace0_1_0 in the cache */
/* replace451_0 -> search443_0 in the cache */

/* replace451_1_0 -> search101_0_0 in the cache */

/* replace451_1_1_0 -> replace101_0_1 in the cache */

/* replace451_1_1_1 -> replace0_1_0 in the cache */
/* replace451_1_1 -> search444_1_1 in the cache */
/* replace451_1 -> search444_1 in the cache */
/* replace451 -> search444 in the cache */

   /* search452_0 -> search0_0 in the cache */

/* search452_1 -> replace0_1_0 in the cache */
/* search452 -> replace445 in the cache */

   /* replace452_0_0 -> search0_0 in the cache */

/* replace452_0_1 -> replace0_1_0 in the cache */
/* replace452_0 -> search445_0 in the cache */

/* replace452_1_0 -> search0_0 in the cache */

/* replace452_1_1_0 -> replace104_0_1 in the cache */

/* replace452_1_1_1 -> replace0_1_0 in the cache */
/* replace452_1_1 -> search446_1_1 in the cache */
/* replace452_1 -> search446_1 in the cache */
/* replace452 -> search446 in the cache */

   /* search453_0 -> search101_0_0 in the cache */

/* search453_1 -> replace0_1_0 in the cache */
/* search453 -> replace447 in the cache */

   /* replace453_0_0 -> search101_0_0 in the cache */

/* replace453_0_1 -> replace0_1_0 in the cache */
/* replace453_0 -> search447_0 in the cache */

/* replace453_1_0 -> search101_0_0 in the cache */

/* replace453_1_1_0 -> replace101_0_1 in the cache */

/* replace453_1_1_1 -> replace0_1_0 in the cache */
/* replace453_1_1 -> search444_1_1 in the cache */
/* replace453_1 -> search448_1 in the cache */
/* replace453 -> search448 in the cache */

   /* search454_0 -> search0_0 in the cache */

/* search454_1 -> replace0_1_0 in the cache */
/* search454 -> replace449 in the cache */

   /* replace454_0_0 -> search0_0 in the cache */

/* replace454_0_1 -> replace0_1_0 in the cache */
/* replace454_0 -> search449_0 in the cache */

/* replace454_1_0 -> search0_0 in the cache */

/* replace454_1_1_0 -> replace104_0_1 in the cache */

/* replace454_1_1_1 -> replace0_1_0 in the cache */
/* replace454_1_1 -> search446_1_1 in the cache */
/* replace454_1 -> search450_1 in the cache */
/* replace454 -> search450 in the cache */

   /* search455_0_0 -> search2_0 in the cache */
static const nir_search_expression search455_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_flog2,
   { &search2_0.value },
   NULL,
};
static const nir_search_expression search455 = {
   { nir_search_value_expression, -1 },
   true,
   -1, 0,
   nir_op_fexp2,
   { &search455_0.value },
   NULL,
};

   /* replace455 -> search2_0 in the cache */

   /* search456_0_0 -> search2_0 in the cache */
static const nir_search_expression search456_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fexp2,
   { &search2_0.value },
   NULL,
};
static const nir_search_expression search456 = {
   { nir_search_value_expression, -1 },
   true,
   -1, 0,
   nir_op_flog2,
   { &search456_0.value },
   NULL,
};

   /* replace456 -> search2_0 in the cache */

   /* search457_0 -> search14_0 in the cache */

/* search457_1 -> replace14_1_0 in the cache */
static const nir_search_expression search457 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_fpow,
   { &search14_0.value, &replace14_1_0.value },
   NULL,
};

   /* replace457_0_0_0 -> search14_0 in the cache */
static const nir_search_expression replace457_0_0 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_flog2,
   { &search14_0.value },
   NULL,
};

/* replace457_0_1 -> replace14_1_0 in the cache */
static const nir_search_expression replace457_0 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_fmul,
   { &replace457_0_0.value, &replace14_1_0.value },
   NULL,
};
static const nir_search_expression replace457 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 1,
   nir_op_fexp2,
   { &replace457_0.value },
   NULL,
};

   /* search458_0_0_0 -> search14_0 in the cache */
/* search458_0_0 -> replace457_0_0 in the cache */

/* search458_0_1 -> replace14_1_0 in the cache */
/* search458_0 -> replace457_0 in the cache */
static const nir_search_expression search458 = {
   { nir_search_value_expression, -2 },
   true,
   -1, 1,
   nir_op_fexp2,
   { &replace457_0.value },
   NULL,
};

   /* replace458_0 -> search14_0 in the cache */

/* replace458_1 -> replace14_1_0 in the cache */
/* replace458 -> search457 in the cache */

   /* search459_0_0_0_0 -> search62_0_0 in the cache */
static const nir_search_expression search459_0_0_0 = {
   { nir_search_value_expression, -4 },
   false,
   -1, 0,
   nir_op_flog2,
   { &search62_0_0.value },
   NULL,
};

/* search459_0_0_1 -> search62_0_1 in the cache */
static const nir_search_expression search459_0_0 = {
   { nir_search_value_expression, -4 },
   false,
   1, 1,
   nir_op_fmul,
   { &search459_0_0_0.value, &search62_0_1.value },
   NULL,
};

/* search459_0_1_0_0 -> search62_1_1 in the cache */
static const nir_search_expression search459_0_1_0 = {
   { nir_search_value_expression, -4 },
   false,
   -1, 0,
   nir_op_flog2,
   { &search62_1_1.value },
   NULL,
};

/* search459_0_1_1 -> search62_2 in the cache */
static const nir_search_expression search459_0_1 = {
   { nir_search_value_expression, -4 },
   false,
   2, 1,
   nir_op_fmul,
   { &search459_0_1_0.value, &search62_2.value },
   NULL,
};
static const nir_search_expression search459_0 = {
   { nir_search_value_expression, -4 },
   false,
   0, 3,
   nir_op_fadd,
   { &search459_0_0.value, &search459_0_1.value },
   NULL,
};
static const nir_search_expression search459 = {
   { nir_search_value_expression, -4 },
   true,
   -1, 3,
   nir_op_fexp2,
   { &search459_0.value },
   NULL,
};

   /* replace459_0_0 -> search62_0_0 in the cache */

/* replace459_0_1 -> search62_0_1 in the cache */
static const nir_search_expression replace459_0 = {
   { nir_search_value_expression, -4 },
   false,
   -1, 0,
   nir_op_fpow,
   { &search62_0_0.value, &search62_0_1.value },
   NULL,
};

/* replace459_1_0 -> search62_1_1 in the cache */

/* replace459_1_1 -> search62_2 in the cache */
static const nir_search_expression replace459_1 = {
   { nir_search_value_expression, -4 },
   false,
   -1, 0,
   nir_op_fpow,
   { &search62_1_1.value, &search62_2.value },
   NULL,
};
static const nir_search_expression replace459 = {
   { nir_search_value_expression, -4 },
   true,
   0, 1,
   nir_op_fmul,
   { &replace459_0.value, &replace459_1.value },
   NULL,
};

   /* search460_0_0_0 -> search2_0 in the cache */
/* search460_0_0 -> search455_0 in the cache */

static const nir_search_constant search460_0_1 = {
   { nir_search_value_constant, -1 },
   nir_type_float, { 0x4000000000000000 /* 2.0 */ },
};
static const nir_search_expression search460_0 = {
   { nir_search_value_expression, -1 },
   false,
   0, 1,
   nir_op_fmul,
   { &search455_0.value, &search460_0_1.value },
   NULL,
};
static const nir_search_expression search460 = {
   { nir_search_value_expression, -1 },
   true,
   -1, 1,
   nir_op_fexp2,
   { &search460_0.value },
   NULL,
};

   /* replace460_0 -> search2_0 in the cache */

/* replace460_1 -> search2_0 in the cache */
/* replace460 -> search45_1 in the cache */

   /* search461_0_0_0 -> search2_0 in the cache */
/* search461_0_0 -> search455_0 in the cache */

static const nir_search_constant search461_0_1 = {
   { nir_search_value_constant, -1 },
   nir_type_float, { 0x4010000000000000 /* 4.0 */ },
};
static const nir_search_expression search461_0 = {
   { nir_search_value_expression, -1 },
   false,
   0, 1,
   nir_op_fmul,
   { &search455_0.value, &search461_0_1.value },
   NULL,
};
static const nir_search_expression search461 = {
   { nir_search_value_expression, -1 },
   true,
   -1, 1,
   nir_op_fexp2,
   { &search461_0.value },
   NULL,
};

   /* replace461_0_0 -> search2_0 in the cache */

/* replace461_0_1 -> search2_0 in the cache */
/* replace461_0 -> search45_1 in the cache */

/* replace461_1_0 -> search2_0 in the cache */

/* replace461_1_1 -> search2_0 in the cache */
/* replace461_1 -> search45_1 in the cache */
static const nir_search_expression replace461 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fmul,
   { &search45_1.value, &search45_1.value },
   NULL,
};

   /* search462_0 -> search2_0 in the cache */

/* search462_1 -> search41_1 in the cache */
static const nir_search_expression search462 = {
   { nir_search_value_expression, -1 },
   true,
   -1, 0,
   nir_op_fpow,
   { &search2_0.value, &search41_1.value },
   NULL,
};

   /* replace462 -> search2_0 in the cache */

   /* search463_0 -> search2_0 in the cache */

/* search463_1 -> search460_0_1 in the cache */
static const nir_search_expression search463 = {
   { nir_search_value_expression, -1 },
   true,
   -1, 0,
   nir_op_fpow,
   { &search2_0.value, &search460_0_1.value },
   NULL,
};

   /* replace463_0 -> search2_0 in the cache */

/* replace463_1 -> search2_0 in the cache */
/* replace463 -> search45_1 in the cache */

   /* search464_0 -> search2_0 in the cache */

/* search464_1 -> search461_0_1 in the cache */
static const nir_search_expression search464 = {
   { nir_search_value_expression, -1 },
   true,
   -1, 0,
   nir_op_fpow,
   { &search2_0.value, &search461_0_1.value },
   NULL,
};

   /* replace464_0_0 -> search2_0 in the cache */

/* replace464_0_1 -> search2_0 in the cache */
/* replace464_0 -> search45_1 in the cache */

/* replace464_1_0 -> search2_0 in the cache */

/* replace464_1_1 -> search2_0 in the cache */
/* replace464_1 -> search45_1 in the cache */
/* replace464 -> replace461 in the cache */

   /* search465_0 -> search460_0_1 in the cache */

/* search465_1 -> search2_0 in the cache */
static const nir_search_expression search465 = {
   { nir_search_value_expression, -1 },
   true,
   -1, 0,
   nir_op_fpow,
   { &search460_0_1.value, &search2_0.value },
   NULL,
};

   /* replace465_0 -> search2_0 in the cache */
/* replace465 -> search456_0 in the cache */

   /* search466_0_0 -> search2_0 in the cache */

static const nir_search_constant search466_0_1 = {
   { nir_search_value_constant, -1 },
   nir_type_float, { 0x400199999999999a /* 2.2 */ },
};
static const nir_search_expression search466_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fpow,
   { &search2_0.value, &search466_0_1.value },
   NULL,
};

static const nir_search_constant search466_1 = {
   { nir_search_value_constant, -1 },
   nir_type_float, { 0x3fdd1743e963dc48 /* 0.454545 */ },
};
static const nir_search_expression search466 = {
   { nir_search_value_expression, -1 },
   true,
   -1, 0,
   nir_op_fpow,
   { &search466_0.value, &search466_1.value },
   NULL,
};

   /* replace466 -> search2_0 in the cache */

   /* search467_0_0_0 -> search2_0 in the cache */

/* search467_0_0_1 -> search466_0_1 in the cache */
/* search467_0_0 -> search466_0 in the cache */
static const nir_search_expression search467_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fabs,
   { &search466_0.value },
   NULL,
};

/* search467_1 -> search466_1 in the cache */
static const nir_search_expression search467 = {
   { nir_search_value_expression, -1 },
   true,
   -1, 0,
   nir_op_fpow,
   { &search467_0.value, &search466_1.value },
   NULL,
};

   /* replace467_0 -> search2_0 in the cache */
/* replace467 -> search17_0 in the cache */

   /* search468_0_0 -> search2_0 in the cache */
/* search468_0 -> search456_0 in the cache */
static const nir_search_expression search468 = {
   { nir_search_value_expression, -1 },
   true,
   -1, 0,
   nir_op_fsqrt,
   { &search456_0.value },
   NULL,
};

   static const nir_search_constant replace468_0_0 = {
   { nir_search_value_constant, -1 },
   nir_type_float, { 0x3fe0000000000000 /* 0.5 */ },
};

/* replace468_0_1 -> search2_0 in the cache */
static const nir_search_expression replace468_0 = {
   { nir_search_value_expression, -1 },
   false,
   0, 1,
   nir_op_fmul,
   { &replace468_0_0.value, &search2_0.value },
   NULL,
};
static const nir_search_expression replace468 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 1,
   nir_op_fexp2,
   { &replace468_0.value },
   NULL,
};

   /* search469_0_0 -> search2_0 in the cache */
/* search469_0 -> search456_0 in the cache */
static const nir_search_expression search469 = {
   { nir_search_value_expression, -1 },
   true,
   -1, 0,
   nir_op_frcp,
   { &search456_0.value },
   NULL,
};

   /* replace469_0_0 -> search2_0 in the cache */
/* replace469_0 -> search15_0 in the cache */
static const nir_search_expression replace469 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fexp2,
   { &search15_0.value },
   NULL,
};

   /* search470_0_0 -> search2_0 in the cache */
/* search470_0 -> search456_0 in the cache */
static const nir_search_expression search470 = {
   { nir_search_value_expression, -1 },
   true,
   -1, 0,
   nir_op_frsq,
   { &search456_0.value },
   NULL,
};

   static const nir_search_constant replace470_0_0 = {
   { nir_search_value_constant, -1 },
   nir_type_float, { 0xbfe0000000000000L /* -0.5 */ },
};

/* replace470_0_1 -> search2_0 in the cache */
static const nir_search_expression replace470_0 = {
   { nir_search_value_expression, -1 },
   false,
   0, 1,
   nir_op_fmul,
   { &replace470_0_0.value, &search2_0.value },
   NULL,
};
static const nir_search_expression replace470 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 1,
   nir_op_fexp2,
   { &replace470_0.value },
   NULL,
};

   /* search471_0_0 -> search2_0 in the cache */
static const nir_search_expression search471_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fsqrt,
   { &search2_0.value },
   NULL,
};
static const nir_search_expression search471 = {
   { nir_search_value_expression, -1 },
   true,
   -1, 0,
   nir_op_flog2,
   { &search471_0.value },
   NULL,
};

   /* replace471_0 -> replace468_0_0 in the cache */

/* replace471_1_0 -> search2_0 in the cache */
/* replace471_1 -> search455_0 in the cache */
static const nir_search_expression replace471 = {
   { nir_search_value_expression, -1 },
   false,
   0, 1,
   nir_op_fmul,
   { &replace468_0_0.value, &search455_0.value },
   NULL,
};

   /* search472_0_0 -> search2_0 in the cache */
static const nir_search_expression search472_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_frcp,
   { &search2_0.value },
   NULL,
};
static const nir_search_expression search472 = {
   { nir_search_value_expression, -1 },
   true,
   -1, 0,
   nir_op_flog2,
   { &search472_0.value },
   NULL,
};

   /* replace472_0_0 -> search2_0 in the cache */
/* replace472_0 -> search455_0 in the cache */
static const nir_search_expression replace472 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fneg,
   { &search455_0.value },
   NULL,
};

   /* search473_0_0 -> search2_0 in the cache */
static const nir_search_expression search473_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_frsq,
   { &search2_0.value },
   NULL,
};
static const nir_search_expression search473 = {
   { nir_search_value_expression, -1 },
   true,
   -1, 0,
   nir_op_flog2,
   { &search473_0.value },
   NULL,
};

   /* replace473_0 -> replace470_0_0 in the cache */

/* replace473_1_0 -> search2_0 in the cache */
/* replace473_1 -> search455_0 in the cache */
static const nir_search_expression replace473 = {
   { nir_search_value_expression, -1 },
   false,
   0, 1,
   nir_op_fmul,
   { &replace470_0_0.value, &search455_0.value },
   NULL,
};

   /* search474_0_0 -> search14_0 in the cache */

/* search474_0_1 -> replace14_1_0 in the cache */
/* search474_0 -> search457 in the cache */
static const nir_search_expression search474 = {
   { nir_search_value_expression, -2 },
   true,
   -1, 0,
   nir_op_flog2,
   { &search457.value },
   NULL,
};

   /* replace474_0 -> replace14_1_0 in the cache */

/* replace474_1_0 -> search14_0 in the cache */
/* replace474_1 -> replace457_0_0 in the cache */
static const nir_search_expression replace474 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_fmul,
   { &replace14_1_0.value, &replace457_0_0.value },
   NULL,
};

   /* search475_0_0 -> search14_0 in the cache */
static const nir_search_expression search475_0 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_fexp2,
   { &search14_0.value },
   (is_used_once),
};

/* search475_1_0 -> replace14_1_0 in the cache */
static const nir_search_expression search475_1 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_fexp2,
   { &replace14_1_0.value },
   (is_used_once),
};
static const nir_search_expression search475 = {
   { nir_search_value_expression, -2 },
   true,
   0, 1,
   nir_op_fmul,
   { &search475_0.value, &search475_1.value },
   NULL,
};

   /* replace475_0_0 -> search14_0 in the cache */

/* replace475_0_1 -> replace14_1_0 in the cache */
/* replace475_0 -> replace49 in the cache */
static const nir_search_expression replace475 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 1,
   nir_op_fexp2,
   { &replace49.value },
   NULL,
};

   /* search476_0_0 -> search2_0 in the cache */

/* search476_0_1 -> search24_1 in the cache */
/* search476_0 -> replace65_0 in the cache */

/* search476_1 -> search24_1 in the cache */

/* search476_2_0 -> search2_0 in the cache */
/* search476_2 -> search471_0 in the cache */
static const nir_search_expression search476 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace65_0.value, &search24_1.value, &search471_0.value },
   NULL,
};

   /* replace476_0_0 -> search2_0 in the cache */

/* replace476_0_1 -> search24_1 in the cache */
/* replace476_0 -> search263_0 in the cache */
static const nir_search_expression replace476 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fsqrt,
   { &search263_0.value },
   NULL,
};

   /* search477_0 -> search41_1 in the cache */

/* search477_1 -> search2_0 in the cache */
static const nir_search_expression search477 = {
   { nir_search_value_expression, -1 },
   true,
   -1, 0,
   nir_op_fdiv,
   { &search41_1.value, &search2_0.value },
   NULL,
};

   /* replace477_0 -> search2_0 in the cache */
/* replace477 -> search472_0 in the cache */

   /* search478_0 -> search14_0 in the cache */

/* search478_1 -> replace14_1_0 in the cache */
static const nir_search_expression search478 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_fdiv,
   { &search14_0.value, &replace14_1_0.value },
   NULL,
};

   /* replace478_0 -> search14_0 in the cache */

/* replace478_1_0 -> replace14_1_0 in the cache */
static const nir_search_expression replace478_1 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_frcp,
   { &replace14_1_0.value },
   NULL,
};
static const nir_search_expression replace478 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_fmul,
   { &search14_0.value, &replace478_1.value },
   NULL,
};

   /* search479_0_0 -> search2_0 in the cache */
/* search479_0 -> search472_0 in the cache */
static const nir_search_expression search479 = {
   { nir_search_value_expression, -1 },
   true,
   -1, 0,
   nir_op_frcp,
   { &search472_0.value },
   NULL,
};

   /* replace479 -> search2_0 in the cache */

   /* search480_0_0 -> search2_0 in the cache */
/* search480_0 -> search471_0 in the cache */
static const nir_search_expression search480 = {
   { nir_search_value_expression, -1 },
   true,
   -1, 0,
   nir_op_frcp,
   { &search471_0.value },
   NULL,
};

   /* replace480_0 -> search2_0 in the cache */
/* replace480 -> search473_0 in the cache */

   /* search481_0 -> search2_0 in the cache */
/* search481 -> search471_0 in the cache */

   /* replace481_0_0 -> search2_0 in the cache */
/* replace481_0 -> search473_0 in the cache */
static const nir_search_expression replace481 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_frcp,
   { &search473_0.value },
   NULL,
};

   /* search482_0_0 -> search2_0 in the cache */
/* search482_0 -> search473_0 in the cache */
static const nir_search_expression search482 = {
   { nir_search_value_expression, -1 },
   true,
   -1, 0,
   nir_op_frcp,
   { &search473_0.value },
   NULL,
};

   /* replace482_0 -> search2_0 in the cache */
/* replace482 -> search471_0 in the cache */

   /* search483_0 -> search2_0 in the cache */
static const nir_search_expression search483 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fsin,
   { &search2_0.value },
   NULL,
};

   /* replace483_0_0_0_0_0_0 -> search460_0_1 in the cache */

static const nir_search_constant replace483_0_0_0_0_0_1_0_0_0 = {
   { nir_search_value_constant, -1 },
   nir_type_float, { 0x3fc45f306dc9c883 /* 0.15915494309189535 */ },
};

/* replace483_0_0_0_0_0_1_0_0_1 -> search2_0 in the cache */
static const nir_search_expression replace483_0_0_0_0_0_1_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   5, 1,
   nir_op_fmul,
   { &replace483_0_0_0_0_0_1_0_0_0.value, &search2_0.value },
   NULL,
};

/* replace483_0_0_0_0_0_1_0_1 -> replace468_0_0 in the cache */
static const nir_search_expression replace483_0_0_0_0_0_1_0 = {
   { nir_search_value_expression, -1 },
   false,
   4, 2,
   nir_op_fadd,
   { &replace483_0_0_0_0_0_1_0_0.value, &replace468_0_0.value },
   NULL,
};
static const nir_search_expression replace483_0_0_0_0_0_1 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 2,
   nir_op_ffract,
   { &replace483_0_0_0_0_0_1_0.value },
   NULL,
};
static const nir_search_expression replace483_0_0_0_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   3, 3,
   nir_op_fmul,
   { &search460_0_1.value, &replace483_0_0_0_0_0_1.value },
   NULL,
};

/* replace483_0_0_0_0_1 -> search41_1 in the cache */
static const nir_search_expression replace483_0_0_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 3,
   nir_op_fsub,
   { &replace483_0_0_0_0_0.value, &search41_1.value },
   NULL,
};

/* replace483_0_0_0_1_0_0_0 -> search460_0_1 in the cache */

/* replace483_0_0_0_1_0_0_1_0_0_0 -> replace483_0_0_0_0_0_1_0_0_0 in the cache */

/* replace483_0_0_0_1_0_0_1_0_0_1 -> search2_0 in the cache */
static const nir_search_expression replace483_0_0_0_1_0_0_1_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   9, 1,
   nir_op_fmul,
   { &replace483_0_0_0_0_0_1_0_0_0.value, &search2_0.value },
   NULL,
};

/* replace483_0_0_0_1_0_0_1_0_1 -> replace468_0_0 in the cache */
static const nir_search_expression replace483_0_0_0_1_0_0_1_0 = {
   { nir_search_value_expression, -1 },
   false,
   8, 2,
   nir_op_fadd,
   { &replace483_0_0_0_1_0_0_1_0_0.value, &replace468_0_0.value },
   NULL,
};
static const nir_search_expression replace483_0_0_0_1_0_0_1 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 2,
   nir_op_ffract,
   { &replace483_0_0_0_1_0_0_1_0.value },
   NULL,
};
static const nir_search_expression replace483_0_0_0_1_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   7, 3,
   nir_op_fmul,
   { &search460_0_1.value, &replace483_0_0_0_1_0_0_1.value },
   NULL,
};

/* replace483_0_0_0_1_0_1 -> search41_1 in the cache */
static const nir_search_expression replace483_0_0_0_1_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 3,
   nir_op_fsub,
   { &replace483_0_0_0_1_0_0.value, &search41_1.value },
   NULL,
};

/* replace483_0_0_0_1_1_0_0_0 -> search460_0_1 in the cache */

/* replace483_0_0_0_1_1_0_0_1_0_0_0 -> replace483_0_0_0_0_0_1_0_0_0 in the cache */

/* replace483_0_0_0_1_1_0_0_1_0_0_1 -> search2_0 in the cache */
static const nir_search_expression replace483_0_0_0_1_1_0_0_1_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   12, 1,
   nir_op_fmul,
   { &replace483_0_0_0_0_0_1_0_0_0.value, &search2_0.value },
   NULL,
};

/* replace483_0_0_0_1_1_0_0_1_0_1 -> replace468_0_0 in the cache */
static const nir_search_expression replace483_0_0_0_1_1_0_0_1_0 = {
   { nir_search_value_expression, -1 },
   false,
   11, 2,
   nir_op_fadd,
   { &replace483_0_0_0_1_1_0_0_1_0_0.value, &replace468_0_0.value },
   NULL,
};
static const nir_search_expression replace483_0_0_0_1_1_0_0_1 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 2,
   nir_op_ffract,
   { &replace483_0_0_0_1_1_0_0_1_0.value },
   NULL,
};
static const nir_search_expression replace483_0_0_0_1_1_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   10, 3,
   nir_op_fmul,
   { &search460_0_1.value, &replace483_0_0_0_1_1_0_0_1.value },
   NULL,
};

/* replace483_0_0_0_1_1_0_1 -> search41_1 in the cache */
static const nir_search_expression replace483_0_0_0_1_1_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 3,
   nir_op_fsub,
   { &replace483_0_0_0_1_1_0_0.value, &search41_1.value },
   NULL,
};
static const nir_search_expression replace483_0_0_0_1_1 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 3,
   nir_op_fabs,
   { &replace483_0_0_0_1_1_0.value },
   NULL,
};
static const nir_search_expression replace483_0_0_0_1 = {
   { nir_search_value_expression, -1 },
   false,
   6, 7,
   nir_op_fmul,
   { &replace483_0_0_0_1_0.value, &replace483_0_0_0_1_1.value },
   NULL,
};
static const nir_search_expression replace483_0_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 10,
   nir_op_fsub,
   { &replace483_0_0_0_0.value, &replace483_0_0_0_1.value },
   NULL,
};

/* replace483_0_0_1 -> search461_0_1 in the cache */
static const nir_search_expression replace483_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   2, 11,
   nir_op_fmul,
   { &replace483_0_0_0.value, &search461_0_1.value },
   NULL,
};

/* replace483_0_1_0_0_0_0_0 -> search460_0_1 in the cache */

/* replace483_0_1_0_0_0_0_1_0_0_0 -> replace483_0_0_0_0_0_1_0_0_0 in the cache */

/* replace483_0_1_0_0_0_0_1_0_0_1 -> search2_0 in the cache */
static const nir_search_expression replace483_0_1_0_0_0_0_1_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   16, 1,
   nir_op_fmul,
   { &replace483_0_0_0_0_0_1_0_0_0.value, &search2_0.value },
   NULL,
};

/* replace483_0_1_0_0_0_0_1_0_1 -> replace468_0_0 in the cache */
static const nir_search_expression replace483_0_1_0_0_0_0_1_0 = {
   { nir_search_value_expression, -1 },
   false,
   15, 2,
   nir_op_fadd,
   { &replace483_0_1_0_0_0_0_1_0_0.value, &replace468_0_0.value },
   NULL,
};
static const nir_search_expression replace483_0_1_0_0_0_0_1 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 2,
   nir_op_ffract,
   { &replace483_0_1_0_0_0_0_1_0.value },
   NULL,
};
static const nir_search_expression replace483_0_1_0_0_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   14, 3,
   nir_op_fmul,
   { &search460_0_1.value, &replace483_0_1_0_0_0_0_1.value },
   NULL,
};

/* replace483_0_1_0_0_0_1 -> search41_1 in the cache */
static const nir_search_expression replace483_0_1_0_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 3,
   nir_op_fsub,
   { &replace483_0_1_0_0_0_0.value, &search41_1.value },
   NULL,
};

/* replace483_0_1_0_0_1_0_0_0 -> search460_0_1 in the cache */

/* replace483_0_1_0_0_1_0_0_1_0_0_0 -> replace483_0_0_0_0_0_1_0_0_0 in the cache */

/* replace483_0_1_0_0_1_0_0_1_0_0_1 -> search2_0 in the cache */
static const nir_search_expression replace483_0_1_0_0_1_0_0_1_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   20, 1,
   nir_op_fmul,
   { &replace483_0_0_0_0_0_1_0_0_0.value, &search2_0.value },
   NULL,
};

/* replace483_0_1_0_0_1_0_0_1_0_1 -> replace468_0_0 in the cache */
static const nir_search_expression replace483_0_1_0_0_1_0_0_1_0 = {
   { nir_search_value_expression, -1 },
   false,
   19, 2,
   nir_op_fadd,
   { &replace483_0_1_0_0_1_0_0_1_0_0.value, &replace468_0_0.value },
   NULL,
};
static const nir_search_expression replace483_0_1_0_0_1_0_0_1 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 2,
   nir_op_ffract,
   { &replace483_0_1_0_0_1_0_0_1_0.value },
   NULL,
};
static const nir_search_expression replace483_0_1_0_0_1_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   18, 3,
   nir_op_fmul,
   { &search460_0_1.value, &replace483_0_1_0_0_1_0_0_1.value },
   NULL,
};

/* replace483_0_1_0_0_1_0_1 -> search41_1 in the cache */
static const nir_search_expression replace483_0_1_0_0_1_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 3,
   nir_op_fsub,
   { &replace483_0_1_0_0_1_0_0.value, &search41_1.value },
   NULL,
};

/* replace483_0_1_0_0_1_1_0_0_0 -> search460_0_1 in the cache */

/* replace483_0_1_0_0_1_1_0_0_1_0_0_0 -> replace483_0_0_0_0_0_1_0_0_0 in the cache */

/* replace483_0_1_0_0_1_1_0_0_1_0_0_1 -> search2_0 in the cache */
static const nir_search_expression replace483_0_1_0_0_1_1_0_0_1_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   23, 1,
   nir_op_fmul,
   { &replace483_0_0_0_0_0_1_0_0_0.value, &search2_0.value },
   NULL,
};

/* replace483_0_1_0_0_1_1_0_0_1_0_1 -> replace468_0_0 in the cache */
static const nir_search_expression replace483_0_1_0_0_1_1_0_0_1_0 = {
   { nir_search_value_expression, -1 },
   false,
   22, 2,
   nir_op_fadd,
   { &replace483_0_1_0_0_1_1_0_0_1_0_0.value, &replace468_0_0.value },
   NULL,
};
static const nir_search_expression replace483_0_1_0_0_1_1_0_0_1 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 2,
   nir_op_ffract,
   { &replace483_0_1_0_0_1_1_0_0_1_0.value },
   NULL,
};
static const nir_search_expression replace483_0_1_0_0_1_1_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   21, 3,
   nir_op_fmul,
   { &search460_0_1.value, &replace483_0_1_0_0_1_1_0_0_1.value },
   NULL,
};

/* replace483_0_1_0_0_1_1_0_1 -> search41_1 in the cache */
static const nir_search_expression replace483_0_1_0_0_1_1_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 3,
   nir_op_fsub,
   { &replace483_0_1_0_0_1_1_0_0.value, &search41_1.value },
   NULL,
};
static const nir_search_expression replace483_0_1_0_0_1_1 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 3,
   nir_op_fabs,
   { &replace483_0_1_0_0_1_1_0.value },
   NULL,
};
static const nir_search_expression replace483_0_1_0_0_1 = {
   { nir_search_value_expression, -1 },
   false,
   17, 7,
   nir_op_fmul,
   { &replace483_0_1_0_0_1_0.value, &replace483_0_1_0_0_1_1.value },
   NULL,
};
static const nir_search_expression replace483_0_1_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 10,
   nir_op_fsub,
   { &replace483_0_1_0_0_0.value, &replace483_0_1_0_0_1.value },
   NULL,
};

/* replace483_0_1_0_1 -> search461_0_1 in the cache */
static const nir_search_expression replace483_0_1_0 = {
   { nir_search_value_expression, -1 },
   false,
   13, 11,
   nir_op_fmul,
   { &replace483_0_1_0_0.value, &search461_0_1.value },
   NULL,
};
static const nir_search_expression replace483_0_1 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 11,
   nir_op_fabs,
   { &replace483_0_1_0.value },
   NULL,
};

/* replace483_0_2_0_0_0_0_0 -> search460_0_1 in the cache */

/* replace483_0_2_0_0_0_0_1_0_0_0 -> replace483_0_0_0_0_0_1_0_0_0 in the cache */

/* replace483_0_2_0_0_0_0_1_0_0_1 -> search2_0 in the cache */
static const nir_search_expression replace483_0_2_0_0_0_0_1_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   27, 1,
   nir_op_fmul,
   { &replace483_0_0_0_0_0_1_0_0_0.value, &search2_0.value },
   NULL,
};

/* replace483_0_2_0_0_0_0_1_0_1 -> replace468_0_0 in the cache */
static const nir_search_expression replace483_0_2_0_0_0_0_1_0 = {
   { nir_search_value_expression, -1 },
   false,
   26, 2,
   nir_op_fadd,
   { &replace483_0_2_0_0_0_0_1_0_0.value, &replace468_0_0.value },
   NULL,
};
static const nir_search_expression replace483_0_2_0_0_0_0_1 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 2,
   nir_op_ffract,
   { &replace483_0_2_0_0_0_0_1_0.value },
   NULL,
};
static const nir_search_expression replace483_0_2_0_0_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   25, 3,
   nir_op_fmul,
   { &search460_0_1.value, &replace483_0_2_0_0_0_0_1.value },
   NULL,
};

/* replace483_0_2_0_0_0_1 -> search41_1 in the cache */
static const nir_search_expression replace483_0_2_0_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 3,
   nir_op_fsub,
   { &replace483_0_2_0_0_0_0.value, &search41_1.value },
   NULL,
};

/* replace483_0_2_0_0_1_0_0_0 -> search460_0_1 in the cache */

/* replace483_0_2_0_0_1_0_0_1_0_0_0 -> replace483_0_0_0_0_0_1_0_0_0 in the cache */

/* replace483_0_2_0_0_1_0_0_1_0_0_1 -> search2_0 in the cache */
static const nir_search_expression replace483_0_2_0_0_1_0_0_1_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   31, 1,
   nir_op_fmul,
   { &replace483_0_0_0_0_0_1_0_0_0.value, &search2_0.value },
   NULL,
};

/* replace483_0_2_0_0_1_0_0_1_0_1 -> replace468_0_0 in the cache */
static const nir_search_expression replace483_0_2_0_0_1_0_0_1_0 = {
   { nir_search_value_expression, -1 },
   false,
   30, 2,
   nir_op_fadd,
   { &replace483_0_2_0_0_1_0_0_1_0_0.value, &replace468_0_0.value },
   NULL,
};
static const nir_search_expression replace483_0_2_0_0_1_0_0_1 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 2,
   nir_op_ffract,
   { &replace483_0_2_0_0_1_0_0_1_0.value },
   NULL,
};
static const nir_search_expression replace483_0_2_0_0_1_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   29, 3,
   nir_op_fmul,
   { &search460_0_1.value, &replace483_0_2_0_0_1_0_0_1.value },
   NULL,
};

/* replace483_0_2_0_0_1_0_1 -> search41_1 in the cache */
static const nir_search_expression replace483_0_2_0_0_1_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 3,
   nir_op_fsub,
   { &replace483_0_2_0_0_1_0_0.value, &search41_1.value },
   NULL,
};

/* replace483_0_2_0_0_1_1_0_0_0 -> search460_0_1 in the cache */

/* replace483_0_2_0_0_1_1_0_0_1_0_0_0 -> replace483_0_0_0_0_0_1_0_0_0 in the cache */

/* replace483_0_2_0_0_1_1_0_0_1_0_0_1 -> search2_0 in the cache */
static const nir_search_expression replace483_0_2_0_0_1_1_0_0_1_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   34, 1,
   nir_op_fmul,
   { &replace483_0_0_0_0_0_1_0_0_0.value, &search2_0.value },
   NULL,
};

/* replace483_0_2_0_0_1_1_0_0_1_0_1 -> replace468_0_0 in the cache */
static const nir_search_expression replace483_0_2_0_0_1_1_0_0_1_0 = {
   { nir_search_value_expression, -1 },
   false,
   33, 2,
   nir_op_fadd,
   { &replace483_0_2_0_0_1_1_0_0_1_0_0.value, &replace468_0_0.value },
   NULL,
};
static const nir_search_expression replace483_0_2_0_0_1_1_0_0_1 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 2,
   nir_op_ffract,
   { &replace483_0_2_0_0_1_1_0_0_1_0.value },
   NULL,
};
static const nir_search_expression replace483_0_2_0_0_1_1_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   32, 3,
   nir_op_fmul,
   { &search460_0_1.value, &replace483_0_2_0_0_1_1_0_0_1.value },
   NULL,
};

/* replace483_0_2_0_0_1_1_0_1 -> search41_1 in the cache */
static const nir_search_expression replace483_0_2_0_0_1_1_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 3,
   nir_op_fsub,
   { &replace483_0_2_0_0_1_1_0_0.value, &search41_1.value },
   NULL,
};
static const nir_search_expression replace483_0_2_0_0_1_1 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 3,
   nir_op_fabs,
   { &replace483_0_2_0_0_1_1_0.value },
   NULL,
};
static const nir_search_expression replace483_0_2_0_0_1 = {
   { nir_search_value_expression, -1 },
   false,
   28, 7,
   nir_op_fmul,
   { &replace483_0_2_0_0_1_0.value, &replace483_0_2_0_0_1_1.value },
   NULL,
};
static const nir_search_expression replace483_0_2_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 10,
   nir_op_fsub,
   { &replace483_0_2_0_0_0.value, &replace483_0_2_0_0_1.value },
   NULL,
};

/* replace483_0_2_0_1 -> search461_0_1 in the cache */
static const nir_search_expression replace483_0_2_0 = {
   { nir_search_value_expression, -1 },
   false,
   24, 11,
   nir_op_fmul,
   { &replace483_0_2_0_0.value, &search461_0_1.value },
   NULL,
};
static const nir_search_expression replace483_0_2 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 11,
   nir_op_fneg,
   { &replace483_0_2_0.value },
   NULL,
};
static const nir_search_expression replace483_0 = {
   { nir_search_value_expression, -1 },
   false,
   1, 34,
   nir_op_ffma,
   { &replace483_0_0.value, &replace483_0_1.value, &replace483_0_2.value },
   NULL,
};

static const nir_search_constant replace483_1 = {
   { nir_search_value_constant, -1 },
   nir_type_float, { 0x3fcccccccccccccd /* 0.225 */ },
};

/* replace483_2_0_0_0_0 -> search460_0_1 in the cache */

/* replace483_2_0_0_0_1_0_0_0 -> replace483_0_0_0_0_0_1_0_0_0 in the cache */

/* replace483_2_0_0_0_1_0_0_1 -> search2_0 in the cache */
static const nir_search_expression replace483_2_0_0_0_1_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   38, 1,
   nir_op_fmul,
   { &replace483_0_0_0_0_0_1_0_0_0.value, &search2_0.value },
   NULL,
};

/* replace483_2_0_0_0_1_0_1 -> replace468_0_0 in the cache */
static const nir_search_expression replace483_2_0_0_0_1_0 = {
   { nir_search_value_expression, -1 },
   false,
   37, 2,
   nir_op_fadd,
   { &replace483_2_0_0_0_1_0_0.value, &replace468_0_0.value },
   NULL,
};
static const nir_search_expression replace483_2_0_0_0_1 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 2,
   nir_op_ffract,
   { &replace483_2_0_0_0_1_0.value },
   NULL,
};
static const nir_search_expression replace483_2_0_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   36, 3,
   nir_op_fmul,
   { &search460_0_1.value, &replace483_2_0_0_0_1.value },
   NULL,
};

/* replace483_2_0_0_1 -> search41_1 in the cache */
static const nir_search_expression replace483_2_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 3,
   nir_op_fsub,
   { &replace483_2_0_0_0.value, &search41_1.value },
   NULL,
};

/* replace483_2_0_1_0_0_0 -> search460_0_1 in the cache */

/* replace483_2_0_1_0_0_1_0_0_0 -> replace483_0_0_0_0_0_1_0_0_0 in the cache */

/* replace483_2_0_1_0_0_1_0_0_1 -> search2_0 in the cache */
static const nir_search_expression replace483_2_0_1_0_0_1_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   42, 1,
   nir_op_fmul,
   { &replace483_0_0_0_0_0_1_0_0_0.value, &search2_0.value },
   NULL,
};

/* replace483_2_0_1_0_0_1_0_1 -> replace468_0_0 in the cache */
static const nir_search_expression replace483_2_0_1_0_0_1_0 = {
   { nir_search_value_expression, -1 },
   false,
   41, 2,
   nir_op_fadd,
   { &replace483_2_0_1_0_0_1_0_0.value, &replace468_0_0.value },
   NULL,
};
static const nir_search_expression replace483_2_0_1_0_0_1 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 2,
   nir_op_ffract,
   { &replace483_2_0_1_0_0_1_0.value },
   NULL,
};
static const nir_search_expression replace483_2_0_1_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   40, 3,
   nir_op_fmul,
   { &search460_0_1.value, &replace483_2_0_1_0_0_1.value },
   NULL,
};

/* replace483_2_0_1_0_1 -> search41_1 in the cache */
static const nir_search_expression replace483_2_0_1_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 3,
   nir_op_fsub,
   { &replace483_2_0_1_0_0.value, &search41_1.value },
   NULL,
};

/* replace483_2_0_1_1_0_0_0 -> search460_0_1 in the cache */

/* replace483_2_0_1_1_0_0_1_0_0_0 -> replace483_0_0_0_0_0_1_0_0_0 in the cache */

/* replace483_2_0_1_1_0_0_1_0_0_1 -> search2_0 in the cache */
static const nir_search_expression replace483_2_0_1_1_0_0_1_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   45, 1,
   nir_op_fmul,
   { &replace483_0_0_0_0_0_1_0_0_0.value, &search2_0.value },
   NULL,
};

/* replace483_2_0_1_1_0_0_1_0_1 -> replace468_0_0 in the cache */
static const nir_search_expression replace483_2_0_1_1_0_0_1_0 = {
   { nir_search_value_expression, -1 },
   false,
   44, 2,
   nir_op_fadd,
   { &replace483_2_0_1_1_0_0_1_0_0.value, &replace468_0_0.value },
   NULL,
};
static const nir_search_expression replace483_2_0_1_1_0_0_1 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 2,
   nir_op_ffract,
   { &replace483_2_0_1_1_0_0_1_0.value },
   NULL,
};
static const nir_search_expression replace483_2_0_1_1_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   43, 3,
   nir_op_fmul,
   { &search460_0_1.value, &replace483_2_0_1_1_0_0_1.value },
   NULL,
};

/* replace483_2_0_1_1_0_1 -> search41_1 in the cache */
static const nir_search_expression replace483_2_0_1_1_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 3,
   nir_op_fsub,
   { &replace483_2_0_1_1_0_0.value, &search41_1.value },
   NULL,
};
static const nir_search_expression replace483_2_0_1_1 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 3,
   nir_op_fabs,
   { &replace483_2_0_1_1_0.value },
   NULL,
};
static const nir_search_expression replace483_2_0_1 = {
   { nir_search_value_expression, -1 },
   false,
   39, 7,
   nir_op_fmul,
   { &replace483_2_0_1_0.value, &replace483_2_0_1_1.value },
   NULL,
};
static const nir_search_expression replace483_2_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 10,
   nir_op_fsub,
   { &replace483_2_0_0.value, &replace483_2_0_1.value },
   NULL,
};

/* replace483_2_1 -> search461_0_1 in the cache */
static const nir_search_expression replace483_2 = {
   { nir_search_value_expression, -1 },
   false,
   35, 11,
   nir_op_fmul,
   { &replace483_2_0.value, &search461_0_1.value },
   NULL,
};
static const nir_search_expression replace483 = {
   { nir_search_value_expression, -1 },
   false,
   0, 46,
   nir_op_ffma,
   { &replace483_0.value, &replace483_1.value, &replace483_2.value },
   NULL,
};

   /* search484_0 -> search2_0 in the cache */
static const nir_search_expression search484 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fcos,
   { &search2_0.value },
   NULL,
};

   /* replace484_0_0_0_0_0_0 -> search460_0_1 in the cache */

/* replace484_0_0_0_0_0_1_0_0_0 -> replace483_0_0_0_0_0_1_0_0_0 in the cache */

/* replace484_0_0_0_0_0_1_0_0_1 -> search2_0 in the cache */
/* replace484_0_0_0_0_0_1_0_0 -> replace483_0_0_0_0_0_1_0_0 in the cache */

static const nir_search_constant replace484_0_0_0_0_0_1_0_1 = {
   { nir_search_value_constant, -1 },
   nir_type_float, { 0x3fe8000000000000 /* 0.75 */ },
};
static const nir_search_expression replace484_0_0_0_0_0_1_0 = {
   { nir_search_value_expression, -1 },
   false,
   4, 2,
   nir_op_fadd,
   { &replace483_0_0_0_0_0_1_0_0.value, &replace484_0_0_0_0_0_1_0_1.value },
   NULL,
};
static const nir_search_expression replace484_0_0_0_0_0_1 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 2,
   nir_op_ffract,
   { &replace484_0_0_0_0_0_1_0.value },
   NULL,
};
static const nir_search_expression replace484_0_0_0_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   3, 3,
   nir_op_fmul,
   { &search460_0_1.value, &replace484_0_0_0_0_0_1.value },
   NULL,
};

/* replace484_0_0_0_0_1 -> search41_1 in the cache */
static const nir_search_expression replace484_0_0_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 3,
   nir_op_fsub,
   { &replace484_0_0_0_0_0.value, &search41_1.value },
   NULL,
};

/* replace484_0_0_0_1_0_0_0 -> search460_0_1 in the cache */

/* replace484_0_0_0_1_0_0_1_0_0_0 -> replace483_0_0_0_0_0_1_0_0_0 in the cache */

/* replace484_0_0_0_1_0_0_1_0_0_1 -> search2_0 in the cache */
/* replace484_0_0_0_1_0_0_1_0_0 -> replace483_0_0_0_1_0_0_1_0_0 in the cache */

/* replace484_0_0_0_1_0_0_1_0_1 -> replace484_0_0_0_0_0_1_0_1 in the cache */
static const nir_search_expression replace484_0_0_0_1_0_0_1_0 = {
   { nir_search_value_expression, -1 },
   false,
   8, 2,
   nir_op_fadd,
   { &replace483_0_0_0_1_0_0_1_0_0.value, &replace484_0_0_0_0_0_1_0_1.value },
   NULL,
};
static const nir_search_expression replace484_0_0_0_1_0_0_1 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 2,
   nir_op_ffract,
   { &replace484_0_0_0_1_0_0_1_0.value },
   NULL,
};
static const nir_search_expression replace484_0_0_0_1_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   7, 3,
   nir_op_fmul,
   { &search460_0_1.value, &replace484_0_0_0_1_0_0_1.value },
   NULL,
};

/* replace484_0_0_0_1_0_1 -> search41_1 in the cache */
static const nir_search_expression replace484_0_0_0_1_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 3,
   nir_op_fsub,
   { &replace484_0_0_0_1_0_0.value, &search41_1.value },
   NULL,
};

/* replace484_0_0_0_1_1_0_0_0 -> search460_0_1 in the cache */

/* replace484_0_0_0_1_1_0_0_1_0_0_0 -> replace483_0_0_0_0_0_1_0_0_0 in the cache */

/* replace484_0_0_0_1_1_0_0_1_0_0_1 -> search2_0 in the cache */
/* replace484_0_0_0_1_1_0_0_1_0_0 -> replace483_0_0_0_1_1_0_0_1_0_0 in the cache */

/* replace484_0_0_0_1_1_0_0_1_0_1 -> replace484_0_0_0_0_0_1_0_1 in the cache */
static const nir_search_expression replace484_0_0_0_1_1_0_0_1_0 = {
   { nir_search_value_expression, -1 },
   false,
   11, 2,
   nir_op_fadd,
   { &replace483_0_0_0_1_1_0_0_1_0_0.value, &replace484_0_0_0_0_0_1_0_1.value },
   NULL,
};
static const nir_search_expression replace484_0_0_0_1_1_0_0_1 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 2,
   nir_op_ffract,
   { &replace484_0_0_0_1_1_0_0_1_0.value },
   NULL,
};
static const nir_search_expression replace484_0_0_0_1_1_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   10, 3,
   nir_op_fmul,
   { &search460_0_1.value, &replace484_0_0_0_1_1_0_0_1.value },
   NULL,
};

/* replace484_0_0_0_1_1_0_1 -> search41_1 in the cache */
static const nir_search_expression replace484_0_0_0_1_1_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 3,
   nir_op_fsub,
   { &replace484_0_0_0_1_1_0_0.value, &search41_1.value },
   NULL,
};
static const nir_search_expression replace484_0_0_0_1_1 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 3,
   nir_op_fabs,
   { &replace484_0_0_0_1_1_0.value },
   NULL,
};
static const nir_search_expression replace484_0_0_0_1 = {
   { nir_search_value_expression, -1 },
   false,
   6, 7,
   nir_op_fmul,
   { &replace484_0_0_0_1_0.value, &replace484_0_0_0_1_1.value },
   NULL,
};
static const nir_search_expression replace484_0_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 10,
   nir_op_fsub,
   { &replace484_0_0_0_0.value, &replace484_0_0_0_1.value },
   NULL,
};

/* replace484_0_0_1 -> search461_0_1 in the cache */
static const nir_search_expression replace484_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   2, 11,
   nir_op_fmul,
   { &replace484_0_0_0.value, &search461_0_1.value },
   NULL,
};

/* replace484_0_1_0_0_0_0_0 -> search460_0_1 in the cache */

/* replace484_0_1_0_0_0_0_1_0_0_0 -> replace483_0_0_0_0_0_1_0_0_0 in the cache */

/* replace484_0_1_0_0_0_0_1_0_0_1 -> search2_0 in the cache */
/* replace484_0_1_0_0_0_0_1_0_0 -> replace483_0_1_0_0_0_0_1_0_0 in the cache */

/* replace484_0_1_0_0_0_0_1_0_1 -> replace484_0_0_0_0_0_1_0_1 in the cache */
static const nir_search_expression replace484_0_1_0_0_0_0_1_0 = {
   { nir_search_value_expression, -1 },
   false,
   15, 2,
   nir_op_fadd,
   { &replace483_0_1_0_0_0_0_1_0_0.value, &replace484_0_0_0_0_0_1_0_1.value },
   NULL,
};
static const nir_search_expression replace484_0_1_0_0_0_0_1 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 2,
   nir_op_ffract,
   { &replace484_0_1_0_0_0_0_1_0.value },
   NULL,
};
static const nir_search_expression replace484_0_1_0_0_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   14, 3,
   nir_op_fmul,
   { &search460_0_1.value, &replace484_0_1_0_0_0_0_1.value },
   NULL,
};

/* replace484_0_1_0_0_0_1 -> search41_1 in the cache */
static const nir_search_expression replace484_0_1_0_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 3,
   nir_op_fsub,
   { &replace484_0_1_0_0_0_0.value, &search41_1.value },
   NULL,
};

/* replace484_0_1_0_0_1_0_0_0 -> search460_0_1 in the cache */

/* replace484_0_1_0_0_1_0_0_1_0_0_0 -> replace483_0_0_0_0_0_1_0_0_0 in the cache */

/* replace484_0_1_0_0_1_0_0_1_0_0_1 -> search2_0 in the cache */
/* replace484_0_1_0_0_1_0_0_1_0_0 -> replace483_0_1_0_0_1_0_0_1_0_0 in the cache */

/* replace484_0_1_0_0_1_0_0_1_0_1 -> replace484_0_0_0_0_0_1_0_1 in the cache */
static const nir_search_expression replace484_0_1_0_0_1_0_0_1_0 = {
   { nir_search_value_expression, -1 },
   false,
   19, 2,
   nir_op_fadd,
   { &replace483_0_1_0_0_1_0_0_1_0_0.value, &replace484_0_0_0_0_0_1_0_1.value },
   NULL,
};
static const nir_search_expression replace484_0_1_0_0_1_0_0_1 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 2,
   nir_op_ffract,
   { &replace484_0_1_0_0_1_0_0_1_0.value },
   NULL,
};
static const nir_search_expression replace484_0_1_0_0_1_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   18, 3,
   nir_op_fmul,
   { &search460_0_1.value, &replace484_0_1_0_0_1_0_0_1.value },
   NULL,
};

/* replace484_0_1_0_0_1_0_1 -> search41_1 in the cache */
static const nir_search_expression replace484_0_1_0_0_1_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 3,
   nir_op_fsub,
   { &replace484_0_1_0_0_1_0_0.value, &search41_1.value },
   NULL,
};

/* replace484_0_1_0_0_1_1_0_0_0 -> search460_0_1 in the cache */

/* replace484_0_1_0_0_1_1_0_0_1_0_0_0 -> replace483_0_0_0_0_0_1_0_0_0 in the cache */

/* replace484_0_1_0_0_1_1_0_0_1_0_0_1 -> search2_0 in the cache */
/* replace484_0_1_0_0_1_1_0_0_1_0_0 -> replace483_0_1_0_0_1_1_0_0_1_0_0 in the cache */

/* replace484_0_1_0_0_1_1_0_0_1_0_1 -> replace484_0_0_0_0_0_1_0_1 in the cache */
static const nir_search_expression replace484_0_1_0_0_1_1_0_0_1_0 = {
   { nir_search_value_expression, -1 },
   false,
   22, 2,
   nir_op_fadd,
   { &replace483_0_1_0_0_1_1_0_0_1_0_0.value, &replace484_0_0_0_0_0_1_0_1.value },
   NULL,
};
static const nir_search_expression replace484_0_1_0_0_1_1_0_0_1 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 2,
   nir_op_ffract,
   { &replace484_0_1_0_0_1_1_0_0_1_0.value },
   NULL,
};
static const nir_search_expression replace484_0_1_0_0_1_1_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   21, 3,
   nir_op_fmul,
   { &search460_0_1.value, &replace484_0_1_0_0_1_1_0_0_1.value },
   NULL,
};

/* replace484_0_1_0_0_1_1_0_1 -> search41_1 in the cache */
static const nir_search_expression replace484_0_1_0_0_1_1_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 3,
   nir_op_fsub,
   { &replace484_0_1_0_0_1_1_0_0.value, &search41_1.value },
   NULL,
};
static const nir_search_expression replace484_0_1_0_0_1_1 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 3,
   nir_op_fabs,
   { &replace484_0_1_0_0_1_1_0.value },
   NULL,
};
static const nir_search_expression replace484_0_1_0_0_1 = {
   { nir_search_value_expression, -1 },
   false,
   17, 7,
   nir_op_fmul,
   { &replace484_0_1_0_0_1_0.value, &replace484_0_1_0_0_1_1.value },
   NULL,
};
static const nir_search_expression replace484_0_1_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 10,
   nir_op_fsub,
   { &replace484_0_1_0_0_0.value, &replace484_0_1_0_0_1.value },
   NULL,
};

/* replace484_0_1_0_1 -> search461_0_1 in the cache */
static const nir_search_expression replace484_0_1_0 = {
   { nir_search_value_expression, -1 },
   false,
   13, 11,
   nir_op_fmul,
   { &replace484_0_1_0_0.value, &search461_0_1.value },
   NULL,
};
static const nir_search_expression replace484_0_1 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 11,
   nir_op_fabs,
   { &replace484_0_1_0.value },
   NULL,
};

/* replace484_0_2_0_0_0_0_0 -> search460_0_1 in the cache */

/* replace484_0_2_0_0_0_0_1_0_0_0 -> replace483_0_0_0_0_0_1_0_0_0 in the cache */

/* replace484_0_2_0_0_0_0_1_0_0_1 -> search2_0 in the cache */
/* replace484_0_2_0_0_0_0_1_0_0 -> replace483_0_2_0_0_0_0_1_0_0 in the cache */

/* replace484_0_2_0_0_0_0_1_0_1 -> replace484_0_0_0_0_0_1_0_1 in the cache */
static const nir_search_expression replace484_0_2_0_0_0_0_1_0 = {
   { nir_search_value_expression, -1 },
   false,
   26, 2,
   nir_op_fadd,
   { &replace483_0_2_0_0_0_0_1_0_0.value, &replace484_0_0_0_0_0_1_0_1.value },
   NULL,
};
static const nir_search_expression replace484_0_2_0_0_0_0_1 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 2,
   nir_op_ffract,
   { &replace484_0_2_0_0_0_0_1_0.value },
   NULL,
};
static const nir_search_expression replace484_0_2_0_0_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   25, 3,
   nir_op_fmul,
   { &search460_0_1.value, &replace484_0_2_0_0_0_0_1.value },
   NULL,
};

/* replace484_0_2_0_0_0_1 -> search41_1 in the cache */
static const nir_search_expression replace484_0_2_0_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 3,
   nir_op_fsub,
   { &replace484_0_2_0_0_0_0.value, &search41_1.value },
   NULL,
};

/* replace484_0_2_0_0_1_0_0_0 -> search460_0_1 in the cache */

/* replace484_0_2_0_0_1_0_0_1_0_0_0 -> replace483_0_0_0_0_0_1_0_0_0 in the cache */

/* replace484_0_2_0_0_1_0_0_1_0_0_1 -> search2_0 in the cache */
/* replace484_0_2_0_0_1_0_0_1_0_0 -> replace483_0_2_0_0_1_0_0_1_0_0 in the cache */

/* replace484_0_2_0_0_1_0_0_1_0_1 -> replace484_0_0_0_0_0_1_0_1 in the cache */
static const nir_search_expression replace484_0_2_0_0_1_0_0_1_0 = {
   { nir_search_value_expression, -1 },
   false,
   30, 2,
   nir_op_fadd,
   { &replace483_0_2_0_0_1_0_0_1_0_0.value, &replace484_0_0_0_0_0_1_0_1.value },
   NULL,
};
static const nir_search_expression replace484_0_2_0_0_1_0_0_1 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 2,
   nir_op_ffract,
   { &replace484_0_2_0_0_1_0_0_1_0.value },
   NULL,
};
static const nir_search_expression replace484_0_2_0_0_1_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   29, 3,
   nir_op_fmul,
   { &search460_0_1.value, &replace484_0_2_0_0_1_0_0_1.value },
   NULL,
};

/* replace484_0_2_0_0_1_0_1 -> search41_1 in the cache */
static const nir_search_expression replace484_0_2_0_0_1_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 3,
   nir_op_fsub,
   { &replace484_0_2_0_0_1_0_0.value, &search41_1.value },
   NULL,
};

/* replace484_0_2_0_0_1_1_0_0_0 -> search460_0_1 in the cache */

/* replace484_0_2_0_0_1_1_0_0_1_0_0_0 -> replace483_0_0_0_0_0_1_0_0_0 in the cache */

/* replace484_0_2_0_0_1_1_0_0_1_0_0_1 -> search2_0 in the cache */
/* replace484_0_2_0_0_1_1_0_0_1_0_0 -> replace483_0_2_0_0_1_1_0_0_1_0_0 in the cache */

/* replace484_0_2_0_0_1_1_0_0_1_0_1 -> replace484_0_0_0_0_0_1_0_1 in the cache */
static const nir_search_expression replace484_0_2_0_0_1_1_0_0_1_0 = {
   { nir_search_value_expression, -1 },
   false,
   33, 2,
   nir_op_fadd,
   { &replace483_0_2_0_0_1_1_0_0_1_0_0.value, &replace484_0_0_0_0_0_1_0_1.value },
   NULL,
};
static const nir_search_expression replace484_0_2_0_0_1_1_0_0_1 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 2,
   nir_op_ffract,
   { &replace484_0_2_0_0_1_1_0_0_1_0.value },
   NULL,
};
static const nir_search_expression replace484_0_2_0_0_1_1_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   32, 3,
   nir_op_fmul,
   { &search460_0_1.value, &replace484_0_2_0_0_1_1_0_0_1.value },
   NULL,
};

/* replace484_0_2_0_0_1_1_0_1 -> search41_1 in the cache */
static const nir_search_expression replace484_0_2_0_0_1_1_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 3,
   nir_op_fsub,
   { &replace484_0_2_0_0_1_1_0_0.value, &search41_1.value },
   NULL,
};
static const nir_search_expression replace484_0_2_0_0_1_1 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 3,
   nir_op_fabs,
   { &replace484_0_2_0_0_1_1_0.value },
   NULL,
};
static const nir_search_expression replace484_0_2_0_0_1 = {
   { nir_search_value_expression, -1 },
   false,
   28, 7,
   nir_op_fmul,
   { &replace484_0_2_0_0_1_0.value, &replace484_0_2_0_0_1_1.value },
   NULL,
};
static const nir_search_expression replace484_0_2_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 10,
   nir_op_fsub,
   { &replace484_0_2_0_0_0.value, &replace484_0_2_0_0_1.value },
   NULL,
};

/* replace484_0_2_0_1 -> search461_0_1 in the cache */
static const nir_search_expression replace484_0_2_0 = {
   { nir_search_value_expression, -1 },
   false,
   24, 11,
   nir_op_fmul,
   { &replace484_0_2_0_0.value, &search461_0_1.value },
   NULL,
};
static const nir_search_expression replace484_0_2 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 11,
   nir_op_fneg,
   { &replace484_0_2_0.value },
   NULL,
};
static const nir_search_expression replace484_0 = {
   { nir_search_value_expression, -1 },
   false,
   1, 34,
   nir_op_ffma,
   { &replace484_0_0.value, &replace484_0_1.value, &replace484_0_2.value },
   NULL,
};

/* replace484_1 -> replace483_1 in the cache */

/* replace484_2_0_0_0_0 -> search460_0_1 in the cache */

/* replace484_2_0_0_0_1_0_0_0 -> replace483_0_0_0_0_0_1_0_0_0 in the cache */

/* replace484_2_0_0_0_1_0_0_1 -> search2_0 in the cache */
/* replace484_2_0_0_0_1_0_0 -> replace483_2_0_0_0_1_0_0 in the cache */

/* replace484_2_0_0_0_1_0_1 -> replace484_0_0_0_0_0_1_0_1 in the cache */
static const nir_search_expression replace484_2_0_0_0_1_0 = {
   { nir_search_value_expression, -1 },
   false,
   37, 2,
   nir_op_fadd,
   { &replace483_2_0_0_0_1_0_0.value, &replace484_0_0_0_0_0_1_0_1.value },
   NULL,
};
static const nir_search_expression replace484_2_0_0_0_1 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 2,
   nir_op_ffract,
   { &replace484_2_0_0_0_1_0.value },
   NULL,
};
static const nir_search_expression replace484_2_0_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   36, 3,
   nir_op_fmul,
   { &search460_0_1.value, &replace484_2_0_0_0_1.value },
   NULL,
};

/* replace484_2_0_0_1 -> search41_1 in the cache */
static const nir_search_expression replace484_2_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 3,
   nir_op_fsub,
   { &replace484_2_0_0_0.value, &search41_1.value },
   NULL,
};

/* replace484_2_0_1_0_0_0 -> search460_0_1 in the cache */

/* replace484_2_0_1_0_0_1_0_0_0 -> replace483_0_0_0_0_0_1_0_0_0 in the cache */

/* replace484_2_0_1_0_0_1_0_0_1 -> search2_0 in the cache */
/* replace484_2_0_1_0_0_1_0_0 -> replace483_2_0_1_0_0_1_0_0 in the cache */

/* replace484_2_0_1_0_0_1_0_1 -> replace484_0_0_0_0_0_1_0_1 in the cache */
static const nir_search_expression replace484_2_0_1_0_0_1_0 = {
   { nir_search_value_expression, -1 },
   false,
   41, 2,
   nir_op_fadd,
   { &replace483_2_0_1_0_0_1_0_0.value, &replace484_0_0_0_0_0_1_0_1.value },
   NULL,
};
static const nir_search_expression replace484_2_0_1_0_0_1 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 2,
   nir_op_ffract,
   { &replace484_2_0_1_0_0_1_0.value },
   NULL,
};
static const nir_search_expression replace484_2_0_1_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   40, 3,
   nir_op_fmul,
   { &search460_0_1.value, &replace484_2_0_1_0_0_1.value },
   NULL,
};

/* replace484_2_0_1_0_1 -> search41_1 in the cache */
static const nir_search_expression replace484_2_0_1_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 3,
   nir_op_fsub,
   { &replace484_2_0_1_0_0.value, &search41_1.value },
   NULL,
};

/* replace484_2_0_1_1_0_0_0 -> search460_0_1 in the cache */

/* replace484_2_0_1_1_0_0_1_0_0_0 -> replace483_0_0_0_0_0_1_0_0_0 in the cache */

/* replace484_2_0_1_1_0_0_1_0_0_1 -> search2_0 in the cache */
/* replace484_2_0_1_1_0_0_1_0_0 -> replace483_2_0_1_1_0_0_1_0_0 in the cache */

/* replace484_2_0_1_1_0_0_1_0_1 -> replace484_0_0_0_0_0_1_0_1 in the cache */
static const nir_search_expression replace484_2_0_1_1_0_0_1_0 = {
   { nir_search_value_expression, -1 },
   false,
   44, 2,
   nir_op_fadd,
   { &replace483_2_0_1_1_0_0_1_0_0.value, &replace484_0_0_0_0_0_1_0_1.value },
   NULL,
};
static const nir_search_expression replace484_2_0_1_1_0_0_1 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 2,
   nir_op_ffract,
   { &replace484_2_0_1_1_0_0_1_0.value },
   NULL,
};
static const nir_search_expression replace484_2_0_1_1_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   43, 3,
   nir_op_fmul,
   { &search460_0_1.value, &replace484_2_0_1_1_0_0_1.value },
   NULL,
};

/* replace484_2_0_1_1_0_1 -> search41_1 in the cache */
static const nir_search_expression replace484_2_0_1_1_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 3,
   nir_op_fsub,
   { &replace484_2_0_1_1_0_0.value, &search41_1.value },
   NULL,
};
static const nir_search_expression replace484_2_0_1_1 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 3,
   nir_op_fabs,
   { &replace484_2_0_1_1_0.value },
   NULL,
};
static const nir_search_expression replace484_2_0_1 = {
   { nir_search_value_expression, -1 },
   false,
   39, 7,
   nir_op_fmul,
   { &replace484_2_0_1_0.value, &replace484_2_0_1_1.value },
   NULL,
};
static const nir_search_expression replace484_2_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 10,
   nir_op_fsub,
   { &replace484_2_0_0.value, &replace484_2_0_1.value },
   NULL,
};

/* replace484_2_1 -> search461_0_1 in the cache */
static const nir_search_expression replace484_2 = {
   { nir_search_value_expression, -1 },
   false,
   35, 11,
   nir_op_fmul,
   { &replace484_2_0.value, &search461_0_1.value },
   NULL,
};
static const nir_search_expression replace484 = {
   { nir_search_value_expression, -1 },
   false,
   0, 46,
   nir_op_ffma,
   { &replace484_0.value, &replace483_1.value, &replace484_2.value },
   NULL,
};

   /* search485_0 -> search2_0 in the cache */
static const nir_search_expression search485 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_i2b32,
   { &search2_0.value },
   (is_used_by_if),
};

   /* replace485_0 -> search2_0 in the cache */

/* replace485_1 -> replace9 in the cache */
static const nir_search_expression replace485 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_ine32,
   { &search2_0.value, &replace9.value },
   NULL,
};

   /* search486_0 -> search2_0 in the cache */
static const nir_search_expression search486 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_i2b1,
   { &search2_0.value },
   (is_used_by_if),
};

   /* replace486_0 -> search2_0 in the cache */

/* replace486_1 -> replace9 in the cache */
/* replace486 -> replace195 in the cache */

   /* search487_0 -> replace80_0 in the cache */

/* search487_1 -> replace197 in the cache */
static const nir_search_expression search487 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &replace80_0.value, &replace197.value },
   NULL,
};

   /* replace487 -> replace80_0 in the cache */

   /* search488_0 -> replace80_0 in the cache */

/* search488_1 -> replace197 in the cache */
static const nir_search_expression search488 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &replace80_0.value, &replace197.value },
   (is_not_used_by_if),
};

   /* replace488_0 -> replace80_0 in the cache */
/* replace488 -> replace146 in the cache */

   /* search489_0 -> replace80_0 in the cache */

/* search489_1 -> replace121 in the cache */
static const nir_search_expression search489 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &replace80_0.value, &replace121.value },
   NULL,
};

   /* replace489 -> replace80_0 in the cache */

   /* search490_0 -> replace80_0 in the cache */

/* search490_1 -> replace121 in the cache */
static const nir_search_expression search490 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &replace80_0.value, &replace121.value },
   (is_not_used_by_if),
};

   /* replace490_0 -> replace80_0 in the cache */
/* replace490 -> replace146 in the cache */

   /* search491_0 -> replace80_0 in the cache */

/* search491_1 -> replace197 in the cache */

/* search491_2 -> replace121 in the cache */
static const nir_search_expression search491 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace80_0.value, &replace197.value, &replace121.value },
   NULL,
};

   /* replace491 -> replace80_0 in the cache */

   /* search492_0 -> replace80_0 in the cache */

/* search492_1 -> replace121 in the cache */

/* search492_2 -> replace197 in the cache */
static const nir_search_expression search492 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace80_0.value, &replace121.value, &replace197.value },
   NULL,
};

   /* replace492_0 -> replace80_0 in the cache */
/* replace492 -> replace146 in the cache */

   /* search493_0 -> replace80_0 in the cache */

/* search493_1 -> replace60_0_0 in the cache */

/* search493_2 -> search312_0_0 in the cache */
static const nir_search_expression search493 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace80_0.value, &replace60_0_0.value, &search312_0_0.value },
   NULL,
};

   /* replace493_0 -> replace80_0 in the cache */
static const nir_search_expression replace493 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_search_op_b2f,
   { &replace80_0.value },
   NULL,
};

   /* search494_0 -> replace80_0 in the cache */

/* search494_1 -> search312_0_0 in the cache */

/* search494_2 -> replace60_0_0 in the cache */
static const nir_search_expression search494 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace80_0.value, &search312_0_0.value, &replace60_0_0.value },
   NULL,
};

   /* replace494_0_0 -> replace80_0 in the cache */
/* replace494_0 -> replace146 in the cache */
static const nir_search_expression replace494 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_search_op_b2f,
   { &replace146.value },
   NULL,
};

   /* search495_0 -> replace80_0 in the cache */

static const nir_search_constant search495_1 = {
   { nir_search_value_constant, 32 },
   nir_type_float, { 0xbff0000000000000L /* -1.0 */ },
};

static const nir_search_constant search495_2 = {
   { nir_search_value_constant, 32 },
   nir_type_float, { 0x8000000000000000L /* -0.0 */ },
};
static const nir_search_expression search495 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace80_0.value, &search495_1.value, &search495_2.value },
   NULL,
};

   /* replace495_0_0 -> replace80_0 in the cache */
/* replace495_0 -> replace493 in the cache */
static const nir_search_expression replace495 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_fneg,
   { &replace493.value },
   NULL,
};

   /* search496_0 -> replace80_0 in the cache */

/* search496_1 -> search495_2 in the cache */

/* search496_2 -> search495_1 in the cache */
static const nir_search_expression search496 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace80_0.value, &search495_2.value, &search495_1.value },
   NULL,
};

   /* replace496_0_0_0 -> replace80_0 in the cache */
/* replace496_0_0 -> replace146 in the cache */
/* replace496_0 -> replace494 in the cache */
static const nir_search_expression replace496 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_fneg,
   { &replace494.value },
   NULL,
};

   /* search497_0 -> replace197 in the cache */

/* search497_1 -> replace137_0 in the cache */

/* search497_2 -> search64_2 in the cache */
static const nir_search_expression search497 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace197.value, &replace137_0.value, &search64_2.value },
   NULL,
};

   /* replace497 -> replace137_0 in the cache */

   /* search498_0 -> replace121 in the cache */

/* search498_1 -> replace137_0 in the cache */

/* search498_2 -> search64_2 in the cache */
static const nir_search_expression search498 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace121.value, &replace137_0.value, &search64_2.value },
   NULL,
};

   /* replace498 -> search64_2 in the cache */

   /* search499_0 -> replace80_0 in the cache */

/* search499_1_0 -> replace0_1_0 in the cache */
static const nir_search_expression search499_1 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_search_op_b2f,
   { &replace0_1_0.value },
   (is_used_once),
};

/* search499_2_0 -> search56_2 in the cache */
static const nir_search_expression search499_2 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_search_op_b2f,
   { &search56_2.value },
   NULL,
};
static const nir_search_expression search499 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace80_0.value, &search499_1.value, &search499_2.value },
   NULL,
};

   /* replace499_0_0 -> replace80_0 in the cache */

/* replace499_0_1 -> replace0_1_0 in the cache */

/* replace499_0_2 -> search56_2 in the cache */
static const nir_search_expression replace499_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace80_0.value, &replace0_1_0.value, &search56_2.value },
   NULL,
};
static const nir_search_expression replace499 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_search_op_b2f,
   { &replace499_0.value },
   NULL,
};

   /* search500_0 -> replace80_0 in the cache */

/* search500_1 -> replace14_1_0 in the cache */

/* search500_2 -> replace14_1_0 in the cache */
static const nir_search_expression search500 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace80_0.value, &replace14_1_0.value, &replace14_1_0.value },
   NULL,
};

   /* replace500 -> replace14_1_0 in the cache */

   /* search501_0 -> search0_0 in the cache */

/* search501_1 -> replace0_1_0 in the cache */

/* search501_2 -> replace0_1_0 in the cache */
static const nir_search_expression search501 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_fcsel,
   { &search0_0.value, &replace0_1_0.value, &replace0_1_0.value },
   NULL,
};

   /* replace501 -> replace0_1_0 in the cache */

   /* search502_0 -> replace80_0 in the cache */

static const nir_search_constant search502_1 = {
   { nir_search_value_constant, 0 },
   nir_type_int, { -0x1 /* -1 */ },
};

/* search502_2 -> search193_1 in the cache */
static const nir_search_expression search502 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace80_0.value, &search502_1.value, &search193_1.value },
   NULL,
};

   /* replace502_0_0 -> replace80_0 in the cache */
/* replace502_0 -> search193_0 in the cache */
static const nir_search_expression replace502 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_op_ineg,
   { &search193_0.value },
   NULL,
};

   /* search503_0 -> replace80_0 in the cache */

/* search503_1 -> search193_1 in the cache */

/* search503_2 -> search502_1 in the cache */
static const nir_search_expression search503 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace80_0.value, &search193_1.value, &search502_1.value },
   NULL,
};

   /* replace503_0_0_0 -> replace80_0 in the cache */
/* replace503_0_0 -> replace146 in the cache */
static const nir_search_expression replace503_0 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_search_op_b2i,
   { &replace146.value },
   NULL,
};
static const nir_search_expression replace503 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_op_ineg,
   { &replace503_0.value },
   NULL,
};

   /* search504_0_0_0 -> replace80_0 in the cache */
/* search504_0_0 -> search193_0 in the cache */
/* search504_0 -> replace502 in the cache */

/* search504_1_0_0 -> search148_0_1_0 in the cache */
/* search504_1_0 -> search407_1 in the cache */
static const nir_search_expression search504_1 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_op_ineg,
   { &search407_1.value },
   NULL,
};
static const nir_search_expression search504 = {
   { nir_search_value_expression, 0 },
   false,
   0, 1,
   nir_op_iand,
   { &replace502.value, &search504_1.value },
   NULL,
};

   /* replace504_0_0_0 -> replace80_0 in the cache */

/* replace504_0_0_1 -> search148_0_1_0 in the cache */
/* replace504_0_0 -> replace152 in the cache */
/* replace504_0 -> replace407 in the cache */
static const nir_search_expression replace504 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 1,
   nir_op_ineg,
   { &replace407.value },
   NULL,
};

   /* search505_0_0_0 -> replace80_0 in the cache */
/* search505_0_0 -> search193_0 in the cache */
/* search505_0 -> replace502 in the cache */

/* search505_1_0_0 -> search148_0_1_0 in the cache */
/* search505_1_0 -> search407_1 in the cache */
/* search505_1 -> search504_1 in the cache */
static const nir_search_expression search505 = {
   { nir_search_value_expression, 0 },
   false,
   0, 1,
   nir_op_ior,
   { &replace502.value, &search504_1.value },
   NULL,
};

   /* replace505_0_0_0 -> replace80_0 in the cache */

/* replace505_0_0_1 -> search148_0_1_0 in the cache */
/* replace505_0_0 -> replace148 in the cache */
static const nir_search_expression replace505_0 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 1,
   nir_search_op_b2i,
   { &replace148.value },
   NULL,
};
static const nir_search_expression replace505 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 1,
   nir_op_ineg,
   { &replace505_0.value },
   NULL,
};

   /* search506_0_0_0 -> replace80_0 in the cache */
/* search506_0_0 -> search193_0 in the cache */
/* search506_0 -> replace502 in the cache */

/* search506_1 -> search193_1 in the cache */
static const nir_search_expression search506 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &replace502.value, &search193_1.value },
   NULL,
};

   /* replace506_0 -> replace80_0 in the cache */
/* replace506 -> replace146 in the cache */

   /* search507_0_0_0 -> replace80_0 in the cache */
/* search507_0_0 -> search193_0 in the cache */
/* search507_0 -> replace502 in the cache */

/* search507_1 -> search502_1 in the cache */
static const nir_search_expression search507 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &replace502.value, &search502_1.value },
   NULL,
};

   /* replace507 -> replace80_0 in the cache */

   /* search508_0_0_0 -> replace80_0 in the cache */
/* search508_0_0 -> search193_0 in the cache */
/* search508_0 -> replace502 in the cache */

/* search508_1 -> search193_1 in the cache */
static const nir_search_expression search508 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &replace502.value, &search193_1.value },
   NULL,
};

   /* replace508 -> replace80_0 in the cache */

   /* search509_0_0_0 -> replace80_0 in the cache */
/* search509_0_0 -> search193_0 in the cache */
/* search509_0 -> replace502 in the cache */

/* search509_1 -> search502_1 in the cache */
static const nir_search_expression search509 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &replace502.value, &search502_1.value },
   NULL,
};

   /* replace509_0 -> replace80_0 in the cache */
/* replace509 -> replace146 in the cache */

   /* search510_0_0_0 -> search2_0 in the cache */
static const nir_search_expression search510_0_0 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_search_op_b2i,
   { &search2_0.value },
   NULL,
};
static const nir_search_expression search510_0 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_op_ineg,
   { &search510_0_0.value },
   NULL,
};

/* search510_1 -> search150_0_1 in the cache */
static const nir_search_expression search510 = {
   { nir_search_value_expression, 0 },
   false,
   0, 1,
   nir_op_iand,
   { &search510_0.value, &search150_0_1.value },
   NULL,
};

   /* replace510_0 -> search2_0 in the cache */
/* replace510 -> search268_0 in the cache */

   /* search511_0 -> search0_0 in the cache */

/* search511_1_0 -> replace106_1_1 in the cache */

/* search511_1_1 -> replace0_1_0 in the cache */
static const nir_search_expression search511_1 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_iand,
   { &replace106_1_1.value, &replace0_1_0.value },
   NULL,
};
static const nir_search_expression search511 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_op_ishl,
   { &search0_0.value, &search511_1.value },
   NULL,
};

   /* replace511_0 -> search0_0 in the cache */

/* replace511_1 -> replace0_1_0 in the cache */
/* replace511 -> search445_0 in the cache */

   /* search512_0 -> search0_0 in the cache */

/* search512_1_0 -> replace106_1_1 in the cache */

/* search512_1_1 -> replace0_1_0 in the cache */
/* search512_1 -> search511_1 in the cache */
static const nir_search_expression search512 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_op_ishr,
   { &search0_0.value, &search511_1.value },
   NULL,
};

   /* replace512_0 -> search0_0 in the cache */

/* replace512_1 -> replace0_1_0 in the cache */
static const nir_search_expression replace512 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_ishr,
   { &search0_0.value, &replace0_1_0.value },
   NULL,
};

   /* search513_0 -> search0_0 in the cache */

/* search513_1_0 -> replace106_1_1 in the cache */

/* search513_1_1 -> replace0_1_0 in the cache */
/* search513_1 -> search511_1 in the cache */
static const nir_search_expression search513 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_op_ushr,
   { &search0_0.value, &search511_1.value },
   NULL,
};

   /* replace513_0 -> search0_0 in the cache */

/* replace513_1 -> replace0_1_0 in the cache */
/* replace513 -> search449_0 in the cache */

   /* search514_0_0 -> search0_0 in the cache */
static const nir_search_expression search514_0 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_search_op_b2i,
   { &search0_0.value },
   NULL,
};
static const nir_search_expression search514 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_i2b32,
   { &search514_0.value },
   NULL,
};

   /* replace514 -> search0_0 in the cache */

   /* search515_0_0 -> search2_0 in the cache */
/* search515_0 -> search65 in the cache */
static const nir_search_expression search515 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_search_op_f2i,
   { &search65.value },
   NULL,
};

   /* replace515_0 -> search2_0 in the cache */
static const nir_search_expression replace515 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_search_op_f2i,
   { &search2_0.value },
   NULL,
};

   /* search516_0_0 -> search2_0 in the cache */
/* search516_0 -> search65 in the cache */
static const nir_search_expression search516 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_search_op_f2u,
   { &search65.value },
   NULL,
};

   /* replace516_0 -> search2_0 in the cache */
static const nir_search_expression replace516 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_search_op_f2u,
   { &search2_0.value },
   NULL,
};

   /* search517_0_0 -> search2_0 in the cache */
/* search517_0 -> search16_0 in the cache */
/* search517 -> search23 in the cache */

   /* replace517_0 -> search2_0 in the cache */
/* replace517 -> replace23 in the cache */

   /* search518_0_0 -> search2_0 in the cache */
/* search518_0 -> search20_0 in the cache */
static const nir_search_expression search518 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_search_op_i2b,
   { &search20_0.value },
   NULL,
};

   /* replace518_0 -> search2_0 in the cache */
/* replace518 -> replace23 in the cache */

   /* search519_0_0 -> search2_0 in the cache */
static const nir_search_expression search519_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_f2b1,
   { &search2_0.value },
   NULL,
};
static const nir_search_expression search519 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_inot,
   { &search519_0.value },
   NULL,
};

   /* replace519_0 -> search2_0 in the cache */

/* replace519_1 -> search24_1 in the cache */
/* replace519 -> replace209 in the cache */

   /* search520_0_0 -> search0_0 in the cache */
static const nir_search_expression search520_0 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_search_op_i2f,
   { &search0_0.value },
   NULL,
};
static const nir_search_expression search520 = {
   { nir_search_value_expression, 32 },
   true,
   -1, 0,
   nir_op_f2i32,
   { &search520_0.value },
   NULL,
};

   /* replace520 -> search0_0 in the cache */

   /* search521_0_0 -> search0_0 in the cache */
static const nir_search_expression search521_0 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_search_op_u2f,
   { &search0_0.value },
   NULL,
};
static const nir_search_expression search521 = {
   { nir_search_value_expression, 32 },
   true,
   -1, 0,
   nir_op_f2i32,
   { &search521_0.value },
   NULL,
};

   /* replace521 -> search0_0 in the cache */

   /* search522_0_0 -> search0_0 in the cache */
/* search522_0 -> search520_0 in the cache */
static const nir_search_expression search522 = {
   { nir_search_value_expression, 32 },
   true,
   -1, 0,
   nir_op_f2u32,
   { &search520_0.value },
   NULL,
};

   /* replace522 -> search0_0 in the cache */

   /* search523_0_0 -> search0_0 in the cache */
/* search523_0 -> search521_0 in the cache */
static const nir_search_expression search523 = {
   { nir_search_value_expression, 32 },
   true,
   -1, 0,
   nir_op_f2u32,
   { &search521_0.value },
   NULL,
};

   /* replace523 -> search0_0 in the cache */

   static const nir_search_variable search524_0 = {
   { nir_search_value_variable, -1 },
   0, /* a */
   false,
   nir_type_invalid,
   (is_integral),
   {0, 1, 2, 3},
};
static const nir_search_expression search524 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_ffloor,
   { &search524_0.value },
   NULL,
};

   /* replace524 -> search2_0 in the cache */

   /* search525_0 -> search524_0 in the cache */
static const nir_search_expression search525 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fceil,
   { &search524_0.value },
   NULL,
};

   /* replace525 -> search2_0 in the cache */

   /* search526_0 -> search524_0 in the cache */
static const nir_search_expression search526 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_ftrunc,
   { &search524_0.value },
   NULL,
};

   /* replace526 -> search2_0 in the cache */

   /* search527_0 -> search524_0 in the cache */
static const nir_search_expression search527 = {
   { nir_search_value_expression, -1 },
   true,
   -1, 0,
   nir_op_ffract,
   { &search524_0.value },
   NULL,
};

   /* replace527 -> search24_1 in the cache */

   static const nir_search_variable search528_0 = {
   { nir_search_value_variable, -1 },
   0, /* a */
   false,
   nir_type_invalid,
   (is_not_negative),
   {0, 1, 2, 3},
};
static const nir_search_expression search528 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fabs,
   { &search528_0.value },
   NULL,
};

   /* replace528 -> search2_0 in the cache */

   /* search529_0 -> search528_0 in the cache */
static const nir_search_expression search529 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_iabs,
   { &search528_0.value },
   NULL,
};

   /* replace529 -> search2_0 in the cache */

   static const nir_search_variable search530_0 = {
   { nir_search_value_variable, -1 },
   0, /* a */
   false,
   nir_type_invalid,
   (is_not_positive),
   {0, 1, 2, 3},
};
static const nir_search_expression search530 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fsat,
   { &search530_0.value },
   NULL,
};

   /* replace530 -> search24_1 in the cache */

   /* search531_0_0 -> search2_0 in the cache */
static const nir_search_expression search531_0 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_search_op_f2u,
   { &search2_0.value },
   NULL,
};

/* search531_1 -> replace14_1_0 in the cache */
static const nir_search_expression search531 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search531_0.value, &replace14_1_0.value },
   NULL,
};

   /* replace531_0_0 -> search2_0 in the cache */
static const nir_search_expression replace531_0 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_search_op_f2i,
   { &search2_0.value },
   NULL,
};

/* replace531_1 -> replace14_1_0 in the cache */
static const nir_search_expression replace531 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &replace531_0.value, &replace14_1_0.value },
   NULL,
};

   static const nir_search_variable search532_0 = {
   { nir_search_value_variable, -1 },
   0, /* b */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

/* search532_1_0 -> search137_1_0 in the cache */
static const nir_search_expression search532_1 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_search_op_f2u,
   { &search137_1_0.value },
   NULL,
};
static const nir_search_expression search532 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search532_0.value, &search532_1.value },
   NULL,
};

   /* replace532_0 -> search532_0 in the cache */

/* replace532_1_0 -> search137_1_0 in the cache */
static const nir_search_expression replace532_1 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_search_op_f2i,
   { &search137_1_0.value },
   NULL,
};
static const nir_search_expression replace532 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search532_0.value, &replace532_1.value },
   NULL,
};

   /* search533_0_0 -> search2_0 in the cache */
/* search533_0 -> search531_0 in the cache */

/* search533_1 -> replace14_1_0 in the cache */
static const nir_search_expression search533 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search531_0.value, &replace14_1_0.value },
   NULL,
};

   /* replace533_0_0 -> search2_0 in the cache */
/* replace533_0 -> replace531_0 in the cache */

/* replace533_1 -> replace14_1_0 in the cache */
static const nir_search_expression replace533 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &replace531_0.value, &replace14_1_0.value },
   NULL,
};

   /* search534_0 -> search532_0 in the cache */

/* search534_1_0 -> search137_1_0 in the cache */
/* search534_1 -> search532_1 in the cache */
static const nir_search_expression search534 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search532_0.value, &search532_1.value },
   NULL,
};

   /* replace534_0 -> search532_0 in the cache */

/* replace534_1_0 -> search137_1_0 in the cache */
/* replace534_1 -> replace532_1 in the cache */
static const nir_search_expression replace534 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search532_0.value, &replace532_1.value },
   NULL,
};

   /* search535_0 -> search528_0 in the cache */

/* search535_1 -> search41_1 in the cache */
static const nir_search_expression search535 = {
   { nir_search_value_expression, -1 },
   true,
   -1, 0,
   nir_op_fmin,
   { &search528_0.value, &search41_1.value },
   NULL,
};

   /* replace535_0 -> search2_0 in the cache */
/* replace535 -> search36_0 in the cache */

   /* search536_0_0_0_0 -> search2_0 in the cache */
/* search536_0_0_0 -> search36_0 in the cache */

/* search536_0_0_1_0_0 -> search2_0 in the cache */
/* search536_0_0_1_0 -> search36_0 in the cache */
static const nir_search_expression search536_0_0_1 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fneg,
   { &search36_0.value },
   NULL,
};
static const nir_search_expression search536_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   1, 1,
   nir_op_fmul,
   { &search36_0.value, &search536_0_0_1.value },
   NULL,
};

/* search536_0_1 -> search41_1 in the cache */
static const nir_search_expression search536_0 = {
   { nir_search_value_expression, -1 },
   false,
   0, 2,
   nir_op_fadd,
   { &search536_0_0.value, &search41_1.value },
   NULL,
};

/* search536_1 -> search24_1 in the cache */
static const nir_search_expression search536 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 2,
   nir_op_flt,
   { &search536_0.value, &search24_1.value },
   NULL,
};

   /* replace536 -> replace121 in the cache */

   /* search537_0_0_0_0_0 -> search2_0 in the cache */
/* search537_0_0_0_0 -> search36_0 in the cache */

/* search537_0_0_0_1_0 -> search2_0 in the cache */
/* search537_0_0_0_1 -> search36_0 in the cache */
static const nir_search_expression search537_0_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fmul,
   { &search36_0.value, &search36_0.value },
   NULL,
};
static const nir_search_expression search537_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fneg,
   { &search537_0_0_0.value },
   NULL,
};

/* search537_0_1 -> search41_1 in the cache */
static const nir_search_expression search537_0 = {
   { nir_search_value_expression, -1 },
   false,
   0, 1,
   nir_op_fadd,
   { &search537_0_0.value, &search41_1.value },
   NULL,
};

/* search537_1 -> search24_1 in the cache */
static const nir_search_expression search537 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_flt,
   { &search537_0.value, &search24_1.value },
   NULL,
};

   /* replace537 -> replace121 in the cache */

   /* search538_0_0_0_0 -> search2_0 in the cache */
/* search538_0_0_0 -> search36_0 in the cache */

/* search538_0_0_1_0_0 -> search2_0 in the cache */
/* search538_0_0_1_0 -> search36_0 in the cache */
/* search538_0_0_1 -> search536_0_0_1 in the cache */
/* search538_0_0 -> search536_0_0 in the cache */

/* search538_0_1 -> search41_1 in the cache */
/* search538_0 -> search536_0 in the cache */

/* search538_1 -> search24_1 in the cache */
static const nir_search_expression search538 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 2,
   nir_op_fmax,
   { &search536_0.value, &search24_1.value },
   NULL,
};

   /* replace538_0_0_0 -> search2_0 in the cache */
/* replace538_0_0 -> search36_0 in the cache */

/* replace538_0_1_0_0 -> search2_0 in the cache */
/* replace538_0_1_0 -> search36_0 in the cache */
/* replace538_0_1 -> search536_0_0_1 in the cache */
/* replace538_0 -> search536_0_0 in the cache */

/* replace538_1 -> search41_1 in the cache */
/* replace538 -> search536_0 in the cache */

   /* search539_0_0_0_0_0 -> search2_0 in the cache */
/* search539_0_0_0_0 -> search36_0 in the cache */

/* search539_0_0_0_1_0 -> search2_0 in the cache */
/* search539_0_0_0_1 -> search36_0 in the cache */
/* search539_0_0_0 -> search537_0_0_0 in the cache */
/* search539_0_0 -> search537_0_0 in the cache */

/* search539_0_1 -> search41_1 in the cache */
/* search539_0 -> search537_0 in the cache */

/* search539_1 -> search24_1 in the cache */
static const nir_search_expression search539 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 1,
   nir_op_fmax,
   { &search537_0.value, &search24_1.value },
   NULL,
};

   /* replace539_0_0_0_0 -> search2_0 in the cache */
/* replace539_0_0_0 -> search36_0 in the cache */

/* replace539_0_0_1_0 -> search2_0 in the cache */
/* replace539_0_0_1 -> search36_0 in the cache */
/* replace539_0_0 -> search537_0_0_0 in the cache */
/* replace539_0 -> search537_0_0 in the cache */

/* replace539_1 -> search41_1 in the cache */
/* replace539 -> search537_0 in the cache */

   static const nir_search_variable search540_0 = {
   { nir_search_value_variable, -1 },
   0, /* a */
   false,
   nir_type_invalid,
   (is_not_zero),
   {0, 1, 2, 3},
};

/* search540_1 -> search24_1 in the cache */
static const nir_search_expression search540 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_fne,
   { &search540_0.value, &search24_1.value },
   NULL,
};

   /* replace540 -> replace197 in the cache */

   /* search541_0 -> search540_0 in the cache */

/* search541_1 -> search24_1 in the cache */
static const nir_search_expression search541 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_feq,
   { &search540_0.value, &search24_1.value },
   NULL,
};

   /* replace541 -> replace121 in the cache */

   static const nir_search_variable search542_0 = {
   { nir_search_value_variable, -2 },
   0, /* a */
   false,
   nir_type_invalid,
   (is_not_negative),
   {0, 1, 2, 3},
};

static const nir_search_variable search542_1 = {
   { nir_search_value_variable, -2 },
   1, /* b */
   false,
   nir_type_invalid,
   (is_not_positive),
   {0, 1, 2, 3},
};
static const nir_search_expression search542 = {
   { nir_search_value_expression, 1 },
   true,
   -1, 0,
   nir_op_fge,
   { &search542_0.value, &search542_1.value },
   NULL,
};

   /* replace542 -> replace197 in the cache */

   static const nir_search_variable search543_0 = {
   { nir_search_value_variable, -2 },
   0, /* b */
   false,
   nir_type_invalid,
   (is_not_positive),
   {0, 1, 2, 3},
};

static const nir_search_variable search543_1 = {
   { nir_search_value_variable, -2 },
   1, /* a */
   false,
   nir_type_invalid,
   (is_gt_zero),
   {0, 1, 2, 3},
};
static const nir_search_expression search543 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search543_0.value, &search543_1.value },
   NULL,
};

   /* replace543 -> replace121 in the cache */

   static const nir_search_variable search544_0 = {
   { nir_search_value_variable, -2 },
   0, /* a */
   false,
   nir_type_invalid,
   (is_lt_zero),
   {0, 1, 2, 3},
};

static const nir_search_variable search544_1 = {
   { nir_search_value_variable, -2 },
   1, /* b */
   false,
   nir_type_invalid,
   (is_not_negative),
   {0, 1, 2, 3},
};
static const nir_search_expression search544 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search544_0.value, &search544_1.value },
   NULL,
};

   /* replace544 -> replace121 in the cache */

   static const nir_search_variable search545_0 = {
   { nir_search_value_variable, -2 },
   0, /* b */
   false,
   nir_type_invalid,
   (is_not_negative),
   {0, 1, 2, 3},
};

static const nir_search_variable search545_1 = {
   { nir_search_value_variable, -2 },
   1, /* a */
   false,
   nir_type_invalid,
   (is_not_positive),
   {0, 1, 2, 3},
};
static const nir_search_expression search545 = {
   { nir_search_value_expression, 1 },
   true,
   -1, 0,
   nir_op_fge,
   { &search545_0.value, &search545_1.value },
   NULL,
};

   /* replace545 -> replace197 in the cache */

   /* search546_0 -> search542_0 in the cache */

/* search546_1 -> search542_1 in the cache */
static const nir_search_expression search546 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search542_0.value, &search542_1.value },
   NULL,
};

   /* replace546 -> replace121 in the cache */

   /* search547_0 -> search543_0 in the cache */

/* search547_1 -> search543_1 in the cache */
static const nir_search_expression search547 = {
   { nir_search_value_expression, 1 },
   true,
   -1, 0,
   nir_op_flt,
   { &search543_0.value, &search543_1.value },
   NULL,
};

   /* replace547 -> replace197 in the cache */

   /* search548_0 -> search544_0 in the cache */

/* search548_1 -> search544_1 in the cache */
static const nir_search_expression search548 = {
   { nir_search_value_expression, 1 },
   true,
   -1, 0,
   nir_op_flt,
   { &search544_0.value, &search544_1.value },
   NULL,
};

   /* replace548 -> replace197 in the cache */

   /* search549_0 -> search545_0 in the cache */

/* search549_1 -> search545_1 in the cache */
static const nir_search_expression search549 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search545_0.value, &search545_1.value },
   NULL,
};

   /* replace549 -> replace121 in the cache */

   /* search550_0 -> search540_0 in the cache */

/* search550_1 -> replace9 in the cache */
static const nir_search_expression search550 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &search540_0.value, &replace9.value },
   NULL,
};

   /* replace550 -> replace197 in the cache */

   /* search551_0 -> search540_0 in the cache */

/* search551_1 -> replace9 in the cache */
static const nir_search_expression search551 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &search540_0.value, &replace9.value },
   NULL,
};

   /* replace551 -> replace121 in the cache */

   /* search552_0 -> search542_0 in the cache */

/* search552_1 -> search542_1 in the cache */
static const nir_search_expression search552 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search542_0.value, &search542_1.value },
   NULL,
};

   /* replace552 -> replace197 in the cache */

   /* search553_0 -> search543_0 in the cache */

/* search553_1 -> search543_1 in the cache */
static const nir_search_expression search553 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search543_0.value, &search543_1.value },
   NULL,
};

   /* replace553 -> replace121 in the cache */

   /* search554_0 -> search544_0 in the cache */

/* search554_1 -> search544_1 in the cache */
static const nir_search_expression search554 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search544_0.value, &search544_1.value },
   NULL,
};

   /* replace554 -> replace121 in the cache */

   /* search555_0 -> search545_0 in the cache */

/* search555_1 -> search545_1 in the cache */
static const nir_search_expression search555 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search545_0.value, &search545_1.value },
   NULL,
};

   /* replace555 -> replace197 in the cache */

   /* search556_0 -> search542_0 in the cache */

/* search556_1 -> search542_1 in the cache */
static const nir_search_expression search556 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search542_0.value, &search542_1.value },
   NULL,
};

   /* replace556 -> replace121 in the cache */

   /* search557_0 -> search543_0 in the cache */

/* search557_1 -> search543_1 in the cache */
static const nir_search_expression search557 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search543_0.value, &search543_1.value },
   NULL,
};

   /* replace557 -> replace197 in the cache */

   /* search558_0 -> search544_0 in the cache */

/* search558_1 -> search544_1 in the cache */
static const nir_search_expression search558 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search544_0.value, &search544_1.value },
   NULL,
};

   /* replace558 -> replace197 in the cache */

   /* search559_0 -> search545_0 in the cache */

/* search559_1 -> search545_1 in the cache */
static const nir_search_expression search559 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search545_0.value, &search545_1.value },
   NULL,
};

   /* replace559 -> replace121 in the cache */

   /* search560_0 -> replace9 in the cache */

static const nir_search_variable search560_1 = {
   { nir_search_value_variable, -1 },
   0, /* a */
   false,
   nir_type_invalid,
   (is_gt_zero),
   {0, 1, 2, 3},
};
static const nir_search_expression search560 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &replace9.value, &search560_1.value },
   NULL,
};

   /* replace560 -> replace197 in the cache */

   /* search561_0_0 -> search0_0 in the cache */

/* search561_0_1 -> replace0_1_0 in the cache */
static const nir_search_expression search561_0 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_pack_64_2x32_split,
   { &search0_0.value, &replace0_1_0.value },
   NULL,
};
static const nir_search_expression search561 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_unpack_64_2x32_split_x,
   { &search561_0.value },
   NULL,
};

   /* replace561 -> search0_0 in the cache */

   /* search562_0_0 -> search0_0 in the cache */

/* search562_0_1 -> replace0_1_0 in the cache */
/* search562_0 -> search561_0 in the cache */
static const nir_search_expression search562 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_unpack_64_2x32_split_y,
   { &search561_0.value },
   NULL,
};

   /* replace562 -> replace0_1_0 in the cache */

   /* search563_0_0 -> search57_0 in the cache */
static const nir_search_expression search563_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_unpack_64_2x32_split_x,
   { &search57_0.value },
   NULL,
};

/* search563_1_0 -> search57_0 in the cache */
static const nir_search_expression search563_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_unpack_64_2x32_split_y,
   { &search57_0.value },
   NULL,
};
static const nir_search_expression search563 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_pack_64_2x32_split,
   { &search563_0.value, &search563_1.value },
   NULL,
};

   /* replace563 -> search57_0 in the cache */

   /* search564_0_0_0 -> search0_0 in the cache */
static const nir_search_expression search564_0_0 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_unpack_32_2x16_split_x,
   { &search0_0.value },
   NULL,
};

static const nir_search_variable search564_0_1 = {
   { nir_search_value_variable, 16 },
   1, /* b */
   true,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search564_0 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ieq,
   { &search564_0_0.value, &search564_0_1.value },
   NULL,
};

/* search564_1_0_0 -> search0_0 in the cache */
static const nir_search_expression search564_1_0 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_unpack_32_2x16_split_y,
   { &search0_0.value },
   NULL,
};

static const nir_search_variable search564_1_1 = {
   { nir_search_value_variable, 16 },
   2, /* c */
   true,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search564_1 = {
   { nir_search_value_expression, 1 },
   false,
   2, 1,
   nir_op_ieq,
   { &search564_1_0.value, &search564_1_1.value },
   NULL,
};
static const nir_search_expression search564 = {
   { nir_search_value_expression, 1 },
   false,
   0, 3,
   nir_op_iand,
   { &search564_0.value, &search564_1.value },
   NULL,
};

   /* replace564_0 -> search0_0 in the cache */

static const nir_search_variable replace564_1_0 = {
   { nir_search_value_variable, 16 },
   1, /* b */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

static const nir_search_variable replace564_1_1 = {
   { nir_search_value_variable, 16 },
   2, /* c */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression replace564_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_pack_32_2x16_split,
   { &replace564_1_0.value, &replace564_1_1.value },
   NULL,
};
static const nir_search_expression replace564 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &search0_0.value, &replace564_1.value },
   NULL,
};

   /* search565_0 -> search101_0_0 in the cache */

/* search565_1 -> replace98_0_1 in the cache */
static const nir_search_expression search565 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_ushr,
   { &search101_0_0.value, &replace98_0_1.value },
   NULL,
};

   /* replace565_0 -> search101_0_0 in the cache */

static const nir_search_constant replace565_1 = {
   { nir_search_value_constant, 16 },
   nir_type_int, { 0x1 /* 1 */ },
};
static const nir_search_expression replace565 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_extract_u8,
   { &search101_0_0.value, &replace565_1.value },
   NULL,
};

   /* search566_0 -> search0_0 in the cache */

/* search566_1 -> search441_1_1 in the cache */
/* search566 -> search441_1 in the cache */

   /* replace566_0 -> search0_0 in the cache */

static const nir_search_constant replace566_1 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { 0x3 /* 3 */ },
};
static const nir_search_expression replace566 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_extract_u8,
   { &search0_0.value, &replace566_1.value },
   NULL,
};

   /* search567_0 -> search57_0 in the cache */

static const nir_search_constant search567_1 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { 0x38 /* 56 */ },
};
static const nir_search_expression search567 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_ushr,
   { &search57_0.value, &search567_1.value },
   NULL,
};

   /* replace567_0 -> search57_0 in the cache */

static const nir_search_constant replace567_1 = {
   { nir_search_value_constant, 64 },
   nir_type_int, { 0x7 /* 7 */ },
};
static const nir_search_expression replace567 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_extract_u8,
   { &search57_0.value, &replace567_1.value },
   NULL,
};

   /* search568_0 -> search101_0_0 in the cache */

/* search568_1 -> replace98_0_1 in the cache */
static const nir_search_expression search568 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_ishr,
   { &search101_0_0.value, &replace98_0_1.value },
   NULL,
};

   /* replace568_0 -> search101_0_0 in the cache */

/* replace568_1 -> replace565_1 in the cache */
static const nir_search_expression replace568 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_extract_i8,
   { &search101_0_0.value, &replace565_1.value },
   NULL,
};

   /* search569_0 -> search0_0 in the cache */

/* search569_1 -> search441_1_1 in the cache */
static const nir_search_expression search569 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_ishr,
   { &search0_0.value, &search441_1_1.value },
   NULL,
};

   /* replace569_0 -> search0_0 in the cache */

/* replace569_1 -> replace566_1 in the cache */
static const nir_search_expression replace569 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_extract_i8,
   { &search0_0.value, &replace566_1.value },
   NULL,
};

   /* search570_0 -> search57_0 in the cache */

/* search570_1 -> search567_1 in the cache */
static const nir_search_expression search570 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_ishr,
   { &search57_0.value, &search567_1.value },
   NULL,
};

   /* replace570_0 -> search57_0 in the cache */

/* replace570_1 -> replace567_1 in the cache */
static const nir_search_expression replace570 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_extract_i8,
   { &search57_0.value, &replace567_1.value },
   NULL,
};

   /* search571_0 -> search279_0_1 in the cache */

/* search571_1 -> search2_0 in the cache */
static const nir_search_expression search571 = {
   { nir_search_value_expression, -1 },
   false,
   0, 1,
   nir_op_iand,
   { &search279_0_1.value, &search2_0.value },
   NULL,
};

   /* replace571_0 -> search2_0 in the cache */

/* replace571_1 -> replace9 in the cache */
static const nir_search_expression replace571 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_extract_u8,
   { &search2_0.value, &replace9.value },
   NULL,
};

   /* search572_0_0 -> search0_0 in the cache */

/* search572_0_1 -> replace101_0_0_0_1 in the cache */
static const nir_search_expression search572_0 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_iand,
   { &search0_0.value, &replace101_0_0_0_1.value },
   NULL,
};
static const nir_search_expression search572 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_op_unpack_half_2x16_split_x,
   { &search572_0.value },
   NULL,
};

   /* replace572_0 -> search0_0 in the cache */
static const nir_search_expression replace572 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_unpack_half_2x16_split_x,
   { &search0_0.value },
   NULL,
};

   /* search573_0_0 -> search0_0 in the cache */

/* search573_0_1 -> replace101_0_0_0_1 in the cache */
/* search573_0 -> search572_0 in the cache */
static const nir_search_expression search573 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 1,
   nir_op_unpack_32_2x16_split_x,
   { &search572_0.value },
   NULL,
};

   /* replace573_0 -> search0_0 in the cache */
/* replace573 -> search564_0_0 in the cache */

   /* search574_0_0 -> search57_0 in the cache */

static const nir_search_constant search574_0_1 = {
   { nir_search_value_constant, 64 },
   nir_type_int, { 0xffffffff /* 4294967295 */ },
};
static const nir_search_expression search574_0 = {
   { nir_search_value_expression, 64 },
   false,
   0, 1,
   nir_op_iand,
   { &search57_0.value, &search574_0_1.value },
   NULL,
};
static const nir_search_expression search574 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_op_unpack_64_2x32_split_x,
   { &search574_0.value },
   NULL,
};

   /* replace574_0 -> search57_0 in the cache */
/* replace574 -> search563_0 in the cache */

   /* search575_0_0 -> search0_0 in the cache */

static const nir_search_constant search575_0_1 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { 0xffff0000 /* 4294901760 */ },
};
static const nir_search_expression search575_0 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_iand,
   { &search0_0.value, &search575_0_1.value },
   NULL,
};
static const nir_search_expression search575 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_op_unpack_half_2x16_split_y,
   { &search575_0.value },
   NULL,
};

   /* replace575_0 -> search0_0 in the cache */
static const nir_search_expression replace575 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_unpack_half_2x16_split_y,
   { &search0_0.value },
   NULL,
};

   /* search576_0_0 -> search0_0 in the cache */

/* search576_0_1 -> search575_0_1 in the cache */
/* search576_0 -> search575_0 in the cache */
static const nir_search_expression search576 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 1,
   nir_op_unpack_32_2x16_split_y,
   { &search575_0.value },
   NULL,
};

   /* replace576_0 -> search0_0 in the cache */
/* replace576 -> search564_1_0 in the cache */

   /* search577_0_0 -> search57_0 in the cache */

static const nir_search_constant search577_0_1 = {
   { nir_search_value_constant, 64 },
   nir_type_int, { 0xffffffff00000000 /* 18446744069414584320 */ },
};
static const nir_search_expression search577_0 = {
   { nir_search_value_expression, 64 },
   false,
   0, 1,
   nir_op_iand,
   { &search57_0.value, &search577_0_1.value },
   NULL,
};
static const nir_search_expression search577 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_op_unpack_64_2x32_split_y,
   { &search577_0.value },
   NULL,
};

   /* replace577_0 -> search57_0 in the cache */
/* replace577 -> search563_1 in the cache */

   /* search578_0_0 -> search101_0_0 in the cache */

/* search578_0_1 -> replace98_0_1 in the cache */
/* search578_0 -> search565 in the cache */

/* search578_1 -> replace101_2 in the cache */
static const nir_search_expression search578 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_extract_u8,
   { &search565.value, &replace101_2.value },
   NULL,
};

   /* replace578_0 -> search101_0_0 in the cache */

/* replace578_1 -> replace565_1 in the cache */
/* replace578 -> replace565 in the cache */

   /* search579_0_0 -> search0_0 in the cache */

/* search579_0_1 -> replace98_0_1 in the cache */
static const nir_search_expression search579_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_ushr,
   { &search0_0.value, &replace98_0_1.value },
   NULL,
};

/* search579_1 -> search26_1 in the cache */
static const nir_search_expression search579 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_extract_u8,
   { &search579_0.value, &search26_1.value },
   NULL,
};

   /* replace579_0 -> search0_0 in the cache */

static const nir_search_constant replace579_1 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { 0x1 /* 1 */ },
};
static const nir_search_expression replace579 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_extract_u8,
   { &search0_0.value, &replace579_1.value },
   NULL,
};

   /* search580_0_0 -> search0_0 in the cache */

/* search580_0_1 -> replace101_0_1 in the cache */
/* search580_0 -> search442_1 in the cache */

/* search580_1 -> search26_1 in the cache */
static const nir_search_expression search580 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_extract_u8,
   { &search442_1.value, &search26_1.value },
   NULL,
};

   /* replace580_0 -> search0_0 in the cache */

static const nir_search_constant replace580_1 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { 0x2 /* 2 */ },
};
static const nir_search_expression replace580 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_extract_u8,
   { &search0_0.value, &replace580_1.value },
   NULL,
};

   /* search581_0_0 -> search0_0 in the cache */

/* search581_0_1 -> search441_1_1 in the cache */
/* search581_0 -> search441_1 in the cache */

/* search581_1 -> search26_1 in the cache */
static const nir_search_expression search581 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_extract_u8,
   { &search441_1.value, &search26_1.value },
   NULL,
};

   /* replace581_0 -> search0_0 in the cache */

/* replace581_1 -> replace566_1 in the cache */
/* replace581 -> replace566 in the cache */

   /* search582_0_0 -> search57_0 in the cache */

/* search582_0_1 -> replace98_0_1 in the cache */
static const nir_search_expression search582_0 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_ushr,
   { &search57_0.value, &replace98_0_1.value },
   NULL,
};

/* search582_1 -> replace107_2 in the cache */
static const nir_search_expression search582 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_extract_u8,
   { &search582_0.value, &replace107_2.value },
   NULL,
};

   /* replace582_0 -> search57_0 in the cache */

static const nir_search_constant replace582_1 = {
   { nir_search_value_constant, 64 },
   nir_type_int, { 0x1 /* 1 */ },
};
static const nir_search_expression replace582 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_extract_u8,
   { &search57_0.value, &replace582_1.value },
   NULL,
};

   /* search583_0_0 -> search57_0 in the cache */

/* search583_0_1 -> replace101_0_1 in the cache */
static const nir_search_expression search583_0 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_ushr,
   { &search57_0.value, &replace101_0_1.value },
   NULL,
};

/* search583_1 -> replace107_2 in the cache */
static const nir_search_expression search583 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_extract_u8,
   { &search583_0.value, &replace107_2.value },
   NULL,
};

   /* replace583_0 -> search57_0 in the cache */

static const nir_search_constant replace583_1 = {
   { nir_search_value_constant, 64 },
   nir_type_int, { 0x2 /* 2 */ },
};
static const nir_search_expression replace583 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_extract_u8,
   { &search57_0.value, &replace583_1.value },
   NULL,
};

   /* search584_0_0 -> search57_0 in the cache */

/* search584_0_1 -> search441_1_1 in the cache */
static const nir_search_expression search584_0 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_ushr,
   { &search57_0.value, &search441_1_1.value },
   NULL,
};

/* search584_1 -> replace107_2 in the cache */
static const nir_search_expression search584 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_extract_u8,
   { &search584_0.value, &replace107_2.value },
   NULL,
};

   /* replace584_0 -> search57_0 in the cache */

static const nir_search_constant replace584_1 = {
   { nir_search_value_constant, 64 },
   nir_type_int, { 0x3 /* 3 */ },
};
static const nir_search_expression replace584 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_extract_u8,
   { &search57_0.value, &replace584_1.value },
   NULL,
};

   /* search585_0_0 -> search57_0 in the cache */

/* search585_0_1 -> replace104_0_1 in the cache */
static const nir_search_expression search585_0 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_ushr,
   { &search57_0.value, &replace104_0_1.value },
   NULL,
};

/* search585_1 -> replace107_2 in the cache */
static const nir_search_expression search585 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_extract_u8,
   { &search585_0.value, &replace107_2.value },
   NULL,
};

   /* replace585_0 -> search57_0 in the cache */

static const nir_search_constant replace585_1 = {
   { nir_search_value_constant, 64 },
   nir_type_int, { 0x4 /* 4 */ },
};
static const nir_search_expression replace585 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_extract_u8,
   { &search57_0.value, &replace585_1.value },
   NULL,
};

   /* search586_0_0 -> search57_0 in the cache */

static const nir_search_constant search586_0_1 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { 0x28 /* 40 */ },
};
static const nir_search_expression search586_0 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_ushr,
   { &search57_0.value, &search586_0_1.value },
   NULL,
};

/* search586_1 -> replace107_2 in the cache */
static const nir_search_expression search586 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_extract_u8,
   { &search586_0.value, &replace107_2.value },
   NULL,
};

   /* replace586_0 -> search57_0 in the cache */

static const nir_search_constant replace586_1 = {
   { nir_search_value_constant, 64 },
   nir_type_int, { 0x5 /* 5 */ },
};
static const nir_search_expression replace586 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_extract_u8,
   { &search57_0.value, &replace586_1.value },
   NULL,
};

   /* search587_0_0 -> search57_0 in the cache */

static const nir_search_constant search587_0_1 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { 0x30 /* 48 */ },
};
static const nir_search_expression search587_0 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_ushr,
   { &search57_0.value, &search587_0_1.value },
   NULL,
};

/* search587_1 -> replace107_2 in the cache */
static const nir_search_expression search587 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_extract_u8,
   { &search587_0.value, &replace107_2.value },
   NULL,
};

   /* replace587_0 -> search57_0 in the cache */

static const nir_search_constant replace587_1 = {
   { nir_search_value_constant, 64 },
   nir_type_int, { 0x6 /* 6 */ },
};
static const nir_search_expression replace587 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_extract_u8,
   { &search57_0.value, &replace587_1.value },
   NULL,
};

   /* search588_0_0 -> search57_0 in the cache */

/* search588_0_1 -> search567_1 in the cache */
/* search588_0 -> search567 in the cache */

/* search588_1 -> replace107_2 in the cache */
static const nir_search_expression search588 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_extract_u8,
   { &search567.value, &replace107_2.value },
   NULL,
};

   /* replace588_0 -> search57_0 in the cache */

/* replace588_1 -> replace567_1 in the cache */
/* replace588 -> replace567 in the cache */

   /* search589_0_0 -> search101_0_0 in the cache */

/* search589_0_1 -> replace98_0_1 in the cache */
/* search589_0 -> search568 in the cache */

/* search589_1 -> replace101_2 in the cache */
static const nir_search_expression search589 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_extract_u8,
   { &search568.value, &replace101_2.value },
   NULL,
};

   /* replace589_0 -> search101_0_0 in the cache */

/* replace589_1 -> replace565_1 in the cache */
/* replace589 -> replace565 in the cache */

   /* search590_0_0 -> search0_0 in the cache */

/* search590_0_1 -> replace98_0_1 in the cache */
static const nir_search_expression search590_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_ishr,
   { &search0_0.value, &replace98_0_1.value },
   NULL,
};

/* search590_1 -> search26_1 in the cache */
static const nir_search_expression search590 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_extract_u8,
   { &search590_0.value, &search26_1.value },
   NULL,
};

   /* replace590_0 -> search0_0 in the cache */

/* replace590_1 -> replace579_1 in the cache */
/* replace590 -> replace579 in the cache */

   /* search591_0_0 -> search0_0 in the cache */

/* search591_0_1 -> replace101_0_1 in the cache */
static const nir_search_expression search591_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_ishr,
   { &search0_0.value, &replace101_0_1.value },
   NULL,
};

/* search591_1 -> search26_1 in the cache */
static const nir_search_expression search591 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_extract_u8,
   { &search591_0.value, &search26_1.value },
   NULL,
};

   /* replace591_0 -> search0_0 in the cache */

/* replace591_1 -> replace580_1 in the cache */
/* replace591 -> replace580 in the cache */

   /* search592_0_0 -> search0_0 in the cache */

/* search592_0_1 -> search441_1_1 in the cache */
/* search592_0 -> search569 in the cache */

/* search592_1 -> search26_1 in the cache */
static const nir_search_expression search592 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_extract_u8,
   { &search569.value, &search26_1.value },
   NULL,
};

   /* replace592_0 -> search0_0 in the cache */

/* replace592_1 -> replace566_1 in the cache */
/* replace592 -> replace566 in the cache */

   /* search593_0_0 -> search57_0 in the cache */

/* search593_0_1 -> replace98_0_1 in the cache */
static const nir_search_expression search593_0 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_ishr,
   { &search57_0.value, &replace98_0_1.value },
   NULL,
};

/* search593_1 -> replace107_2 in the cache */
static const nir_search_expression search593 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_extract_u8,
   { &search593_0.value, &replace107_2.value },
   NULL,
};

   /* replace593_0 -> search57_0 in the cache */

/* replace593_1 -> replace582_1 in the cache */
/* replace593 -> replace582 in the cache */

   /* search594_0_0 -> search57_0 in the cache */

/* search594_0_1 -> replace101_0_1 in the cache */
static const nir_search_expression search594_0 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_ishr,
   { &search57_0.value, &replace101_0_1.value },
   NULL,
};

/* search594_1 -> replace107_2 in the cache */
static const nir_search_expression search594 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_extract_u8,
   { &search594_0.value, &replace107_2.value },
   NULL,
};

   /* replace594_0 -> search57_0 in the cache */

/* replace594_1 -> replace583_1 in the cache */
/* replace594 -> replace583 in the cache */

   /* search595_0_0 -> search57_0 in the cache */

/* search595_0_1 -> search441_1_1 in the cache */
static const nir_search_expression search595_0 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_ishr,
   { &search57_0.value, &search441_1_1.value },
   NULL,
};

/* search595_1 -> replace107_2 in the cache */
static const nir_search_expression search595 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_extract_u8,
   { &search595_0.value, &replace107_2.value },
   NULL,
};

   /* replace595_0 -> search57_0 in the cache */

/* replace595_1 -> replace584_1 in the cache */
/* replace595 -> replace584 in the cache */

   /* search596_0_0 -> search57_0 in the cache */

/* search596_0_1 -> replace104_0_1 in the cache */
static const nir_search_expression search596_0 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_ishr,
   { &search57_0.value, &replace104_0_1.value },
   NULL,
};

/* search596_1 -> replace107_2 in the cache */
static const nir_search_expression search596 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_extract_u8,
   { &search596_0.value, &replace107_2.value },
   NULL,
};

   /* replace596_0 -> search57_0 in the cache */

/* replace596_1 -> replace585_1 in the cache */
/* replace596 -> replace585 in the cache */

   /* search597_0_0 -> search57_0 in the cache */

/* search597_0_1 -> search586_0_1 in the cache */
static const nir_search_expression search597_0 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_ishr,
   { &search57_0.value, &search586_0_1.value },
   NULL,
};

/* search597_1 -> replace107_2 in the cache */
static const nir_search_expression search597 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_extract_u8,
   { &search597_0.value, &replace107_2.value },
   NULL,
};

   /* replace597_0 -> search57_0 in the cache */

/* replace597_1 -> replace586_1 in the cache */
/* replace597 -> replace586 in the cache */

   /* search598_0_0 -> search57_0 in the cache */

/* search598_0_1 -> search587_0_1 in the cache */
static const nir_search_expression search598_0 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_ishr,
   { &search57_0.value, &search587_0_1.value },
   NULL,
};

/* search598_1 -> replace107_2 in the cache */
static const nir_search_expression search598 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_extract_u8,
   { &search598_0.value, &replace107_2.value },
   NULL,
};

   /* replace598_0 -> search57_0 in the cache */

/* replace598_1 -> replace587_1 in the cache */
/* replace598 -> replace587 in the cache */

   /* search599_0_0 -> search57_0 in the cache */

/* search599_0_1 -> search567_1 in the cache */
/* search599_0 -> search570 in the cache */

/* search599_1 -> replace107_2 in the cache */
static const nir_search_expression search599 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_extract_u8,
   { &search570.value, &replace107_2.value },
   NULL,
};

   /* replace599_0 -> search57_0 in the cache */

/* replace599_1 -> replace567_1 in the cache */
/* replace599 -> replace567 in the cache */

   /* search600_0_0 -> search2_0 in the cache */

/* search600_0_1 -> replace2_1_0 in the cache */
static const nir_search_expression search600_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_extract_u16,
   { &search2_0.value, &replace2_1_0.value },
   NULL,
};

/* search600_1 -> replace9 in the cache */
static const nir_search_expression search600 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_extract_u8,
   { &search600_0.value, &replace9.value },
   NULL,
};

   /* replace600_0 -> search2_0 in the cache */

/* replace600_1 -> search321_1_1 in the cache */
static const nir_search_expression replace600 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_extract_u8,
   { &search2_0.value, &search321_1_1.value },
   NULL,
};

   /* search601_0_0 -> search101_0_0 in the cache */

/* search601_0_1 -> replace98_0_1 in the cache */
static const nir_search_expression search601_0 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_ishl,
   { &search101_0_0.value, &replace98_0_1.value },
   NULL,
};

/* search601_1 -> replace565_1 in the cache */
static const nir_search_expression search601 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_extract_u8,
   { &search601_0.value, &replace565_1.value },
   NULL,
};

   /* replace601_0 -> search101_0_0 in the cache */

/* replace601_1 -> replace101_2 in the cache */
static const nir_search_expression replace601 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_extract_u8,
   { &search101_0_0.value, &replace101_2.value },
   NULL,
};

   /* search602_0_0 -> search0_0 in the cache */

/* search602_0_1 -> replace98_0_1 in the cache */
static const nir_search_expression search602_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_ishl,
   { &search0_0.value, &replace98_0_1.value },
   NULL,
};

/* search602_1 -> replace566_1 in the cache */
static const nir_search_expression search602 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_extract_u8,
   { &search602_0.value, &replace566_1.value },
   NULL,
};

   /* replace602_0 -> search0_0 in the cache */

/* replace602_1 -> replace580_1 in the cache */
/* replace602 -> replace580 in the cache */

   /* search603_0_0 -> search0_0 in the cache */

/* search603_0_1 -> replace101_0_1 in the cache */
static const nir_search_expression search603_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_ishl,
   { &search0_0.value, &replace101_0_1.value },
   NULL,
};

/* search603_1 -> replace566_1 in the cache */
static const nir_search_expression search603 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_extract_u8,
   { &search603_0.value, &replace566_1.value },
   NULL,
};

   /* replace603_0 -> search0_0 in the cache */

/* replace603_1 -> replace579_1 in the cache */
/* replace603 -> replace579 in the cache */

   /* search604_0_0 -> search0_0 in the cache */

/* search604_0_1 -> search441_1_1 in the cache */
static const nir_search_expression search604_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_ishl,
   { &search0_0.value, &search441_1_1.value },
   NULL,
};

/* search604_1 -> replace566_1 in the cache */
static const nir_search_expression search604 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_extract_u8,
   { &search604_0.value, &replace566_1.value },
   NULL,
};

   /* replace604_0 -> search0_0 in the cache */

/* replace604_1 -> search26_1 in the cache */
static const nir_search_expression replace604 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_extract_u8,
   { &search0_0.value, &search26_1.value },
   NULL,
};

   /* search605_0_0 -> search57_0 in the cache */

/* search605_0_1 -> replace98_0_1 in the cache */
static const nir_search_expression search605_0 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_ishl,
   { &search57_0.value, &replace98_0_1.value },
   NULL,
};

/* search605_1 -> replace567_1 in the cache */
static const nir_search_expression search605 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_extract_u8,
   { &search605_0.value, &replace567_1.value },
   NULL,
};

   /* replace605_0 -> search57_0 in the cache */

/* replace605_1 -> replace587_1 in the cache */
/* replace605 -> replace587 in the cache */

   /* search606_0_0 -> search57_0 in the cache */

/* search606_0_1 -> replace101_0_1 in the cache */
static const nir_search_expression search606_0 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_ishl,
   { &search57_0.value, &replace101_0_1.value },
   NULL,
};

/* search606_1 -> replace567_1 in the cache */
static const nir_search_expression search606 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_extract_u8,
   { &search606_0.value, &replace567_1.value },
   NULL,
};

   /* replace606_0 -> search57_0 in the cache */

/* replace606_1 -> replace586_1 in the cache */
/* replace606 -> replace586 in the cache */

   /* search607_0_0 -> search57_0 in the cache */

/* search607_0_1 -> search441_1_1 in the cache */
static const nir_search_expression search607_0 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_ishl,
   { &search57_0.value, &search441_1_1.value },
   NULL,
};

/* search607_1 -> replace567_1 in the cache */
static const nir_search_expression search607 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_extract_u8,
   { &search607_0.value, &replace567_1.value },
   NULL,
};

   /* replace607_0 -> search57_0 in the cache */

/* replace607_1 -> replace585_1 in the cache */
/* replace607 -> replace585 in the cache */

   /* search608_0_0 -> search57_0 in the cache */

/* search608_0_1 -> replace104_0_1 in the cache */
static const nir_search_expression search608_0 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_ishl,
   { &search57_0.value, &replace104_0_1.value },
   NULL,
};

/* search608_1 -> replace567_1 in the cache */
static const nir_search_expression search608 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_extract_u8,
   { &search608_0.value, &replace567_1.value },
   NULL,
};

   /* replace608_0 -> search57_0 in the cache */

/* replace608_1 -> replace584_1 in the cache */
/* replace608 -> replace584 in the cache */

   /* search609_0_0 -> search57_0 in the cache */

/* search609_0_1 -> search586_0_1 in the cache */
static const nir_search_expression search609_0 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_ishl,
   { &search57_0.value, &search586_0_1.value },
   NULL,
};

/* search609_1 -> replace567_1 in the cache */
static const nir_search_expression search609 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_extract_u8,
   { &search609_0.value, &replace567_1.value },
   NULL,
};

   /* replace609_0 -> search57_0 in the cache */

/* replace609_1 -> replace583_1 in the cache */
/* replace609 -> replace583 in the cache */

   /* search610_0_0 -> search57_0 in the cache */

/* search610_0_1 -> search587_0_1 in the cache */
static const nir_search_expression search610_0 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_ishl,
   { &search57_0.value, &search587_0_1.value },
   NULL,
};

/* search610_1 -> replace567_1 in the cache */
static const nir_search_expression search610 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_extract_u8,
   { &search610_0.value, &replace567_1.value },
   NULL,
};

   /* replace610_0 -> search57_0 in the cache */

/* replace610_1 -> replace582_1 in the cache */
/* replace610 -> replace582 in the cache */

   /* search611_0_0 -> search57_0 in the cache */

/* search611_0_1 -> search567_1 in the cache */
static const nir_search_expression search611_0 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_ishl,
   { &search57_0.value, &search567_1.value },
   NULL,
};

/* search611_1 -> replace567_1 in the cache */
static const nir_search_expression search611 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_extract_u8,
   { &search611_0.value, &replace567_1.value },
   NULL,
};

   /* replace611_0 -> search57_0 in the cache */

/* replace611_1 -> replace107_2 in the cache */
static const nir_search_expression replace611 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_extract_u8,
   { &search57_0.value, &replace107_2.value },
   NULL,
};

   /* search612_0_0 -> search101_0_0 in the cache */

/* search612_0_1 -> replace98_0_1 in the cache */
/* search612_0 -> search601_0 in the cache */

/* search612_1 -> replace565_1 in the cache */
static const nir_search_expression search612 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_extract_i8,
   { &search601_0.value, &replace565_1.value },
   NULL,
};

   /* replace612_0 -> search101_0_0 in the cache */

/* replace612_1 -> replace101_2 in the cache */
static const nir_search_expression replace612 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_extract_i8,
   { &search101_0_0.value, &replace101_2.value },
   NULL,
};

   /* search613_0_0 -> search0_0 in the cache */

/* search613_0_1 -> replace98_0_1 in the cache */
/* search613_0 -> search602_0 in the cache */

/* search613_1 -> replace566_1 in the cache */
static const nir_search_expression search613 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_extract_i8,
   { &search602_0.value, &replace566_1.value },
   NULL,
};

   /* replace613_0 -> search0_0 in the cache */

/* replace613_1 -> replace580_1 in the cache */
static const nir_search_expression replace613 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_extract_i8,
   { &search0_0.value, &replace580_1.value },
   NULL,
};

   /* search614_0_0 -> search0_0 in the cache */

/* search614_0_1 -> replace101_0_1 in the cache */
/* search614_0 -> search603_0 in the cache */

/* search614_1 -> replace566_1 in the cache */
static const nir_search_expression search614 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_extract_i8,
   { &search603_0.value, &replace566_1.value },
   NULL,
};

   /* replace614_0 -> search0_0 in the cache */

/* replace614_1 -> replace579_1 in the cache */
static const nir_search_expression replace614 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_extract_i8,
   { &search0_0.value, &replace579_1.value },
   NULL,
};

   /* search615_0_0 -> search0_0 in the cache */

/* search615_0_1 -> search441_1_1 in the cache */
/* search615_0 -> search604_0 in the cache */

/* search615_1 -> replace566_1 in the cache */
static const nir_search_expression search615 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_extract_i8,
   { &search604_0.value, &replace566_1.value },
   NULL,
};

   /* replace615_0 -> search0_0 in the cache */

/* replace615_1 -> search26_1 in the cache */
static const nir_search_expression replace615 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_extract_i8,
   { &search0_0.value, &search26_1.value },
   NULL,
};

   /* search616_0_0 -> search57_0 in the cache */

/* search616_0_1 -> replace98_0_1 in the cache */
/* search616_0 -> search605_0 in the cache */

/* search616_1 -> replace567_1 in the cache */
static const nir_search_expression search616 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_extract_i8,
   { &search605_0.value, &replace567_1.value },
   NULL,
};

   /* replace616_0 -> search57_0 in the cache */

/* replace616_1 -> replace587_1 in the cache */
static const nir_search_expression replace616 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_extract_i8,
   { &search57_0.value, &replace587_1.value },
   NULL,
};

   /* search617_0_0 -> search57_0 in the cache */

/* search617_0_1 -> replace101_0_1 in the cache */
/* search617_0 -> search606_0 in the cache */

/* search617_1 -> replace567_1 in the cache */
static const nir_search_expression search617 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_extract_i8,
   { &search606_0.value, &replace567_1.value },
   NULL,
};

   /* replace617_0 -> search57_0 in the cache */

/* replace617_1 -> replace586_1 in the cache */
static const nir_search_expression replace617 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_extract_i8,
   { &search57_0.value, &replace586_1.value },
   NULL,
};

   /* search618_0_0 -> search57_0 in the cache */

/* search618_0_1 -> search441_1_1 in the cache */
/* search618_0 -> search607_0 in the cache */

/* search618_1 -> replace567_1 in the cache */
static const nir_search_expression search618 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_extract_i8,
   { &search607_0.value, &replace567_1.value },
   NULL,
};

   /* replace618_0 -> search57_0 in the cache */

/* replace618_1 -> replace585_1 in the cache */
static const nir_search_expression replace618 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_extract_i8,
   { &search57_0.value, &replace585_1.value },
   NULL,
};

   /* search619_0_0 -> search57_0 in the cache */

/* search619_0_1 -> replace104_0_1 in the cache */
/* search619_0 -> search608_0 in the cache */

/* search619_1 -> replace567_1 in the cache */
static const nir_search_expression search619 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_extract_i8,
   { &search608_0.value, &replace567_1.value },
   NULL,
};

   /* replace619_0 -> search57_0 in the cache */

/* replace619_1 -> replace584_1 in the cache */
static const nir_search_expression replace619 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_extract_i8,
   { &search57_0.value, &replace584_1.value },
   NULL,
};

   /* search620_0_0 -> search57_0 in the cache */

/* search620_0_1 -> search586_0_1 in the cache */
/* search620_0 -> search609_0 in the cache */

/* search620_1 -> replace567_1 in the cache */
static const nir_search_expression search620 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_extract_i8,
   { &search609_0.value, &replace567_1.value },
   NULL,
};

   /* replace620_0 -> search57_0 in the cache */

/* replace620_1 -> replace583_1 in the cache */
static const nir_search_expression replace620 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_extract_i8,
   { &search57_0.value, &replace583_1.value },
   NULL,
};

   /* search621_0_0 -> search57_0 in the cache */

/* search621_0_1 -> search587_0_1 in the cache */
/* search621_0 -> search610_0 in the cache */

/* search621_1 -> replace567_1 in the cache */
static const nir_search_expression search621 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_extract_i8,
   { &search610_0.value, &replace567_1.value },
   NULL,
};

   /* replace621_0 -> search57_0 in the cache */

/* replace621_1 -> replace582_1 in the cache */
static const nir_search_expression replace621 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_extract_i8,
   { &search57_0.value, &replace582_1.value },
   NULL,
};

   /* search622_0_0 -> search57_0 in the cache */

/* search622_0_1 -> search567_1 in the cache */
/* search622_0 -> search611_0 in the cache */

/* search622_1 -> replace567_1 in the cache */
static const nir_search_expression search622 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_extract_i8,
   { &search611_0.value, &replace567_1.value },
   NULL,
};

   /* replace622_0 -> search57_0 in the cache */

/* replace622_1 -> replace107_2 in the cache */
static const nir_search_expression replace622 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_extract_i8,
   { &search57_0.value, &replace107_2.value },
   NULL,
};

   /* search623_0_0 -> search0_0 in the cache */

/* search623_0_1 -> replace101_0_1 in the cache */
/* search623_0 -> search603_0 in the cache */

/* search623_1 -> replace101_0_1 in the cache */
static const nir_search_expression search623 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_ushr,
   { &search603_0.value, &replace101_0_1.value },
   NULL,
};

   /* replace623_0 -> search0_0 in the cache */

/* replace623_1 -> search26_1 in the cache */
static const nir_search_expression replace623 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_extract_u16,
   { &search0_0.value, &search26_1.value },
   NULL,
};

   /* search624_0 -> search0_0 in the cache */

/* search624_1 -> replace101_0_1 in the cache */
/* search624 -> search442_1 in the cache */

   /* replace624_0 -> search0_0 in the cache */

/* replace624_1 -> replace579_1 in the cache */
static const nir_search_expression replace624 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_extract_u16,
   { &search0_0.value, &replace579_1.value },
   NULL,
};

   /* search625_0_0 -> search0_0 in the cache */

/* search625_0_1 -> replace101_0_1 in the cache */
/* search625_0 -> search603_0 in the cache */

/* search625_1 -> replace101_0_1 in the cache */
static const nir_search_expression search625 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_ishr,
   { &search603_0.value, &replace101_0_1.value },
   NULL,
};

   /* replace625_0 -> search0_0 in the cache */

/* replace625_1 -> search26_1 in the cache */
static const nir_search_expression replace625 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_extract_i16,
   { &search0_0.value, &search26_1.value },
   NULL,
};

   /* search626_0 -> search0_0 in the cache */

/* search626_1 -> replace101_0_1 in the cache */
/* search626 -> search591_0 in the cache */

   /* replace626_0 -> search0_0 in the cache */

/* replace626_1 -> replace579_1 in the cache */
static const nir_search_expression replace626 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_extract_i16,
   { &search0_0.value, &replace579_1.value },
   NULL,
};

   static const nir_search_constant search627_0 = {
   { nir_search_value_constant, -1 },
   nir_type_int, { 0xffff /* 65535 */ },
};

/* search627_1 -> search2_0 in the cache */
static const nir_search_expression search627 = {
   { nir_search_value_expression, -1 },
   false,
   0, 1,
   nir_op_iand,
   { &search627_0.value, &search2_0.value },
   NULL,
};

   /* replace627_0 -> search2_0 in the cache */

/* replace627_1 -> replace9 in the cache */
static const nir_search_expression replace627 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_extract_u16,
   { &search2_0.value, &replace9.value },
   NULL,
};

   /* search628_0 -> search14_0 in the cache */

/* search628_1_0 -> search47_0 in the cache */

/* search628_1_1 -> replace14_1_0 in the cache */
static const nir_search_expression search628_1 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_fsub,
   { &search47_0.value, &replace14_1_0.value },
   NULL,
};
static const nir_search_expression search628 = {
   { nir_search_value_expression, -2 },
   true,
   -1, 0,
   nir_op_fsub,
   { &search14_0.value, &search628_1.value },
   NULL,
};

   /* replace628_0 -> search14_0 in the cache */

/* replace628_1 -> replace14_1_0 in the cache */
/* replace628 -> replace49 in the cache */

   /* search629_0 -> search14_0 in the cache */

/* search629_1_0 -> replace187_1 in the cache */

/* search629_1_1 -> replace14_1_0 in the cache */
static const nir_search_expression search629_1 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_isub,
   { &replace187_1.value, &replace14_1_0.value },
   NULL,
};
static const nir_search_expression search629 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_isub,
   { &search14_0.value, &search629_1.value },
   NULL,
};

   /* replace629_0 -> search14_0 in the cache */

/* replace629_1 -> replace14_1_0 in the cache */
static const nir_search_expression replace629 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_iadd,
   { &search14_0.value, &replace14_1_0.value },
   NULL,
};

   /* search630_0 -> search0_0 in the cache */

/* search630_1 -> search26_1 in the cache */
static const nir_search_expression search630 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_ussub_4x8,
   { &search0_0.value, &search26_1.value },
   NULL,
};

   /* replace630 -> search0_0 in the cache */

   /* search631_0 -> search0_0 in the cache */

/* search631_1 -> search27_1 in the cache */
static const nir_search_expression search631 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_ussub_4x8,
   { &search0_0.value, &search27_1.value },
   NULL,
};

   /* replace631 -> search26_1 in the cache */

   /* search632_0 -> search14_0 in the cache */

/* search632_1 -> replace14_1_0 in the cache */
static const nir_search_expression search632 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_fsub,
   { &search14_0.value, &replace14_1_0.value },
   NULL,
};

   /* replace632_0 -> search14_0 in the cache */

/* replace632_1_0 -> replace14_1_0 in the cache */
/* replace632_1 -> search126_1 in the cache */
static const nir_search_expression replace632 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_fadd,
   { &search14_0.value, &search126_1.value },
   NULL,
};

   /* search633_0 -> search14_0 in the cache */

/* search633_1 -> replace14_1_0 in the cache */
static const nir_search_expression search633 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_isub,
   { &search14_0.value, &replace14_1_0.value },
   NULL,
};

   /* replace633_0 -> search14_0 in the cache */

/* replace633_1_0 -> replace14_1_0 in the cache */
static const nir_search_expression replace633_1 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_ineg,
   { &replace14_1_0.value },
   NULL,
};
static const nir_search_expression replace633 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_iadd,
   { &search14_0.value, &replace633_1.value },
   NULL,
};

   /* search634_0 -> search2_0 in the cache */
/* search634 -> search15_0 in the cache */

   /* replace634_0 -> search24_1 in the cache */

/* replace634_1 -> search2_0 in the cache */
static const nir_search_expression replace634 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fsub,
   { &search24_1.value, &search2_0.value },
   NULL,
};

   /* search635_0 -> search2_0 in the cache */
/* search635 -> search16_0 in the cache */

   /* replace635_0 -> replace9 in the cache */

/* replace635_1 -> search2_0 in the cache */
static const nir_search_expression replace635 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_isub,
   { &replace9.value, &search2_0.value },
   NULL,
};

   /* search636_0 -> search14_0 in the cache */

/* search636_1_0 -> search47_0 in the cache */

/* search636_1_1 -> replace14_1_0 in the cache */
/* search636_1 -> search628_1 in the cache */
static const nir_search_expression search636 = {
   { nir_search_value_expression, -2 },
   true,
   0, 1,
   nir_op_fadd,
   { &search14_0.value, &search628_1.value },
   NULL,
};

   /* replace636_0 -> search14_0 in the cache */

/* replace636_1 -> replace14_1_0 in the cache */
/* replace636 -> search632 in the cache */

   /* search637_0 -> search14_0 in the cache */

/* search637_1_0 -> replace187_1 in the cache */

/* search637_1_1 -> replace14_1_0 in the cache */
/* search637_1 -> search629_1 in the cache */
static const nir_search_expression search637 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_iadd,
   { &search14_0.value, &search629_1.value },
   NULL,
};

   /* replace637_0 -> search14_0 in the cache */

/* replace637_1 -> replace14_1_0 in the cache */
/* replace637 -> search633 in the cache */

   /* search638_0_0 -> search24_1 in the cache */

/* search638_0_1 -> search2_0 in the cache */
/* search638_0 -> replace634 in the cache */
static const nir_search_expression search638 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fabs,
   { &replace634.value },
   NULL,
};

   /* replace638_0 -> search2_0 in the cache */
/* replace638 -> search17_0 in the cache */

   /* search639_0_0 -> replace9 in the cache */

/* search639_0_1 -> search2_0 in the cache */
/* search639_0 -> replace635 in the cache */
static const nir_search_expression search639 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_iabs,
   { &replace635.value },
   NULL,
};

   /* replace639_0 -> search2_0 in the cache */
/* replace639 -> search20_0 in the cache */

   /* search640_0_0 -> search14_0 in the cache */
/* search640_0 -> search34_0 in the cache */

/* search640_1 -> replace14_1_0 in the cache */
static const nir_search_expression search640 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_fmul,
   { &search34_0.value, &replace14_1_0.value },
   (is_used_by_non_fsat),
};

   /* replace640_0_0 -> search14_0 in the cache */

/* replace640_0_1 -> replace14_1_0 in the cache */
/* replace640_0 -> replace48 in the cache */
static const nir_search_expression replace640 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 1,
   nir_op_fneg,
   { &replace48.value },
   NULL,
};

   /* search641_0_0 -> search14_0 in the cache */
/* search641_0 -> search32_0 in the cache */

/* search641_1 -> replace14_1_0 in the cache */
static const nir_search_expression search641 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_imul,
   { &search32_0.value, &replace14_1_0.value },
   NULL,
};

   /* replace641_0_0 -> search14_0 in the cache */

/* replace641_0_1 -> replace14_1_0 in the cache */
static const nir_search_expression replace641_0 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_imul,
   { &search14_0.value, &replace14_1_0.value },
   NULL,
};
static const nir_search_expression replace641 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 1,
   nir_op_ineg,
   { &replace641_0.value },
   NULL,
};

   static const nir_search_variable search642_0_0 = {
   { nir_search_value_variable, -3 },
   0, /* a */
   false,
   nir_type_invalid,
   (is_not_const),
   {0, 1, 2, 3},
};

static const nir_search_variable search642_0_1 = {
   { nir_search_value_variable, -3 },
   1, /* b */
   false,
   nir_type_invalid,
   (is_not_const),
   {0, 1, 2, 3},
};
static const nir_search_expression search642_0 = {
   { nir_search_value_expression, -3 },
   false,
   1, 1,
   nir_op_fmul,
   { &search642_0_0.value, &search642_0_1.value },
   (is_used_once),
};

/* search642_1 -> search96_0_1 in the cache */
static const nir_search_expression search642 = {
   { nir_search_value_expression, -3 },
   true,
   0, 2,
   nir_op_fmul,
   { &search642_0.value, &search96_0_1.value },
   (is_used_once),
};

   /* replace642_0_0 -> search28_0_0 in the cache */

/* replace642_0_1 -> search28_1_1 in the cache */
static const nir_search_expression replace642_0 = {
   { nir_search_value_expression, -3 },
   false,
   1, 1,
   nir_op_fmul,
   { &search28_0_0.value, &search28_1_1.value },
   NULL,
};

/* replace642_1 -> search28_0_1 in the cache */
static const nir_search_expression replace642 = {
   { nir_search_value_expression, -3 },
   false,
   0, 2,
   nir_op_fmul,
   { &replace642_0.value, &search28_0_1.value },
   NULL,
};

   /* search643_0_0 -> search642_0_0 in the cache */

/* search643_0_1 -> search642_0_1 in the cache */
static const nir_search_expression search643_0 = {
   { nir_search_value_expression, -3 },
   false,
   1, 1,
   nir_op_imul,
   { &search642_0_0.value, &search642_0_1.value },
   (is_used_once),
};

/* search643_1 -> search96_0_1 in the cache */
static const nir_search_expression search643 = {
   { nir_search_value_expression, -3 },
   false,
   0, 2,
   nir_op_imul,
   { &search643_0.value, &search96_0_1.value },
   (is_used_once),
};

   /* replace643_0_0 -> search28_0_0 in the cache */

/* replace643_0_1 -> search28_1_1 in the cache */
static const nir_search_expression replace643_0 = {
   { nir_search_value_expression, -3 },
   false,
   1, 1,
   nir_op_imul,
   { &search28_0_0.value, &search28_1_1.value },
   NULL,
};

/* replace643_1 -> search28_0_1 in the cache */
static const nir_search_expression replace643 = {
   { nir_search_value_expression, -3 },
   false,
   0, 2,
   nir_op_imul,
   { &replace643_0.value, &search28_0_1.value },
   NULL,
};

   /* search644_0_0 -> search642_0_0 in the cache */

/* search644_0_1 -> search642_0_1 in the cache */
static const nir_search_expression search644_0 = {
   { nir_search_value_expression, -3 },
   false,
   1, 1,
   nir_op_fadd,
   { &search642_0_0.value, &search642_0_1.value },
   (is_used_once),
};

/* search644_1 -> search96_0_1 in the cache */
static const nir_search_expression search644 = {
   { nir_search_value_expression, -3 },
   true,
   0, 2,
   nir_op_fadd,
   { &search644_0.value, &search96_0_1.value },
   (is_used_once),
};

   /* replace644_0_0 -> search28_0_0 in the cache */

/* replace644_0_1 -> search28_1_1 in the cache */
static const nir_search_expression replace644_0 = {
   { nir_search_value_expression, -3 },
   false,
   1, 1,
   nir_op_fadd,
   { &search28_0_0.value, &search28_1_1.value },
   NULL,
};

/* replace644_1 -> search28_0_1 in the cache */
static const nir_search_expression replace644 = {
   { nir_search_value_expression, -3 },
   false,
   0, 2,
   nir_op_fadd,
   { &replace644_0.value, &search28_0_1.value },
   NULL,
};

   /* search645_0_0 -> search642_0_0 in the cache */

/* search645_0_1 -> search642_0_1 in the cache */
static const nir_search_expression search645_0 = {
   { nir_search_value_expression, -3 },
   false,
   1, 1,
   nir_op_iadd,
   { &search642_0_0.value, &search642_0_1.value },
   (is_used_once),
};

/* search645_1 -> search96_0_1 in the cache */
static const nir_search_expression search645 = {
   { nir_search_value_expression, -3 },
   false,
   0, 2,
   nir_op_iadd,
   { &search645_0.value, &search96_0_1.value },
   (is_used_once),
};

   /* replace645_0_0 -> search28_0_0 in the cache */

/* replace645_0_1 -> search28_1_1 in the cache */
static const nir_search_expression replace645_0 = {
   { nir_search_value_expression, -3 },
   false,
   1, 1,
   nir_op_iadd,
   { &search28_0_0.value, &search28_1_1.value },
   NULL,
};

/* replace645_1 -> search28_0_1 in the cache */
static const nir_search_expression replace645 = {
   { nir_search_value_expression, -3 },
   false,
   0, 2,
   nir_op_iadd,
   { &replace645_0.value, &search28_0_1.value },
   NULL,
};

   /* search646_0 -> search357_0 in the cache */

/* search646_1_0 -> search642_0_1 in the cache */

/* search646_1_1 -> search96_0_1 in the cache */
static const nir_search_expression search646_1 = {
   { nir_search_value_expression, -3 },
   false,
   1, 1,
   nir_op_fmul,
   { &search642_0_1.value, &search96_0_1.value },
   NULL,
};
static const nir_search_expression search646 = {
   { nir_search_value_expression, -3 },
   true,
   0, 2,
   nir_op_fmul,
   { &search357_0.value, &search646_1.value },
   NULL,
};

   /* replace646_0_0 -> search28_0_0 in the cache */

/* replace646_0_1 -> search28_1_1 in the cache */
/* replace646_0 -> replace642_0 in the cache */

/* replace646_1 -> search28_0_1 in the cache */
/* replace646 -> replace642 in the cache */

   /* search647_0 -> search357_0 in the cache */

/* search647_1_0 -> search642_0_1 in the cache */

/* search647_1_1 -> search96_0_1 in the cache */
static const nir_search_expression search647_1 = {
   { nir_search_value_expression, -3 },
   false,
   1, 1,
   nir_op_imul,
   { &search642_0_1.value, &search96_0_1.value },
   NULL,
};
static const nir_search_expression search647 = {
   { nir_search_value_expression, -3 },
   false,
   0, 2,
   nir_op_imul,
   { &search357_0.value, &search647_1.value },
   NULL,
};

   /* replace647_0_0 -> search28_0_0 in the cache */

/* replace647_0_1 -> search28_1_1 in the cache */
/* replace647_0 -> replace643_0 in the cache */

/* replace647_1 -> search28_0_1 in the cache */
/* replace647 -> replace643 in the cache */

   /* search648_0 -> search357_0 in the cache */

/* search648_1_0 -> search642_0_1 in the cache */

/* search648_1_1 -> search96_0_1 in the cache */
static const nir_search_expression search648_1 = {
   { nir_search_value_expression, -3 },
   false,
   1, 1,
   nir_op_fadd,
   { &search642_0_1.value, &search96_0_1.value },
   NULL,
};
static const nir_search_expression search648 = {
   { nir_search_value_expression, -3 },
   true,
   0, 2,
   nir_op_fadd,
   { &search357_0.value, &search648_1.value },
   NULL,
};

   /* replace648_0_0 -> search28_0_0 in the cache */

/* replace648_0_1 -> search28_1_1 in the cache */
/* replace648_0 -> replace644_0 in the cache */

/* replace648_1 -> search28_0_1 in the cache */
/* replace648 -> replace644 in the cache */

   /* search649_0 -> search357_0 in the cache */

/* search649_1_0_0 -> search642_0_1 in the cache */

/* search649_1_0_1 -> search96_0_1 in the cache */
/* search649_1_0 -> search648_1 in the cache */
static const nir_search_expression search649_1 = {
   { nir_search_value_expression, -3 },
   false,
   -1, 1,
   nir_op_fneg,
   { &search648_1.value },
   NULL,
};
static const nir_search_expression search649 = {
   { nir_search_value_expression, -3 },
   true,
   0, 2,
   nir_op_fadd,
   { &search357_0.value, &search649_1.value },
   NULL,
};

   /* replace649_0_0 -> search28_0_0 in the cache */

/* replace649_0_1_0 -> search28_1_1 in the cache */
static const nir_search_expression replace649_0_1 = {
   { nir_search_value_expression, -3 },
   false,
   -1, 0,
   nir_op_fneg,
   { &search28_1_1.value },
   NULL,
};
static const nir_search_expression replace649_0 = {
   { nir_search_value_expression, -3 },
   false,
   1, 1,
   nir_op_fadd,
   { &search28_0_0.value, &replace649_0_1.value },
   NULL,
};

/* replace649_1_0 -> search28_0_1 in the cache */
/* replace649_1 -> replace179_1_1 in the cache */
static const nir_search_expression replace649 = {
   { nir_search_value_expression, -3 },
   false,
   0, 2,
   nir_op_fadd,
   { &replace649_0.value, &replace179_1_1.value },
   NULL,
};

   /* search650_0 -> search357_0 in the cache */

/* search650_1_0 -> search642_0_1 in the cache */

/* search650_1_1 -> search96_0_1 in the cache */
static const nir_search_expression search650_1 = {
   { nir_search_value_expression, -3 },
   false,
   1, 1,
   nir_op_iadd,
   { &search642_0_1.value, &search96_0_1.value },
   NULL,
};
static const nir_search_expression search650 = {
   { nir_search_value_expression, -3 },
   false,
   0, 2,
   nir_op_iadd,
   { &search357_0.value, &search650_1.value },
   NULL,
};

   /* replace650_0_0 -> search28_0_0 in the cache */

/* replace650_0_1 -> search28_1_1 in the cache */
/* replace650_0 -> replace645_0 in the cache */

/* replace650_1 -> search28_0_1 in the cache */
/* replace650 -> replace645 in the cache */

   /* search651_0_0 -> search14_0 in the cache */

/* search651_0_1 -> replace14_1_0 in the cache */
static const nir_search_expression search651_0 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_imul,
   { &search14_0.value, &replace14_1_0.value },
   (no_signed_wrap),
};

/* search651_1 -> replace14_1_0 in the cache */
static const nir_search_expression search651 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 1,
   nir_op_idiv,
   { &search651_0.value, &replace14_1_0.value },
   NULL,
};

   /* replace651 -> search14_0 in the cache */

   /* search652_0_0_0 -> search2_0 in the cache */
static const nir_search_expression search652_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_find_lsb,
   { &search2_0.value },
   NULL,
};

/* search652_0_1 -> search26_1 in the cache */
static const nir_search_expression search652_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search652_0_0.value, &search26_1.value },
   NULL,
};

/* search652_1_0 -> search2_0 in the cache */
/* search652_1 -> search652_0_0 in the cache */

/* search652_2 -> search27_1 in the cache */
static const nir_search_expression search652 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &search652_0.value, &search652_0_0.value, &search27_1.value },
   NULL,
};

   /* replace652_0 -> search2_0 in the cache */
/* replace652 -> search652_0_0 in the cache */

   /* search653_0_0_0 -> search0_0 in the cache */
static const nir_search_expression search653_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_ifind_msb,
   { &search0_0.value },
   NULL,
};

/* search653_0_1 -> search26_1 in the cache */
static const nir_search_expression search653_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search653_0_0.value, &search26_1.value },
   NULL,
};

/* search653_1_0 -> search0_0 in the cache */
/* search653_1 -> search653_0_0 in the cache */

/* search653_2 -> search27_1 in the cache */
static const nir_search_expression search653 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &search653_0.value, &search653_0_0.value, &search27_1.value },
   NULL,
};

   /* replace653_0 -> search0_0 in the cache */
/* replace653 -> search653_0_0 in the cache */

   /* search654_0_0_0 -> search2_0 in the cache */
static const nir_search_expression search654_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_ufind_msb,
   { &search2_0.value },
   NULL,
};

/* search654_0_1 -> search26_1 in the cache */
static const nir_search_expression search654_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search654_0_0.value, &search26_1.value },
   NULL,
};

/* search654_1_0 -> search2_0 in the cache */
/* search654_1 -> search654_0_0 in the cache */

/* search654_2 -> search27_1 in the cache */
static const nir_search_expression search654 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &search654_0.value, &search654_0_0.value, &search27_1.value },
   NULL,
};

   /* replace654_0 -> search2_0 in the cache */
/* replace654 -> search654_0_0 in the cache */

   /* search655_0_0 -> search2_0 in the cache */

/* search655_0_1 -> replace9 in the cache */
/* search655_0 -> replace195 in the cache */

/* search655_1_0 -> search2_0 in the cache */
/* search655_1 -> search652_0_0 in the cache */

/* search655_2 -> search27_1 in the cache */
static const nir_search_expression search655 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_op_bcsel,
   { &replace195.value, &search652_0_0.value, &search27_1.value },
   NULL,
};

   /* replace655_0 -> search2_0 in the cache */
/* replace655 -> search652_0_0 in the cache */

   /* search656_0_0 -> search0_0 in the cache */

/* search656_0_1 -> search26_1 in the cache */
static const nir_search_expression search656_0 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &search0_0.value, &search26_1.value },
   NULL,
};

/* search656_1_0 -> search0_0 in the cache */
/* search656_1 -> search653_0_0 in the cache */

/* search656_2 -> search27_1 in the cache */
static const nir_search_expression search656 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_op_bcsel,
   { &search656_0.value, &search653_0_0.value, &search27_1.value },
   NULL,
};

   /* replace656_0 -> search0_0 in the cache */
/* replace656 -> search653_0_0 in the cache */

   /* search657_0_0 -> search2_0 in the cache */

/* search657_0_1 -> replace9 in the cache */
/* search657_0 -> replace195 in the cache */

/* search657_1_0 -> search2_0 in the cache */
/* search657_1 -> search654_0_0 in the cache */

/* search657_2 -> search27_1 in the cache */
static const nir_search_expression search657 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_op_bcsel,
   { &replace195.value, &search654_0_0.value, &search27_1.value },
   NULL,
};

   /* replace657_0 -> search2_0 in the cache */
/* replace657 -> search654_0_0 in the cache */

   /* search658_0_0 -> search0_0 in the cache */

/* search658_0_1 -> search27_1 in the cache */
static const nir_search_expression search658_0 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &search0_0.value, &search27_1.value },
   NULL,
};

/* search658_1_0 -> search0_0 in the cache */
/* search658_1 -> search653_0_0 in the cache */

/* search658_2 -> search27_1 in the cache */
static const nir_search_expression search658 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_op_bcsel,
   { &search658_0.value, &search653_0_0.value, &search27_1.value },
   NULL,
};

   /* replace658_0 -> search0_0 in the cache */
/* replace658 -> search653_0_0 in the cache */

   /* search659_0 -> search101_0_0 in the cache */

/* search659_1 -> replace564_1_0 in the cache */
static const nir_search_expression search659 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_fmod,
   { &search101_0_0.value, &replace564_1_0.value },
   NULL,
};

   /* replace659_0 -> search101_0_0 in the cache */

/* replace659_1_0 -> replace564_1_0 in the cache */

/* replace659_1_1_0_0 -> search101_0_0 in the cache */

/* replace659_1_1_0_1 -> replace564_1_0 in the cache */
static const nir_search_expression replace659_1_1_0 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_fdiv,
   { &search101_0_0.value, &replace564_1_0.value },
   NULL,
};
static const nir_search_expression replace659_1_1 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_ffloor,
   { &replace659_1_1_0.value },
   NULL,
};
static const nir_search_expression replace659_1 = {
   { nir_search_value_expression, 16 },
   false,
   0, 1,
   nir_op_fmul,
   { &replace564_1_0.value, &replace659_1_1.value },
   NULL,
};
static const nir_search_expression replace659 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 1,
   nir_op_fsub,
   { &search101_0_0.value, &replace659_1.value },
   NULL,
};

   /* search660_0 -> search0_0 in the cache */

/* search660_1 -> replace0_1_0 in the cache */
static const nir_search_expression search660 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_fmod,
   { &search0_0.value, &replace0_1_0.value },
   NULL,
};

   /* replace660_0 -> search0_0 in the cache */

/* replace660_1_0 -> replace0_1_0 in the cache */

/* replace660_1_1_0_0 -> search0_0 in the cache */

/* replace660_1_1_0_1 -> replace0_1_0 in the cache */
static const nir_search_expression replace660_1_1_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_fdiv,
   { &search0_0.value, &replace0_1_0.value },
   NULL,
};
static const nir_search_expression replace660_1_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_ffloor,
   { &replace660_1_1_0.value },
   NULL,
};
static const nir_search_expression replace660_1 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_fmul,
   { &replace0_1_0.value, &replace660_1_1.value },
   NULL,
};
static const nir_search_expression replace660 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_op_fsub,
   { &search0_0.value, &replace660_1.value },
   NULL,
};

   /* search661_0 -> search14_0 in the cache */

/* search661_1 -> replace14_1_0 in the cache */
static const nir_search_expression search661 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_frem,
   { &search14_0.value, &replace14_1_0.value },
   NULL,
};

   /* replace661_0 -> search14_0 in the cache */

/* replace661_1_0 -> replace14_1_0 in the cache */

/* replace661_1_1_0_0 -> search14_0 in the cache */

/* replace661_1_1_0_1 -> replace14_1_0 in the cache */
/* replace661_1_1_0 -> search478 in the cache */
static const nir_search_expression replace661_1_1 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_ftrunc,
   { &search478.value },
   NULL,
};
static const nir_search_expression replace661_1 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_fmul,
   { &replace14_1_0.value, &replace661_1_1.value },
   NULL,
};
static const nir_search_expression replace661 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 1,
   nir_op_fsub,
   { &search14_0.value, &replace661_1.value },
   NULL,
};

   /* search662_0 -> search0_0 in the cache */

/* search662_1 -> replace0_1_0 in the cache */
static const nir_search_expression search662 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_uadd_carry,
   { &search0_0.value, &replace0_1_0.value },
   NULL,
};

   /* replace662_0_0_0 -> search0_0 in the cache */

/* replace662_0_0_1 -> replace0_1_0 in the cache */
static const nir_search_expression replace662_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_iadd,
   { &search0_0.value, &replace0_1_0.value },
   NULL,
};

/* replace662_0_1 -> search0_0 in the cache */
static const nir_search_expression replace662_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_ult,
   { &replace662_0_0.value, &search0_0.value },
   NULL,
};
static const nir_search_expression replace662 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_search_op_b2i,
   { &replace662_0.value },
   NULL,
};

   /* search663_0 -> search0_0 in the cache */

/* search663_1 -> replace0_1_0 in the cache */
static const nir_search_expression search663 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_usub_borrow,
   { &search0_0.value, &replace0_1_0.value },
   NULL,
};

   /* replace663_0_0 -> search0_0 in the cache */

/* replace663_0_1 -> replace0_1_0 in the cache */
static const nir_search_expression replace663_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search0_0.value, &replace0_1_0.value },
   NULL,
};
static const nir_search_expression replace663 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_search_op_b2i,
   { &replace663_0.value },
   NULL,
};

   static const nir_search_variable search664_0 = {
   { nir_search_value_variable, 32 },
   0, /* base */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

static const nir_search_variable search664_1 = {
   { nir_search_value_variable, 32 },
   1, /* insert */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

static const nir_search_variable search664_2 = {
   { nir_search_value_variable, 32 },
   2, /* offset */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

static const nir_search_variable search664_3 = {
   { nir_search_value_variable, 32 },
   3, /* bits */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search664 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_bitfield_insert,
   { &search664_0.value, &search664_1.value, &search664_2.value, &search664_3.value },
   NULL,
};

   /* replace664_0_0 -> replace106_1_1 in the cache */

/* replace664_0_1 -> search664_3 in the cache */
static const nir_search_expression replace664_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &replace106_1_1.value, &search664_3.value },
   NULL,
};

/* replace664_1 -> search664_1 in the cache */

/* replace664_2_0_0 -> search664_3 in the cache */

/* replace664_2_0_1 -> search664_2 in the cache */
static const nir_search_expression replace664_2_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_bfm,
   { &search664_3.value, &search664_2.value },
   NULL,
};

/* replace664_2_1 -> search664_1 in the cache */

/* replace664_2_2 -> search664_0 in the cache */
static const nir_search_expression replace664_2 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_bfi,
   { &replace664_2_0.value, &search664_1.value, &search664_0.value },
   NULL,
};
static const nir_search_expression replace664 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace664_0.value, &search664_1.value, &replace664_2.value },
   NULL,
};

   /* search665_0 -> search14_0 in the cache */

/* search665_1 -> replace14_1_0 in the cache */
static const nir_search_expression search665 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_ihadd,
   { &search14_0.value, &replace14_1_0.value },
   NULL,
};

   /* replace665_0_0 -> search14_0 in the cache */

/* replace665_0_1 -> replace14_1_0 in the cache */
/* replace665_0 -> search429_0 in the cache */

/* replace665_1_0_0 -> search14_0 in the cache */

/* replace665_1_0_1 -> replace14_1_0 in the cache */
static const nir_search_expression replace665_1_0 = {
   { nir_search_value_expression, -2 },
   false,
   2, 1,
   nir_op_ixor,
   { &search14_0.value, &replace14_1_0.value },
   NULL,
};

/* replace665_1_1 -> replace579_1 in the cache */
static const nir_search_expression replace665_1 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 1,
   nir_op_ishr,
   { &replace665_1_0.value, &replace579_1.value },
   NULL,
};
static const nir_search_expression replace665 = {
   { nir_search_value_expression, -2 },
   false,
   0, 3,
   nir_op_iadd,
   { &search429_0.value, &replace665_1.value },
   NULL,
};

   /* search666_0 -> search14_0 in the cache */

/* search666_1 -> replace14_1_0 in the cache */
static const nir_search_expression search666 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_uhadd,
   { &search14_0.value, &replace14_1_0.value },
   NULL,
};

   /* replace666_0_0 -> search14_0 in the cache */

/* replace666_0_1 -> replace14_1_0 in the cache */
/* replace666_0 -> search429_0 in the cache */

/* replace666_1_0_0 -> search14_0 in the cache */

/* replace666_1_0_1 -> replace14_1_0 in the cache */
/* replace666_1_0 -> replace665_1_0 in the cache */

/* replace666_1_1 -> replace579_1 in the cache */
static const nir_search_expression replace666_1 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 1,
   nir_op_ushr,
   { &replace665_1_0.value, &replace579_1.value },
   NULL,
};
static const nir_search_expression replace666 = {
   { nir_search_value_expression, -2 },
   false,
   0, 3,
   nir_op_iadd,
   { &search429_0.value, &replace666_1.value },
   NULL,
};

   /* search667_0 -> search14_0 in the cache */

/* search667_1 -> replace14_1_0 in the cache */
static const nir_search_expression search667 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_irhadd,
   { &search14_0.value, &replace14_1_0.value },
   NULL,
};

   /* replace667_0_0 -> search14_0 in the cache */

/* replace667_0_1 -> replace14_1_0 in the cache */
/* replace667_0 -> search354_0 in the cache */

/* replace667_1_0_0 -> search14_0 in the cache */

/* replace667_1_0_1 -> replace14_1_0 in the cache */
static const nir_search_expression replace667_1_0 = {
   { nir_search_value_expression, -2 },
   false,
   1, 1,
   nir_op_ixor,
   { &search14_0.value, &replace14_1_0.value },
   NULL,
};

/* replace667_1_1 -> replace579_1 in the cache */
static const nir_search_expression replace667_1 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 1,
   nir_op_ishr,
   { &replace667_1_0.value, &replace579_1.value },
   NULL,
};
static const nir_search_expression replace667 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 2,
   nir_op_isub,
   { &search354_0.value, &replace667_1.value },
   NULL,
};

   /* search668_0 -> search14_0 in the cache */

/* search668_1 -> replace14_1_0 in the cache */
static const nir_search_expression search668 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_urhadd,
   { &search14_0.value, &replace14_1_0.value },
   NULL,
};

   /* replace668_0_0 -> search14_0 in the cache */

/* replace668_0_1 -> replace14_1_0 in the cache */
/* replace668_0 -> search354_0 in the cache */

/* replace668_1_0_0 -> search14_0 in the cache */

/* replace668_1_0_1 -> replace14_1_0 in the cache */
/* replace668_1_0 -> replace667_1_0 in the cache */

/* replace668_1_1 -> replace579_1 in the cache */
static const nir_search_expression replace668_1 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 1,
   nir_op_ushr,
   { &replace667_1_0.value, &replace579_1.value },
   NULL,
};
static const nir_search_expression replace668 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 2,
   nir_op_isub,
   { &search354_0.value, &replace668_1.value },
   NULL,
};

   /* search669_0 -> search14_0 in the cache */

/* search669_1 -> replace14_1_0 in the cache */
static const nir_search_expression search669 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_uadd_sat,
   { &search14_0.value, &replace14_1_0.value },
   NULL,
};

   /* replace669_0_0_0 -> search14_0 in the cache */

/* replace669_0_0_1 -> replace14_1_0 in the cache */
/* replace669_0_0 -> replace629 in the cache */

/* replace669_0_1 -> search14_0 in the cache */
static const nir_search_expression replace669_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_ult,
   { &replace629.value, &search14_0.value },
   NULL,
};

static const nir_search_constant replace669_1 = {
   { nir_search_value_constant, -2 },
   nir_type_int, { -0x1 /* -1 */ },
};

/* replace669_2_0 -> search14_0 in the cache */

/* replace669_2_1 -> replace14_1_0 in the cache */
/* replace669_2 -> search32_1 in the cache */
static const nir_search_expression replace669 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 2,
   nir_op_bcsel,
   { &replace669_0.value, &replace669_1.value, &search32_1.value },
   NULL,
};

   /* search670_0 -> search14_0 in the cache */

/* search670_1 -> replace14_1_0 in the cache */
static const nir_search_expression search670 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_usub_sat,
   { &search14_0.value, &replace14_1_0.value },
   NULL,
};

   /* replace670_0_0 -> search14_0 in the cache */

/* replace670_0_1 -> replace14_1_0 in the cache */
/* replace670_0 -> search116_0 in the cache */

/* replace670_1 -> replace187_1 in the cache */

/* replace670_2_0 -> search14_0 in the cache */

/* replace670_2_1 -> replace14_1_0 in the cache */
/* replace670_2 -> search633 in the cache */
static const nir_search_expression replace670 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &search116_0.value, &replace187_1.value, &search633.value },
   NULL,
};

   /* search671_0 -> search664_0 in the cache */

/* search671_1 -> search664_1 in the cache */

/* search671_2 -> search664_2 in the cache */

/* search671_3 -> search664_3 in the cache */
/* search671 -> search664 in the cache */

   /* replace671_0_0 -> replace106_1_1 in the cache */

/* replace671_0_1 -> search664_3 in the cache */
/* replace671_0 -> replace664_0 in the cache */

/* replace671_1 -> search664_1 in the cache */

/* replace671_2_0_0 -> search664_0 in the cache */

/* replace671_2_0_1_0_0_0_0 -> replace579_1 in the cache */

/* replace671_2_0_1_0_0_0_1 -> search664_3 in the cache */
static const nir_search_expression replace671_2_0_1_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_ishl,
   { &replace579_1.value, &search664_3.value },
   NULL,
};

/* replace671_2_0_1_0_0_1 -> replace579_1 in the cache */
static const nir_search_expression replace671_2_0_1_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_isub,
   { &replace671_2_0_1_0_0_0.value, &replace579_1.value },
   NULL,
};

/* replace671_2_0_1_0_1 -> search664_2 in the cache */
static const nir_search_expression replace671_2_0_1_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_ishl,
   { &replace671_2_0_1_0_0.value, &search664_2.value },
   NULL,
};
static const nir_search_expression replace671_2_0_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_inot,
   { &replace671_2_0_1_0.value },
   NULL,
};
static const nir_search_expression replace671_2_0 = {
   { nir_search_value_expression, 32 },
   false,
   1, 1,
   nir_op_iand,
   { &search664_0.value, &replace671_2_0_1.value },
   NULL,
};

/* replace671_2_1_0_0 -> search664_1 in the cache */

/* replace671_2_1_0_1 -> search664_2 in the cache */
static const nir_search_expression replace671_2_1_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_ishl,
   { &search664_1.value, &search664_2.value },
   NULL,
};

/* replace671_2_1_1_0_0_0 -> replace579_1 in the cache */

/* replace671_2_1_1_0_0_1 -> search664_3 in the cache */
/* replace671_2_1_1_0_0 -> replace671_2_0_1_0_0_0 in the cache */

/* replace671_2_1_1_0_1 -> replace579_1 in the cache */
/* replace671_2_1_1_0 -> replace671_2_0_1_0_0 in the cache */

/* replace671_2_1_1_1 -> search664_2 in the cache */
/* replace671_2_1_1 -> replace671_2_0_1_0 in the cache */
static const nir_search_expression replace671_2_1 = {
   { nir_search_value_expression, 32 },
   false,
   2, 1,
   nir_op_iand,
   { &replace671_2_1_0.value, &replace671_2_0_1_0.value },
   NULL,
};
static const nir_search_expression replace671_2 = {
   { nir_search_value_expression, 32 },
   false,
   0, 3,
   nir_op_ior,
   { &replace671_2_0.value, &replace671_2_1.value },
   NULL,
};
static const nir_search_expression replace671 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 3,
   nir_op_bcsel,
   { &replace664_0.value, &search664_1.value, &replace671_2.value },
   NULL,
};

   /* search672_0 -> search664_0 in the cache */

/* search672_1 -> search664_1 in the cache */

/* search672_2 -> search664_2 in the cache */

/* search672_3 -> search664_3 in the cache */
/* search672 -> search664 in the cache */

   /* replace672_0_0 -> replace106_1_1 in the cache */

/* replace672_0_1 -> search664_3 in the cache */
/* replace672_0 -> replace664_0 in the cache */

/* replace672_1 -> search664_1 in the cache */

/* replace672_2_0_0 -> search664_3 in the cache */

/* replace672_2_0_1 -> search664_2 in the cache */
/* replace672_2_0 -> replace664_2_0 in the cache */

/* replace672_2_1_0 -> search664_1 in the cache */

/* replace672_2_1_1 -> search664_2 in the cache */
/* replace672_2_1 -> replace671_2_1_0 in the cache */

/* replace672_2_2 -> search664_0 in the cache */
static const nir_search_expression replace672_2 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_bitfield_select,
   { &replace664_2_0.value, &replace671_2_1_0.value, &search664_0.value },
   NULL,
};
static const nir_search_expression replace672 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace664_0.value, &search664_1.value, &replace672_2.value },
   NULL,
};

   static const nir_search_variable search673_0 = {
   { nir_search_value_variable, 32 },
   0, /* value */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

static const nir_search_variable search673_1 = {
   { nir_search_value_variable, 32 },
   1, /* offset */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

static const nir_search_variable search673_2 = {
   { nir_search_value_variable, 32 },
   2, /* bits */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search673 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_ibitfield_extract,
   { &search673_0.value, &search673_1.value, &search673_2.value },
   NULL,
};

   /* replace673_0_0 -> replace106_1_1 in the cache */

/* replace673_0_1 -> search673_2 in the cache */
static const nir_search_expression replace673_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &replace106_1_1.value, &search673_2.value },
   NULL,
};

/* replace673_1 -> search673_0 in the cache */

/* replace673_2_0 -> search673_0 in the cache */

/* replace673_2_1 -> search673_1 in the cache */

/* replace673_2_2 -> search673_2 in the cache */
static const nir_search_expression replace673_2 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_ibfe,
   { &search673_0.value, &search673_1.value, &search673_2.value },
   NULL,
};
static const nir_search_expression replace673 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace673_0.value, &search673_0.value, &replace673_2.value },
   NULL,
};

   /* search674_0 -> search673_0 in the cache */

/* search674_1 -> search673_1 in the cache */

/* search674_2 -> search673_2 in the cache */
static const nir_search_expression search674 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_ubitfield_extract,
   { &search673_0.value, &search673_1.value, &search673_2.value },
   NULL,
};

   /* replace674_0_0 -> replace106_1_1 in the cache */

/* replace674_0_1 -> search673_2 in the cache */
/* replace674_0 -> replace673_0 in the cache */

/* replace674_1 -> search673_0 in the cache */

/* replace674_2_0 -> search673_0 in the cache */

/* replace674_2_1 -> search673_1 in the cache */

/* replace674_2_2 -> search673_2 in the cache */
static const nir_search_expression replace674_2 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_ubfe,
   { &search673_0.value, &search673_1.value, &search673_2.value },
   NULL,
};
static const nir_search_expression replace674 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace673_0.value, &search673_0.value, &replace674_2.value },
   NULL,
};

   /* search675_0 -> search673_0 in the cache */

/* search675_1 -> search673_1 in the cache */

/* search675_2_0 -> replace106_1_1 in the cache */

/* search675_2_1 -> search673_2 in the cache */
static const nir_search_expression search675_2 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_iand,
   { &replace106_1_1.value, &search673_2.value },
   NULL,
};
static const nir_search_expression search675 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_op_ubfe,
   { &search673_0.value, &search673_1.value, &search675_2.value },
   NULL,
};

   /* replace675_0 -> search673_0 in the cache */

/* replace675_1 -> search673_1 in the cache */

/* replace675_2 -> search673_2 in the cache */
/* replace675 -> replace674_2 in the cache */

   /* search676_0 -> search673_0 in the cache */

/* search676_1_0 -> replace106_1_1 in the cache */

/* search676_1_1 -> search673_1 in the cache */
static const nir_search_expression search676_1 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_iand,
   { &replace106_1_1.value, &search673_1.value },
   NULL,
};

/* search676_2 -> search673_2 in the cache */
static const nir_search_expression search676 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_op_ubfe,
   { &search673_0.value, &search676_1.value, &search673_2.value },
   NULL,
};

   /* replace676_0 -> search673_0 in the cache */

/* replace676_1 -> search673_1 in the cache */

/* replace676_2 -> search673_2 in the cache */
/* replace676 -> replace674_2 in the cache */

   /* search677_0 -> search673_0 in the cache */

/* search677_1 -> search673_1 in the cache */

/* search677_2_0 -> replace106_1_1 in the cache */

/* search677_2_1 -> search673_2 in the cache */
/* search677_2 -> search675_2 in the cache */
static const nir_search_expression search677 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_op_ibfe,
   { &search673_0.value, &search673_1.value, &search675_2.value },
   NULL,
};

   /* replace677_0 -> search673_0 in the cache */

/* replace677_1 -> search673_1 in the cache */

/* replace677_2 -> search673_2 in the cache */
/* replace677 -> replace673_2 in the cache */

   /* search678_0 -> search673_0 in the cache */

/* search678_1_0 -> replace106_1_1 in the cache */

/* search678_1_1 -> search673_1 in the cache */
/* search678_1 -> search676_1 in the cache */

/* search678_2 -> search673_2 in the cache */
static const nir_search_expression search678 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_op_ibfe,
   { &search673_0.value, &search676_1.value, &search673_2.value },
   NULL,
};

   /* replace678_0 -> search673_0 in the cache */

/* replace678_1 -> search673_1 in the cache */

/* replace678_2 -> search673_2 in the cache */
/* replace678 -> replace673_2 in the cache */

   static const nir_search_variable search679_0 = {
   { nir_search_value_variable, 32 },
   0, /* bits */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

/* search679_1_0 -> replace106_1_1 in the cache */

/* search679_1_1 -> search673_1 in the cache */
/* search679_1 -> search676_1 in the cache */
static const nir_search_expression search679 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_op_bfm,
   { &search679_0.value, &search676_1.value },
   NULL,
};

   /* replace679_0 -> search679_0 in the cache */

/* replace679_1 -> search673_1 in the cache */
static const nir_search_expression replace679 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_bfm,
   { &search679_0.value, &search673_1.value },
   NULL,
};

   /* search680_0_0 -> replace106_1_1 in the cache */

/* search680_0_1 -> search679_0 in the cache */
static const nir_search_expression search680_0 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_iand,
   { &replace106_1_1.value, &search679_0.value },
   NULL,
};

/* search680_1 -> search673_1 in the cache */
static const nir_search_expression search680 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_op_bfm,
   { &search680_0.value, &search673_1.value },
   NULL,
};

   /* replace680_0 -> search679_0 in the cache */

/* replace680_1 -> search673_1 in the cache */
/* replace680 -> replace679 in the cache */

   /* search681_0 -> search673_0 in the cache */

/* search681_1 -> search673_1 in the cache */

/* search681_2 -> search673_2 in the cache */
/* search681 -> search673 in the cache */

   /* replace681_0_0 -> search26_1 in the cache */

/* replace681_0_1 -> search673_2 in the cache */
static const nir_search_expression replace681_0 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &search26_1.value, &search673_2.value },
   NULL,
};

/* replace681_1 -> search26_1 in the cache */

/* replace681_2_0_0 -> search673_0 in the cache */

/* replace681_2_0_1_0_0 -> replace104_0_1 in the cache */

/* replace681_2_0_1_0_1 -> search673_2 in the cache */
static const nir_search_expression replace681_2_0_1_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_isub,
   { &replace104_0_1.value, &search673_2.value },
   NULL,
};

/* replace681_2_0_1_1 -> search673_1 in the cache */
static const nir_search_expression replace681_2_0_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_isub,
   { &replace681_2_0_1_0.value, &search673_1.value },
   NULL,
};
static const nir_search_expression replace681_2_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_ishl,
   { &search673_0.value, &replace681_2_0_1.value },
   NULL,
};

/* replace681_2_1_0 -> replace104_0_1 in the cache */

/* replace681_2_1_1 -> search673_2 in the cache */
/* replace681_2_1 -> replace681_2_0_1_0 in the cache */
static const nir_search_expression replace681_2 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_ishr,
   { &replace681_2_0.value, &replace681_2_0_1_0.value },
   NULL,
};
static const nir_search_expression replace681 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_op_bcsel,
   { &replace681_0.value, &search26_1.value, &replace681_2.value },
   NULL,
};

   /* search682_0 -> search673_0 in the cache */

/* search682_1 -> search673_1 in the cache */

/* search682_2 -> search673_2 in the cache */
/* search682 -> search674 in the cache */

   /* replace682_0_0 -> search673_0 in the cache */

/* replace682_0_1 -> search673_1 in the cache */
static const nir_search_expression replace682_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_ushr,
   { &search673_0.value, &search673_1.value },
   NULL,
};

/* replace682_1_0_0 -> search673_2 in the cache */

/* replace682_1_0_1 -> replace104_0_1 in the cache */
static const nir_search_expression replace682_1_0 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ieq,
   { &search673_2.value, &replace104_0_1.value },
   NULL,
};

/* replace682_1_1 -> replace104_0_0_0_1 in the cache */

/* replace682_1_2_0_0 -> replace579_1 in the cache */

/* replace682_1_2_0_1 -> search673_2 in the cache */
static const nir_search_expression replace682_1_2_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_ishl,
   { &replace579_1.value, &search673_2.value },
   NULL,
};

/* replace682_1_2_1 -> replace579_1 in the cache */
static const nir_search_expression replace682_1_2 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_isub,
   { &replace682_1_2_0.value, &replace579_1.value },
   NULL,
};
static const nir_search_expression replace682_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_op_bcsel,
   { &replace682_1_0.value, &replace104_0_0_0_1.value, &replace682_1_2.value },
   NULL,
};
static const nir_search_expression replace682 = {
   { nir_search_value_expression, 32 },
   false,
   0, 2,
   nir_op_iand,
   { &replace682_0.value, &replace682_1.value },
   NULL,
};

   /* search683_0 -> search673_0 in the cache */
static const nir_search_expression search683 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_ifind_msb,
   { &search673_0.value },
   NULL,
};

   /* replace683_0_0_0 -> search673_0 in the cache */

/* replace683_0_0_1 -> search26_1 in the cache */
static const nir_search_expression replace683_0_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search673_0.value, &search26_1.value },
   NULL,
};

/* replace683_0_1_0 -> search673_0 in the cache */
static const nir_search_expression replace683_0_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_inot,
   { &search673_0.value },
   NULL,
};

/* replace683_0_2 -> search673_0 in the cache */
static const nir_search_expression replace683_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace683_0_0.value, &replace683_0_1.value, &search673_0.value },
   NULL,
};
static const nir_search_expression replace683 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_ufind_msb,
   { &replace683_0.value },
   NULL,
};

   static const nir_search_variable search684_0 = {
   { nir_search_value_variable, -1 },
   0, /* value */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search684 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_find_lsb,
   { &search684_0.value },
   NULL,
};

   /* replace684_0_0 -> search684_0 in the cache */

/* replace684_0_1_0 -> search684_0 in the cache */
static const nir_search_expression replace684_0_1 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_ineg,
   { &search684_0.value },
   NULL,
};
static const nir_search_expression replace684_0 = {
   { nir_search_value_expression, -1 },
   false,
   0, 1,
   nir_op_iand,
   { &search684_0.value, &replace684_0_1.value },
   NULL,
};
static const nir_search_expression replace684 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_op_ufind_msb,
   { &replace684_0.value },
   NULL,
};

   /* search685_0 -> search0_0 in the cache */

/* search685_1 -> replace0_1_0 in the cache */
static const nir_search_expression search685 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_extract_i8,
   { &search0_0.value, &replace0_1_0.value },
   NULL,
};

   /* replace685_0_0 -> search0_0 in the cache */

/* replace685_0_1_0_0 -> replace566_1 in the cache */

/* replace685_0_1_0_1 -> replace0_1_0 in the cache */
static const nir_search_expression replace685_0_1_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_isub,
   { &replace566_1.value, &replace0_1_0.value },
   NULL,
};

/* replace685_0_1_1 -> replace98_0_1 in the cache */
static const nir_search_expression replace685_0_1 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_imul,
   { &replace685_0_1_0.value, &replace98_0_1.value },
   NULL,
};
static const nir_search_expression replace685_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_op_ishl,
   { &search0_0.value, &replace685_0_1.value },
   NULL,
};

/* replace685_1 -> search441_1_1 in the cache */
static const nir_search_expression replace685 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_op_ishr,
   { &replace685_0.value, &search441_1_1.value },
   NULL,
};

   /* search686_0 -> search0_0 in the cache */

/* search686_1 -> replace0_1_0 in the cache */
static const nir_search_expression search686 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_extract_u8,
   { &search0_0.value, &replace0_1_0.value },
   NULL,
};

   /* replace686_0_0 -> search0_0 in the cache */

/* replace686_0_1_0 -> replace0_1_0 in the cache */

/* replace686_0_1_1 -> replace98_0_1 in the cache */
static const nir_search_expression replace686_0_1 = {
   { nir_search_value_expression, 32 },
   false,
   1, 1,
   nir_op_imul,
   { &replace0_1_0.value, &replace98_0_1.value },
   NULL,
};
static const nir_search_expression replace686_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_op_ushr,
   { &search0_0.value, &replace686_0_1.value },
   NULL,
};

/* replace686_1 -> replace98_0_0_0_1 in the cache */
static const nir_search_expression replace686 = {
   { nir_search_value_expression, 32 },
   false,
   0, 2,
   nir_op_iand,
   { &replace686_0.value, &replace98_0_0_0_1.value },
   NULL,
};

   /* search687_0 -> search0_0 in the cache */

/* search687_1 -> replace0_1_0 in the cache */
static const nir_search_expression search687 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_extract_i16,
   { &search0_0.value, &replace0_1_0.value },
   NULL,
};

   /* replace687_0_0 -> search0_0 in the cache */

/* replace687_0_1_0_0 -> replace579_1 in the cache */

/* replace687_0_1_0_1 -> replace0_1_0 in the cache */
static const nir_search_expression replace687_0_1_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_isub,
   { &replace579_1.value, &replace0_1_0.value },
   NULL,
};

/* replace687_0_1_1 -> replace101_0_1 in the cache */
static const nir_search_expression replace687_0_1 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_imul,
   { &replace687_0_1_0.value, &replace101_0_1.value },
   NULL,
};
static const nir_search_expression replace687_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_op_ishl,
   { &search0_0.value, &replace687_0_1.value },
   NULL,
};

/* replace687_1 -> replace101_0_1 in the cache */
static const nir_search_expression replace687 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_op_ishr,
   { &replace687_0.value, &replace101_0_1.value },
   NULL,
};

   /* search688_0 -> search0_0 in the cache */

/* search688_1 -> replace0_1_0 in the cache */
static const nir_search_expression search688 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_extract_u16,
   { &search0_0.value, &replace0_1_0.value },
   NULL,
};

   /* replace688_0_0 -> search0_0 in the cache */

/* replace688_0_1_0 -> replace0_1_0 in the cache */

/* replace688_0_1_1 -> replace101_0_1 in the cache */
static const nir_search_expression replace688_0_1 = {
   { nir_search_value_expression, 32 },
   false,
   1, 1,
   nir_op_imul,
   { &replace0_1_0.value, &replace101_0_1.value },
   NULL,
};
static const nir_search_expression replace688_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_op_ushr,
   { &search0_0.value, &replace688_0_1.value },
   NULL,
};

/* replace688_1 -> replace101_0_0_0_1 in the cache */
static const nir_search_expression replace688 = {
   { nir_search_value_expression, 32 },
   false,
   0, 2,
   nir_op_iand,
   { &replace688_0.value, &replace101_0_0_0_1.value },
   NULL,
};

   static const nir_search_variable search689_0 = {
   { nir_search_value_variable, 32 },
   0, /* v */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search689 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_pack_unorm_2x16,
   { &search689_0.value },
   NULL,
};

   /* replace689_0_0_0_0_0 -> search689_0 in the cache */
static const nir_search_expression replace689_0_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_fsat,
   { &search689_0.value },
   NULL,
};

static const nir_search_constant replace689_0_0_0_1 = {
   { nir_search_value_constant, 32 },
   nir_type_float, { 0x40efffe000000000 /* 65535.0 */ },
};
static const nir_search_expression replace689_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_fmul,
   { &replace689_0_0_0_0.value, &replace689_0_0_0_1.value },
   NULL,
};
static const nir_search_expression replace689_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_op_fround_even,
   { &replace689_0_0_0.value },
   NULL,
};
static const nir_search_expression replace689_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_op_f2u32,
   { &replace689_0_0.value },
   NULL,
};
static const nir_search_expression replace689 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_op_pack_uvec2_to_uint,
   { &replace689_0.value },
   NULL,
};

   /* search690_0 -> search689_0 in the cache */
static const nir_search_expression search690 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_pack_unorm_4x8,
   { &search689_0.value },
   NULL,
};

   /* replace690_0_0_0_0_0 -> search689_0 in the cache */
/* replace690_0_0_0_0 -> replace689_0_0_0_0 in the cache */

static const nir_search_constant replace690_0_0_0_1 = {
   { nir_search_value_constant, 32 },
   nir_type_float, { 0x406fe00000000000 /* 255.0 */ },
};
static const nir_search_expression replace690_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_fmul,
   { &replace689_0_0_0_0.value, &replace690_0_0_0_1.value },
   NULL,
};
static const nir_search_expression replace690_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_op_fround_even,
   { &replace690_0_0_0.value },
   NULL,
};
static const nir_search_expression replace690_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_op_f2u32,
   { &replace690_0_0.value },
   NULL,
};
static const nir_search_expression replace690 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_op_pack_uvec4_to_uint,
   { &replace690_0.value },
   NULL,
};

   /* search691_0 -> search689_0 in the cache */
static const nir_search_expression search691 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_pack_snorm_2x16,
   { &search689_0.value },
   NULL,
};

   /* replace691_0_0_0_0_0 -> replace60_0_0 in the cache */

/* replace691_0_0_0_0_1_0 -> search495_1 in the cache */

/* replace691_0_0_0_0_1_1 -> search689_0 in the cache */
static const nir_search_expression replace691_0_0_0_0_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_fmax,
   { &search495_1.value, &search689_0.value },
   NULL,
};
static const nir_search_expression replace691_0_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_fmin,
   { &replace60_0_0.value, &replace691_0_0_0_0_1.value },
   NULL,
};

static const nir_search_constant replace691_0_0_0_1 = {
   { nir_search_value_constant, 32 },
   nir_type_float, { 0x40dfffc000000000 /* 32767.0 */ },
};
static const nir_search_expression replace691_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_fmul,
   { &replace691_0_0_0_0.value, &replace691_0_0_0_1.value },
   NULL,
};
static const nir_search_expression replace691_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_op_fround_even,
   { &replace691_0_0_0.value },
   NULL,
};
static const nir_search_expression replace691_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_op_f2i32,
   { &replace691_0_0.value },
   NULL,
};
static const nir_search_expression replace691 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_op_pack_uvec2_to_uint,
   { &replace691_0.value },
   NULL,
};

   /* search692_0 -> search689_0 in the cache */
static const nir_search_expression search692 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_pack_snorm_4x8,
   { &search689_0.value },
   NULL,
};

   /* replace692_0_0_0_0_0 -> replace60_0_0 in the cache */

/* replace692_0_0_0_0_1_0 -> search495_1 in the cache */

/* replace692_0_0_0_0_1_1 -> search689_0 in the cache */
/* replace692_0_0_0_0_1 -> replace691_0_0_0_0_1 in the cache */
/* replace692_0_0_0_0 -> replace691_0_0_0_0 in the cache */

static const nir_search_constant replace692_0_0_0_1 = {
   { nir_search_value_constant, 32 },
   nir_type_float, { 0x405fc00000000000 /* 127.0 */ },
};
static const nir_search_expression replace692_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_fmul,
   { &replace691_0_0_0_0.value, &replace692_0_0_0_1.value },
   NULL,
};
static const nir_search_expression replace692_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_op_fround_even,
   { &replace692_0_0_0.value },
   NULL,
};
static const nir_search_expression replace692_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_op_f2i32,
   { &replace692_0_0.value },
   NULL,
};
static const nir_search_expression replace692 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_op_pack_uvec4_to_uint,
   { &replace692_0.value },
   NULL,
};

   /* search693_0 -> search689_0 in the cache */
static const nir_search_expression search693 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_unpack_unorm_2x16,
   { &search689_0.value },
   NULL,
};

   /* replace693_0_0_0_0 -> search689_0 in the cache */

/* replace693_0_0_0_1 -> search26_1 in the cache */
static const nir_search_expression replace693_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_extract_u16,
   { &search689_0.value, &search26_1.value },
   NULL,
};

/* replace693_0_0_1_0 -> search689_0 in the cache */

/* replace693_0_0_1_1 -> replace579_1 in the cache */
static const nir_search_expression replace693_0_0_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_extract_u16,
   { &search689_0.value, &replace579_1.value },
   NULL,
};
static const nir_search_expression replace693_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_vec2,
   { &replace693_0_0_0.value, &replace693_0_0_1.value },
   NULL,
};
static const nir_search_expression replace693_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_u2f32,
   { &replace693_0_0.value },
   NULL,
};

/* replace693_1 -> replace689_0_0_0_1 in the cache */
static const nir_search_expression replace693 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_fdiv,
   { &replace693_0.value, &replace689_0_0_0_1.value },
   NULL,
};

   /* search694_0 -> search689_0 in the cache */
static const nir_search_expression search694 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_unpack_unorm_4x8,
   { &search689_0.value },
   NULL,
};

   /* replace694_0_0_0_0 -> search689_0 in the cache */

/* replace694_0_0_0_1 -> search26_1 in the cache */
static const nir_search_expression replace694_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_extract_u8,
   { &search689_0.value, &search26_1.value },
   NULL,
};

/* replace694_0_0_1_0 -> search689_0 in the cache */

/* replace694_0_0_1_1 -> replace579_1 in the cache */
static const nir_search_expression replace694_0_0_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_extract_u8,
   { &search689_0.value, &replace579_1.value },
   NULL,
};

/* replace694_0_0_2_0 -> search689_0 in the cache */

/* replace694_0_0_2_1 -> replace580_1 in the cache */
static const nir_search_expression replace694_0_0_2 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_extract_u8,
   { &search689_0.value, &replace580_1.value },
   NULL,
};

/* replace694_0_0_3_0 -> search689_0 in the cache */

/* replace694_0_0_3_1 -> replace566_1 in the cache */
static const nir_search_expression replace694_0_0_3 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_extract_u8,
   { &search689_0.value, &replace566_1.value },
   NULL,
};
static const nir_search_expression replace694_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_vec4,
   { &replace694_0_0_0.value, &replace694_0_0_1.value, &replace694_0_0_2.value, &replace694_0_0_3.value },
   NULL,
};
static const nir_search_expression replace694_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_u2f32,
   { &replace694_0_0.value },
   NULL,
};

/* replace694_1 -> replace690_0_0_0_1 in the cache */
static const nir_search_expression replace694 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_fdiv,
   { &replace694_0.value, &replace690_0_0_0_1.value },
   NULL,
};

   /* search695_0 -> search689_0 in the cache */
static const nir_search_expression search695 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_unpack_snorm_2x16,
   { &search689_0.value },
   NULL,
};

   /* replace695_0 -> replace60_0_0 in the cache */

/* replace695_1_0 -> search495_1 in the cache */

/* replace695_1_1_0_0_0_0 -> search689_0 in the cache */

/* replace695_1_1_0_0_0_1 -> search26_1 in the cache */
static const nir_search_expression replace695_1_1_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_extract_i16,
   { &search689_0.value, &search26_1.value },
   NULL,
};

/* replace695_1_1_0_0_1_0 -> search689_0 in the cache */

/* replace695_1_1_0_0_1_1 -> replace579_1 in the cache */
static const nir_search_expression replace695_1_1_0_0_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_extract_i16,
   { &search689_0.value, &replace579_1.value },
   NULL,
};
static const nir_search_expression replace695_1_1_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_vec2,
   { &replace695_1_1_0_0_0.value, &replace695_1_1_0_0_1.value },
   NULL,
};
static const nir_search_expression replace695_1_1_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_search_op_i2f,
   { &replace695_1_1_0_0.value },
   NULL,
};

/* replace695_1_1_1 -> replace691_0_0_0_1 in the cache */
static const nir_search_expression replace695_1_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_fdiv,
   { &replace695_1_1_0.value, &replace691_0_0_0_1.value },
   NULL,
};
static const nir_search_expression replace695_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_fmax,
   { &search495_1.value, &replace695_1_1.value },
   NULL,
};
static const nir_search_expression replace695 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_fmin,
   { &replace60_0_0.value, &replace695_1.value },
   NULL,
};

   /* search696_0 -> search689_0 in the cache */
static const nir_search_expression search696 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_unpack_snorm_4x8,
   { &search689_0.value },
   NULL,
};

   /* replace696_0 -> replace60_0_0 in the cache */

/* replace696_1_0 -> search495_1 in the cache */

/* replace696_1_1_0_0_0_0 -> search689_0 in the cache */

/* replace696_1_1_0_0_0_1 -> search26_1 in the cache */
static const nir_search_expression replace696_1_1_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_extract_i8,
   { &search689_0.value, &search26_1.value },
   NULL,
};

/* replace696_1_1_0_0_1_0 -> search689_0 in the cache */

/* replace696_1_1_0_0_1_1 -> replace579_1 in the cache */
static const nir_search_expression replace696_1_1_0_0_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_extract_i8,
   { &search689_0.value, &replace579_1.value },
   NULL,
};

/* replace696_1_1_0_0_2_0 -> search689_0 in the cache */

/* replace696_1_1_0_0_2_1 -> replace580_1 in the cache */
static const nir_search_expression replace696_1_1_0_0_2 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_extract_i8,
   { &search689_0.value, &replace580_1.value },
   NULL,
};

/* replace696_1_1_0_0_3_0 -> search689_0 in the cache */

/* replace696_1_1_0_0_3_1 -> replace566_1 in the cache */
static const nir_search_expression replace696_1_1_0_0_3 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_extract_i8,
   { &search689_0.value, &replace566_1.value },
   NULL,
};
static const nir_search_expression replace696_1_1_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_vec4,
   { &replace696_1_1_0_0_0.value, &replace696_1_1_0_0_1.value, &replace696_1_1_0_0_2.value, &replace696_1_1_0_0_3.value },
   NULL,
};
static const nir_search_expression replace696_1_1_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_search_op_i2f,
   { &replace696_1_1_0_0.value },
   NULL,
};

/* replace696_1_1_1 -> replace692_0_0_0_1 in the cache */
static const nir_search_expression replace696_1_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_fdiv,
   { &replace696_1_1_0.value, &replace692_0_0_0_1.value },
   NULL,
};
static const nir_search_expression replace696_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_fmax,
   { &search495_1.value, &replace696_1_1.value },
   NULL,
};
static const nir_search_expression replace696 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_fmin,
   { &replace60_0_0.value, &replace696_1.value },
   NULL,
};

   /* search697_0 -> search2_0 in the cache */
static const nir_search_expression search697 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_isign,
   { &search2_0.value },
   NULL,
};

   /* replace697_0_0 -> search2_0 in the cache */

/* replace697_0_1 -> search44_1 in the cache */
static const nir_search_expression replace697_0 = {
   { nir_search_value_expression, -1 },
   false,
   1, 1,
   nir_op_imax,
   { &search2_0.value, &search44_1.value },
   NULL,
};

/* replace697_1 -> replace2_1_0 in the cache */
static const nir_search_expression replace697 = {
   { nir_search_value_expression, -1 },
   false,
   0, 2,
   nir_op_imin,
   { &replace697_0.value, &replace2_1_0.value },
   NULL,
};

   /* search698_0 -> search2_0 in the cache */
/* search698 -> search45_0 in the cache */

   /* replace698_0_0_0 -> search24_1 in the cache */

/* replace698_0_0_1 -> search2_0 in the cache */
/* replace698_0_0 -> replace145 in the cache */
/* replace698_0 -> replace267 in the cache */

/* replace698_1_0_0 -> search2_0 in the cache */

/* replace698_1_0_1 -> search24_1 in the cache */
/* replace698_1_0 -> replace65_0 in the cache */
static const nir_search_expression replace698_1 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_search_op_b2f,
   { &replace65_0.value },
   NULL,
};
static const nir_search_expression replace698 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fsub,
   { &replace267.value, &replace698_1.value },
   NULL,
};

   /* search699_0 -> search98_0_0 in the cache */

static const nir_search_variable search699_1 = {
   { nir_search_value_variable, 8 },
   1, /* b */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search699 = {
   { nir_search_value_expression, 8 },
   false,
   0, 1,
   nir_op_iadd_sat,
   { &search98_0_0.value, &search699_1.value },
   NULL,
};

   /* replace699_0_0 -> search699_1 in the cache */

static const nir_search_constant replace699_0_1 = {
   { nir_search_value_constant, 8 },
   nir_type_int, { 0x1 /* 1 */ },
};
static const nir_search_expression replace699_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search699_1.value, &replace699_0_1.value },
   NULL,
};

/* replace699_1_0_0_0 -> search98_0_0 in the cache */

/* replace699_1_0_0_1 -> search699_1 in the cache */
static const nir_search_expression replace699_1_0_0 = {
   { nir_search_value_expression, 8 },
   false,
   0, 1,
   nir_op_iadd,
   { &search98_0_0.value, &search699_1.value },
   NULL,
};

/* replace699_1_0_1 -> search98_0_0 in the cache */
static const nir_search_expression replace699_1_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_ilt,
   { &replace699_1_0_0.value, &search98_0_0.value },
   NULL,
};

static const nir_search_constant replace699_1_1 = {
   { nir_search_value_constant, 8 },
   nir_type_int, { 0x7f /* 127 */ },
};

/* replace699_1_2_0 -> search98_0_0 in the cache */

/* replace699_1_2_1 -> search699_1 in the cache */
static const nir_search_expression replace699_1_2 = {
   { nir_search_value_expression, 8 },
   false,
   1, 1,
   nir_op_iadd,
   { &search98_0_0.value, &search699_1.value },
   NULL,
};
static const nir_search_expression replace699_1 = {
   { nir_search_value_expression, 8 },
   false,
   -1, 2,
   nir_op_bcsel,
   { &replace699_1_0.value, &replace699_1_1.value, &replace699_1_2.value },
   NULL,
};

/* replace699_2_0_0 -> search98_0_0 in the cache */

/* replace699_2_0_1_0 -> search98_0_0 in the cache */

/* replace699_2_0_1_1 -> search699_1 in the cache */
static const nir_search_expression replace699_2_0_1 = {
   { nir_search_value_expression, 8 },
   false,
   2, 1,
   nir_op_iadd,
   { &search98_0_0.value, &search699_1.value },
   NULL,
};
static const nir_search_expression replace699_2_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_ilt,
   { &search98_0_0.value, &replace699_2_0_1.value },
   NULL,
};

static const nir_search_constant replace699_2_1 = {
   { nir_search_value_constant, 8 },
   nir_type_int, { 0x80 /* 128 */ },
};

/* replace699_2_2_0 -> search98_0_0 in the cache */

/* replace699_2_2_1 -> search699_1 in the cache */
static const nir_search_expression replace699_2_2 = {
   { nir_search_value_expression, 8 },
   false,
   3, 1,
   nir_op_iadd,
   { &search98_0_0.value, &search699_1.value },
   NULL,
};
static const nir_search_expression replace699_2 = {
   { nir_search_value_expression, 8 },
   false,
   -1, 2,
   nir_op_bcsel,
   { &replace699_2_0.value, &replace699_2_1.value, &replace699_2_2.value },
   NULL,
};
static const nir_search_expression replace699 = {
   { nir_search_value_expression, 8 },
   false,
   -1, 4,
   nir_op_bcsel,
   { &replace699_0.value, &replace699_1.value, &replace699_2.value },
   NULL,
};

   /* search700_0 -> search98_0_0 in the cache */

/* search700_1 -> search699_1 in the cache */
static const nir_search_expression search700 = {
   { nir_search_value_expression, 8 },
   false,
   -1, 0,
   nir_op_isub_sat,
   { &search98_0_0.value, &search699_1.value },
   NULL,
};

   /* replace700_0_0 -> search699_1 in the cache */

/* replace700_0_1 -> replace98_2 in the cache */
static const nir_search_expression replace700_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search699_1.value, &replace98_2.value },
   NULL,
};

/* replace700_1_0_0_0 -> search98_0_0 in the cache */

/* replace700_1_0_0_1 -> search699_1 in the cache */
static const nir_search_expression replace700_1_0_0 = {
   { nir_search_value_expression, 8 },
   false,
   -1, 0,
   nir_op_isub,
   { &search98_0_0.value, &search699_1.value },
   NULL,
};

/* replace700_1_0_1 -> search98_0_0 in the cache */
static const nir_search_expression replace700_1_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &replace700_1_0_0.value, &search98_0_0.value },
   NULL,
};

/* replace700_1_1 -> replace699_1_1 in the cache */

/* replace700_1_2_0 -> search98_0_0 in the cache */

/* replace700_1_2_1 -> search699_1 in the cache */
/* replace700_1_2 -> replace700_1_0_0 in the cache */
static const nir_search_expression replace700_1 = {
   { nir_search_value_expression, 8 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace700_1_0.value, &replace699_1_1.value, &replace700_1_0_0.value },
   NULL,
};

/* replace700_2_0_0 -> search98_0_0 in the cache */

/* replace700_2_0_1_0 -> search98_0_0 in the cache */

/* replace700_2_0_1_1 -> search699_1 in the cache */
/* replace700_2_0_1 -> replace700_1_0_0 in the cache */
static const nir_search_expression replace700_2_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search98_0_0.value, &replace700_1_0_0.value },
   NULL,
};

/* replace700_2_1 -> replace699_2_1 in the cache */

/* replace700_2_2_0 -> search98_0_0 in the cache */

/* replace700_2_2_1 -> search699_1 in the cache */
/* replace700_2_2 -> replace700_1_0_0 in the cache */
static const nir_search_expression replace700_2 = {
   { nir_search_value_expression, 8 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace700_2_0.value, &replace699_2_1.value, &replace700_1_0_0.value },
   NULL,
};
static const nir_search_expression replace700 = {
   { nir_search_value_expression, 8 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace700_0.value, &replace700_1.value, &replace700_2.value },
   NULL,
};

   /* search701_0 -> search101_0_0 in the cache */

/* search701_1 -> replace564_1_0 in the cache */
static const nir_search_expression search701 = {
   { nir_search_value_expression, 16 },
   false,
   0, 1,
   nir_op_iadd_sat,
   { &search101_0_0.value, &replace564_1_0.value },
   NULL,
};

   /* replace701_0_0 -> replace564_1_0 in the cache */

/* replace701_0_1 -> replace565_1 in the cache */
static const nir_search_expression replace701_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &replace564_1_0.value, &replace565_1.value },
   NULL,
};

/* replace701_1_0_0_0 -> search101_0_0 in the cache */

/* replace701_1_0_0_1 -> replace564_1_0 in the cache */
static const nir_search_expression replace701_1_0_0 = {
   { nir_search_value_expression, 16 },
   false,
   0, 1,
   nir_op_iadd,
   { &search101_0_0.value, &replace564_1_0.value },
   NULL,
};

/* replace701_1_0_1 -> search101_0_0 in the cache */
static const nir_search_expression replace701_1_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_ilt,
   { &replace701_1_0_0.value, &search101_0_0.value },
   NULL,
};

static const nir_search_constant replace701_1_1 = {
   { nir_search_value_constant, 16 },
   nir_type_int, { 0x7fff /* 32767 */ },
};

/* replace701_1_2_0 -> search101_0_0 in the cache */

/* replace701_1_2_1 -> replace564_1_0 in the cache */
static const nir_search_expression replace701_1_2 = {
   { nir_search_value_expression, 16 },
   false,
   1, 1,
   nir_op_iadd,
   { &search101_0_0.value, &replace564_1_0.value },
   NULL,
};
static const nir_search_expression replace701_1 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 2,
   nir_op_bcsel,
   { &replace701_1_0.value, &replace701_1_1.value, &replace701_1_2.value },
   NULL,
};

/* replace701_2_0_0 -> search101_0_0 in the cache */

/* replace701_2_0_1_0 -> search101_0_0 in the cache */

/* replace701_2_0_1_1 -> replace564_1_0 in the cache */
static const nir_search_expression replace701_2_0_1 = {
   { nir_search_value_expression, 16 },
   false,
   2, 1,
   nir_op_iadd,
   { &search101_0_0.value, &replace564_1_0.value },
   NULL,
};
static const nir_search_expression replace701_2_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_ilt,
   { &search101_0_0.value, &replace701_2_0_1.value },
   NULL,
};

static const nir_search_constant replace701_2_1 = {
   { nir_search_value_constant, 16 },
   nir_type_int, { 0x8000 /* 32768 */ },
};

/* replace701_2_2_0 -> search101_0_0 in the cache */

/* replace701_2_2_1 -> replace564_1_0 in the cache */
static const nir_search_expression replace701_2_2 = {
   { nir_search_value_expression, 16 },
   false,
   3, 1,
   nir_op_iadd,
   { &search101_0_0.value, &replace564_1_0.value },
   NULL,
};
static const nir_search_expression replace701_2 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 2,
   nir_op_bcsel,
   { &replace701_2_0.value, &replace701_2_1.value, &replace701_2_2.value },
   NULL,
};
static const nir_search_expression replace701 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 4,
   nir_op_bcsel,
   { &replace701_0.value, &replace701_1.value, &replace701_2.value },
   NULL,
};

   /* search702_0 -> search101_0_0 in the cache */

/* search702_1 -> replace564_1_0 in the cache */
static const nir_search_expression search702 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_isub_sat,
   { &search101_0_0.value, &replace564_1_0.value },
   NULL,
};

   /* replace702_0_0 -> replace564_1_0 in the cache */

/* replace702_0_1 -> replace101_2 in the cache */
static const nir_search_expression replace702_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &replace564_1_0.value, &replace101_2.value },
   NULL,
};

/* replace702_1_0_0_0 -> search101_0_0 in the cache */

/* replace702_1_0_0_1 -> replace564_1_0 in the cache */
static const nir_search_expression replace702_1_0_0 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_isub,
   { &search101_0_0.value, &replace564_1_0.value },
   NULL,
};

/* replace702_1_0_1 -> search101_0_0 in the cache */
static const nir_search_expression replace702_1_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &replace702_1_0_0.value, &search101_0_0.value },
   NULL,
};

/* replace702_1_1 -> replace701_1_1 in the cache */

/* replace702_1_2_0 -> search101_0_0 in the cache */

/* replace702_1_2_1 -> replace564_1_0 in the cache */
/* replace702_1_2 -> replace702_1_0_0 in the cache */
static const nir_search_expression replace702_1 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace702_1_0.value, &replace701_1_1.value, &replace702_1_0_0.value },
   NULL,
};

/* replace702_2_0_0 -> search101_0_0 in the cache */

/* replace702_2_0_1_0 -> search101_0_0 in the cache */

/* replace702_2_0_1_1 -> replace564_1_0 in the cache */
/* replace702_2_0_1 -> replace702_1_0_0 in the cache */
static const nir_search_expression replace702_2_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search101_0_0.value, &replace702_1_0_0.value },
   NULL,
};

/* replace702_2_1 -> replace701_2_1 in the cache */

/* replace702_2_2_0 -> search101_0_0 in the cache */

/* replace702_2_2_1 -> replace564_1_0 in the cache */
/* replace702_2_2 -> replace702_1_0_0 in the cache */
static const nir_search_expression replace702_2 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace702_2_0.value, &replace701_2_1.value, &replace702_1_0_0.value },
   NULL,
};
static const nir_search_expression replace702 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace702_0.value, &replace702_1.value, &replace702_2.value },
   NULL,
};

   /* search703_0 -> search0_0 in the cache */

/* search703_1 -> replace0_1_0 in the cache */
static const nir_search_expression search703 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_iadd_sat,
   { &search0_0.value, &replace0_1_0.value },
   NULL,
};

   /* replace703_0_0 -> replace0_1_0 in the cache */

/* replace703_0_1 -> replace579_1 in the cache */
static const nir_search_expression replace703_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &replace0_1_0.value, &replace579_1.value },
   NULL,
};

/* replace703_1_0_0_0 -> search0_0 in the cache */

/* replace703_1_0_0_1 -> replace0_1_0 in the cache */
/* replace703_1_0_0 -> replace662_0_0 in the cache */

/* replace703_1_0_1 -> search0_0 in the cache */
static const nir_search_expression replace703_1_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_ilt,
   { &replace662_0_0.value, &search0_0.value },
   NULL,
};

static const nir_search_constant replace703_1_1 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { 0x7fffffff /* 2147483647 */ },
};

/* replace703_1_2_0 -> search0_0 in the cache */

/* replace703_1_2_1 -> replace0_1_0 in the cache */
static const nir_search_expression replace703_1_2 = {
   { nir_search_value_expression, 32 },
   false,
   1, 1,
   nir_op_iadd,
   { &search0_0.value, &replace0_1_0.value },
   NULL,
};
static const nir_search_expression replace703_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 2,
   nir_op_bcsel,
   { &replace703_1_0.value, &replace703_1_1.value, &replace703_1_2.value },
   NULL,
};

/* replace703_2_0_0 -> search0_0 in the cache */

/* replace703_2_0_1_0 -> search0_0 in the cache */

/* replace703_2_0_1_1 -> replace0_1_0 in the cache */
static const nir_search_expression replace703_2_0_1 = {
   { nir_search_value_expression, 32 },
   false,
   2, 1,
   nir_op_iadd,
   { &search0_0.value, &replace0_1_0.value },
   NULL,
};
static const nir_search_expression replace703_2_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_ilt,
   { &search0_0.value, &replace703_2_0_1.value },
   NULL,
};

/* replace703_2_1 -> replace323_1_1 in the cache */

/* replace703_2_2_0 -> search0_0 in the cache */

/* replace703_2_2_1 -> replace0_1_0 in the cache */
static const nir_search_expression replace703_2_2 = {
   { nir_search_value_expression, 32 },
   false,
   3, 1,
   nir_op_iadd,
   { &search0_0.value, &replace0_1_0.value },
   NULL,
};
static const nir_search_expression replace703_2 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 2,
   nir_op_bcsel,
   { &replace703_2_0.value, &replace323_1_1.value, &replace703_2_2.value },
   NULL,
};
static const nir_search_expression replace703 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 4,
   nir_op_bcsel,
   { &replace703_0.value, &replace703_1.value, &replace703_2.value },
   NULL,
};

   /* search704_0 -> search0_0 in the cache */

/* search704_1 -> replace0_1_0 in the cache */
static const nir_search_expression search704 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_isub_sat,
   { &search0_0.value, &replace0_1_0.value },
   NULL,
};

   /* replace704_0_0 -> replace0_1_0 in the cache */

/* replace704_0_1 -> search26_1 in the cache */
static const nir_search_expression replace704_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &replace0_1_0.value, &search26_1.value },
   NULL,
};

/* replace704_1_0_0_0 -> search0_0 in the cache */

/* replace704_1_0_0_1 -> replace0_1_0 in the cache */
static const nir_search_expression replace704_1_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_isub,
   { &search0_0.value, &replace0_1_0.value },
   NULL,
};

/* replace704_1_0_1 -> search0_0 in the cache */
static const nir_search_expression replace704_1_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &replace704_1_0_0.value, &search0_0.value },
   NULL,
};

/* replace704_1_1 -> replace703_1_1 in the cache */

/* replace704_1_2_0 -> search0_0 in the cache */

/* replace704_1_2_1 -> replace0_1_0 in the cache */
/* replace704_1_2 -> replace704_1_0_0 in the cache */
static const nir_search_expression replace704_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace704_1_0.value, &replace703_1_1.value, &replace704_1_0_0.value },
   NULL,
};

/* replace704_2_0_0 -> search0_0 in the cache */

/* replace704_2_0_1_0 -> search0_0 in the cache */

/* replace704_2_0_1_1 -> replace0_1_0 in the cache */
/* replace704_2_0_1 -> replace704_1_0_0 in the cache */
static const nir_search_expression replace704_2_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search0_0.value, &replace704_1_0_0.value },
   NULL,
};

/* replace704_2_1 -> replace323_1_1 in the cache */

/* replace704_2_2_0 -> search0_0 in the cache */

/* replace704_2_2_1 -> replace0_1_0 in the cache */
/* replace704_2_2 -> replace704_1_0_0 in the cache */
static const nir_search_expression replace704_2 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace704_2_0.value, &replace323_1_1.value, &replace704_1_0_0.value },
   NULL,
};
static const nir_search_expression replace704 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace704_0.value, &replace704_1.value, &replace704_2.value },
   NULL,
};

   /* search705_0 -> search57_0 in the cache */

/* search705_1 -> search57_1_1 in the cache */
static const nir_search_expression search705 = {
   { nir_search_value_expression, 64 },
   false,
   0, 1,
   nir_op_iadd_sat,
   { &search57_0.value, &search57_1_1.value },
   NULL,
};

   /* replace705_0_0 -> search57_1_1 in the cache */

/* replace705_0_1 -> replace582_1 in the cache */
static const nir_search_expression replace705_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search57_1_1.value, &replace582_1.value },
   NULL,
};

/* replace705_1_0_0_0 -> search57_0 in the cache */

/* replace705_1_0_0_1 -> search57_1_1 in the cache */
static const nir_search_expression replace705_1_0_0 = {
   { nir_search_value_expression, 64 },
   false,
   0, 1,
   nir_op_iadd,
   { &search57_0.value, &search57_1_1.value },
   NULL,
};

/* replace705_1_0_1 -> search57_0 in the cache */
static const nir_search_expression replace705_1_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_ilt,
   { &replace705_1_0_0.value, &search57_0.value },
   NULL,
};

static const nir_search_constant replace705_1_1 = {
   { nir_search_value_constant, 64 },
   nir_type_int, { 0x7fffffffffffffff /* 9223372036854775807 */ },
};

/* replace705_1_2_0 -> search57_0 in the cache */

/* replace705_1_2_1 -> search57_1_1 in the cache */
static const nir_search_expression replace705_1_2 = {
   { nir_search_value_expression, 64 },
   false,
   1, 1,
   nir_op_iadd,
   { &search57_0.value, &search57_1_1.value },
   NULL,
};
static const nir_search_expression replace705_1 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 2,
   nir_op_bcsel,
   { &replace705_1_0.value, &replace705_1_1.value, &replace705_1_2.value },
   NULL,
};

/* replace705_2_0_0 -> search57_0 in the cache */

/* replace705_2_0_1_0 -> search57_0 in the cache */

/* replace705_2_0_1_1 -> search57_1_1 in the cache */
static const nir_search_expression replace705_2_0_1 = {
   { nir_search_value_expression, 64 },
   false,
   2, 1,
   nir_op_iadd,
   { &search57_0.value, &search57_1_1.value },
   NULL,
};
static const nir_search_expression replace705_2_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_ilt,
   { &search57_0.value, &replace705_2_0_1.value },
   NULL,
};

static const nir_search_constant replace705_2_1 = {
   { nir_search_value_constant, 64 },
   nir_type_int, { 0x8000000000000000 /* 9223372036854775808 */ },
};

/* replace705_2_2_0 -> search57_0 in the cache */

/* replace705_2_2_1 -> search57_1_1 in the cache */
static const nir_search_expression replace705_2_2 = {
   { nir_search_value_expression, 64 },
   false,
   3, 1,
   nir_op_iadd,
   { &search57_0.value, &search57_1_1.value },
   NULL,
};
static const nir_search_expression replace705_2 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 2,
   nir_op_bcsel,
   { &replace705_2_0.value, &replace705_2_1.value, &replace705_2_2.value },
   NULL,
};
static const nir_search_expression replace705 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 4,
   nir_op_bcsel,
   { &replace705_0.value, &replace705_1.value, &replace705_2.value },
   NULL,
};

   /* search706_0 -> search57_0 in the cache */

/* search706_1 -> search57_1_1 in the cache */
static const nir_search_expression search706 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_isub_sat,
   { &search57_0.value, &search57_1_1.value },
   NULL,
};

   /* replace706_0_0 -> search57_1_1 in the cache */

/* replace706_0_1 -> replace107_2 in the cache */
static const nir_search_expression replace706_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search57_1_1.value, &replace107_2.value },
   NULL,
};

/* replace706_1_0_0_0 -> search57_0 in the cache */

/* replace706_1_0_0_1 -> search57_1_1 in the cache */
static const nir_search_expression replace706_1_0_0 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_isub,
   { &search57_0.value, &search57_1_1.value },
   NULL,
};

/* replace706_1_0_1 -> search57_0 in the cache */
static const nir_search_expression replace706_1_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &replace706_1_0_0.value, &search57_0.value },
   NULL,
};

/* replace706_1_1 -> replace705_1_1 in the cache */

/* replace706_1_2_0 -> search57_0 in the cache */

/* replace706_1_2_1 -> search57_1_1 in the cache */
/* replace706_1_2 -> replace706_1_0_0 in the cache */
static const nir_search_expression replace706_1 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace706_1_0.value, &replace705_1_1.value, &replace706_1_0_0.value },
   NULL,
};

/* replace706_2_0_0 -> search57_0 in the cache */

/* replace706_2_0_1_0 -> search57_0 in the cache */

/* replace706_2_0_1_1 -> search57_1_1 in the cache */
/* replace706_2_0_1 -> replace706_1_0_0 in the cache */
static const nir_search_expression replace706_2_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search57_0.value, &replace706_1_0_0.value },
   NULL,
};

/* replace706_2_1 -> replace705_2_1 in the cache */

/* replace706_2_2_0 -> search57_0 in the cache */

/* replace706_2_2_1 -> search57_1_1 in the cache */
/* replace706_2_2 -> replace706_1_0_0 in the cache */
static const nir_search_expression replace706_2 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace706_2_0.value, &replace705_2_1.value, &replace706_1_0_0.value },
   NULL,
};
static const nir_search_expression replace706 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace706_0.value, &replace706_1.value, &replace706_2.value },
   NULL,
};

   /* search707_0_0_0 -> search14_0 in the cache */

/* search707_0_0_1 -> replace14_1_0 in the cache */
/* search707_0_0 -> search121_0 in the cache */

/* search707_0_1_0 -> search62_1_1 in the cache */

/* search707_0_1_1 -> search62_2 in the cache */
static const nir_search_expression search707_0_1 = {
   { nir_search_value_expression, 1 },
   false,
   2, 1,
   nir_op_feq,
   { &search62_1_1.value, &search62_2.value },
   NULL,
};
static const nir_search_expression search707_0 = {
   { nir_search_value_expression, 1 },
   false,
   0, 3,
   nir_op_ior,
   { &search121_0.value, &search707_0_1.value },
   (is_used_once),
};
static const nir_search_expression search707 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 3,
   nir_op_inot,
   { &search707_0.value },
   NULL,
};

   /* replace707_0_0 -> search14_0 in the cache */

/* replace707_0_1 -> replace14_1_0 in the cache */
static const nir_search_expression replace707_0 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_fne,
   { &search14_0.value, &replace14_1_0.value },
   NULL,
};

/* replace707_1_0 -> search62_1_1 in the cache */

/* replace707_1_1 -> search62_2 in the cache */
static const nir_search_expression replace707_1 = {
   { nir_search_value_expression, 1 },
   false,
   2, 1,
   nir_op_fne,
   { &search62_1_1.value, &search62_2.value },
   NULL,
};
static const nir_search_expression replace707 = {
   { nir_search_value_expression, 1 },
   false,
   0, 3,
   nir_op_iand,
   { &replace707_0.value, &replace707_1.value },
   NULL,
};

   /* search708_0_0_0 -> search14_0 in the cache */

/* search708_0_0_1 -> replace14_1_0 in the cache */
/* search708_0_0 -> search121_0 in the cache */

/* search708_0_1_0 -> search62_1_1 in the cache */

/* search708_0_1_1 -> search62_2 in the cache */
/* search708_0_1 -> search707_0_1 in the cache */
static const nir_search_expression search708_0 = {
   { nir_search_value_expression, 1 },
   false,
   0, 3,
   nir_op_iand,
   { &search121_0.value, &search707_0_1.value },
   (is_used_once),
};
static const nir_search_expression search708 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 3,
   nir_op_inot,
   { &search708_0.value },
   NULL,
};

   /* replace708_0_0 -> search14_0 in the cache */

/* replace708_0_1 -> replace14_1_0 in the cache */
/* replace708_0 -> replace707_0 in the cache */

/* replace708_1_0 -> search62_1_1 in the cache */

/* replace708_1_1 -> search62_2 in the cache */
/* replace708_1 -> replace707_1 in the cache */
static const nir_search_expression replace708 = {
   { nir_search_value_expression, 1 },
   false,
   0, 3,
   nir_op_ior,
   { &replace707_0.value, &replace707_1.value },
   NULL,
};

   /* search709_0_0_0 -> search14_0 in the cache */

/* search709_0_0_1 -> replace14_1_0 in the cache */
/* search709_0_0 -> search121_0 in the cache */

/* search709_0_1_0 -> search62_1_1 in the cache */

/* search709_0_1_1 -> search62_2 in the cache */
/* search709_0_1 -> replace707_1 in the cache */
static const nir_search_expression search709_0 = {
   { nir_search_value_expression, 1 },
   false,
   0, 3,
   nir_op_ior,
   { &search121_0.value, &replace707_1.value },
   (is_used_once),
};
static const nir_search_expression search709 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 3,
   nir_op_inot,
   { &search709_0.value },
   NULL,
};

   /* replace709_0_0 -> search14_0 in the cache */

/* replace709_0_1 -> replace14_1_0 in the cache */
/* replace709_0 -> replace707_0 in the cache */

/* replace709_1_0 -> search62_1_1 in the cache */

/* replace709_1_1 -> search62_2 in the cache */
/* replace709_1 -> search707_0_1 in the cache */
static const nir_search_expression replace709 = {
   { nir_search_value_expression, 1 },
   false,
   0, 3,
   nir_op_iand,
   { &replace707_0.value, &search707_0_1.value },
   NULL,
};

   /* search710_0_0_0 -> search14_0 in the cache */

/* search710_0_0_1 -> replace14_1_0 in the cache */
/* search710_0_0 -> search121_0 in the cache */

/* search710_0_1_0 -> search62_1_1 in the cache */

/* search710_0_1_1 -> search62_2 in the cache */
/* search710_0_1 -> replace707_1 in the cache */
static const nir_search_expression search710_0 = {
   { nir_search_value_expression, 1 },
   false,
   0, 3,
   nir_op_iand,
   { &search121_0.value, &replace707_1.value },
   (is_used_once),
};
static const nir_search_expression search710 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 3,
   nir_op_inot,
   { &search710_0.value },
   NULL,
};

   /* replace710_0_0 -> search14_0 in the cache */

/* replace710_0_1 -> replace14_1_0 in the cache */
/* replace710_0 -> replace707_0 in the cache */

/* replace710_1_0 -> search62_1_1 in the cache */

/* replace710_1_1 -> search62_2 in the cache */
/* replace710_1 -> search707_0_1 in the cache */
static const nir_search_expression replace710 = {
   { nir_search_value_expression, 1 },
   false,
   0, 3,
   nir_op_ior,
   { &replace707_0.value, &search707_0_1.value },
   NULL,
};

   /* search711_0_0_0 -> search14_0 in the cache */

/* search711_0_0_1 -> replace14_1_0 in the cache */
/* search711_0_0 -> search121_0 in the cache */

/* search711_0_1_0 -> search62_1_1 in the cache */

/* search711_0_1_1 -> search62_2 in the cache */
static const nir_search_expression search711_0_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search62_1_1.value, &search62_2.value },
   NULL,
};
static const nir_search_expression search711_0 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_ior,
   { &search121_0.value, &search711_0_1.value },
   (is_used_once),
};
static const nir_search_expression search711 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 2,
   nir_op_inot,
   { &search711_0.value },
   NULL,
};

   /* replace711_0_0 -> search14_0 in the cache */

/* replace711_0_1 -> replace14_1_0 in the cache */
/* replace711_0 -> replace707_0 in the cache */

/* replace711_1_0 -> search62_1_1 in the cache */

/* replace711_1_1 -> search62_2 in the cache */
static const nir_search_expression replace711_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search62_1_1.value, &search62_2.value },
   NULL,
};
static const nir_search_expression replace711 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &replace707_0.value, &replace711_1.value },
   NULL,
};

   /* search712_0_0_0 -> search14_0 in the cache */

/* search712_0_0_1 -> replace14_1_0 in the cache */
/* search712_0_0 -> search121_0 in the cache */

/* search712_0_1_0 -> search62_1_1 in the cache */

/* search712_0_1_1 -> search62_2 in the cache */
/* search712_0_1 -> search711_0_1 in the cache */
static const nir_search_expression search712_0 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &search121_0.value, &search711_0_1.value },
   (is_used_once),
};
static const nir_search_expression search712 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 2,
   nir_op_inot,
   { &search712_0.value },
   NULL,
};

   /* replace712_0_0 -> search14_0 in the cache */

/* replace712_0_1 -> replace14_1_0 in the cache */
/* replace712_0 -> replace707_0 in the cache */

/* replace712_1_0 -> search62_1_1 in the cache */

/* replace712_1_1 -> search62_2 in the cache */
/* replace712_1 -> replace711_1 in the cache */
static const nir_search_expression replace712 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_ior,
   { &replace707_0.value, &replace711_1.value },
   NULL,
};

   /* search713_0_0_0 -> search14_0 in the cache */

/* search713_0_0_1 -> replace14_1_0 in the cache */
/* search713_0_0 -> search121_0 in the cache */

/* search713_0_1_0 -> search62_1_1 in the cache */

/* search713_0_1_1 -> search62_2 in the cache */
/* search713_0_1 -> replace711_1 in the cache */
static const nir_search_expression search713_0 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_ior,
   { &search121_0.value, &replace711_1.value },
   (is_used_once),
};
static const nir_search_expression search713 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 2,
   nir_op_inot,
   { &search713_0.value },
   NULL,
};

   /* replace713_0_0 -> search14_0 in the cache */

/* replace713_0_1 -> replace14_1_0 in the cache */
/* replace713_0 -> replace707_0 in the cache */

/* replace713_1_0 -> search62_1_1 in the cache */

/* replace713_1_1 -> search62_2 in the cache */
/* replace713_1 -> search711_0_1 in the cache */
static const nir_search_expression replace713 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &replace707_0.value, &search711_0_1.value },
   NULL,
};

   /* search714_0_0_0 -> search14_0 in the cache */

/* search714_0_0_1 -> replace14_1_0 in the cache */
/* search714_0_0 -> search121_0 in the cache */

/* search714_0_1_0 -> search62_1_1 in the cache */

/* search714_0_1_1 -> search62_2 in the cache */
/* search714_0_1 -> replace711_1 in the cache */
static const nir_search_expression search714_0 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &search121_0.value, &replace711_1.value },
   (is_used_once),
};
static const nir_search_expression search714 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 2,
   nir_op_inot,
   { &search714_0.value },
   NULL,
};

   /* replace714_0_0 -> search14_0 in the cache */

/* replace714_0_1 -> replace14_1_0 in the cache */
/* replace714_0 -> replace707_0 in the cache */

/* replace714_1_0 -> search62_1_1 in the cache */

/* replace714_1_1 -> search62_2 in the cache */
/* replace714_1 -> search711_0_1 in the cache */
static const nir_search_expression replace714 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_ior,
   { &replace707_0.value, &search711_0_1.value },
   NULL,
};

   /* search715_0_0_0 -> search14_0 in the cache */

/* search715_0_0_1 -> replace14_1_0 in the cache */
/* search715_0_0 -> replace707_0 in the cache */

/* search715_0_1_0 -> search62_1_1 in the cache */

/* search715_0_1_1 -> search62_2 in the cache */
/* search715_0_1 -> replace707_1 in the cache */
static const nir_search_expression search715_0 = {
   { nir_search_value_expression, 1 },
   false,
   0, 3,
   nir_op_ior,
   { &replace707_0.value, &replace707_1.value },
   (is_used_once),
};
static const nir_search_expression search715 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 3,
   nir_op_inot,
   { &search715_0.value },
   NULL,
};

   /* replace715_0_0 -> search14_0 in the cache */

/* replace715_0_1 -> replace14_1_0 in the cache */
/* replace715_0 -> search121_0 in the cache */

/* replace715_1_0 -> search62_1_1 in the cache */

/* replace715_1_1 -> search62_2 in the cache */
/* replace715_1 -> search707_0_1 in the cache */
static const nir_search_expression replace715 = {
   { nir_search_value_expression, 1 },
   false,
   0, 3,
   nir_op_iand,
   { &search121_0.value, &search707_0_1.value },
   NULL,
};

   /* search716_0_0_0 -> search14_0 in the cache */

/* search716_0_0_1 -> replace14_1_0 in the cache */
/* search716_0_0 -> replace707_0 in the cache */

/* search716_0_1_0 -> search62_1_1 in the cache */

/* search716_0_1_1 -> search62_2 in the cache */
/* search716_0_1 -> replace707_1 in the cache */
static const nir_search_expression search716_0 = {
   { nir_search_value_expression, 1 },
   false,
   0, 3,
   nir_op_iand,
   { &replace707_0.value, &replace707_1.value },
   (is_used_once),
};
static const nir_search_expression search716 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 3,
   nir_op_inot,
   { &search716_0.value },
   NULL,
};

   /* replace716_0_0 -> search14_0 in the cache */

/* replace716_0_1 -> replace14_1_0 in the cache */
/* replace716_0 -> search121_0 in the cache */

/* replace716_1_0 -> search62_1_1 in the cache */

/* replace716_1_1 -> search62_2 in the cache */
/* replace716_1 -> search707_0_1 in the cache */
static const nir_search_expression replace716 = {
   { nir_search_value_expression, 1 },
   false,
   0, 3,
   nir_op_ior,
   { &search121_0.value, &search707_0_1.value },
   NULL,
};

   /* search717_0_0_0 -> search14_0 in the cache */

/* search717_0_0_1 -> replace14_1_0 in the cache */
/* search717_0_0 -> replace707_0 in the cache */

/* search717_0_1_0 -> search62_1_1 in the cache */

/* search717_0_1_1 -> search62_2 in the cache */
/* search717_0_1 -> search711_0_1 in the cache */
static const nir_search_expression search717_0 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_ior,
   { &replace707_0.value, &search711_0_1.value },
   (is_used_once),
};
static const nir_search_expression search717 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 2,
   nir_op_inot,
   { &search717_0.value },
   NULL,
};

   /* replace717_0_0 -> search14_0 in the cache */

/* replace717_0_1 -> replace14_1_0 in the cache */
/* replace717_0 -> search121_0 in the cache */

/* replace717_1_0 -> search62_1_1 in the cache */

/* replace717_1_1 -> search62_2 in the cache */
/* replace717_1 -> replace711_1 in the cache */
static const nir_search_expression replace717 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &search121_0.value, &replace711_1.value },
   NULL,
};

   /* search718_0_0_0 -> search14_0 in the cache */

/* search718_0_0_1 -> replace14_1_0 in the cache */
/* search718_0_0 -> replace707_0 in the cache */

/* search718_0_1_0 -> search62_1_1 in the cache */

/* search718_0_1_1 -> search62_2 in the cache */
/* search718_0_1 -> search711_0_1 in the cache */
static const nir_search_expression search718_0 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &replace707_0.value, &search711_0_1.value },
   (is_used_once),
};
static const nir_search_expression search718 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 2,
   nir_op_inot,
   { &search718_0.value },
   NULL,
};

   /* replace718_0_0 -> search14_0 in the cache */

/* replace718_0_1 -> replace14_1_0 in the cache */
/* replace718_0 -> search121_0 in the cache */

/* replace718_1_0 -> search62_1_1 in the cache */

/* replace718_1_1 -> search62_2 in the cache */
/* replace718_1 -> replace711_1 in the cache */
static const nir_search_expression replace718 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_ior,
   { &search121_0.value, &replace711_1.value },
   NULL,
};

   /* search719_0_0_0 -> search14_0 in the cache */

/* search719_0_0_1 -> replace14_1_0 in the cache */
/* search719_0_0 -> replace707_0 in the cache */

/* search719_0_1_0 -> search62_1_1 in the cache */

/* search719_0_1_1 -> search62_2 in the cache */
/* search719_0_1 -> replace711_1 in the cache */
static const nir_search_expression search719_0 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_ior,
   { &replace707_0.value, &replace711_1.value },
   (is_used_once),
};
static const nir_search_expression search719 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 2,
   nir_op_inot,
   { &search719_0.value },
   NULL,
};

   /* replace719_0_0 -> search14_0 in the cache */

/* replace719_0_1 -> replace14_1_0 in the cache */
/* replace719_0 -> search121_0 in the cache */

/* replace719_1_0 -> search62_1_1 in the cache */

/* replace719_1_1 -> search62_2 in the cache */
/* replace719_1 -> search711_0_1 in the cache */
static const nir_search_expression replace719 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &search121_0.value, &search711_0_1.value },
   NULL,
};

   /* search720_0_0_0 -> search14_0 in the cache */

/* search720_0_0_1 -> replace14_1_0 in the cache */
/* search720_0_0 -> replace707_0 in the cache */

/* search720_0_1_0 -> search62_1_1 in the cache */

/* search720_0_1_1 -> search62_2 in the cache */
/* search720_0_1 -> replace711_1 in the cache */
static const nir_search_expression search720_0 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &replace707_0.value, &replace711_1.value },
   (is_used_once),
};
static const nir_search_expression search720 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 2,
   nir_op_inot,
   { &search720_0.value },
   NULL,
};

   /* replace720_0_0 -> search14_0 in the cache */

/* replace720_0_1 -> replace14_1_0 in the cache */
/* replace720_0 -> search121_0 in the cache */

/* replace720_1_0 -> search62_1_1 in the cache */

/* replace720_1_1 -> search62_2 in the cache */
/* replace720_1 -> search711_0_1 in the cache */
static const nir_search_expression replace720 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_ior,
   { &search121_0.value, &search711_0_1.value },
   NULL,
};

   /* search721_0_0_0 -> search14_0 in the cache */

/* search721_0_0_1 -> replace14_1_0 in the cache */
/* search721_0_0 -> replace111 in the cache */

/* search721_0_1_0 -> search62_1_1 in the cache */

/* search721_0_1_1 -> search62_2 in the cache */
/* search721_0_1 -> search711_0_1 in the cache */
static const nir_search_expression search721_0 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ior,
   { &replace111.value, &search711_0_1.value },
   (is_used_once),
};
static const nir_search_expression search721 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_inot,
   { &search721_0.value },
   NULL,
};

   /* replace721_0_0 -> search14_0 in the cache */

/* replace721_0_1 -> replace14_1_0 in the cache */
/* replace721_0 -> search111_0 in the cache */

/* replace721_1_0 -> search62_1_1 in the cache */

/* replace721_1_1 -> search62_2 in the cache */
/* replace721_1 -> replace711_1 in the cache */
static const nir_search_expression replace721 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_iand,
   { &search111_0.value, &replace711_1.value },
   NULL,
};

   /* search722_0_0_0 -> search14_0 in the cache */

/* search722_0_0_1 -> replace14_1_0 in the cache */
/* search722_0_0 -> replace111 in the cache */

/* search722_0_1_0 -> search62_1_1 in the cache */

/* search722_0_1_1 -> search62_2 in the cache */
/* search722_0_1 -> search711_0_1 in the cache */
static const nir_search_expression search722_0 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_iand,
   { &replace111.value, &search711_0_1.value },
   (is_used_once),
};
static const nir_search_expression search722 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_inot,
   { &search722_0.value },
   NULL,
};

   /* replace722_0_0 -> search14_0 in the cache */

/* replace722_0_1 -> replace14_1_0 in the cache */
/* replace722_0 -> search111_0 in the cache */

/* replace722_1_0 -> search62_1_1 in the cache */

/* replace722_1_1 -> search62_2 in the cache */
/* replace722_1 -> replace711_1 in the cache */
static const nir_search_expression replace722 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ior,
   { &search111_0.value, &replace711_1.value },
   NULL,
};

   /* search723_0_0_0 -> search14_0 in the cache */

/* search723_0_0_1 -> replace14_1_0 in the cache */
/* search723_0_0 -> replace111 in the cache */

/* search723_0_1_0 -> search62_1_1 in the cache */

/* search723_0_1_1 -> search62_2 in the cache */
/* search723_0_1 -> replace711_1 in the cache */
static const nir_search_expression search723_0 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ior,
   { &replace111.value, &replace711_1.value },
   (is_used_once),
};
static const nir_search_expression search723 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_inot,
   { &search723_0.value },
   NULL,
};

   /* replace723_0_0 -> search14_0 in the cache */

/* replace723_0_1 -> replace14_1_0 in the cache */
/* replace723_0 -> search111_0 in the cache */

/* replace723_1_0 -> search62_1_1 in the cache */

/* replace723_1_1 -> search62_2 in the cache */
/* replace723_1 -> search711_0_1 in the cache */
static const nir_search_expression replace723 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_iand,
   { &search111_0.value, &search711_0_1.value },
   NULL,
};

   /* search724_0_0_0 -> search14_0 in the cache */

/* search724_0_0_1 -> replace14_1_0 in the cache */
/* search724_0_0 -> replace111 in the cache */

/* search724_0_1_0 -> search62_1_1 in the cache */

/* search724_0_1_1 -> search62_2 in the cache */
/* search724_0_1 -> replace711_1 in the cache */
static const nir_search_expression search724_0 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_iand,
   { &replace111.value, &replace711_1.value },
   (is_used_once),
};
static const nir_search_expression search724 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_inot,
   { &search724_0.value },
   NULL,
};

   /* replace724_0_0 -> search14_0 in the cache */

/* replace724_0_1 -> replace14_1_0 in the cache */
/* replace724_0 -> search111_0 in the cache */

/* replace724_1_0 -> search62_1_1 in the cache */

/* replace724_1_1 -> search62_2 in the cache */
/* replace724_1 -> search711_0_1 in the cache */
static const nir_search_expression replace724 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ior,
   { &search111_0.value, &search711_0_1.value },
   NULL,
};

   /* search725_0_0_0 -> search14_0 in the cache */

/* search725_0_0_1 -> replace14_1_0 in the cache */
/* search725_0_0 -> search111_0 in the cache */

/* search725_0_1_0 -> search62_1_1 in the cache */

/* search725_0_1_1 -> search62_2 in the cache */
/* search725_0_1 -> replace711_1 in the cache */
static const nir_search_expression search725_0 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ior,
   { &search111_0.value, &replace711_1.value },
   (is_used_once),
};
static const nir_search_expression search725 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_inot,
   { &search725_0.value },
   NULL,
};

   /* replace725_0_0 -> search14_0 in the cache */

/* replace725_0_1 -> replace14_1_0 in the cache */
/* replace725_0 -> replace111 in the cache */

/* replace725_1_0 -> search62_1_1 in the cache */

/* replace725_1_1 -> search62_2 in the cache */
/* replace725_1 -> search711_0_1 in the cache */
static const nir_search_expression replace725 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_iand,
   { &replace111.value, &search711_0_1.value },
   NULL,
};

   /* search726_0_0_0 -> search14_0 in the cache */

/* search726_0_0_1 -> replace14_1_0 in the cache */
/* search726_0_0 -> search111_0 in the cache */

/* search726_0_1_0 -> search62_1_1 in the cache */

/* search726_0_1_1 -> search62_2 in the cache */
/* search726_0_1 -> replace711_1 in the cache */
static const nir_search_expression search726_0 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_iand,
   { &search111_0.value, &replace711_1.value },
   (is_used_once),
};
static const nir_search_expression search726 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_inot,
   { &search726_0.value },
   NULL,
};

   /* replace726_0_0 -> search14_0 in the cache */

/* replace726_0_1 -> replace14_1_0 in the cache */
/* replace726_0 -> replace111 in the cache */

/* replace726_1_0 -> search62_1_1 in the cache */

/* replace726_1_1 -> search62_2 in the cache */
/* replace726_1 -> search711_0_1 in the cache */
static const nir_search_expression replace726 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ior,
   { &replace111.value, &search711_0_1.value },
   NULL,
};

   /* search727_0_0 -> replace80_0 in the cache */
/* search727_0 -> search146_1 in the cache */
static const nir_search_expression search727 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_f2b1,
   { &search146_1.value },
   NULL,
};

   /* replace727 -> replace80_0 in the cache */

   /* search728_0_0 -> replace80_0 in the cache */
/* search728_0 -> search193_0 in the cache */
static const nir_search_expression search728 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_i2b1,
   { &search193_0.value },
   NULL,
};

   /* replace728 -> replace80_0 in the cache */

   /* search729_0_0 -> search0_0 in the cache */
static const nir_search_expression search729_0 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_search_op_b2f,
   { &search0_0.value },
   NULL,
};
static const nir_search_expression search729 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_f2b32,
   { &search729_0.value },
   NULL,
};

   /* replace729 -> search0_0 in the cache */

   /* search730_0_0 -> search0_0 in the cache */
/* search730_0 -> search514_0 in the cache */
/* search730 -> search514 in the cache */

   /* replace730 -> search0_0 in the cache */

   /* search731_0_0 -> search2_0 in the cache */
/* search731_0 -> search268_0 in the cache */
static const nir_search_expression search731 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_search_op_f2f,
   { &search268_0.value },
   NULL,
};

   /* replace731_0 -> search2_0 in the cache */
/* replace731 -> search268_0 in the cache */

   /* search732_0_0 -> search2_0 in the cache */
/* search732_0 -> search268_0 in the cache */
static const nir_search_expression search732 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_search_op_f2u,
   { &search268_0.value },
   NULL,
};

   /* replace732_0 -> search2_0 in the cache */
/* replace732 -> search510_0_0 in the cache */

   /* search733_0_0 -> search2_0 in the cache */
/* search733_0 -> search268_0 in the cache */
static const nir_search_expression search733 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_search_op_f2i,
   { &search268_0.value },
   NULL,
};

   /* replace733_0 -> search2_0 in the cache */
/* replace733 -> search510_0_0 in the cache */

   /* search734_0_0 -> search2_0 in the cache */
/* search734_0 -> search510_0_0 in the cache */
static const nir_search_expression search734 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_search_op_u2f,
   { &search510_0_0.value },
   NULL,
};

   /* replace734_0 -> search2_0 in the cache */
/* replace734 -> search268_0 in the cache */

   /* search735_0_0 -> search2_0 in the cache */
/* search735_0 -> search510_0_0 in the cache */
static const nir_search_expression search735 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_search_op_u2u,
   { &search510_0_0.value },
   NULL,
};

   /* replace735_0 -> search2_0 in the cache */
/* replace735 -> search510_0_0 in the cache */

   /* search736_0_0 -> search2_0 in the cache */
/* search736_0 -> search510_0_0 in the cache */
static const nir_search_expression search736 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_search_op_i2f,
   { &search510_0_0.value },
   NULL,
};

   /* replace736_0 -> search2_0 in the cache */
/* replace736 -> search268_0 in the cache */

   /* search737_0_0 -> search2_0 in the cache */
/* search737_0 -> search510_0_0 in the cache */
static const nir_search_expression search737 = {
   { nir_search_value_expression, 0 },
   false,
   -1, 0,
   nir_search_op_i2i,
   { &search510_0_0.value },
   NULL,
};

   /* replace737_0 -> search2_0 in the cache */
/* replace737 -> search510_0_0 in the cache */

   /* search738_0 -> replace80_0 in the cache */
static const nir_search_expression search738 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_i2i1,
   { &replace80_0.value },
   NULL,
};

   /* replace738 -> replace80_0 in the cache */

   /* search739_0 -> search98_0_0 in the cache */
static const nir_search_expression search739 = {
   { nir_search_value_expression, 8 },
   false,
   -1, 0,
   nir_op_i2i8,
   { &search98_0_0.value },
   NULL,
};

   /* replace739 -> search98_0_0 in the cache */

   /* search740_0 -> search101_0_0 in the cache */
static const nir_search_expression search740 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_i2i16,
   { &search101_0_0.value },
   NULL,
};

   /* replace740 -> search101_0_0 in the cache */

   /* search741_0 -> search0_0 in the cache */
static const nir_search_expression search741 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_i2i32,
   { &search0_0.value },
   NULL,
};

   /* replace741 -> search0_0 in the cache */

   /* search742_0 -> search57_0 in the cache */
static const nir_search_expression search742 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_i2i64,
   { &search57_0.value },
   NULL,
};

   /* replace742 -> search57_0 in the cache */

   /* search743_0 -> replace80_0 in the cache */
static const nir_search_expression search743 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_u2u1,
   { &replace80_0.value },
   NULL,
};

   /* replace743 -> replace80_0 in the cache */

   /* search744_0 -> search98_0_0 in the cache */
static const nir_search_expression search744 = {
   { nir_search_value_expression, 8 },
   false,
   -1, 0,
   nir_op_u2u8,
   { &search98_0_0.value },
   NULL,
};

   /* replace744 -> search98_0_0 in the cache */

   /* search745_0 -> search101_0_0 in the cache */
static const nir_search_expression search745 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_u2u16,
   { &search101_0_0.value },
   NULL,
};

   /* replace745 -> search101_0_0 in the cache */

   /* search746_0 -> search0_0 in the cache */
static const nir_search_expression search746 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_u2u32,
   { &search0_0.value },
   NULL,
};

   /* replace746 -> search0_0 in the cache */

   /* search747_0 -> search57_0 in the cache */
static const nir_search_expression search747 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_u2u64,
   { &search57_0.value },
   NULL,
};

   /* replace747 -> search57_0 in the cache */

   /* search748_0 -> search101_0_0 in the cache */
static const nir_search_expression search748 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_f2f16,
   { &search101_0_0.value },
   NULL,
};

   /* replace748 -> search101_0_0 in the cache */

   /* search749_0 -> search0_0 in the cache */
static const nir_search_expression search749 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_f2f32,
   { &search0_0.value },
   NULL,
};

   /* replace749 -> search0_0 in the cache */

   /* search750_0 -> search57_0 in the cache */
static const nir_search_expression search750 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_f2f64,
   { &search57_0.value },
   NULL,
};

   /* replace750 -> search57_0 in the cache */

   /* search751_0_0 -> search2_0 in the cache */
static const nir_search_expression search751_0 = {
   { nir_search_value_expression, 8 },
   false,
   -1, 0,
   nir_op_i2i8,
   { &search2_0.value },
   NULL,
};
static const nir_search_expression search751 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_i2i1,
   { &search751_0.value },
   NULL,
};

   /* replace751_0 -> search2_0 in the cache */
static const nir_search_expression replace751 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_i2i1,
   { &search2_0.value },
   NULL,
};

   /* search752_0_0 -> search2_0 in the cache */
static const nir_search_expression search752_0 = {
   { nir_search_value_expression, 8 },
   false,
   -1, 0,
   nir_op_u2u8,
   { &search2_0.value },
   NULL,
};
static const nir_search_expression search752 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_i2i1,
   { &search752_0.value },
   NULL,
};

   /* replace752_0 -> search2_0 in the cache */
static const nir_search_expression replace752 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_u2u1,
   { &search2_0.value },
   NULL,
};

   /* search753_0_0 -> search2_0 in the cache */
/* search753_0 -> search751_0 in the cache */
static const nir_search_expression search753 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_u2u1,
   { &search751_0.value },
   NULL,
};

   /* replace753_0 -> search2_0 in the cache */
/* replace753 -> replace751 in the cache */

   /* search754_0_0 -> search2_0 in the cache */
/* search754_0 -> search752_0 in the cache */
static const nir_search_expression search754 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_u2u1,
   { &search752_0.value },
   NULL,
};

   /* replace754_0 -> search2_0 in the cache */
/* replace754 -> replace752 in the cache */

   /* search755_0_0 -> search2_0 in the cache */
static const nir_search_expression search755_0 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_i2i16,
   { &search2_0.value },
   NULL,
};
static const nir_search_expression search755 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_i2i1,
   { &search755_0.value },
   NULL,
};

   /* replace755_0 -> search2_0 in the cache */
/* replace755 -> replace751 in the cache */

   /* search756_0_0 -> search2_0 in the cache */
static const nir_search_expression search756_0 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_u2u16,
   { &search2_0.value },
   NULL,
};
static const nir_search_expression search756 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_i2i1,
   { &search756_0.value },
   NULL,
};

   /* replace756_0 -> search2_0 in the cache */
/* replace756 -> replace752 in the cache */

   /* search757_0_0 -> search2_0 in the cache */
/* search757_0 -> search755_0 in the cache */
static const nir_search_expression search757 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_u2u1,
   { &search755_0.value },
   NULL,
};

   /* replace757_0 -> search2_0 in the cache */
/* replace757 -> replace751 in the cache */

   /* search758_0_0 -> search2_0 in the cache */
/* search758_0 -> search756_0 in the cache */
static const nir_search_expression search758 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_u2u1,
   { &search756_0.value },
   NULL,
};

   /* replace758_0 -> search2_0 in the cache */
/* replace758 -> replace752 in the cache */

   /* search759_0_0 -> search2_0 in the cache */
static const nir_search_expression search759_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_i2i32,
   { &search2_0.value },
   NULL,
};
static const nir_search_expression search759 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_i2i1,
   { &search759_0.value },
   NULL,
};

   /* replace759_0 -> search2_0 in the cache */
/* replace759 -> replace751 in the cache */

   /* search760_0_0 -> search2_0 in the cache */
static const nir_search_expression search760_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_u2u32,
   { &search2_0.value },
   NULL,
};
static const nir_search_expression search760 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_i2i1,
   { &search760_0.value },
   NULL,
};

   /* replace760_0 -> search2_0 in the cache */
/* replace760 -> replace752 in the cache */

   /* search761_0_0 -> search2_0 in the cache */
/* search761_0 -> search759_0 in the cache */
static const nir_search_expression search761 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_u2u1,
   { &search759_0.value },
   NULL,
};

   /* replace761_0 -> search2_0 in the cache */
/* replace761 -> replace751 in the cache */

   /* search762_0_0 -> search2_0 in the cache */
/* search762_0 -> search760_0 in the cache */
static const nir_search_expression search762 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_u2u1,
   { &search760_0.value },
   NULL,
};

   /* replace762_0 -> search2_0 in the cache */
/* replace762 -> replace752 in the cache */

   /* search763_0_0 -> search2_0 in the cache */
static const nir_search_expression search763_0 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_i2i64,
   { &search2_0.value },
   NULL,
};
static const nir_search_expression search763 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_i2i1,
   { &search763_0.value },
   NULL,
};

   /* replace763_0 -> search2_0 in the cache */
/* replace763 -> replace751 in the cache */

   /* search764_0_0 -> search2_0 in the cache */
static const nir_search_expression search764_0 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_u2u64,
   { &search2_0.value },
   NULL,
};
static const nir_search_expression search764 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_i2i1,
   { &search764_0.value },
   NULL,
};

   /* replace764_0 -> search2_0 in the cache */
/* replace764 -> replace752 in the cache */

   /* search765_0_0 -> search2_0 in the cache */
/* search765_0 -> search763_0 in the cache */
static const nir_search_expression search765 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_u2u1,
   { &search763_0.value },
   NULL,
};

   /* replace765_0 -> search2_0 in the cache */
/* replace765 -> replace751 in the cache */

   /* search766_0_0 -> search2_0 in the cache */
/* search766_0 -> search764_0 in the cache */
static const nir_search_expression search766 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_u2u1,
   { &search764_0.value },
   NULL,
};

   /* replace766_0 -> search2_0 in the cache */
/* replace766 -> replace752 in the cache */

   /* search767_0_0 -> replace80_0 in the cache */
/* search767_0 -> search738 in the cache */
static const nir_search_expression search767 = {
   { nir_search_value_expression, 8 },
   false,
   -1, 0,
   nir_op_i2i8,
   { &search738.value },
   NULL,
};

   /* replace767_0 -> replace80_0 in the cache */
static const nir_search_expression replace767 = {
   { nir_search_value_expression, 8 },
   false,
   -1, 0,
   nir_op_i2i8,
   { &replace80_0.value },
   NULL,
};

   /* search768_0_0 -> replace80_0 in the cache */
/* search768_0 -> search743 in the cache */
static const nir_search_expression search768 = {
   { nir_search_value_expression, 8 },
   false,
   -1, 0,
   nir_op_u2u8,
   { &search743.value },
   NULL,
};

   /* replace768_0 -> replace80_0 in the cache */
static const nir_search_expression replace768 = {
   { nir_search_value_expression, 8 },
   false,
   -1, 0,
   nir_op_u2u8,
   { &replace80_0.value },
   NULL,
};

   /* search769_0_0 -> search2_0 in the cache */
/* search769_0 -> search755_0 in the cache */
static const nir_search_expression search769 = {
   { nir_search_value_expression, 8 },
   false,
   -1, 0,
   nir_op_i2i8,
   { &search755_0.value },
   NULL,
};

   /* replace769_0 -> search2_0 in the cache */
/* replace769 -> search751_0 in the cache */

   /* search770_0_0 -> search2_0 in the cache */
/* search770_0 -> search756_0 in the cache */
static const nir_search_expression search770 = {
   { nir_search_value_expression, 8 },
   false,
   -1, 0,
   nir_op_i2i8,
   { &search756_0.value },
   NULL,
};

   /* replace770_0 -> search2_0 in the cache */
/* replace770 -> search752_0 in the cache */

   /* search771_0_0 -> search2_0 in the cache */
/* search771_0 -> search755_0 in the cache */
static const nir_search_expression search771 = {
   { nir_search_value_expression, 8 },
   false,
   -1, 0,
   nir_op_u2u8,
   { &search755_0.value },
   NULL,
};

   /* replace771_0 -> search2_0 in the cache */
/* replace771 -> search751_0 in the cache */

   /* search772_0_0 -> search2_0 in the cache */
/* search772_0 -> search756_0 in the cache */
static const nir_search_expression search772 = {
   { nir_search_value_expression, 8 },
   false,
   -1, 0,
   nir_op_u2u8,
   { &search756_0.value },
   NULL,
};

   /* replace772_0 -> search2_0 in the cache */
/* replace772 -> search752_0 in the cache */

   /* search773_0_0 -> search2_0 in the cache */
/* search773_0 -> search759_0 in the cache */
static const nir_search_expression search773 = {
   { nir_search_value_expression, 8 },
   false,
   -1, 0,
   nir_op_i2i8,
   { &search759_0.value },
   NULL,
};

   /* replace773_0 -> search2_0 in the cache */
/* replace773 -> search751_0 in the cache */

   /* search774_0_0 -> search2_0 in the cache */
/* search774_0 -> search760_0 in the cache */
static const nir_search_expression search774 = {
   { nir_search_value_expression, 8 },
   false,
   -1, 0,
   nir_op_i2i8,
   { &search760_0.value },
   NULL,
};

   /* replace774_0 -> search2_0 in the cache */
/* replace774 -> search752_0 in the cache */

   /* search775_0_0 -> search2_0 in the cache */
/* search775_0 -> search759_0 in the cache */
static const nir_search_expression search775 = {
   { nir_search_value_expression, 8 },
   false,
   -1, 0,
   nir_op_u2u8,
   { &search759_0.value },
   NULL,
};

   /* replace775_0 -> search2_0 in the cache */
/* replace775 -> search751_0 in the cache */

   /* search776_0_0 -> search2_0 in the cache */
/* search776_0 -> search760_0 in the cache */
static const nir_search_expression search776 = {
   { nir_search_value_expression, 8 },
   false,
   -1, 0,
   nir_op_u2u8,
   { &search760_0.value },
   NULL,
};

   /* replace776_0 -> search2_0 in the cache */
/* replace776 -> search752_0 in the cache */

   /* search777_0_0 -> search2_0 in the cache */
/* search777_0 -> search763_0 in the cache */
static const nir_search_expression search777 = {
   { nir_search_value_expression, 8 },
   false,
   -1, 0,
   nir_op_i2i8,
   { &search763_0.value },
   NULL,
};

   /* replace777_0 -> search2_0 in the cache */
/* replace777 -> search751_0 in the cache */

   /* search778_0_0 -> search2_0 in the cache */
/* search778_0 -> search764_0 in the cache */
static const nir_search_expression search778 = {
   { nir_search_value_expression, 8 },
   false,
   -1, 0,
   nir_op_i2i8,
   { &search764_0.value },
   NULL,
};

   /* replace778_0 -> search2_0 in the cache */
/* replace778 -> search752_0 in the cache */

   /* search779_0_0 -> search2_0 in the cache */
/* search779_0 -> search763_0 in the cache */
static const nir_search_expression search779 = {
   { nir_search_value_expression, 8 },
   false,
   -1, 0,
   nir_op_u2u8,
   { &search763_0.value },
   NULL,
};

   /* replace779_0 -> search2_0 in the cache */
/* replace779 -> search751_0 in the cache */

   /* search780_0_0 -> search2_0 in the cache */
/* search780_0 -> search764_0 in the cache */
static const nir_search_expression search780 = {
   { nir_search_value_expression, 8 },
   false,
   -1, 0,
   nir_op_u2u8,
   { &search764_0.value },
   NULL,
};

   /* replace780_0 -> search2_0 in the cache */
/* replace780 -> search752_0 in the cache */

   /* search781_0_0 -> replace80_0 in the cache */
/* search781_0 -> search738 in the cache */
static const nir_search_expression search781 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_i2i16,
   { &search738.value },
   NULL,
};

   /* replace781_0 -> replace80_0 in the cache */
static const nir_search_expression replace781 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_i2i16,
   { &replace80_0.value },
   NULL,
};

   /* search782_0_0 -> replace80_0 in the cache */
/* search782_0 -> search743 in the cache */
static const nir_search_expression search782 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_u2u16,
   { &search743.value },
   NULL,
};

   /* replace782_0 -> replace80_0 in the cache */
static const nir_search_expression replace782 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_u2u16,
   { &replace80_0.value },
   NULL,
};

   /* search783_0_0 -> replace80_0 in the cache */
/* search783_0 -> replace767 in the cache */
static const nir_search_expression search783 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_i2i16,
   { &replace767.value },
   NULL,
};

   /* replace783_0 -> replace80_0 in the cache */
/* replace783 -> replace781 in the cache */

   /* search784_0_0 -> replace80_0 in the cache */
/* search784_0 -> replace768 in the cache */
static const nir_search_expression search784 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_u2u16,
   { &replace768.value },
   NULL,
};

   /* replace784_0 -> replace80_0 in the cache */
/* replace784 -> replace782 in the cache */

   /* search785_0_0 -> search98_0_0 in the cache */
/* search785_0 -> search739 in the cache */
static const nir_search_expression search785 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_i2i16,
   { &search739.value },
   NULL,
};

   /* replace785_0 -> search98_0_0 in the cache */
static const nir_search_expression replace785 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_i2i16,
   { &search98_0_0.value },
   NULL,
};

   /* search786_0_0 -> search98_0_0 in the cache */
/* search786_0 -> search744 in the cache */
static const nir_search_expression search786 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_u2u16,
   { &search744.value },
   NULL,
};

   /* replace786_0 -> search98_0_0 in the cache */
static const nir_search_expression replace786 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_u2u16,
   { &search98_0_0.value },
   NULL,
};

   /* search787_0_0 -> search2_0 in the cache */
/* search787_0 -> search759_0 in the cache */
static const nir_search_expression search787 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_i2i16,
   { &search759_0.value },
   NULL,
};

   /* replace787_0 -> search2_0 in the cache */
/* replace787 -> search755_0 in the cache */

   /* search788_0_0 -> search2_0 in the cache */
/* search788_0 -> search760_0 in the cache */
static const nir_search_expression search788 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_i2i16,
   { &search760_0.value },
   NULL,
};

   /* replace788_0 -> search2_0 in the cache */
/* replace788 -> search756_0 in the cache */

   /* search789_0_0 -> search2_0 in the cache */
/* search789_0 -> search759_0 in the cache */
static const nir_search_expression search789 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_u2u16,
   { &search759_0.value },
   NULL,
};

   /* replace789_0 -> search2_0 in the cache */
/* replace789 -> search755_0 in the cache */

   /* search790_0_0 -> search2_0 in the cache */
/* search790_0 -> search760_0 in the cache */
static const nir_search_expression search790 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_u2u16,
   { &search760_0.value },
   NULL,
};

   /* replace790_0 -> search2_0 in the cache */
/* replace790 -> search756_0 in the cache */

   /* search791_0_0 -> search2_0 in the cache */
/* search791_0 -> search763_0 in the cache */
static const nir_search_expression search791 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_i2i16,
   { &search763_0.value },
   NULL,
};

   /* replace791_0 -> search2_0 in the cache */
/* replace791 -> search755_0 in the cache */

   /* search792_0_0 -> search2_0 in the cache */
/* search792_0 -> search764_0 in the cache */
static const nir_search_expression search792 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_i2i16,
   { &search764_0.value },
   NULL,
};

   /* replace792_0 -> search2_0 in the cache */
/* replace792 -> search756_0 in the cache */

   /* search793_0_0 -> search2_0 in the cache */
/* search793_0 -> search763_0 in the cache */
static const nir_search_expression search793 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_u2u16,
   { &search763_0.value },
   NULL,
};

   /* replace793_0 -> search2_0 in the cache */
/* replace793 -> search755_0 in the cache */

   /* search794_0_0 -> search2_0 in the cache */
/* search794_0 -> search764_0 in the cache */
static const nir_search_expression search794 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_u2u16,
   { &search764_0.value },
   NULL,
};

   /* replace794_0 -> search2_0 in the cache */
/* replace794 -> search756_0 in the cache */

   /* search795_0_0 -> replace80_0 in the cache */
/* search795_0 -> search738 in the cache */
static const nir_search_expression search795 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_i2i32,
   { &search738.value },
   NULL,
};

   /* replace795_0 -> replace80_0 in the cache */
static const nir_search_expression replace795 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_i2i32,
   { &replace80_0.value },
   NULL,
};

   /* search796_0_0 -> replace80_0 in the cache */
/* search796_0 -> search743 in the cache */
static const nir_search_expression search796 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_u2u32,
   { &search743.value },
   NULL,
};

   /* replace796_0 -> replace80_0 in the cache */
static const nir_search_expression replace796 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_u2u32,
   { &replace80_0.value },
   NULL,
};

   /* search797_0_0 -> replace80_0 in the cache */
/* search797_0 -> replace767 in the cache */
static const nir_search_expression search797 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_i2i32,
   { &replace767.value },
   NULL,
};

   /* replace797_0 -> replace80_0 in the cache */
/* replace797 -> replace795 in the cache */

   /* search798_0_0 -> replace80_0 in the cache */
/* search798_0 -> replace768 in the cache */
static const nir_search_expression search798 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_u2u32,
   { &replace768.value },
   NULL,
};

   /* replace798_0 -> replace80_0 in the cache */
/* replace798 -> replace796 in the cache */

   /* search799_0_0 -> search98_0_0 in the cache */
/* search799_0 -> search739 in the cache */
static const nir_search_expression search799 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_i2i32,
   { &search739.value },
   NULL,
};

   /* replace799_0 -> search98_0_0 in the cache */
static const nir_search_expression replace799 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_i2i32,
   { &search98_0_0.value },
   NULL,
};

   /* search800_0_0 -> search98_0_0 in the cache */
/* search800_0 -> search744 in the cache */
static const nir_search_expression search800 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_u2u32,
   { &search744.value },
   NULL,
};

   /* replace800_0 -> search98_0_0 in the cache */
static const nir_search_expression replace800 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_u2u32,
   { &search98_0_0.value },
   NULL,
};

   /* search801_0_0 -> replace80_0 in the cache */
/* search801_0 -> replace781 in the cache */
static const nir_search_expression search801 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_i2i32,
   { &replace781.value },
   NULL,
};

   /* replace801_0 -> replace80_0 in the cache */
/* replace801 -> replace795 in the cache */

   /* search802_0_0 -> replace80_0 in the cache */
/* search802_0 -> replace782 in the cache */
static const nir_search_expression search802 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_u2u32,
   { &replace782.value },
   NULL,
};

   /* replace802_0 -> replace80_0 in the cache */
/* replace802 -> replace796 in the cache */

   /* search803_0_0 -> search98_0_0 in the cache */
/* search803_0 -> replace785 in the cache */
static const nir_search_expression search803 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_i2i32,
   { &replace785.value },
   NULL,
};

   /* replace803_0 -> search98_0_0 in the cache */
/* replace803 -> replace799 in the cache */

   /* search804_0_0 -> search98_0_0 in the cache */
/* search804_0 -> replace786 in the cache */
static const nir_search_expression search804 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_u2u32,
   { &replace786.value },
   NULL,
};

   /* replace804_0 -> search98_0_0 in the cache */
/* replace804 -> replace800 in the cache */

   /* search805_0_0 -> search101_0_0 in the cache */
/* search805_0 -> search740 in the cache */
static const nir_search_expression search805 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_i2i32,
   { &search740.value },
   NULL,
};

   /* replace805_0 -> search101_0_0 in the cache */
static const nir_search_expression replace805 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_i2i32,
   { &search101_0_0.value },
   NULL,
};

   /* search806_0_0 -> search101_0_0 in the cache */
/* search806_0 -> search745 in the cache */
static const nir_search_expression search806 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_u2u32,
   { &search745.value },
   NULL,
};

   /* replace806_0 -> search101_0_0 in the cache */
static const nir_search_expression replace806 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_u2u32,
   { &search101_0_0.value },
   NULL,
};

   /* search807_0_0 -> search2_0 in the cache */
/* search807_0 -> search763_0 in the cache */
static const nir_search_expression search807 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_i2i32,
   { &search763_0.value },
   NULL,
};

   /* replace807_0 -> search2_0 in the cache */
/* replace807 -> search759_0 in the cache */

   /* search808_0_0 -> search2_0 in the cache */
/* search808_0 -> search764_0 in the cache */
static const nir_search_expression search808 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_i2i32,
   { &search764_0.value },
   NULL,
};

   /* replace808_0 -> search2_0 in the cache */
/* replace808 -> search760_0 in the cache */

   /* search809_0_0 -> search2_0 in the cache */
/* search809_0 -> search763_0 in the cache */
static const nir_search_expression search809 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_u2u32,
   { &search763_0.value },
   NULL,
};

   /* replace809_0 -> search2_0 in the cache */
/* replace809 -> search759_0 in the cache */

   /* search810_0_0 -> search2_0 in the cache */
/* search810_0 -> search764_0 in the cache */
static const nir_search_expression search810 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_u2u32,
   { &search764_0.value },
   NULL,
};

   /* replace810_0 -> search2_0 in the cache */
/* replace810 -> search760_0 in the cache */

   /* search811_0_0 -> replace80_0 in the cache */
/* search811_0 -> search738 in the cache */
static const nir_search_expression search811 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_i2i64,
   { &search738.value },
   NULL,
};

   /* replace811_0 -> replace80_0 in the cache */
static const nir_search_expression replace811 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_i2i64,
   { &replace80_0.value },
   NULL,
};

   /* search812_0_0 -> replace80_0 in the cache */
/* search812_0 -> search743 in the cache */
static const nir_search_expression search812 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_u2u64,
   { &search743.value },
   NULL,
};

   /* replace812_0 -> replace80_0 in the cache */
static const nir_search_expression replace812 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_u2u64,
   { &replace80_0.value },
   NULL,
};

   /* search813_0_0 -> replace80_0 in the cache */
/* search813_0 -> replace767 in the cache */
static const nir_search_expression search813 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_i2i64,
   { &replace767.value },
   NULL,
};

   /* replace813_0 -> replace80_0 in the cache */
/* replace813 -> replace811 in the cache */

   /* search814_0_0 -> replace80_0 in the cache */
/* search814_0 -> replace768 in the cache */
static const nir_search_expression search814 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_u2u64,
   { &replace768.value },
   NULL,
};

   /* replace814_0 -> replace80_0 in the cache */
/* replace814 -> replace812 in the cache */

   /* search815_0_0 -> search98_0_0 in the cache */
/* search815_0 -> search739 in the cache */
static const nir_search_expression search815 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_i2i64,
   { &search739.value },
   NULL,
};

   /* replace815_0 -> search98_0_0 in the cache */
static const nir_search_expression replace815 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_i2i64,
   { &search98_0_0.value },
   NULL,
};

   /* search816_0_0 -> search98_0_0 in the cache */
/* search816_0 -> search744 in the cache */
static const nir_search_expression search816 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_u2u64,
   { &search744.value },
   NULL,
};

   /* replace816_0 -> search98_0_0 in the cache */
static const nir_search_expression replace816 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_u2u64,
   { &search98_0_0.value },
   NULL,
};

   /* search817_0_0 -> replace80_0 in the cache */
/* search817_0 -> replace781 in the cache */
static const nir_search_expression search817 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_i2i64,
   { &replace781.value },
   NULL,
};

   /* replace817_0 -> replace80_0 in the cache */
/* replace817 -> replace811 in the cache */

   /* search818_0_0 -> replace80_0 in the cache */
/* search818_0 -> replace782 in the cache */
static const nir_search_expression search818 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_u2u64,
   { &replace782.value },
   NULL,
};

   /* replace818_0 -> replace80_0 in the cache */
/* replace818 -> replace812 in the cache */

   /* search819_0_0 -> search98_0_0 in the cache */
/* search819_0 -> replace785 in the cache */
static const nir_search_expression search819 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_i2i64,
   { &replace785.value },
   NULL,
};

   /* replace819_0 -> search98_0_0 in the cache */
/* replace819 -> replace815 in the cache */

   /* search820_0_0 -> search98_0_0 in the cache */
/* search820_0 -> replace786 in the cache */
static const nir_search_expression search820 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_u2u64,
   { &replace786.value },
   NULL,
};

   /* replace820_0 -> search98_0_0 in the cache */
/* replace820 -> replace816 in the cache */

   /* search821_0_0 -> search101_0_0 in the cache */
/* search821_0 -> search740 in the cache */
static const nir_search_expression search821 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_i2i64,
   { &search740.value },
   NULL,
};

   /* replace821_0 -> search101_0_0 in the cache */
static const nir_search_expression replace821 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_i2i64,
   { &search101_0_0.value },
   NULL,
};

   /* search822_0_0 -> search101_0_0 in the cache */
/* search822_0 -> search745 in the cache */
static const nir_search_expression search822 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_u2u64,
   { &search745.value },
   NULL,
};

   /* replace822_0 -> search101_0_0 in the cache */
static const nir_search_expression replace822 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_u2u64,
   { &search101_0_0.value },
   NULL,
};

   /* search823_0_0 -> replace80_0 in the cache */
/* search823_0 -> replace795 in the cache */
static const nir_search_expression search823 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_i2i64,
   { &replace795.value },
   NULL,
};

   /* replace823_0 -> replace80_0 in the cache */
/* replace823 -> replace811 in the cache */

   /* search824_0_0 -> replace80_0 in the cache */
/* search824_0 -> replace796 in the cache */
static const nir_search_expression search824 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_u2u64,
   { &replace796.value },
   NULL,
};

   /* replace824_0 -> replace80_0 in the cache */
/* replace824 -> replace812 in the cache */

   /* search825_0_0 -> search98_0_0 in the cache */
/* search825_0 -> replace799 in the cache */
static const nir_search_expression search825 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_i2i64,
   { &replace799.value },
   NULL,
};

   /* replace825_0 -> search98_0_0 in the cache */
/* replace825 -> replace815 in the cache */

   /* search826_0_0 -> search98_0_0 in the cache */
/* search826_0 -> replace800 in the cache */
static const nir_search_expression search826 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_u2u64,
   { &replace800.value },
   NULL,
};

   /* replace826_0 -> search98_0_0 in the cache */
/* replace826 -> replace816 in the cache */

   /* search827_0_0 -> search101_0_0 in the cache */
/* search827_0 -> replace805 in the cache */
static const nir_search_expression search827 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_i2i64,
   { &replace805.value },
   NULL,
};

   /* replace827_0 -> search101_0_0 in the cache */
/* replace827 -> replace821 in the cache */

   /* search828_0_0 -> search101_0_0 in the cache */
/* search828_0 -> replace806 in the cache */
static const nir_search_expression search828 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_u2u64,
   { &replace806.value },
   NULL,
};

   /* replace828_0 -> search101_0_0 in the cache */
/* replace828 -> replace822 in the cache */

   /* search829_0_0 -> search0_0 in the cache */
/* search829_0 -> search741 in the cache */
static const nir_search_expression search829 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_i2i64,
   { &search741.value },
   NULL,
};

   /* replace829_0 -> search0_0 in the cache */
static const nir_search_expression replace829 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_i2i64,
   { &search0_0.value },
   NULL,
};

   /* search830_0_0 -> search0_0 in the cache */
/* search830_0 -> search746 in the cache */
static const nir_search_expression search830 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_u2u64,
   { &search746.value },
   NULL,
};

   /* replace830_0 -> search0_0 in the cache */
static const nir_search_expression replace830 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_u2u64,
   { &search0_0.value },
   NULL,
};

   /* search831_0_0 -> search98_0_0 in the cache */
/* search831_0 -> replace785 in the cache */

/* search831_1_0 -> search699_1 in the cache */
static const nir_search_expression search831_1 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_i2i16,
   { &search699_1.value },
   NULL,
};
static const nir_search_expression search831 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &replace785.value, &search831_1.value },
   NULL,
};

   /* replace831_0 -> search98_0_0 in the cache */

/* replace831_1_0 -> search699_1 in the cache */
static const nir_search_expression replace831_1 = {
   { nir_search_value_expression, 8 },
   false,
   -1, 0,
   nir_op_i2i8,
   { &search699_1.value },
   NULL,
};
static const nir_search_expression replace831 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &search98_0_0.value, &replace831_1.value },
   NULL,
};

   /* search832_0_0 -> search98_0_0 in the cache */
/* search832_0 -> replace785 in the cache */

/* search832_1_0 -> search699_1 in the cache */
/* search832_1 -> search831_1 in the cache */
static const nir_search_expression search832 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &replace785.value, &search831_1.value },
   NULL,
};

   /* replace832_0 -> search98_0_0 in the cache */

/* replace832_1_0 -> search699_1 in the cache */
/* replace832_1 -> replace831_1 in the cache */
static const nir_search_expression replace832 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &search98_0_0.value, &replace831_1.value },
   NULL,
};

   /* search833_0_0 -> search98_0_0 in the cache */
/* search833_0 -> replace785 in the cache */

/* search833_1_0 -> search699_1 in the cache */
/* search833_1 -> search831_1 in the cache */
static const nir_search_expression search833 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &replace785.value, &search831_1.value },
   NULL,
};

   /* replace833_0 -> search98_0_0 in the cache */

/* replace833_1_0 -> search699_1 in the cache */
/* replace833_1 -> replace831_1 in the cache */
static const nir_search_expression replace833 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search98_0_0.value, &replace831_1.value },
   NULL,
};

   /* search834_0_0 -> search98_0_0 in the cache */
/* search834_0 -> replace785 in the cache */

/* search834_1_0 -> search699_1 in the cache */
/* search834_1 -> search831_1 in the cache */
static const nir_search_expression search834 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &replace785.value, &search831_1.value },
   NULL,
};

   /* replace834_0 -> search98_0_0 in the cache */

/* replace834_1_0 -> search699_1 in the cache */
/* replace834_1 -> replace831_1 in the cache */
static const nir_search_expression replace834 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search98_0_0.value, &replace831_1.value },
   NULL,
};

   static const nir_search_variable search835_0_0 = {
   { nir_search_value_variable, 8 },
   0, /* b */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search835_0 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_i2i16,
   { &search835_0_0.value },
   NULL,
};

static const nir_search_variable search835_1_0 = {
   { nir_search_value_variable, 8 },
   1, /* a */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search835_1 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_i2i16,
   { &search835_1_0.value },
   NULL,
};
static const nir_search_expression search835 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search835_0.value, &search835_1.value },
   NULL,
};

   /* replace835_0_0 -> search835_0_0 in the cache */
static const nir_search_expression replace835_0 = {
   { nir_search_value_expression, 8 },
   false,
   -1, 0,
   nir_op_i2i8,
   { &search835_0_0.value },
   NULL,
};

/* replace835_1 -> search835_1_0 in the cache */
static const nir_search_expression replace835 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &replace835_0.value, &search835_1_0.value },
   NULL,
};

   /* search836_0_0 -> search835_0_0 in the cache */
/* search836_0 -> search835_0 in the cache */

/* search836_1_0 -> search835_1_0 in the cache */
/* search836_1 -> search835_1 in the cache */
static const nir_search_expression search836 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search835_0.value, &search835_1.value },
   NULL,
};

   /* replace836_0_0 -> search835_0_0 in the cache */
/* replace836_0 -> replace835_0 in the cache */

/* replace836_1 -> search835_1_0 in the cache */
static const nir_search_expression replace836 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &replace835_0.value, &search835_1_0.value },
   NULL,
};

   /* search837_0_0 -> search98_0_0 in the cache */
/* search837_0 -> replace785 in the cache */

/* search837_1 -> search564_0_1 in the cache */
static const nir_search_expression search837 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &replace785.value, &search564_0_1.value },
   NULL,
};

   /* replace837_0_0 -> search98_0_0 in the cache */

/* replace837_0_1_0 -> replace564_1_0 in the cache */
static const nir_search_expression replace837_0_1 = {
   { nir_search_value_expression, 8 },
   false,
   -1, 0,
   nir_op_i2i8,
   { &replace564_1_0.value },
   NULL,
};
static const nir_search_expression replace837_0 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ieq,
   { &search98_0_0.value, &replace837_0_1.value },
   NULL,
};

/* replace837_1_0_0_0 -> replace564_1_0 in the cache */
/* replace837_1_0_0 -> replace837_0_1 in the cache */
static const nir_search_expression replace837_1_0 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_i2i16,
   { &replace837_0_1.value },
   NULL,
};

/* replace837_1_1 -> replace564_1_0 in the cache */
static const nir_search_expression replace837_1 = {
   { nir_search_value_expression, 1 },
   false,
   2, 1,
   nir_op_ieq,
   { &replace837_1_0.value, &replace564_1_0.value },
   NULL,
};
static const nir_search_expression replace837 = {
   { nir_search_value_expression, 1 },
   false,
   0, 3,
   nir_op_iand,
   { &replace837_0.value, &replace837_1.value },
   NULL,
};

   /* search838_0_0 -> search98_0_0 in the cache */
/* search838_0 -> replace785 in the cache */

/* search838_1 -> search564_0_1 in the cache */
static const nir_search_expression search838 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &replace785.value, &search564_0_1.value },
   NULL,
};

   /* replace838_0_0 -> search98_0_0 in the cache */

/* replace838_0_1_0 -> replace564_1_0 in the cache */
/* replace838_0_1 -> replace837_0_1 in the cache */
static const nir_search_expression replace838_0 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ine,
   { &search98_0_0.value, &replace837_0_1.value },
   NULL,
};

/* replace838_1_0_0_0 -> replace564_1_0 in the cache */
/* replace838_1_0_0 -> replace837_0_1 in the cache */
/* replace838_1_0 -> replace837_1_0 in the cache */

/* replace838_1_1 -> replace564_1_0 in the cache */
static const nir_search_expression replace838_1 = {
   { nir_search_value_expression, 1 },
   false,
   2, 1,
   nir_op_ine,
   { &replace837_1_0.value, &replace564_1_0.value },
   NULL,
};
static const nir_search_expression replace838 = {
   { nir_search_value_expression, 1 },
   false,
   0, 3,
   nir_op_ior,
   { &replace838_0.value, &replace838_1.value },
   NULL,
};

   /* search839_0_0 -> search98_0_0 in the cache */
/* search839_0 -> replace785 in the cache */

/* search839_1 -> search564_0_1 in the cache */
static const nir_search_expression search839 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &replace785.value, &search564_0_1.value },
   NULL,
};

   static const nir_search_constant replace839_0_0 = {
   { nir_search_value_constant, 16 },
   nir_type_int, { -0x80 /* -128 */ },
};

/* replace839_0_1 -> replace564_1_0 in the cache */
static const nir_search_expression replace839_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &replace839_0_0.value, &replace564_1_0.value },
   NULL,
};

static const nir_search_constant replace839_1_0_0 = {
   { nir_search_value_constant, 16 },
   nir_type_int, { 0x7f /* 127 */ },
};

/* replace839_1_0_1 -> replace564_1_0 in the cache */
static const nir_search_expression replace839_1_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &replace839_1_0_0.value, &replace564_1_0.value },
   NULL,
};

/* replace839_1_1_0 -> search98_0_0 in the cache */

/* replace839_1_1_1_0 -> replace564_1_0 in the cache */
/* replace839_1_1_1 -> replace837_0_1 in the cache */
static const nir_search_expression replace839_1_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search98_0_0.value, &replace837_0_1.value },
   NULL,
};
static const nir_search_expression replace839_1 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ior,
   { &replace839_1_0.value, &replace839_1_1.value },
   NULL,
};
static const nir_search_expression replace839 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &replace839_0.value, &replace839_1.value },
   NULL,
};

   static const nir_search_variable search840_0 = {
   { nir_search_value_variable, 16 },
   0, /* a */
   true,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

/* search840_1_0 -> search699_1 in the cache */
/* search840_1 -> search831_1 in the cache */
static const nir_search_expression search840 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search840_0.value, &search831_1.value },
   NULL,
};

   /* replace840_0_0 -> search101_0_0 in the cache */

/* replace840_0_1 -> replace839_1_0_0 in the cache */
static const nir_search_expression replace840_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search101_0_0.value, &replace839_1_0_0.value },
   NULL,
};

/* replace840_1_0_0 -> search101_0_0 in the cache */

/* replace840_1_0_1 -> replace839_0_0 in the cache */
static const nir_search_expression replace840_1_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search101_0_0.value, &replace839_0_0.value },
   NULL,
};

/* replace840_1_1_0_0 -> search101_0_0 in the cache */
static const nir_search_expression replace840_1_1_0 = {
   { nir_search_value_expression, 8 },
   false,
   -1, 0,
   nir_op_i2i8,
   { &search101_0_0.value },
   NULL,
};

/* replace840_1_1_1 -> search699_1 in the cache */
static const nir_search_expression replace840_1_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &replace840_1_1_0.value, &search699_1.value },
   NULL,
};
static const nir_search_expression replace840_1 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ior,
   { &replace840_1_0.value, &replace840_1_1.value },
   NULL,
};
static const nir_search_expression replace840 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &replace840_0.value, &replace840_1.value },
   NULL,
};

   /* search841_0_0 -> search98_0_0 in the cache */
/* search841_0 -> replace785 in the cache */

/* search841_1 -> search564_0_1 in the cache */
static const nir_search_expression search841 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &replace785.value, &search564_0_1.value },
   NULL,
};

   /* replace841_0_0 -> replace839_1_0_0 in the cache */

/* replace841_0_1 -> replace564_1_0 in the cache */
static const nir_search_expression replace841_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &replace839_1_0_0.value, &replace564_1_0.value },
   NULL,
};

/* replace841_1_0_0 -> replace839_0_0 in the cache */

/* replace841_1_0_1 -> replace564_1_0 in the cache */
static const nir_search_expression replace841_1_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &replace839_0_0.value, &replace564_1_0.value },
   NULL,
};

/* replace841_1_1_0 -> search98_0_0 in the cache */

/* replace841_1_1_1_0 -> replace564_1_0 in the cache */
/* replace841_1_1_1 -> replace837_0_1 in the cache */
static const nir_search_expression replace841_1_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search98_0_0.value, &replace837_0_1.value },
   NULL,
};
static const nir_search_expression replace841_1 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ior,
   { &replace841_1_0.value, &replace841_1_1.value },
   NULL,
};
static const nir_search_expression replace841 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &replace841_0.value, &replace841_1.value },
   NULL,
};

   /* search842_0 -> search840_0 in the cache */

/* search842_1_0 -> search699_1 in the cache */
/* search842_1 -> search831_1 in the cache */
static const nir_search_expression search842 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search840_0.value, &search831_1.value },
   NULL,
};

   /* replace842_0_0 -> search101_0_0 in the cache */

/* replace842_0_1 -> replace839_0_0 in the cache */
static const nir_search_expression replace842_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search101_0_0.value, &replace839_0_0.value },
   NULL,
};

/* replace842_1_0_0 -> search101_0_0 in the cache */

/* replace842_1_0_1 -> replace839_1_0_0 in the cache */
static const nir_search_expression replace842_1_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search101_0_0.value, &replace839_1_0_0.value },
   NULL,
};

/* replace842_1_1_0_0 -> search101_0_0 in the cache */
/* replace842_1_1_0 -> replace840_1_1_0 in the cache */

/* replace842_1_1_1 -> search699_1 in the cache */
static const nir_search_expression replace842_1_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &replace840_1_1_0.value, &search699_1.value },
   NULL,
};
static const nir_search_expression replace842_1 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ior,
   { &replace842_1_0.value, &replace842_1_1.value },
   NULL,
};
static const nir_search_expression replace842 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &replace842_0.value, &replace842_1.value },
   NULL,
};

   /* search843_0_0 -> search98_0_0 in the cache */
/* search843_0 -> replace799 in the cache */

/* search843_1_0 -> search699_1 in the cache */
static const nir_search_expression search843_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_i2i32,
   { &search699_1.value },
   NULL,
};
static const nir_search_expression search843 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &replace799.value, &search843_1.value },
   NULL,
};

   /* replace843_0 -> search98_0_0 in the cache */

/* replace843_1_0 -> search699_1 in the cache */
/* replace843_1 -> replace831_1 in the cache */
/* replace843 -> replace831 in the cache */

   /* search844_0_0 -> search98_0_0 in the cache */
/* search844_0 -> replace799 in the cache */

/* search844_1_0 -> search699_1 in the cache */
/* search844_1 -> search843_1 in the cache */
static const nir_search_expression search844 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &replace799.value, &search843_1.value },
   NULL,
};

   /* replace844_0 -> search98_0_0 in the cache */

/* replace844_1_0 -> search699_1 in the cache */
/* replace844_1 -> replace831_1 in the cache */
/* replace844 -> replace832 in the cache */

   /* search845_0_0 -> search98_0_0 in the cache */
/* search845_0 -> replace799 in the cache */

/* search845_1_0 -> search699_1 in the cache */
/* search845_1 -> search843_1 in the cache */
static const nir_search_expression search845 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &replace799.value, &search843_1.value },
   NULL,
};

   /* replace845_0 -> search98_0_0 in the cache */

/* replace845_1_0 -> search699_1 in the cache */
/* replace845_1 -> replace831_1 in the cache */
/* replace845 -> replace833 in the cache */

   /* search846_0_0 -> search98_0_0 in the cache */
/* search846_0 -> replace799 in the cache */

/* search846_1_0 -> search699_1 in the cache */
/* search846_1 -> search843_1 in the cache */
static const nir_search_expression search846 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &replace799.value, &search843_1.value },
   NULL,
};

   /* replace846_0 -> search98_0_0 in the cache */

/* replace846_1_0 -> search699_1 in the cache */
/* replace846_1 -> replace831_1 in the cache */
/* replace846 -> replace834 in the cache */

   /* search847_0_0 -> search835_0_0 in the cache */
static const nir_search_expression search847_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_i2i32,
   { &search835_0_0.value },
   NULL,
};

/* search847_1_0 -> search835_1_0 in the cache */
static const nir_search_expression search847_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_i2i32,
   { &search835_1_0.value },
   NULL,
};
static const nir_search_expression search847 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search847_0.value, &search847_1.value },
   NULL,
};

   /* replace847_0_0 -> search835_0_0 in the cache */
/* replace847_0 -> replace835_0 in the cache */

/* replace847_1 -> search835_1_0 in the cache */
/* replace847 -> replace835 in the cache */

   /* search848_0_0 -> search835_0_0 in the cache */
/* search848_0 -> search847_0 in the cache */

/* search848_1_0 -> search835_1_0 in the cache */
/* search848_1 -> search847_1 in the cache */
static const nir_search_expression search848 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search847_0.value, &search847_1.value },
   NULL,
};

   /* replace848_0_0 -> search835_0_0 in the cache */
/* replace848_0 -> replace835_0 in the cache */

/* replace848_1 -> search835_1_0 in the cache */
/* replace848 -> replace836 in the cache */

   /* search849_0_0 -> search98_0_0 in the cache */
/* search849_0 -> replace799 in the cache */

/* search849_1 -> search2_1 in the cache */
static const nir_search_expression search849 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &replace799.value, &search2_1.value },
   NULL,
};

   /* replace849_0_0 -> search98_0_0 in the cache */

/* replace849_0_1_0 -> replace0_1_0 in the cache */
static const nir_search_expression replace849_0_1 = {
   { nir_search_value_expression, 8 },
   false,
   -1, 0,
   nir_op_i2i8,
   { &replace0_1_0.value },
   NULL,
};
static const nir_search_expression replace849_0 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ieq,
   { &search98_0_0.value, &replace849_0_1.value },
   NULL,
};

/* replace849_1_0_0_0 -> replace0_1_0 in the cache */
/* replace849_1_0_0 -> replace849_0_1 in the cache */
static const nir_search_expression replace849_1_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_i2i32,
   { &replace849_0_1.value },
   NULL,
};

/* replace849_1_1 -> replace0_1_0 in the cache */
static const nir_search_expression replace849_1 = {
   { nir_search_value_expression, 1 },
   false,
   2, 1,
   nir_op_ieq,
   { &replace849_1_0.value, &replace0_1_0.value },
   NULL,
};
static const nir_search_expression replace849 = {
   { nir_search_value_expression, 1 },
   false,
   0, 3,
   nir_op_iand,
   { &replace849_0.value, &replace849_1.value },
   NULL,
};

   /* search850_0_0 -> search98_0_0 in the cache */
/* search850_0 -> replace799 in the cache */

/* search850_1 -> search2_1 in the cache */
static const nir_search_expression search850 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &replace799.value, &search2_1.value },
   NULL,
};

   /* replace850_0_0 -> search98_0_0 in the cache */

/* replace850_0_1_0 -> replace0_1_0 in the cache */
/* replace850_0_1 -> replace849_0_1 in the cache */
static const nir_search_expression replace850_0 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ine,
   { &search98_0_0.value, &replace849_0_1.value },
   NULL,
};

/* replace850_1_0_0_0 -> replace0_1_0 in the cache */
/* replace850_1_0_0 -> replace849_0_1 in the cache */
/* replace850_1_0 -> replace849_1_0 in the cache */

/* replace850_1_1 -> replace0_1_0 in the cache */
static const nir_search_expression replace850_1 = {
   { nir_search_value_expression, 1 },
   false,
   2, 1,
   nir_op_ine,
   { &replace849_1_0.value, &replace0_1_0.value },
   NULL,
};
static const nir_search_expression replace850 = {
   { nir_search_value_expression, 1 },
   false,
   0, 3,
   nir_op_ior,
   { &replace850_0.value, &replace850_1.value },
   NULL,
};

   /* search851_0_0 -> search98_0_0 in the cache */
/* search851_0 -> replace799 in the cache */

/* search851_1 -> search2_1 in the cache */
static const nir_search_expression search851 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &replace799.value, &search2_1.value },
   NULL,
};

   static const nir_search_constant replace851_0_0 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { -0x80 /* -128 */ },
};

/* replace851_0_1 -> replace0_1_0 in the cache */
static const nir_search_expression replace851_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &replace851_0_0.value, &replace0_1_0.value },
   NULL,
};

static const nir_search_constant replace851_1_0_0 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { 0x7f /* 127 */ },
};

/* replace851_1_0_1 -> replace0_1_0 in the cache */
static const nir_search_expression replace851_1_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &replace851_1_0_0.value, &replace0_1_0.value },
   NULL,
};

/* replace851_1_1_0 -> search98_0_0 in the cache */

/* replace851_1_1_1_0 -> replace0_1_0 in the cache */
/* replace851_1_1_1 -> replace849_0_1 in the cache */
static const nir_search_expression replace851_1_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search98_0_0.value, &replace849_0_1.value },
   NULL,
};
static const nir_search_expression replace851_1 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ior,
   { &replace851_1_0.value, &replace851_1_1.value },
   NULL,
};
static const nir_search_expression replace851 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &replace851_0.value, &replace851_1.value },
   NULL,
};

   static const nir_search_variable search852_0 = {
   { nir_search_value_variable, 32 },
   0, /* a */
   true,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

/* search852_1_0 -> search699_1 in the cache */
/* search852_1 -> search843_1 in the cache */
static const nir_search_expression search852 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search852_0.value, &search843_1.value },
   NULL,
};

   /* replace852_0_0 -> search0_0 in the cache */

/* replace852_0_1 -> replace851_1_0_0 in the cache */
static const nir_search_expression replace852_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search0_0.value, &replace851_1_0_0.value },
   NULL,
};

/* replace852_1_0_0 -> search0_0 in the cache */

/* replace852_1_0_1 -> replace851_0_0 in the cache */
static const nir_search_expression replace852_1_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search0_0.value, &replace851_0_0.value },
   NULL,
};

/* replace852_1_1_0_0 -> search0_0 in the cache */
static const nir_search_expression replace852_1_1_0 = {
   { nir_search_value_expression, 8 },
   false,
   -1, 0,
   nir_op_i2i8,
   { &search0_0.value },
   NULL,
};

/* replace852_1_1_1 -> search699_1 in the cache */
static const nir_search_expression replace852_1_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &replace852_1_1_0.value, &search699_1.value },
   NULL,
};
static const nir_search_expression replace852_1 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ior,
   { &replace852_1_0.value, &replace852_1_1.value },
   NULL,
};
static const nir_search_expression replace852 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &replace852_0.value, &replace852_1.value },
   NULL,
};

   /* search853_0_0 -> search98_0_0 in the cache */
/* search853_0 -> replace799 in the cache */

/* search853_1 -> search2_1 in the cache */
static const nir_search_expression search853 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &replace799.value, &search2_1.value },
   NULL,
};

   /* replace853_0_0 -> replace851_1_0_0 in the cache */

/* replace853_0_1 -> replace0_1_0 in the cache */
static const nir_search_expression replace853_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &replace851_1_0_0.value, &replace0_1_0.value },
   NULL,
};

/* replace853_1_0_0 -> replace851_0_0 in the cache */

/* replace853_1_0_1 -> replace0_1_0 in the cache */
static const nir_search_expression replace853_1_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &replace851_0_0.value, &replace0_1_0.value },
   NULL,
};

/* replace853_1_1_0 -> search98_0_0 in the cache */

/* replace853_1_1_1_0 -> replace0_1_0 in the cache */
/* replace853_1_1_1 -> replace849_0_1 in the cache */
static const nir_search_expression replace853_1_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search98_0_0.value, &replace849_0_1.value },
   NULL,
};
static const nir_search_expression replace853_1 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ior,
   { &replace853_1_0.value, &replace853_1_1.value },
   NULL,
};
static const nir_search_expression replace853 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &replace853_0.value, &replace853_1.value },
   NULL,
};

   /* search854_0 -> search852_0 in the cache */

/* search854_1_0 -> search699_1 in the cache */
/* search854_1 -> search843_1 in the cache */
static const nir_search_expression search854 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search852_0.value, &search843_1.value },
   NULL,
};

   /* replace854_0_0 -> search0_0 in the cache */

/* replace854_0_1 -> replace851_0_0 in the cache */
static const nir_search_expression replace854_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search0_0.value, &replace851_0_0.value },
   NULL,
};

/* replace854_1_0_0 -> search0_0 in the cache */

/* replace854_1_0_1 -> replace851_1_0_0 in the cache */
static const nir_search_expression replace854_1_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search0_0.value, &replace851_1_0_0.value },
   NULL,
};

/* replace854_1_1_0_0 -> search0_0 in the cache */
/* replace854_1_1_0 -> replace852_1_1_0 in the cache */

/* replace854_1_1_1 -> search699_1 in the cache */
static const nir_search_expression replace854_1_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &replace852_1_1_0.value, &search699_1.value },
   NULL,
};
static const nir_search_expression replace854_1 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ior,
   { &replace854_1_0.value, &replace854_1_1.value },
   NULL,
};
static const nir_search_expression replace854 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &replace854_0.value, &replace854_1.value },
   NULL,
};

   /* search855_0_0 -> search98_0_0 in the cache */
/* search855_0 -> replace815 in the cache */

/* search855_1_0 -> search699_1 in the cache */
static const nir_search_expression search855_1 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_i2i64,
   { &search699_1.value },
   NULL,
};
static const nir_search_expression search855 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &replace815.value, &search855_1.value },
   NULL,
};

   /* replace855_0 -> search98_0_0 in the cache */

/* replace855_1_0 -> search699_1 in the cache */
/* replace855_1 -> replace831_1 in the cache */
/* replace855 -> replace831 in the cache */

   /* search856_0_0 -> search98_0_0 in the cache */
/* search856_0 -> replace815 in the cache */

/* search856_1_0 -> search699_1 in the cache */
/* search856_1 -> search855_1 in the cache */
static const nir_search_expression search856 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &replace815.value, &search855_1.value },
   NULL,
};

   /* replace856_0 -> search98_0_0 in the cache */

/* replace856_1_0 -> search699_1 in the cache */
/* replace856_1 -> replace831_1 in the cache */
/* replace856 -> replace832 in the cache */

   /* search857_0_0 -> search98_0_0 in the cache */
/* search857_0 -> replace815 in the cache */

/* search857_1_0 -> search699_1 in the cache */
/* search857_1 -> search855_1 in the cache */
static const nir_search_expression search857 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &replace815.value, &search855_1.value },
   NULL,
};

   /* replace857_0 -> search98_0_0 in the cache */

/* replace857_1_0 -> search699_1 in the cache */
/* replace857_1 -> replace831_1 in the cache */
/* replace857 -> replace833 in the cache */

   /* search858_0_0 -> search98_0_0 in the cache */
/* search858_0 -> replace815 in the cache */

/* search858_1_0 -> search699_1 in the cache */
/* search858_1 -> search855_1 in the cache */
static const nir_search_expression search858 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &replace815.value, &search855_1.value },
   NULL,
};

   /* replace858_0 -> search98_0_0 in the cache */

/* replace858_1_0 -> search699_1 in the cache */
/* replace858_1 -> replace831_1 in the cache */
/* replace858 -> replace834 in the cache */

   /* search859_0_0 -> search835_0_0 in the cache */
static const nir_search_expression search859_0 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_i2i64,
   { &search835_0_0.value },
   NULL,
};

/* search859_1_0 -> search835_1_0 in the cache */
static const nir_search_expression search859_1 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_i2i64,
   { &search835_1_0.value },
   NULL,
};
static const nir_search_expression search859 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search859_0.value, &search859_1.value },
   NULL,
};

   /* replace859_0_0 -> search835_0_0 in the cache */
/* replace859_0 -> replace835_0 in the cache */

/* replace859_1 -> search835_1_0 in the cache */
/* replace859 -> replace835 in the cache */

   /* search860_0_0 -> search835_0_0 in the cache */
/* search860_0 -> search859_0 in the cache */

/* search860_1_0 -> search835_1_0 in the cache */
/* search860_1 -> search859_1 in the cache */
static const nir_search_expression search860 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search859_0.value, &search859_1.value },
   NULL,
};

   /* replace860_0_0 -> search835_0_0 in the cache */
/* replace860_0 -> replace835_0 in the cache */

/* replace860_1 -> search835_1_0 in the cache */
/* replace860 -> replace836 in the cache */

   /* search861_0_0 -> search98_0_0 in the cache */
/* search861_0 -> replace815 in the cache */

static const nir_search_variable search861_1 = {
   { nir_search_value_variable, 64 },
   1, /* b */
   true,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search861 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &replace815.value, &search861_1.value },
   NULL,
};

   /* replace861_0_0 -> search98_0_0 in the cache */

/* replace861_0_1_0 -> search57_1_1 in the cache */
static const nir_search_expression replace861_0_1 = {
   { nir_search_value_expression, 8 },
   false,
   -1, 0,
   nir_op_i2i8,
   { &search57_1_1.value },
   NULL,
};
static const nir_search_expression replace861_0 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ieq,
   { &search98_0_0.value, &replace861_0_1.value },
   NULL,
};

/* replace861_1_0_0_0 -> search57_1_1 in the cache */
/* replace861_1_0_0 -> replace861_0_1 in the cache */
static const nir_search_expression replace861_1_0 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_i2i64,
   { &replace861_0_1.value },
   NULL,
};

/* replace861_1_1 -> search57_1_1 in the cache */
static const nir_search_expression replace861_1 = {
   { nir_search_value_expression, 1 },
   false,
   2, 1,
   nir_op_ieq,
   { &replace861_1_0.value, &search57_1_1.value },
   NULL,
};
static const nir_search_expression replace861 = {
   { nir_search_value_expression, 1 },
   false,
   0, 3,
   nir_op_iand,
   { &replace861_0.value, &replace861_1.value },
   NULL,
};

   /* search862_0_0 -> search98_0_0 in the cache */
/* search862_0 -> replace815 in the cache */

/* search862_1 -> search861_1 in the cache */
static const nir_search_expression search862 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &replace815.value, &search861_1.value },
   NULL,
};

   /* replace862_0_0 -> search98_0_0 in the cache */

/* replace862_0_1_0 -> search57_1_1 in the cache */
/* replace862_0_1 -> replace861_0_1 in the cache */
static const nir_search_expression replace862_0 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ine,
   { &search98_0_0.value, &replace861_0_1.value },
   NULL,
};

/* replace862_1_0_0_0 -> search57_1_1 in the cache */
/* replace862_1_0_0 -> replace861_0_1 in the cache */
/* replace862_1_0 -> replace861_1_0 in the cache */

/* replace862_1_1 -> search57_1_1 in the cache */
static const nir_search_expression replace862_1 = {
   { nir_search_value_expression, 1 },
   false,
   2, 1,
   nir_op_ine,
   { &replace861_1_0.value, &search57_1_1.value },
   NULL,
};
static const nir_search_expression replace862 = {
   { nir_search_value_expression, 1 },
   false,
   0, 3,
   nir_op_ior,
   { &replace862_0.value, &replace862_1.value },
   NULL,
};

   /* search863_0_0 -> search98_0_0 in the cache */
/* search863_0 -> replace815 in the cache */

/* search863_1 -> search861_1 in the cache */
static const nir_search_expression search863 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &replace815.value, &search861_1.value },
   NULL,
};

   static const nir_search_constant replace863_0_0 = {
   { nir_search_value_constant, 64 },
   nir_type_int, { -0x80 /* -128 */ },
};

/* replace863_0_1 -> search57_1_1 in the cache */
static const nir_search_expression replace863_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &replace863_0_0.value, &search57_1_1.value },
   NULL,
};

static const nir_search_constant replace863_1_0_0 = {
   { nir_search_value_constant, 64 },
   nir_type_int, { 0x7f /* 127 */ },
};

/* replace863_1_0_1 -> search57_1_1 in the cache */
static const nir_search_expression replace863_1_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &replace863_1_0_0.value, &search57_1_1.value },
   NULL,
};

/* replace863_1_1_0 -> search98_0_0 in the cache */

/* replace863_1_1_1_0 -> search57_1_1 in the cache */
/* replace863_1_1_1 -> replace861_0_1 in the cache */
static const nir_search_expression replace863_1_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search98_0_0.value, &replace861_0_1.value },
   NULL,
};
static const nir_search_expression replace863_1 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ior,
   { &replace863_1_0.value, &replace863_1_1.value },
   NULL,
};
static const nir_search_expression replace863 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &replace863_0.value, &replace863_1.value },
   NULL,
};

   static const nir_search_variable search864_0 = {
   { nir_search_value_variable, 64 },
   0, /* a */
   true,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

/* search864_1_0 -> search699_1 in the cache */
/* search864_1 -> search855_1 in the cache */
static const nir_search_expression search864 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search864_0.value, &search855_1.value },
   NULL,
};

   /* replace864_0_0 -> search57_0 in the cache */

/* replace864_0_1 -> replace863_1_0_0 in the cache */
static const nir_search_expression replace864_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search57_0.value, &replace863_1_0_0.value },
   NULL,
};

/* replace864_1_0_0 -> search57_0 in the cache */

/* replace864_1_0_1 -> replace863_0_0 in the cache */
static const nir_search_expression replace864_1_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search57_0.value, &replace863_0_0.value },
   NULL,
};

/* replace864_1_1_0_0 -> search57_0 in the cache */
static const nir_search_expression replace864_1_1_0 = {
   { nir_search_value_expression, 8 },
   false,
   -1, 0,
   nir_op_i2i8,
   { &search57_0.value },
   NULL,
};

/* replace864_1_1_1 -> search699_1 in the cache */
static const nir_search_expression replace864_1_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &replace864_1_1_0.value, &search699_1.value },
   NULL,
};
static const nir_search_expression replace864_1 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ior,
   { &replace864_1_0.value, &replace864_1_1.value },
   NULL,
};
static const nir_search_expression replace864 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &replace864_0.value, &replace864_1.value },
   NULL,
};

   /* search865_0_0 -> search98_0_0 in the cache */
/* search865_0 -> replace815 in the cache */

/* search865_1 -> search861_1 in the cache */
static const nir_search_expression search865 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &replace815.value, &search861_1.value },
   NULL,
};

   /* replace865_0_0 -> replace863_1_0_0 in the cache */

/* replace865_0_1 -> search57_1_1 in the cache */
static const nir_search_expression replace865_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &replace863_1_0_0.value, &search57_1_1.value },
   NULL,
};

/* replace865_1_0_0 -> replace863_0_0 in the cache */

/* replace865_1_0_1 -> search57_1_1 in the cache */
static const nir_search_expression replace865_1_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &replace863_0_0.value, &search57_1_1.value },
   NULL,
};

/* replace865_1_1_0 -> search98_0_0 in the cache */

/* replace865_1_1_1_0 -> search57_1_1 in the cache */
/* replace865_1_1_1 -> replace861_0_1 in the cache */
static const nir_search_expression replace865_1_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search98_0_0.value, &replace861_0_1.value },
   NULL,
};
static const nir_search_expression replace865_1 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ior,
   { &replace865_1_0.value, &replace865_1_1.value },
   NULL,
};
static const nir_search_expression replace865 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &replace865_0.value, &replace865_1.value },
   NULL,
};

   /* search866_0 -> search864_0 in the cache */

/* search866_1_0 -> search699_1 in the cache */
/* search866_1 -> search855_1 in the cache */
static const nir_search_expression search866 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search864_0.value, &search855_1.value },
   NULL,
};

   /* replace866_0_0 -> search57_0 in the cache */

/* replace866_0_1 -> replace863_0_0 in the cache */
static const nir_search_expression replace866_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search57_0.value, &replace863_0_0.value },
   NULL,
};

/* replace866_1_0_0 -> search57_0 in the cache */

/* replace866_1_0_1 -> replace863_1_0_0 in the cache */
static const nir_search_expression replace866_1_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search57_0.value, &replace863_1_0_0.value },
   NULL,
};

/* replace866_1_1_0_0 -> search57_0 in the cache */
/* replace866_1_1_0 -> replace864_1_1_0 in the cache */

/* replace866_1_1_1 -> search699_1 in the cache */
static const nir_search_expression replace866_1_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &replace864_1_1_0.value, &search699_1.value },
   NULL,
};
static const nir_search_expression replace866_1 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ior,
   { &replace866_1_0.value, &replace866_1_1.value },
   NULL,
};
static const nir_search_expression replace866 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &replace866_0.value, &replace866_1.value },
   NULL,
};

   /* search867_0_0 -> search101_0_0 in the cache */
/* search867_0 -> replace805 in the cache */

/* search867_1_0 -> search699_1 in the cache */
/* search867_1 -> search843_1 in the cache */
static const nir_search_expression search867 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &replace805.value, &search843_1.value },
   NULL,
};

   /* replace867_0 -> search101_0_0 in the cache */

/* replace867_1_0 -> search699_1 in the cache */
/* replace867_1 -> search831_1 in the cache */
static const nir_search_expression replace867 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &search101_0_0.value, &search831_1.value },
   NULL,
};

   /* search868_0_0 -> search101_0_0 in the cache */
/* search868_0 -> replace805 in the cache */

/* search868_1_0 -> search699_1 in the cache */
/* search868_1 -> search843_1 in the cache */
static const nir_search_expression search868 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &replace805.value, &search843_1.value },
   NULL,
};

   /* replace868_0 -> search101_0_0 in the cache */

/* replace868_1_0 -> search699_1 in the cache */
/* replace868_1 -> search831_1 in the cache */
static const nir_search_expression replace868 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &search101_0_0.value, &search831_1.value },
   NULL,
};

   /* search869_0_0 -> search101_0_0 in the cache */
/* search869_0 -> replace805 in the cache */

/* search869_1_0 -> search699_1 in the cache */
/* search869_1 -> search843_1 in the cache */
static const nir_search_expression search869 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &replace805.value, &search843_1.value },
   NULL,
};

   /* replace869_0 -> search101_0_0 in the cache */

/* replace869_1_0 -> search699_1 in the cache */
/* replace869_1 -> search831_1 in the cache */
static const nir_search_expression replace869 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search101_0_0.value, &search831_1.value },
   NULL,
};

   /* search870_0_0 -> search101_0_0 in the cache */
/* search870_0 -> replace805 in the cache */

/* search870_1_0 -> search699_1 in the cache */
/* search870_1 -> search843_1 in the cache */
static const nir_search_expression search870 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &replace805.value, &search843_1.value },
   NULL,
};

   /* replace870_0 -> search101_0_0 in the cache */

/* replace870_1_0 -> search699_1 in the cache */
/* replace870_1 -> search831_1 in the cache */
static const nir_search_expression replace870 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search101_0_0.value, &search831_1.value },
   NULL,
};

   /* search871_0_0 -> search835_0_0 in the cache */
/* search871_0 -> search847_0 in the cache */

static const nir_search_variable search871_1_0 = {
   { nir_search_value_variable, 16 },
   1, /* a */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search871_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_i2i32,
   { &search871_1_0.value },
   NULL,
};
static const nir_search_expression search871 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search847_0.value, &search871_1.value },
   NULL,
};

   /* replace871_0_0 -> search835_0_0 in the cache */
/* replace871_0 -> search835_0 in the cache */

/* replace871_1 -> search871_1_0 in the cache */
static const nir_search_expression replace871 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search835_0.value, &search871_1_0.value },
   NULL,
};

   /* search872_0_0 -> search835_0_0 in the cache */
/* search872_0 -> search847_0 in the cache */

/* search872_1_0 -> search871_1_0 in the cache */
/* search872_1 -> search871_1 in the cache */
static const nir_search_expression search872 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search847_0.value, &search871_1.value },
   NULL,
};

   /* replace872_0_0 -> search835_0_0 in the cache */
/* replace872_0 -> search835_0 in the cache */

/* replace872_1 -> search871_1_0 in the cache */
static const nir_search_expression replace872 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search835_0.value, &search871_1_0.value },
   NULL,
};

   /* search873_0_0 -> search101_0_0 in the cache */
/* search873_0 -> replace805 in the cache */

/* search873_1_0 -> replace564_1_0 in the cache */
static const nir_search_expression search873_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_i2i32,
   { &replace564_1_0.value },
   NULL,
};
static const nir_search_expression search873 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &replace805.value, &search873_1.value },
   NULL,
};

   /* replace873_0 -> search101_0_0 in the cache */

/* replace873_1_0 -> replace564_1_0 in the cache */
static const nir_search_expression replace873_1 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_i2i16,
   { &replace564_1_0.value },
   NULL,
};
static const nir_search_expression replace873 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &search101_0_0.value, &replace873_1.value },
   NULL,
};

   /* search874_0_0 -> search101_0_0 in the cache */
/* search874_0 -> replace805 in the cache */

/* search874_1_0 -> replace564_1_0 in the cache */
/* search874_1 -> search873_1 in the cache */
static const nir_search_expression search874 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &replace805.value, &search873_1.value },
   NULL,
};

   /* replace874_0 -> search101_0_0 in the cache */

/* replace874_1_0 -> replace564_1_0 in the cache */
/* replace874_1 -> replace873_1 in the cache */
static const nir_search_expression replace874 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &search101_0_0.value, &replace873_1.value },
   NULL,
};

   /* search875_0_0 -> search101_0_0 in the cache */
/* search875_0 -> replace805 in the cache */

/* search875_1_0 -> replace564_1_0 in the cache */
/* search875_1 -> search873_1 in the cache */
static const nir_search_expression search875 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &replace805.value, &search873_1.value },
   NULL,
};

   /* replace875_0 -> search101_0_0 in the cache */

/* replace875_1_0 -> replace564_1_0 in the cache */
/* replace875_1 -> replace873_1 in the cache */
static const nir_search_expression replace875 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search101_0_0.value, &replace873_1.value },
   NULL,
};

   /* search876_0_0 -> search101_0_0 in the cache */
/* search876_0 -> replace805 in the cache */

/* search876_1_0 -> replace564_1_0 in the cache */
/* search876_1 -> search873_1 in the cache */
static const nir_search_expression search876 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &replace805.value, &search873_1.value },
   NULL,
};

   /* replace876_0 -> search101_0_0 in the cache */

/* replace876_1_0 -> replace564_1_0 in the cache */
/* replace876_1 -> replace873_1 in the cache */
static const nir_search_expression replace876 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search101_0_0.value, &replace873_1.value },
   NULL,
};

   static const nir_search_variable search877_0_0 = {
   { nir_search_value_variable, 16 },
   0, /* b */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search877_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_i2i32,
   { &search877_0_0.value },
   NULL,
};

/* search877_1_0 -> search871_1_0 in the cache */
/* search877_1 -> search871_1 in the cache */
static const nir_search_expression search877 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search877_0.value, &search871_1.value },
   NULL,
};

   /* replace877_0_0 -> search877_0_0 in the cache */
static const nir_search_expression replace877_0 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_i2i16,
   { &search877_0_0.value },
   NULL,
};

/* replace877_1 -> search871_1_0 in the cache */
static const nir_search_expression replace877 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &replace877_0.value, &search871_1_0.value },
   NULL,
};

   /* search878_0_0 -> search877_0_0 in the cache */
/* search878_0 -> search877_0 in the cache */

/* search878_1_0 -> search871_1_0 in the cache */
/* search878_1 -> search871_1 in the cache */
static const nir_search_expression search878 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search877_0.value, &search871_1.value },
   NULL,
};

   /* replace878_0_0 -> search877_0_0 in the cache */
/* replace878_0 -> replace877_0 in the cache */

/* replace878_1 -> search871_1_0 in the cache */
static const nir_search_expression replace878 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &replace877_0.value, &search871_1_0.value },
   NULL,
};

   /* search879_0_0 -> search101_0_0 in the cache */
/* search879_0 -> replace805 in the cache */

/* search879_1 -> search2_1 in the cache */
static const nir_search_expression search879 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &replace805.value, &search2_1.value },
   NULL,
};

   /* replace879_0_0 -> search101_0_0 in the cache */

/* replace879_0_1_0 -> replace0_1_0 in the cache */
static const nir_search_expression replace879_0_1 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_i2i16,
   { &replace0_1_0.value },
   NULL,
};
static const nir_search_expression replace879_0 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ieq,
   { &search101_0_0.value, &replace879_0_1.value },
   NULL,
};

/* replace879_1_0_0_0 -> replace0_1_0 in the cache */
/* replace879_1_0_0 -> replace879_0_1 in the cache */
static const nir_search_expression replace879_1_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_i2i32,
   { &replace879_0_1.value },
   NULL,
};

/* replace879_1_1 -> replace0_1_0 in the cache */
static const nir_search_expression replace879_1 = {
   { nir_search_value_expression, 1 },
   false,
   2, 1,
   nir_op_ieq,
   { &replace879_1_0.value, &replace0_1_0.value },
   NULL,
};
static const nir_search_expression replace879 = {
   { nir_search_value_expression, 1 },
   false,
   0, 3,
   nir_op_iand,
   { &replace879_0.value, &replace879_1.value },
   NULL,
};

   /* search880_0_0 -> search101_0_0 in the cache */
/* search880_0 -> replace805 in the cache */

/* search880_1 -> search2_1 in the cache */
static const nir_search_expression search880 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &replace805.value, &search2_1.value },
   NULL,
};

   /* replace880_0_0 -> search101_0_0 in the cache */

/* replace880_0_1_0 -> replace0_1_0 in the cache */
/* replace880_0_1 -> replace879_0_1 in the cache */
static const nir_search_expression replace880_0 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ine,
   { &search101_0_0.value, &replace879_0_1.value },
   NULL,
};

/* replace880_1_0_0_0 -> replace0_1_0 in the cache */
/* replace880_1_0_0 -> replace879_0_1 in the cache */
/* replace880_1_0 -> replace879_1_0 in the cache */

/* replace880_1_1 -> replace0_1_0 in the cache */
static const nir_search_expression replace880_1 = {
   { nir_search_value_expression, 1 },
   false,
   2, 1,
   nir_op_ine,
   { &replace879_1_0.value, &replace0_1_0.value },
   NULL,
};
static const nir_search_expression replace880 = {
   { nir_search_value_expression, 1 },
   false,
   0, 3,
   nir_op_ior,
   { &replace880_0.value, &replace880_1.value },
   NULL,
};

   /* search881_0_0 -> search101_0_0 in the cache */
/* search881_0 -> replace805 in the cache */

/* search881_1 -> search2_1 in the cache */
static const nir_search_expression search881 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &replace805.value, &search2_1.value },
   NULL,
};

   static const nir_search_constant replace881_0_0 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { -0x8000 /* -32768 */ },
};

/* replace881_0_1 -> replace0_1_0 in the cache */
static const nir_search_expression replace881_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &replace881_0_0.value, &replace0_1_0.value },
   NULL,
};

static const nir_search_constant replace881_1_0_0 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { 0x7fff /* 32767 */ },
};

/* replace881_1_0_1 -> replace0_1_0 in the cache */
static const nir_search_expression replace881_1_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &replace881_1_0_0.value, &replace0_1_0.value },
   NULL,
};

/* replace881_1_1_0 -> search101_0_0 in the cache */

/* replace881_1_1_1_0 -> replace0_1_0 in the cache */
/* replace881_1_1_1 -> replace879_0_1 in the cache */
static const nir_search_expression replace881_1_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search101_0_0.value, &replace879_0_1.value },
   NULL,
};
static const nir_search_expression replace881_1 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ior,
   { &replace881_1_0.value, &replace881_1_1.value },
   NULL,
};
static const nir_search_expression replace881 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &replace881_0.value, &replace881_1.value },
   NULL,
};

   /* search882_0 -> search852_0 in the cache */

/* search882_1_0 -> replace564_1_0 in the cache */
/* search882_1 -> search873_1 in the cache */
static const nir_search_expression search882 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search852_0.value, &search873_1.value },
   NULL,
};

   /* replace882_0_0 -> search0_0 in the cache */

/* replace882_0_1 -> replace881_1_0_0 in the cache */
static const nir_search_expression replace882_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search0_0.value, &replace881_1_0_0.value },
   NULL,
};

/* replace882_1_0_0 -> search0_0 in the cache */

/* replace882_1_0_1 -> replace881_0_0 in the cache */
static const nir_search_expression replace882_1_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search0_0.value, &replace881_0_0.value },
   NULL,
};

/* replace882_1_1_0_0 -> search0_0 in the cache */
static const nir_search_expression replace882_1_1_0 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_i2i16,
   { &search0_0.value },
   NULL,
};

/* replace882_1_1_1 -> replace564_1_0 in the cache */
static const nir_search_expression replace882_1_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &replace882_1_1_0.value, &replace564_1_0.value },
   NULL,
};
static const nir_search_expression replace882_1 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ior,
   { &replace882_1_0.value, &replace882_1_1.value },
   NULL,
};
static const nir_search_expression replace882 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &replace882_0.value, &replace882_1.value },
   NULL,
};

   /* search883_0_0 -> search101_0_0 in the cache */
/* search883_0 -> replace805 in the cache */

/* search883_1 -> search2_1 in the cache */
static const nir_search_expression search883 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &replace805.value, &search2_1.value },
   NULL,
};

   /* replace883_0_0 -> replace881_1_0_0 in the cache */

/* replace883_0_1 -> replace0_1_0 in the cache */
static const nir_search_expression replace883_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &replace881_1_0_0.value, &replace0_1_0.value },
   NULL,
};

/* replace883_1_0_0 -> replace881_0_0 in the cache */

/* replace883_1_0_1 -> replace0_1_0 in the cache */
static const nir_search_expression replace883_1_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &replace881_0_0.value, &replace0_1_0.value },
   NULL,
};

/* replace883_1_1_0 -> search101_0_0 in the cache */

/* replace883_1_1_1_0 -> replace0_1_0 in the cache */
/* replace883_1_1_1 -> replace879_0_1 in the cache */
static const nir_search_expression replace883_1_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search101_0_0.value, &replace879_0_1.value },
   NULL,
};
static const nir_search_expression replace883_1 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ior,
   { &replace883_1_0.value, &replace883_1_1.value },
   NULL,
};
static const nir_search_expression replace883 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &replace883_0.value, &replace883_1.value },
   NULL,
};

   /* search884_0 -> search852_0 in the cache */

/* search884_1_0 -> replace564_1_0 in the cache */
/* search884_1 -> search873_1 in the cache */
static const nir_search_expression search884 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search852_0.value, &search873_1.value },
   NULL,
};

   /* replace884_0_0 -> search0_0 in the cache */

/* replace884_0_1 -> replace881_0_0 in the cache */
static const nir_search_expression replace884_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search0_0.value, &replace881_0_0.value },
   NULL,
};

/* replace884_1_0_0 -> search0_0 in the cache */

/* replace884_1_0_1 -> replace881_1_0_0 in the cache */
static const nir_search_expression replace884_1_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search0_0.value, &replace881_1_0_0.value },
   NULL,
};

/* replace884_1_1_0_0 -> search0_0 in the cache */
/* replace884_1_1_0 -> replace882_1_1_0 in the cache */

/* replace884_1_1_1 -> replace564_1_0 in the cache */
static const nir_search_expression replace884_1_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &replace882_1_1_0.value, &replace564_1_0.value },
   NULL,
};
static const nir_search_expression replace884_1 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ior,
   { &replace884_1_0.value, &replace884_1_1.value },
   NULL,
};
static const nir_search_expression replace884 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &replace884_0.value, &replace884_1.value },
   NULL,
};

   /* search885_0_0 -> search101_0_0 in the cache */
/* search885_0 -> replace821 in the cache */

/* search885_1_0 -> search699_1 in the cache */
/* search885_1 -> search855_1 in the cache */
static const nir_search_expression search885 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &replace821.value, &search855_1.value },
   NULL,
};

   /* replace885_0 -> search101_0_0 in the cache */

/* replace885_1_0 -> search699_1 in the cache */
/* replace885_1 -> search831_1 in the cache */
/* replace885 -> replace867 in the cache */

   /* search886_0_0 -> search101_0_0 in the cache */
/* search886_0 -> replace821 in the cache */

/* search886_1_0 -> search699_1 in the cache */
/* search886_1 -> search855_1 in the cache */
static const nir_search_expression search886 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &replace821.value, &search855_1.value },
   NULL,
};

   /* replace886_0 -> search101_0_0 in the cache */

/* replace886_1_0 -> search699_1 in the cache */
/* replace886_1 -> search831_1 in the cache */
/* replace886 -> replace868 in the cache */

   /* search887_0_0 -> search101_0_0 in the cache */
/* search887_0 -> replace821 in the cache */

/* search887_1_0 -> search699_1 in the cache */
/* search887_1 -> search855_1 in the cache */
static const nir_search_expression search887 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &replace821.value, &search855_1.value },
   NULL,
};

   /* replace887_0 -> search101_0_0 in the cache */

/* replace887_1_0 -> search699_1 in the cache */
/* replace887_1 -> search831_1 in the cache */
/* replace887 -> replace869 in the cache */

   /* search888_0_0 -> search101_0_0 in the cache */
/* search888_0 -> replace821 in the cache */

/* search888_1_0 -> search699_1 in the cache */
/* search888_1 -> search855_1 in the cache */
static const nir_search_expression search888 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &replace821.value, &search855_1.value },
   NULL,
};

   /* replace888_0 -> search101_0_0 in the cache */

/* replace888_1_0 -> search699_1 in the cache */
/* replace888_1 -> search831_1 in the cache */
/* replace888 -> replace870 in the cache */

   /* search889_0_0 -> search835_0_0 in the cache */
/* search889_0 -> search859_0 in the cache */

/* search889_1_0 -> search871_1_0 in the cache */
static const nir_search_expression search889_1 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_i2i64,
   { &search871_1_0.value },
   NULL,
};
static const nir_search_expression search889 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search859_0.value, &search889_1.value },
   NULL,
};

   /* replace889_0_0 -> search835_0_0 in the cache */
/* replace889_0 -> search835_0 in the cache */

/* replace889_1 -> search871_1_0 in the cache */
/* replace889 -> replace871 in the cache */

   /* search890_0_0 -> search835_0_0 in the cache */
/* search890_0 -> search859_0 in the cache */

/* search890_1_0 -> search871_1_0 in the cache */
/* search890_1 -> search889_1 in the cache */
static const nir_search_expression search890 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search859_0.value, &search889_1.value },
   NULL,
};

   /* replace890_0_0 -> search835_0_0 in the cache */
/* replace890_0 -> search835_0 in the cache */

/* replace890_1 -> search871_1_0 in the cache */
/* replace890 -> replace872 in the cache */

   /* search891_0_0 -> search101_0_0 in the cache */
/* search891_0 -> replace821 in the cache */

/* search891_1_0 -> replace564_1_0 in the cache */
static const nir_search_expression search891_1 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_i2i64,
   { &replace564_1_0.value },
   NULL,
};
static const nir_search_expression search891 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &replace821.value, &search891_1.value },
   NULL,
};

   /* replace891_0 -> search101_0_0 in the cache */

/* replace891_1_0 -> replace564_1_0 in the cache */
/* replace891_1 -> replace873_1 in the cache */
/* replace891 -> replace873 in the cache */

   /* search892_0_0 -> search101_0_0 in the cache */
/* search892_0 -> replace821 in the cache */

/* search892_1_0 -> replace564_1_0 in the cache */
/* search892_1 -> search891_1 in the cache */
static const nir_search_expression search892 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &replace821.value, &search891_1.value },
   NULL,
};

   /* replace892_0 -> search101_0_0 in the cache */

/* replace892_1_0 -> replace564_1_0 in the cache */
/* replace892_1 -> replace873_1 in the cache */
/* replace892 -> replace874 in the cache */

   /* search893_0_0 -> search101_0_0 in the cache */
/* search893_0 -> replace821 in the cache */

/* search893_1_0 -> replace564_1_0 in the cache */
/* search893_1 -> search891_1 in the cache */
static const nir_search_expression search893 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &replace821.value, &search891_1.value },
   NULL,
};

   /* replace893_0 -> search101_0_0 in the cache */

/* replace893_1_0 -> replace564_1_0 in the cache */
/* replace893_1 -> replace873_1 in the cache */
/* replace893 -> replace875 in the cache */

   /* search894_0_0 -> search101_0_0 in the cache */
/* search894_0 -> replace821 in the cache */

/* search894_1_0 -> replace564_1_0 in the cache */
/* search894_1 -> search891_1 in the cache */
static const nir_search_expression search894 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &replace821.value, &search891_1.value },
   NULL,
};

   /* replace894_0 -> search101_0_0 in the cache */

/* replace894_1_0 -> replace564_1_0 in the cache */
/* replace894_1 -> replace873_1 in the cache */
/* replace894 -> replace876 in the cache */

   /* search895_0_0 -> search877_0_0 in the cache */
static const nir_search_expression search895_0 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_i2i64,
   { &search877_0_0.value },
   NULL,
};

/* search895_1_0 -> search871_1_0 in the cache */
/* search895_1 -> search889_1 in the cache */
static const nir_search_expression search895 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search895_0.value, &search889_1.value },
   NULL,
};

   /* replace895_0_0 -> search877_0_0 in the cache */
/* replace895_0 -> replace877_0 in the cache */

/* replace895_1 -> search871_1_0 in the cache */
/* replace895 -> replace877 in the cache */

   /* search896_0_0 -> search877_0_0 in the cache */
/* search896_0 -> search895_0 in the cache */

/* search896_1_0 -> search871_1_0 in the cache */
/* search896_1 -> search889_1 in the cache */
static const nir_search_expression search896 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search895_0.value, &search889_1.value },
   NULL,
};

   /* replace896_0_0 -> search877_0_0 in the cache */
/* replace896_0 -> replace877_0 in the cache */

/* replace896_1 -> search871_1_0 in the cache */
/* replace896 -> replace878 in the cache */

   /* search897_0_0 -> search101_0_0 in the cache */
/* search897_0 -> replace821 in the cache */

/* search897_1 -> search861_1 in the cache */
static const nir_search_expression search897 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &replace821.value, &search861_1.value },
   NULL,
};

   /* replace897_0_0 -> search101_0_0 in the cache */

/* replace897_0_1_0 -> search57_1_1 in the cache */
static const nir_search_expression replace897_0_1 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_i2i16,
   { &search57_1_1.value },
   NULL,
};
static const nir_search_expression replace897_0 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ieq,
   { &search101_0_0.value, &replace897_0_1.value },
   NULL,
};

/* replace897_1_0_0_0 -> search57_1_1 in the cache */
/* replace897_1_0_0 -> replace897_0_1 in the cache */
static const nir_search_expression replace897_1_0 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_i2i64,
   { &replace897_0_1.value },
   NULL,
};

/* replace897_1_1 -> search57_1_1 in the cache */
static const nir_search_expression replace897_1 = {
   { nir_search_value_expression, 1 },
   false,
   2, 1,
   nir_op_ieq,
   { &replace897_1_0.value, &search57_1_1.value },
   NULL,
};
static const nir_search_expression replace897 = {
   { nir_search_value_expression, 1 },
   false,
   0, 3,
   nir_op_iand,
   { &replace897_0.value, &replace897_1.value },
   NULL,
};

   /* search898_0_0 -> search101_0_0 in the cache */
/* search898_0 -> replace821 in the cache */

/* search898_1 -> search861_1 in the cache */
static const nir_search_expression search898 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &replace821.value, &search861_1.value },
   NULL,
};

   /* replace898_0_0 -> search101_0_0 in the cache */

/* replace898_0_1_0 -> search57_1_1 in the cache */
/* replace898_0_1 -> replace897_0_1 in the cache */
static const nir_search_expression replace898_0 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ine,
   { &search101_0_0.value, &replace897_0_1.value },
   NULL,
};

/* replace898_1_0_0_0 -> search57_1_1 in the cache */
/* replace898_1_0_0 -> replace897_0_1 in the cache */
/* replace898_1_0 -> replace897_1_0 in the cache */

/* replace898_1_1 -> search57_1_1 in the cache */
static const nir_search_expression replace898_1 = {
   { nir_search_value_expression, 1 },
   false,
   2, 1,
   nir_op_ine,
   { &replace897_1_0.value, &search57_1_1.value },
   NULL,
};
static const nir_search_expression replace898 = {
   { nir_search_value_expression, 1 },
   false,
   0, 3,
   nir_op_ior,
   { &replace898_0.value, &replace898_1.value },
   NULL,
};

   /* search899_0_0 -> search101_0_0 in the cache */
/* search899_0 -> replace821 in the cache */

/* search899_1 -> search861_1 in the cache */
static const nir_search_expression search899 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &replace821.value, &search861_1.value },
   NULL,
};

   static const nir_search_constant replace899_0_0 = {
   { nir_search_value_constant, 64 },
   nir_type_int, { -0x8000 /* -32768 */ },
};

/* replace899_0_1 -> search57_1_1 in the cache */
static const nir_search_expression replace899_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &replace899_0_0.value, &search57_1_1.value },
   NULL,
};

static const nir_search_constant replace899_1_0_0 = {
   { nir_search_value_constant, 64 },
   nir_type_int, { 0x7fff /* 32767 */ },
};

/* replace899_1_0_1 -> search57_1_1 in the cache */
static const nir_search_expression replace899_1_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &replace899_1_0_0.value, &search57_1_1.value },
   NULL,
};

/* replace899_1_1_0 -> search101_0_0 in the cache */

/* replace899_1_1_1_0 -> search57_1_1 in the cache */
/* replace899_1_1_1 -> replace897_0_1 in the cache */
static const nir_search_expression replace899_1_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search101_0_0.value, &replace897_0_1.value },
   NULL,
};
static const nir_search_expression replace899_1 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ior,
   { &replace899_1_0.value, &replace899_1_1.value },
   NULL,
};
static const nir_search_expression replace899 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &replace899_0.value, &replace899_1.value },
   NULL,
};

   /* search900_0 -> search864_0 in the cache */

/* search900_1_0 -> replace564_1_0 in the cache */
/* search900_1 -> search891_1 in the cache */
static const nir_search_expression search900 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search864_0.value, &search891_1.value },
   NULL,
};

   /* replace900_0_0 -> search57_0 in the cache */

/* replace900_0_1 -> replace899_1_0_0 in the cache */
static const nir_search_expression replace900_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search57_0.value, &replace899_1_0_0.value },
   NULL,
};

/* replace900_1_0_0 -> search57_0 in the cache */

/* replace900_1_0_1 -> replace899_0_0 in the cache */
static const nir_search_expression replace900_1_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search57_0.value, &replace899_0_0.value },
   NULL,
};

/* replace900_1_1_0_0 -> search57_0 in the cache */
static const nir_search_expression replace900_1_1_0 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_i2i16,
   { &search57_0.value },
   NULL,
};

/* replace900_1_1_1 -> replace564_1_0 in the cache */
static const nir_search_expression replace900_1_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &replace900_1_1_0.value, &replace564_1_0.value },
   NULL,
};
static const nir_search_expression replace900_1 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ior,
   { &replace900_1_0.value, &replace900_1_1.value },
   NULL,
};
static const nir_search_expression replace900 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &replace900_0.value, &replace900_1.value },
   NULL,
};

   /* search901_0_0 -> search101_0_0 in the cache */
/* search901_0 -> replace821 in the cache */

/* search901_1 -> search861_1 in the cache */
static const nir_search_expression search901 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &replace821.value, &search861_1.value },
   NULL,
};

   /* replace901_0_0 -> replace899_1_0_0 in the cache */

/* replace901_0_1 -> search57_1_1 in the cache */
static const nir_search_expression replace901_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &replace899_1_0_0.value, &search57_1_1.value },
   NULL,
};

/* replace901_1_0_0 -> replace899_0_0 in the cache */

/* replace901_1_0_1 -> search57_1_1 in the cache */
static const nir_search_expression replace901_1_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &replace899_0_0.value, &search57_1_1.value },
   NULL,
};

/* replace901_1_1_0 -> search101_0_0 in the cache */

/* replace901_1_1_1_0 -> search57_1_1 in the cache */
/* replace901_1_1_1 -> replace897_0_1 in the cache */
static const nir_search_expression replace901_1_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search101_0_0.value, &replace897_0_1.value },
   NULL,
};
static const nir_search_expression replace901_1 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ior,
   { &replace901_1_0.value, &replace901_1_1.value },
   NULL,
};
static const nir_search_expression replace901 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &replace901_0.value, &replace901_1.value },
   NULL,
};

   /* search902_0 -> search864_0 in the cache */

/* search902_1_0 -> replace564_1_0 in the cache */
/* search902_1 -> search891_1 in the cache */
static const nir_search_expression search902 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search864_0.value, &search891_1.value },
   NULL,
};

   /* replace902_0_0 -> search57_0 in the cache */

/* replace902_0_1 -> replace899_0_0 in the cache */
static const nir_search_expression replace902_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search57_0.value, &replace899_0_0.value },
   NULL,
};

/* replace902_1_0_0 -> search57_0 in the cache */

/* replace902_1_0_1 -> replace899_1_0_0 in the cache */
static const nir_search_expression replace902_1_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search57_0.value, &replace899_1_0_0.value },
   NULL,
};

/* replace902_1_1_0_0 -> search57_0 in the cache */
/* replace902_1_1_0 -> replace900_1_1_0 in the cache */

/* replace902_1_1_1 -> replace564_1_0 in the cache */
static const nir_search_expression replace902_1_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &replace900_1_1_0.value, &replace564_1_0.value },
   NULL,
};
static const nir_search_expression replace902_1 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ior,
   { &replace902_1_0.value, &replace902_1_1.value },
   NULL,
};
static const nir_search_expression replace902 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &replace902_0.value, &replace902_1.value },
   NULL,
};

   /* search903_0_0 -> search0_0 in the cache */
/* search903_0 -> replace829 in the cache */

/* search903_1_0 -> search699_1 in the cache */
/* search903_1 -> search855_1 in the cache */
static const nir_search_expression search903 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &replace829.value, &search855_1.value },
   NULL,
};

   /* replace903_0 -> search0_0 in the cache */

/* replace903_1_0 -> search699_1 in the cache */
/* replace903_1 -> search843_1 in the cache */
static const nir_search_expression replace903 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &search0_0.value, &search843_1.value },
   NULL,
};

   /* search904_0_0 -> search0_0 in the cache */
/* search904_0 -> replace829 in the cache */

/* search904_1_0 -> search699_1 in the cache */
/* search904_1 -> search855_1 in the cache */
static const nir_search_expression search904 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &replace829.value, &search855_1.value },
   NULL,
};

   /* replace904_0 -> search0_0 in the cache */

/* replace904_1_0 -> search699_1 in the cache */
/* replace904_1 -> search843_1 in the cache */
static const nir_search_expression replace904 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &search0_0.value, &search843_1.value },
   NULL,
};

   /* search905_0_0 -> search0_0 in the cache */
/* search905_0 -> replace829 in the cache */

/* search905_1_0 -> search699_1 in the cache */
/* search905_1 -> search855_1 in the cache */
static const nir_search_expression search905 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &replace829.value, &search855_1.value },
   NULL,
};

   /* replace905_0 -> search0_0 in the cache */

/* replace905_1_0 -> search699_1 in the cache */
/* replace905_1 -> search843_1 in the cache */
static const nir_search_expression replace905 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search0_0.value, &search843_1.value },
   NULL,
};

   /* search906_0_0 -> search0_0 in the cache */
/* search906_0 -> replace829 in the cache */

/* search906_1_0 -> search699_1 in the cache */
/* search906_1 -> search855_1 in the cache */
static const nir_search_expression search906 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &replace829.value, &search855_1.value },
   NULL,
};

   /* replace906_0 -> search0_0 in the cache */

/* replace906_1_0 -> search699_1 in the cache */
/* replace906_1 -> search843_1 in the cache */
static const nir_search_expression replace906 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search0_0.value, &search843_1.value },
   NULL,
};

   /* search907_0_0 -> search835_0_0 in the cache */
/* search907_0 -> search859_0 in the cache */

static const nir_search_variable search907_1_0 = {
   { nir_search_value_variable, 32 },
   1, /* a */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search907_1 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_i2i64,
   { &search907_1_0.value },
   NULL,
};
static const nir_search_expression search907 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search859_0.value, &search907_1.value },
   NULL,
};

   /* replace907_0_0 -> search835_0_0 in the cache */
/* replace907_0 -> search847_0 in the cache */

/* replace907_1 -> search907_1_0 in the cache */
static const nir_search_expression replace907 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search847_0.value, &search907_1_0.value },
   NULL,
};

   /* search908_0_0 -> search835_0_0 in the cache */
/* search908_0 -> search859_0 in the cache */

/* search908_1_0 -> search907_1_0 in the cache */
/* search908_1 -> search907_1 in the cache */
static const nir_search_expression search908 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search859_0.value, &search907_1.value },
   NULL,
};

   /* replace908_0_0 -> search835_0_0 in the cache */
/* replace908_0 -> search847_0 in the cache */

/* replace908_1 -> search907_1_0 in the cache */
static const nir_search_expression replace908 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search847_0.value, &search907_1_0.value },
   NULL,
};

   /* search909_0_0 -> search0_0 in the cache */
/* search909_0 -> replace829 in the cache */

/* search909_1_0 -> replace564_1_0 in the cache */
/* search909_1 -> search891_1 in the cache */
static const nir_search_expression search909 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &replace829.value, &search891_1.value },
   NULL,
};

   /* replace909_0 -> search0_0 in the cache */

/* replace909_1_0 -> replace564_1_0 in the cache */
/* replace909_1 -> search873_1 in the cache */
static const nir_search_expression replace909 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &search0_0.value, &search873_1.value },
   NULL,
};

   /* search910_0_0 -> search0_0 in the cache */
/* search910_0 -> replace829 in the cache */

/* search910_1_0 -> replace564_1_0 in the cache */
/* search910_1 -> search891_1 in the cache */
static const nir_search_expression search910 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &replace829.value, &search891_1.value },
   NULL,
};

   /* replace910_0 -> search0_0 in the cache */

/* replace910_1_0 -> replace564_1_0 in the cache */
/* replace910_1 -> search873_1 in the cache */
static const nir_search_expression replace910 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &search0_0.value, &search873_1.value },
   NULL,
};

   /* search911_0_0 -> search0_0 in the cache */
/* search911_0 -> replace829 in the cache */

/* search911_1_0 -> replace564_1_0 in the cache */
/* search911_1 -> search891_1 in the cache */
static const nir_search_expression search911 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &replace829.value, &search891_1.value },
   NULL,
};

   /* replace911_0 -> search0_0 in the cache */

/* replace911_1_0 -> replace564_1_0 in the cache */
/* replace911_1 -> search873_1 in the cache */
static const nir_search_expression replace911 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search0_0.value, &search873_1.value },
   NULL,
};

   /* search912_0_0 -> search0_0 in the cache */
/* search912_0 -> replace829 in the cache */

/* search912_1_0 -> replace564_1_0 in the cache */
/* search912_1 -> search891_1 in the cache */
static const nir_search_expression search912 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &replace829.value, &search891_1.value },
   NULL,
};

   /* replace912_0 -> search0_0 in the cache */

/* replace912_1_0 -> replace564_1_0 in the cache */
/* replace912_1 -> search873_1 in the cache */
static const nir_search_expression replace912 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search0_0.value, &search873_1.value },
   NULL,
};

   /* search913_0_0 -> search877_0_0 in the cache */
/* search913_0 -> search895_0 in the cache */

/* search913_1_0 -> search907_1_0 in the cache */
/* search913_1 -> search907_1 in the cache */
static const nir_search_expression search913 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search895_0.value, &search907_1.value },
   NULL,
};

   /* replace913_0_0 -> search877_0_0 in the cache */
/* replace913_0 -> search877_0 in the cache */

/* replace913_1 -> search907_1_0 in the cache */
static const nir_search_expression replace913 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search877_0.value, &search907_1_0.value },
   NULL,
};

   /* search914_0_0 -> search877_0_0 in the cache */
/* search914_0 -> search895_0 in the cache */

/* search914_1_0 -> search907_1_0 in the cache */
/* search914_1 -> search907_1 in the cache */
static const nir_search_expression search914 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search895_0.value, &search907_1.value },
   NULL,
};

   /* replace914_0_0 -> search877_0_0 in the cache */
/* replace914_0 -> search877_0 in the cache */

/* replace914_1 -> search907_1_0 in the cache */
static const nir_search_expression replace914 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search877_0.value, &search907_1_0.value },
   NULL,
};

   /* search915_0_0 -> search0_0 in the cache */
/* search915_0 -> replace829 in the cache */

/* search915_1_0 -> replace0_1_0 in the cache */
static const nir_search_expression search915_1 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_i2i64,
   { &replace0_1_0.value },
   NULL,
};
static const nir_search_expression search915 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &replace829.value, &search915_1.value },
   NULL,
};

   /* replace915_0 -> search0_0 in the cache */

/* replace915_1_0 -> replace0_1_0 in the cache */
static const nir_search_expression replace915_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_i2i32,
   { &replace0_1_0.value },
   NULL,
};
static const nir_search_expression replace915 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &search0_0.value, &replace915_1.value },
   NULL,
};

   /* search916_0_0 -> search0_0 in the cache */
/* search916_0 -> replace829 in the cache */

/* search916_1_0 -> replace0_1_0 in the cache */
/* search916_1 -> search915_1 in the cache */
static const nir_search_expression search916 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &replace829.value, &search915_1.value },
   NULL,
};

   /* replace916_0 -> search0_0 in the cache */

/* replace916_1_0 -> replace0_1_0 in the cache */
/* replace916_1 -> replace915_1 in the cache */
static const nir_search_expression replace916 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &search0_0.value, &replace915_1.value },
   NULL,
};

   /* search917_0_0 -> search0_0 in the cache */
/* search917_0 -> replace829 in the cache */

/* search917_1_0 -> replace0_1_0 in the cache */
/* search917_1 -> search915_1 in the cache */
static const nir_search_expression search917 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &replace829.value, &search915_1.value },
   NULL,
};

   /* replace917_0 -> search0_0 in the cache */

/* replace917_1_0 -> replace0_1_0 in the cache */
/* replace917_1 -> replace915_1 in the cache */
static const nir_search_expression replace917 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search0_0.value, &replace915_1.value },
   NULL,
};

   /* search918_0_0 -> search0_0 in the cache */
/* search918_0 -> replace829 in the cache */

/* search918_1_0 -> replace0_1_0 in the cache */
/* search918_1 -> search915_1 in the cache */
static const nir_search_expression search918 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &replace829.value, &search915_1.value },
   NULL,
};

   /* replace918_0 -> search0_0 in the cache */

/* replace918_1_0 -> replace0_1_0 in the cache */
/* replace918_1 -> replace915_1 in the cache */
static const nir_search_expression replace918 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search0_0.value, &replace915_1.value },
   NULL,
};

   static const nir_search_variable search919_0_0 = {
   { nir_search_value_variable, 32 },
   0, /* b */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search919_0 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_i2i64,
   { &search919_0_0.value },
   NULL,
};

/* search919_1_0 -> search907_1_0 in the cache */
/* search919_1 -> search907_1 in the cache */
static const nir_search_expression search919 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search919_0.value, &search907_1.value },
   NULL,
};

   /* replace919_0_0 -> search919_0_0 in the cache */
static const nir_search_expression replace919_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_i2i32,
   { &search919_0_0.value },
   NULL,
};

/* replace919_1 -> search907_1_0 in the cache */
static const nir_search_expression replace919 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &replace919_0.value, &search907_1_0.value },
   NULL,
};

   /* search920_0_0 -> search919_0_0 in the cache */
/* search920_0 -> search919_0 in the cache */

/* search920_1_0 -> search907_1_0 in the cache */
/* search920_1 -> search907_1 in the cache */
static const nir_search_expression search920 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search919_0.value, &search907_1.value },
   NULL,
};

   /* replace920_0_0 -> search919_0_0 in the cache */
/* replace920_0 -> replace919_0 in the cache */

/* replace920_1 -> search907_1_0 in the cache */
static const nir_search_expression replace920 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &replace919_0.value, &search907_1_0.value },
   NULL,
};

   /* search921_0_0 -> search0_0 in the cache */
/* search921_0 -> replace829 in the cache */

/* search921_1 -> search861_1 in the cache */
static const nir_search_expression search921 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &replace829.value, &search861_1.value },
   NULL,
};

   /* replace921_0_0 -> search0_0 in the cache */

/* replace921_0_1_0 -> search57_1_1 in the cache */
static const nir_search_expression replace921_0_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_i2i32,
   { &search57_1_1.value },
   NULL,
};
static const nir_search_expression replace921_0 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ieq,
   { &search0_0.value, &replace921_0_1.value },
   NULL,
};

/* replace921_1_0_0_0 -> search57_1_1 in the cache */
/* replace921_1_0_0 -> replace921_0_1 in the cache */
static const nir_search_expression replace921_1_0 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_i2i64,
   { &replace921_0_1.value },
   NULL,
};

/* replace921_1_1 -> search57_1_1 in the cache */
static const nir_search_expression replace921_1 = {
   { nir_search_value_expression, 1 },
   false,
   2, 1,
   nir_op_ieq,
   { &replace921_1_0.value, &search57_1_1.value },
   NULL,
};
static const nir_search_expression replace921 = {
   { nir_search_value_expression, 1 },
   false,
   0, 3,
   nir_op_iand,
   { &replace921_0.value, &replace921_1.value },
   NULL,
};

   /* search922_0_0 -> search0_0 in the cache */
/* search922_0 -> replace829 in the cache */

/* search922_1 -> search861_1 in the cache */
static const nir_search_expression search922 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &replace829.value, &search861_1.value },
   NULL,
};

   /* replace922_0_0 -> search0_0 in the cache */

/* replace922_0_1_0 -> search57_1_1 in the cache */
/* replace922_0_1 -> replace921_0_1 in the cache */
static const nir_search_expression replace922_0 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ine,
   { &search0_0.value, &replace921_0_1.value },
   NULL,
};

/* replace922_1_0_0_0 -> search57_1_1 in the cache */
/* replace922_1_0_0 -> replace921_0_1 in the cache */
/* replace922_1_0 -> replace921_1_0 in the cache */

/* replace922_1_1 -> search57_1_1 in the cache */
static const nir_search_expression replace922_1 = {
   { nir_search_value_expression, 1 },
   false,
   2, 1,
   nir_op_ine,
   { &replace921_1_0.value, &search57_1_1.value },
   NULL,
};
static const nir_search_expression replace922 = {
   { nir_search_value_expression, 1 },
   false,
   0, 3,
   nir_op_ior,
   { &replace922_0.value, &replace922_1.value },
   NULL,
};

   /* search923_0_0 -> search0_0 in the cache */
/* search923_0 -> replace829 in the cache */

/* search923_1 -> search861_1 in the cache */
static const nir_search_expression search923 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &replace829.value, &search861_1.value },
   NULL,
};

   static const nir_search_constant replace923_0_0 = {
   { nir_search_value_constant, 64 },
   nir_type_int, { -0x80000000 /* -2147483648 */ },
};

/* replace923_0_1 -> search57_1_1 in the cache */
static const nir_search_expression replace923_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &replace923_0_0.value, &search57_1_1.value },
   NULL,
};

static const nir_search_constant replace923_1_0_0 = {
   { nir_search_value_constant, 64 },
   nir_type_int, { 0x7fffffff /* 2147483647 */ },
};

/* replace923_1_0_1 -> search57_1_1 in the cache */
static const nir_search_expression replace923_1_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &replace923_1_0_0.value, &search57_1_1.value },
   NULL,
};

/* replace923_1_1_0 -> search0_0 in the cache */

/* replace923_1_1_1_0 -> search57_1_1 in the cache */
/* replace923_1_1_1 -> replace921_0_1 in the cache */
static const nir_search_expression replace923_1_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search0_0.value, &replace921_0_1.value },
   NULL,
};
static const nir_search_expression replace923_1 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ior,
   { &replace923_1_0.value, &replace923_1_1.value },
   NULL,
};
static const nir_search_expression replace923 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &replace923_0.value, &replace923_1.value },
   NULL,
};

   /* search924_0 -> search864_0 in the cache */

/* search924_1_0 -> replace0_1_0 in the cache */
/* search924_1 -> search915_1 in the cache */
static const nir_search_expression search924 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search864_0.value, &search915_1.value },
   NULL,
};

   /* replace924_0_0 -> search57_0 in the cache */

/* replace924_0_1 -> replace923_1_0_0 in the cache */
static const nir_search_expression replace924_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search57_0.value, &replace923_1_0_0.value },
   NULL,
};

/* replace924_1_0_0 -> search57_0 in the cache */

/* replace924_1_0_1 -> replace923_0_0 in the cache */
static const nir_search_expression replace924_1_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search57_0.value, &replace923_0_0.value },
   NULL,
};

/* replace924_1_1_0_0 -> search57_0 in the cache */
static const nir_search_expression replace924_1_1_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_i2i32,
   { &search57_0.value },
   NULL,
};

/* replace924_1_1_1 -> replace0_1_0 in the cache */
static const nir_search_expression replace924_1_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &replace924_1_1_0.value, &replace0_1_0.value },
   NULL,
};
static const nir_search_expression replace924_1 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ior,
   { &replace924_1_0.value, &replace924_1_1.value },
   NULL,
};
static const nir_search_expression replace924 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &replace924_0.value, &replace924_1.value },
   NULL,
};

   /* search925_0_0 -> search0_0 in the cache */
/* search925_0 -> replace829 in the cache */

/* search925_1 -> search861_1 in the cache */
static const nir_search_expression search925 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &replace829.value, &search861_1.value },
   NULL,
};

   /* replace925_0_0 -> replace923_1_0_0 in the cache */

/* replace925_0_1 -> search57_1_1 in the cache */
static const nir_search_expression replace925_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &replace923_1_0_0.value, &search57_1_1.value },
   NULL,
};

/* replace925_1_0_0 -> replace923_0_0 in the cache */

/* replace925_1_0_1 -> search57_1_1 in the cache */
static const nir_search_expression replace925_1_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &replace923_0_0.value, &search57_1_1.value },
   NULL,
};

/* replace925_1_1_0 -> search0_0 in the cache */

/* replace925_1_1_1_0 -> search57_1_1 in the cache */
/* replace925_1_1_1 -> replace921_0_1 in the cache */
static const nir_search_expression replace925_1_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search0_0.value, &replace921_0_1.value },
   NULL,
};
static const nir_search_expression replace925_1 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ior,
   { &replace925_1_0.value, &replace925_1_1.value },
   NULL,
};
static const nir_search_expression replace925 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &replace925_0.value, &replace925_1.value },
   NULL,
};

   /* search926_0 -> search864_0 in the cache */

/* search926_1_0 -> replace0_1_0 in the cache */
/* search926_1 -> search915_1 in the cache */
static const nir_search_expression search926 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search864_0.value, &search915_1.value },
   NULL,
};

   /* replace926_0_0 -> search57_0 in the cache */

/* replace926_0_1 -> replace923_0_0 in the cache */
static const nir_search_expression replace926_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search57_0.value, &replace923_0_0.value },
   NULL,
};

/* replace926_1_0_0 -> search57_0 in the cache */

/* replace926_1_0_1 -> replace923_1_0_0 in the cache */
static const nir_search_expression replace926_1_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search57_0.value, &replace923_1_0_0.value },
   NULL,
};

/* replace926_1_1_0_0 -> search57_0 in the cache */
/* replace926_1_1_0 -> replace924_1_1_0 in the cache */

/* replace926_1_1_1 -> replace0_1_0 in the cache */
static const nir_search_expression replace926_1_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &replace924_1_1_0.value, &replace0_1_0.value },
   NULL,
};
static const nir_search_expression replace926_1 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ior,
   { &replace926_1_0.value, &replace926_1_1.value },
   NULL,
};
static const nir_search_expression replace926 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &replace926_0.value, &replace926_1.value },
   NULL,
};

   /* search927_0_0 -> search98_0_0 in the cache */
/* search927_0 -> replace786 in the cache */

/* search927_1_0 -> search699_1 in the cache */
static const nir_search_expression search927_1 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_u2u16,
   { &search699_1.value },
   NULL,
};
static const nir_search_expression search927 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &replace786.value, &search927_1.value },
   NULL,
};

   /* replace927_0 -> search98_0_0 in the cache */

/* replace927_1_0 -> search699_1 in the cache */
static const nir_search_expression replace927_1 = {
   { nir_search_value_expression, 8 },
   false,
   -1, 0,
   nir_op_u2u8,
   { &search699_1.value },
   NULL,
};
static const nir_search_expression replace927 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &search98_0_0.value, &replace927_1.value },
   NULL,
};

   /* search928_0_0 -> search98_0_0 in the cache */
/* search928_0 -> replace786 in the cache */

/* search928_1_0 -> search699_1 in the cache */
/* search928_1 -> search927_1 in the cache */
static const nir_search_expression search928 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &replace786.value, &search927_1.value },
   NULL,
};

   /* replace928_0 -> search98_0_0 in the cache */

/* replace928_1_0 -> search699_1 in the cache */
/* replace928_1 -> replace927_1 in the cache */
static const nir_search_expression replace928 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &search98_0_0.value, &replace927_1.value },
   NULL,
};

   /* search929_0_0 -> search98_0_0 in the cache */
/* search929_0 -> replace786 in the cache */

/* search929_1_0 -> search699_1 in the cache */
/* search929_1 -> search927_1 in the cache */
static const nir_search_expression search929 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &replace786.value, &search927_1.value },
   NULL,
};

   /* replace929_0 -> search98_0_0 in the cache */

/* replace929_1_0 -> search699_1 in the cache */
/* replace929_1 -> replace927_1 in the cache */
static const nir_search_expression replace929 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search98_0_0.value, &replace927_1.value },
   NULL,
};

   /* search930_0_0 -> search98_0_0 in the cache */
/* search930_0 -> replace786 in the cache */

/* search930_1_0 -> search699_1 in the cache */
/* search930_1 -> search927_1 in the cache */
static const nir_search_expression search930 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &replace786.value, &search927_1.value },
   NULL,
};

   /* replace930_0 -> search98_0_0 in the cache */

/* replace930_1_0 -> search699_1 in the cache */
/* replace930_1 -> replace927_1 in the cache */
static const nir_search_expression replace930 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search98_0_0.value, &replace927_1.value },
   NULL,
};

   /* search931_0_0 -> search835_0_0 in the cache */
static const nir_search_expression search931_0 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_u2u16,
   { &search835_0_0.value },
   NULL,
};

/* search931_1_0 -> search835_1_0 in the cache */
static const nir_search_expression search931_1 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_u2u16,
   { &search835_1_0.value },
   NULL,
};
static const nir_search_expression search931 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search931_0.value, &search931_1.value },
   NULL,
};

   /* replace931_0_0 -> search835_0_0 in the cache */
static const nir_search_expression replace931_0 = {
   { nir_search_value_expression, 8 },
   false,
   -1, 0,
   nir_op_u2u8,
   { &search835_0_0.value },
   NULL,
};

/* replace931_1 -> search835_1_0 in the cache */
static const nir_search_expression replace931 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &replace931_0.value, &search835_1_0.value },
   NULL,
};

   /* search932_0_0 -> search835_0_0 in the cache */
/* search932_0 -> search931_0 in the cache */

/* search932_1_0 -> search835_1_0 in the cache */
/* search932_1 -> search931_1 in the cache */
static const nir_search_expression search932 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search931_0.value, &search931_1.value },
   NULL,
};

   /* replace932_0_0 -> search835_0_0 in the cache */
/* replace932_0 -> replace931_0 in the cache */

/* replace932_1 -> search835_1_0 in the cache */
static const nir_search_expression replace932 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &replace931_0.value, &search835_1_0.value },
   NULL,
};

   /* search933_0_0 -> search98_0_0 in the cache */
/* search933_0 -> replace786 in the cache */

/* search933_1 -> search564_0_1 in the cache */
static const nir_search_expression search933 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &replace786.value, &search564_0_1.value },
   NULL,
};

   /* replace933_0_0 -> search98_0_0 in the cache */

/* replace933_0_1_0 -> replace564_1_0 in the cache */
static const nir_search_expression replace933_0_1 = {
   { nir_search_value_expression, 8 },
   false,
   -1, 0,
   nir_op_u2u8,
   { &replace564_1_0.value },
   NULL,
};
static const nir_search_expression replace933_0 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ieq,
   { &search98_0_0.value, &replace933_0_1.value },
   NULL,
};

/* replace933_1_0_0_0 -> replace564_1_0 in the cache */
/* replace933_1_0_0 -> replace933_0_1 in the cache */
static const nir_search_expression replace933_1_0 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_u2u16,
   { &replace933_0_1.value },
   NULL,
};

/* replace933_1_1 -> replace564_1_0 in the cache */
static const nir_search_expression replace933_1 = {
   { nir_search_value_expression, 1 },
   false,
   2, 1,
   nir_op_ieq,
   { &replace933_1_0.value, &replace564_1_0.value },
   NULL,
};
static const nir_search_expression replace933 = {
   { nir_search_value_expression, 1 },
   false,
   0, 3,
   nir_op_iand,
   { &replace933_0.value, &replace933_1.value },
   NULL,
};

   /* search934_0_0 -> search98_0_0 in the cache */
/* search934_0 -> replace786 in the cache */

/* search934_1 -> search564_0_1 in the cache */
static const nir_search_expression search934 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &replace786.value, &search564_0_1.value },
   NULL,
};

   /* replace934_0_0 -> search98_0_0 in the cache */

/* replace934_0_1_0 -> replace564_1_0 in the cache */
/* replace934_0_1 -> replace933_0_1 in the cache */
static const nir_search_expression replace934_0 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ine,
   { &search98_0_0.value, &replace933_0_1.value },
   NULL,
};

/* replace934_1_0_0_0 -> replace564_1_0 in the cache */
/* replace934_1_0_0 -> replace933_0_1 in the cache */
/* replace934_1_0 -> replace933_1_0 in the cache */

/* replace934_1_1 -> replace564_1_0 in the cache */
static const nir_search_expression replace934_1 = {
   { nir_search_value_expression, 1 },
   false,
   2, 1,
   nir_op_ine,
   { &replace933_1_0.value, &replace564_1_0.value },
   NULL,
};
static const nir_search_expression replace934 = {
   { nir_search_value_expression, 1 },
   false,
   0, 3,
   nir_op_ior,
   { &replace934_0.value, &replace934_1.value },
   NULL,
};

   /* search935_0_0 -> search98_0_0 in the cache */
/* search935_0 -> replace786 in the cache */

/* search935_1 -> search564_0_1 in the cache */
static const nir_search_expression search935 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &replace786.value, &search564_0_1.value },
   NULL,
};

   /* replace935_0_0 -> replace101_2 in the cache */

/* replace935_0_1 -> replace564_1_0 in the cache */
static const nir_search_expression replace935_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &replace101_2.value, &replace564_1_0.value },
   NULL,
};

static const nir_search_constant replace935_1_0_0 = {
   { nir_search_value_constant, 16 },
   nir_type_int, { 0xff /* 255 */ },
};

/* replace935_1_0_1 -> replace564_1_0 in the cache */
static const nir_search_expression replace935_1_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &replace935_1_0_0.value, &replace564_1_0.value },
   NULL,
};

/* replace935_1_1_0 -> search98_0_0 in the cache */

/* replace935_1_1_1_0 -> replace564_1_0 in the cache */
/* replace935_1_1_1 -> replace933_0_1 in the cache */
static const nir_search_expression replace935_1_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search98_0_0.value, &replace933_0_1.value },
   NULL,
};
static const nir_search_expression replace935_1 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ior,
   { &replace935_1_0.value, &replace935_1_1.value },
   NULL,
};
static const nir_search_expression replace935 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &replace935_0.value, &replace935_1.value },
   NULL,
};

   /* search936_0 -> search840_0 in the cache */

/* search936_1_0 -> search699_1 in the cache */
/* search936_1 -> search927_1 in the cache */
static const nir_search_expression search936 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search840_0.value, &search927_1.value },
   NULL,
};

   /* replace936_0_0 -> search101_0_0 in the cache */

/* replace936_0_1 -> replace935_1_0_0 in the cache */
static const nir_search_expression replace936_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search101_0_0.value, &replace935_1_0_0.value },
   NULL,
};

/* replace936_1_0_0 -> search101_0_0 in the cache */

/* replace936_1_0_1 -> replace101_2 in the cache */
static const nir_search_expression replace936_1_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search101_0_0.value, &replace101_2.value },
   NULL,
};

/* replace936_1_1_0_0 -> search101_0_0 in the cache */
static const nir_search_expression replace936_1_1_0 = {
   { nir_search_value_expression, 8 },
   false,
   -1, 0,
   nir_op_u2u8,
   { &search101_0_0.value },
   NULL,
};

/* replace936_1_1_1 -> search699_1 in the cache */
static const nir_search_expression replace936_1_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &replace936_1_1_0.value, &search699_1.value },
   NULL,
};
static const nir_search_expression replace936_1 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ior,
   { &replace936_1_0.value, &replace936_1_1.value },
   NULL,
};
static const nir_search_expression replace936 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &replace936_0.value, &replace936_1.value },
   NULL,
};

   /* search937_0_0 -> search98_0_0 in the cache */
/* search937_0 -> replace786 in the cache */

/* search937_1 -> search564_0_1 in the cache */
static const nir_search_expression search937 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &replace786.value, &search564_0_1.value },
   NULL,
};

   /* replace937_0_0 -> replace935_1_0_0 in the cache */

/* replace937_0_1 -> replace564_1_0 in the cache */
static const nir_search_expression replace937_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &replace935_1_0_0.value, &replace564_1_0.value },
   NULL,
};

/* replace937_1_0_0 -> replace101_2 in the cache */

/* replace937_1_0_1 -> replace564_1_0 in the cache */
static const nir_search_expression replace937_1_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &replace101_2.value, &replace564_1_0.value },
   NULL,
};

/* replace937_1_1_0 -> search98_0_0 in the cache */

/* replace937_1_1_1_0 -> replace564_1_0 in the cache */
/* replace937_1_1_1 -> replace933_0_1 in the cache */
static const nir_search_expression replace937_1_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search98_0_0.value, &replace933_0_1.value },
   NULL,
};
static const nir_search_expression replace937_1 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ior,
   { &replace937_1_0.value, &replace937_1_1.value },
   NULL,
};
static const nir_search_expression replace937 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &replace937_0.value, &replace937_1.value },
   NULL,
};

   /* search938_0 -> search840_0 in the cache */

/* search938_1_0 -> search699_1 in the cache */
/* search938_1 -> search927_1 in the cache */
static const nir_search_expression search938 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search840_0.value, &search927_1.value },
   NULL,
};

   /* replace938_0_0 -> search101_0_0 in the cache */

/* replace938_0_1 -> replace101_2 in the cache */
static const nir_search_expression replace938_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search101_0_0.value, &replace101_2.value },
   NULL,
};

/* replace938_1_0_0 -> search101_0_0 in the cache */

/* replace938_1_0_1 -> replace935_1_0_0 in the cache */
static const nir_search_expression replace938_1_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search101_0_0.value, &replace935_1_0_0.value },
   NULL,
};

/* replace938_1_1_0_0 -> search101_0_0 in the cache */
/* replace938_1_1_0 -> replace936_1_1_0 in the cache */

/* replace938_1_1_1 -> search699_1 in the cache */
static const nir_search_expression replace938_1_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &replace936_1_1_0.value, &search699_1.value },
   NULL,
};
static const nir_search_expression replace938_1 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ior,
   { &replace938_1_0.value, &replace938_1_1.value },
   NULL,
};
static const nir_search_expression replace938 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &replace938_0.value, &replace938_1.value },
   NULL,
};

   /* search939_0_0 -> search98_0_0 in the cache */
/* search939_0 -> replace800 in the cache */

/* search939_1_0 -> search699_1 in the cache */
static const nir_search_expression search939_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_u2u32,
   { &search699_1.value },
   NULL,
};
static const nir_search_expression search939 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &replace800.value, &search939_1.value },
   NULL,
};

   /* replace939_0 -> search98_0_0 in the cache */

/* replace939_1_0 -> search699_1 in the cache */
/* replace939_1 -> replace927_1 in the cache */
/* replace939 -> replace927 in the cache */

   /* search940_0_0 -> search98_0_0 in the cache */
/* search940_0 -> replace800 in the cache */

/* search940_1_0 -> search699_1 in the cache */
/* search940_1 -> search939_1 in the cache */
static const nir_search_expression search940 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &replace800.value, &search939_1.value },
   NULL,
};

   /* replace940_0 -> search98_0_0 in the cache */

/* replace940_1_0 -> search699_1 in the cache */
/* replace940_1 -> replace927_1 in the cache */
/* replace940 -> replace928 in the cache */

   /* search941_0_0 -> search98_0_0 in the cache */
/* search941_0 -> replace800 in the cache */

/* search941_1_0 -> search699_1 in the cache */
/* search941_1 -> search939_1 in the cache */
static const nir_search_expression search941 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &replace800.value, &search939_1.value },
   NULL,
};

   /* replace941_0 -> search98_0_0 in the cache */

/* replace941_1_0 -> search699_1 in the cache */
/* replace941_1 -> replace927_1 in the cache */
/* replace941 -> replace929 in the cache */

   /* search942_0_0 -> search98_0_0 in the cache */
/* search942_0 -> replace800 in the cache */

/* search942_1_0 -> search699_1 in the cache */
/* search942_1 -> search939_1 in the cache */
static const nir_search_expression search942 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &replace800.value, &search939_1.value },
   NULL,
};

   /* replace942_0 -> search98_0_0 in the cache */

/* replace942_1_0 -> search699_1 in the cache */
/* replace942_1 -> replace927_1 in the cache */
/* replace942 -> replace930 in the cache */

   /* search943_0_0 -> search835_0_0 in the cache */
static const nir_search_expression search943_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_u2u32,
   { &search835_0_0.value },
   NULL,
};

/* search943_1_0 -> search835_1_0 in the cache */
static const nir_search_expression search943_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_u2u32,
   { &search835_1_0.value },
   NULL,
};
static const nir_search_expression search943 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search943_0.value, &search943_1.value },
   NULL,
};

   /* replace943_0_0 -> search835_0_0 in the cache */
/* replace943_0 -> replace931_0 in the cache */

/* replace943_1 -> search835_1_0 in the cache */
/* replace943 -> replace931 in the cache */

   /* search944_0_0 -> search835_0_0 in the cache */
/* search944_0 -> search943_0 in the cache */

/* search944_1_0 -> search835_1_0 in the cache */
/* search944_1 -> search943_1 in the cache */
static const nir_search_expression search944 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search943_0.value, &search943_1.value },
   NULL,
};

   /* replace944_0_0 -> search835_0_0 in the cache */
/* replace944_0 -> replace931_0 in the cache */

/* replace944_1 -> search835_1_0 in the cache */
/* replace944 -> replace932 in the cache */

   /* search945_0_0 -> search98_0_0 in the cache */
/* search945_0 -> replace800 in the cache */

/* search945_1 -> search2_1 in the cache */
static const nir_search_expression search945 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &replace800.value, &search2_1.value },
   NULL,
};

   /* replace945_0_0 -> search98_0_0 in the cache */

/* replace945_0_1_0 -> replace0_1_0 in the cache */
static const nir_search_expression replace945_0_1 = {
   { nir_search_value_expression, 8 },
   false,
   -1, 0,
   nir_op_u2u8,
   { &replace0_1_0.value },
   NULL,
};
static const nir_search_expression replace945_0 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ieq,
   { &search98_0_0.value, &replace945_0_1.value },
   NULL,
};

/* replace945_1_0_0_0 -> replace0_1_0 in the cache */
/* replace945_1_0_0 -> replace945_0_1 in the cache */
static const nir_search_expression replace945_1_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_u2u32,
   { &replace945_0_1.value },
   NULL,
};

/* replace945_1_1 -> replace0_1_0 in the cache */
static const nir_search_expression replace945_1 = {
   { nir_search_value_expression, 1 },
   false,
   2, 1,
   nir_op_ieq,
   { &replace945_1_0.value, &replace0_1_0.value },
   NULL,
};
static const nir_search_expression replace945 = {
   { nir_search_value_expression, 1 },
   false,
   0, 3,
   nir_op_iand,
   { &replace945_0.value, &replace945_1.value },
   NULL,
};

   /* search946_0_0 -> search98_0_0 in the cache */
/* search946_0 -> replace800 in the cache */

/* search946_1 -> search2_1 in the cache */
static const nir_search_expression search946 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &replace800.value, &search2_1.value },
   NULL,
};

   /* replace946_0_0 -> search98_0_0 in the cache */

/* replace946_0_1_0 -> replace0_1_0 in the cache */
/* replace946_0_1 -> replace945_0_1 in the cache */
static const nir_search_expression replace946_0 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ine,
   { &search98_0_0.value, &replace945_0_1.value },
   NULL,
};

/* replace946_1_0_0_0 -> replace0_1_0 in the cache */
/* replace946_1_0_0 -> replace945_0_1 in the cache */
/* replace946_1_0 -> replace945_1_0 in the cache */

/* replace946_1_1 -> replace0_1_0 in the cache */
static const nir_search_expression replace946_1 = {
   { nir_search_value_expression, 1 },
   false,
   2, 1,
   nir_op_ine,
   { &replace945_1_0.value, &replace0_1_0.value },
   NULL,
};
static const nir_search_expression replace946 = {
   { nir_search_value_expression, 1 },
   false,
   0, 3,
   nir_op_ior,
   { &replace946_0.value, &replace946_1.value },
   NULL,
};

   /* search947_0_0 -> search98_0_0 in the cache */
/* search947_0 -> replace800 in the cache */

/* search947_1 -> search2_1 in the cache */
static const nir_search_expression search947 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &replace800.value, &search2_1.value },
   NULL,
};

   /* replace947_0_0 -> search26_1 in the cache */

/* replace947_0_1 -> replace0_1_0 in the cache */
static const nir_search_expression replace947_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search26_1.value, &replace0_1_0.value },
   NULL,
};

/* replace947_1_0_0 -> replace98_0_0_0_1 in the cache */

/* replace947_1_0_1 -> replace0_1_0 in the cache */
static const nir_search_expression replace947_1_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &replace98_0_0_0_1.value, &replace0_1_0.value },
   NULL,
};

/* replace947_1_1_0 -> search98_0_0 in the cache */

/* replace947_1_1_1_0 -> replace0_1_0 in the cache */
/* replace947_1_1_1 -> replace945_0_1 in the cache */
static const nir_search_expression replace947_1_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search98_0_0.value, &replace945_0_1.value },
   NULL,
};
static const nir_search_expression replace947_1 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ior,
   { &replace947_1_0.value, &replace947_1_1.value },
   NULL,
};
static const nir_search_expression replace947 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &replace947_0.value, &replace947_1.value },
   NULL,
};

   /* search948_0 -> search852_0 in the cache */

/* search948_1_0 -> search699_1 in the cache */
/* search948_1 -> search939_1 in the cache */
static const nir_search_expression search948 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search852_0.value, &search939_1.value },
   NULL,
};

   /* replace948_0_0 -> search0_0 in the cache */

/* replace948_0_1 -> replace98_0_0_0_1 in the cache */
static const nir_search_expression replace948_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search0_0.value, &replace98_0_0_0_1.value },
   NULL,
};

/* replace948_1_0_0 -> search0_0 in the cache */

/* replace948_1_0_1 -> search26_1 in the cache */
static const nir_search_expression replace948_1_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search0_0.value, &search26_1.value },
   NULL,
};

/* replace948_1_1_0_0 -> search0_0 in the cache */
static const nir_search_expression replace948_1_1_0 = {
   { nir_search_value_expression, 8 },
   false,
   -1, 0,
   nir_op_u2u8,
   { &search0_0.value },
   NULL,
};

/* replace948_1_1_1 -> search699_1 in the cache */
static const nir_search_expression replace948_1_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &replace948_1_1_0.value, &search699_1.value },
   NULL,
};
static const nir_search_expression replace948_1 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ior,
   { &replace948_1_0.value, &replace948_1_1.value },
   NULL,
};
static const nir_search_expression replace948 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &replace948_0.value, &replace948_1.value },
   NULL,
};

   /* search949_0_0 -> search98_0_0 in the cache */
/* search949_0 -> replace800 in the cache */

/* search949_1 -> search2_1 in the cache */
static const nir_search_expression search949 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &replace800.value, &search2_1.value },
   NULL,
};

   /* replace949_0_0 -> replace98_0_0_0_1 in the cache */

/* replace949_0_1 -> replace0_1_0 in the cache */
static const nir_search_expression replace949_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &replace98_0_0_0_1.value, &replace0_1_0.value },
   NULL,
};

/* replace949_1_0_0 -> search26_1 in the cache */

/* replace949_1_0_1 -> replace0_1_0 in the cache */
static const nir_search_expression replace949_1_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search26_1.value, &replace0_1_0.value },
   NULL,
};

/* replace949_1_1_0 -> search98_0_0 in the cache */

/* replace949_1_1_1_0 -> replace0_1_0 in the cache */
/* replace949_1_1_1 -> replace945_0_1 in the cache */
static const nir_search_expression replace949_1_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search98_0_0.value, &replace945_0_1.value },
   NULL,
};
static const nir_search_expression replace949_1 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ior,
   { &replace949_1_0.value, &replace949_1_1.value },
   NULL,
};
static const nir_search_expression replace949 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &replace949_0.value, &replace949_1.value },
   NULL,
};

   /* search950_0 -> search852_0 in the cache */

/* search950_1_0 -> search699_1 in the cache */
/* search950_1 -> search939_1 in the cache */
static const nir_search_expression search950 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search852_0.value, &search939_1.value },
   NULL,
};

   /* replace950_0_0 -> search0_0 in the cache */

/* replace950_0_1 -> search26_1 in the cache */
static const nir_search_expression replace950_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search0_0.value, &search26_1.value },
   NULL,
};

/* replace950_1_0_0 -> search0_0 in the cache */

/* replace950_1_0_1 -> replace98_0_0_0_1 in the cache */
static const nir_search_expression replace950_1_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search0_0.value, &replace98_0_0_0_1.value },
   NULL,
};

/* replace950_1_1_0_0 -> search0_0 in the cache */
/* replace950_1_1_0 -> replace948_1_1_0 in the cache */

/* replace950_1_1_1 -> search699_1 in the cache */
static const nir_search_expression replace950_1_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &replace948_1_1_0.value, &search699_1.value },
   NULL,
};
static const nir_search_expression replace950_1 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ior,
   { &replace950_1_0.value, &replace950_1_1.value },
   NULL,
};
static const nir_search_expression replace950 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &replace950_0.value, &replace950_1.value },
   NULL,
};

   /* search951_0_0 -> search98_0_0 in the cache */
/* search951_0 -> replace816 in the cache */

/* search951_1_0 -> search699_1 in the cache */
static const nir_search_expression search951_1 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_u2u64,
   { &search699_1.value },
   NULL,
};
static const nir_search_expression search951 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &replace816.value, &search951_1.value },
   NULL,
};

   /* replace951_0 -> search98_0_0 in the cache */

/* replace951_1_0 -> search699_1 in the cache */
/* replace951_1 -> replace927_1 in the cache */
/* replace951 -> replace927 in the cache */

   /* search952_0_0 -> search98_0_0 in the cache */
/* search952_0 -> replace816 in the cache */

/* search952_1_0 -> search699_1 in the cache */
/* search952_1 -> search951_1 in the cache */
static const nir_search_expression search952 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &replace816.value, &search951_1.value },
   NULL,
};

   /* replace952_0 -> search98_0_0 in the cache */

/* replace952_1_0 -> search699_1 in the cache */
/* replace952_1 -> replace927_1 in the cache */
/* replace952 -> replace928 in the cache */

   /* search953_0_0 -> search98_0_0 in the cache */
/* search953_0 -> replace816 in the cache */

/* search953_1_0 -> search699_1 in the cache */
/* search953_1 -> search951_1 in the cache */
static const nir_search_expression search953 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &replace816.value, &search951_1.value },
   NULL,
};

   /* replace953_0 -> search98_0_0 in the cache */

/* replace953_1_0 -> search699_1 in the cache */
/* replace953_1 -> replace927_1 in the cache */
/* replace953 -> replace929 in the cache */

   /* search954_0_0 -> search98_0_0 in the cache */
/* search954_0 -> replace816 in the cache */

/* search954_1_0 -> search699_1 in the cache */
/* search954_1 -> search951_1 in the cache */
static const nir_search_expression search954 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &replace816.value, &search951_1.value },
   NULL,
};

   /* replace954_0 -> search98_0_0 in the cache */

/* replace954_1_0 -> search699_1 in the cache */
/* replace954_1 -> replace927_1 in the cache */
/* replace954 -> replace930 in the cache */

   /* search955_0_0 -> search835_0_0 in the cache */
static const nir_search_expression search955_0 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_u2u64,
   { &search835_0_0.value },
   NULL,
};

/* search955_1_0 -> search835_1_0 in the cache */
static const nir_search_expression search955_1 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_u2u64,
   { &search835_1_0.value },
   NULL,
};
static const nir_search_expression search955 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search955_0.value, &search955_1.value },
   NULL,
};

   /* replace955_0_0 -> search835_0_0 in the cache */
/* replace955_0 -> replace931_0 in the cache */

/* replace955_1 -> search835_1_0 in the cache */
/* replace955 -> replace931 in the cache */

   /* search956_0_0 -> search835_0_0 in the cache */
/* search956_0 -> search955_0 in the cache */

/* search956_1_0 -> search835_1_0 in the cache */
/* search956_1 -> search955_1 in the cache */
static const nir_search_expression search956 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search955_0.value, &search955_1.value },
   NULL,
};

   /* replace956_0_0 -> search835_0_0 in the cache */
/* replace956_0 -> replace931_0 in the cache */

/* replace956_1 -> search835_1_0 in the cache */
/* replace956 -> replace932 in the cache */

   /* search957_0_0 -> search98_0_0 in the cache */
/* search957_0 -> replace816 in the cache */

/* search957_1 -> search861_1 in the cache */
static const nir_search_expression search957 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &replace816.value, &search861_1.value },
   NULL,
};

   /* replace957_0_0 -> search98_0_0 in the cache */

/* replace957_0_1_0 -> search57_1_1 in the cache */
static const nir_search_expression replace957_0_1 = {
   { nir_search_value_expression, 8 },
   false,
   -1, 0,
   nir_op_u2u8,
   { &search57_1_1.value },
   NULL,
};
static const nir_search_expression replace957_0 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ieq,
   { &search98_0_0.value, &replace957_0_1.value },
   NULL,
};

/* replace957_1_0_0_0 -> search57_1_1 in the cache */
/* replace957_1_0_0 -> replace957_0_1 in the cache */
static const nir_search_expression replace957_1_0 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_u2u64,
   { &replace957_0_1.value },
   NULL,
};

/* replace957_1_1 -> search57_1_1 in the cache */
static const nir_search_expression replace957_1 = {
   { nir_search_value_expression, 1 },
   false,
   2, 1,
   nir_op_ieq,
   { &replace957_1_0.value, &search57_1_1.value },
   NULL,
};
static const nir_search_expression replace957 = {
   { nir_search_value_expression, 1 },
   false,
   0, 3,
   nir_op_iand,
   { &replace957_0.value, &replace957_1.value },
   NULL,
};

   /* search958_0_0 -> search98_0_0 in the cache */
/* search958_0 -> replace816 in the cache */

/* search958_1 -> search861_1 in the cache */
static const nir_search_expression search958 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &replace816.value, &search861_1.value },
   NULL,
};

   /* replace958_0_0 -> search98_0_0 in the cache */

/* replace958_0_1_0 -> search57_1_1 in the cache */
/* replace958_0_1 -> replace957_0_1 in the cache */
static const nir_search_expression replace958_0 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ine,
   { &search98_0_0.value, &replace957_0_1.value },
   NULL,
};

/* replace958_1_0_0_0 -> search57_1_1 in the cache */
/* replace958_1_0_0 -> replace957_0_1 in the cache */
/* replace958_1_0 -> replace957_1_0 in the cache */

/* replace958_1_1 -> search57_1_1 in the cache */
static const nir_search_expression replace958_1 = {
   { nir_search_value_expression, 1 },
   false,
   2, 1,
   nir_op_ine,
   { &replace957_1_0.value, &search57_1_1.value },
   NULL,
};
static const nir_search_expression replace958 = {
   { nir_search_value_expression, 1 },
   false,
   0, 3,
   nir_op_ior,
   { &replace958_0.value, &replace958_1.value },
   NULL,
};

   /* search959_0_0 -> search98_0_0 in the cache */
/* search959_0 -> replace816 in the cache */

/* search959_1 -> search861_1 in the cache */
static const nir_search_expression search959 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &replace816.value, &search861_1.value },
   NULL,
};

   /* replace959_0_0 -> replace107_2 in the cache */

/* replace959_0_1 -> search57_1_1 in the cache */
static const nir_search_expression replace959_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &replace107_2.value, &search57_1_1.value },
   NULL,
};

static const nir_search_constant replace959_1_0_0 = {
   { nir_search_value_constant, 64 },
   nir_type_int, { 0xff /* 255 */ },
};

/* replace959_1_0_1 -> search57_1_1 in the cache */
static const nir_search_expression replace959_1_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &replace959_1_0_0.value, &search57_1_1.value },
   NULL,
};

/* replace959_1_1_0 -> search98_0_0 in the cache */

/* replace959_1_1_1_0 -> search57_1_1 in the cache */
/* replace959_1_1_1 -> replace957_0_1 in the cache */
static const nir_search_expression replace959_1_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search98_0_0.value, &replace957_0_1.value },
   NULL,
};
static const nir_search_expression replace959_1 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ior,
   { &replace959_1_0.value, &replace959_1_1.value },
   NULL,
};
static const nir_search_expression replace959 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &replace959_0.value, &replace959_1.value },
   NULL,
};

   /* search960_0 -> search864_0 in the cache */

/* search960_1_0 -> search699_1 in the cache */
/* search960_1 -> search951_1 in the cache */
static const nir_search_expression search960 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search864_0.value, &search951_1.value },
   NULL,
};

   /* replace960_0_0 -> search57_0 in the cache */

/* replace960_0_1 -> replace959_1_0_0 in the cache */
static const nir_search_expression replace960_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search57_0.value, &replace959_1_0_0.value },
   NULL,
};

/* replace960_1_0_0 -> search57_0 in the cache */

/* replace960_1_0_1 -> replace107_2 in the cache */
static const nir_search_expression replace960_1_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search57_0.value, &replace107_2.value },
   NULL,
};

/* replace960_1_1_0_0 -> search57_0 in the cache */
static const nir_search_expression replace960_1_1_0 = {
   { nir_search_value_expression, 8 },
   false,
   -1, 0,
   nir_op_u2u8,
   { &search57_0.value },
   NULL,
};

/* replace960_1_1_1 -> search699_1 in the cache */
static const nir_search_expression replace960_1_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &replace960_1_1_0.value, &search699_1.value },
   NULL,
};
static const nir_search_expression replace960_1 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ior,
   { &replace960_1_0.value, &replace960_1_1.value },
   NULL,
};
static const nir_search_expression replace960 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &replace960_0.value, &replace960_1.value },
   NULL,
};

   /* search961_0_0 -> search98_0_0 in the cache */
/* search961_0 -> replace816 in the cache */

/* search961_1 -> search861_1 in the cache */
static const nir_search_expression search961 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &replace816.value, &search861_1.value },
   NULL,
};

   /* replace961_0_0 -> replace959_1_0_0 in the cache */

/* replace961_0_1 -> search57_1_1 in the cache */
static const nir_search_expression replace961_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &replace959_1_0_0.value, &search57_1_1.value },
   NULL,
};

/* replace961_1_0_0 -> replace107_2 in the cache */

/* replace961_1_0_1 -> search57_1_1 in the cache */
static const nir_search_expression replace961_1_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &replace107_2.value, &search57_1_1.value },
   NULL,
};

/* replace961_1_1_0 -> search98_0_0 in the cache */

/* replace961_1_1_1_0 -> search57_1_1 in the cache */
/* replace961_1_1_1 -> replace957_0_1 in the cache */
static const nir_search_expression replace961_1_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search98_0_0.value, &replace957_0_1.value },
   NULL,
};
static const nir_search_expression replace961_1 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ior,
   { &replace961_1_0.value, &replace961_1_1.value },
   NULL,
};
static const nir_search_expression replace961 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &replace961_0.value, &replace961_1.value },
   NULL,
};

   /* search962_0 -> search864_0 in the cache */

/* search962_1_0 -> search699_1 in the cache */
/* search962_1 -> search951_1 in the cache */
static const nir_search_expression search962 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search864_0.value, &search951_1.value },
   NULL,
};

   /* replace962_0_0 -> search57_0 in the cache */

/* replace962_0_1 -> replace107_2 in the cache */
static const nir_search_expression replace962_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search57_0.value, &replace107_2.value },
   NULL,
};

/* replace962_1_0_0 -> search57_0 in the cache */

/* replace962_1_0_1 -> replace959_1_0_0 in the cache */
static const nir_search_expression replace962_1_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search57_0.value, &replace959_1_0_0.value },
   NULL,
};

/* replace962_1_1_0_0 -> search57_0 in the cache */
/* replace962_1_1_0 -> replace960_1_1_0 in the cache */

/* replace962_1_1_1 -> search699_1 in the cache */
static const nir_search_expression replace962_1_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &replace960_1_1_0.value, &search699_1.value },
   NULL,
};
static const nir_search_expression replace962_1 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ior,
   { &replace962_1_0.value, &replace962_1_1.value },
   NULL,
};
static const nir_search_expression replace962 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &replace962_0.value, &replace962_1.value },
   NULL,
};

   /* search963_0_0 -> search101_0_0 in the cache */
/* search963_0 -> replace806 in the cache */

/* search963_1_0 -> search699_1 in the cache */
/* search963_1 -> search939_1 in the cache */
static const nir_search_expression search963 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &replace806.value, &search939_1.value },
   NULL,
};

   /* replace963_0 -> search101_0_0 in the cache */

/* replace963_1_0 -> search699_1 in the cache */
/* replace963_1 -> search927_1 in the cache */
static const nir_search_expression replace963 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &search101_0_0.value, &search927_1.value },
   NULL,
};

   /* search964_0_0 -> search101_0_0 in the cache */
/* search964_0 -> replace806 in the cache */

/* search964_1_0 -> search699_1 in the cache */
/* search964_1 -> search939_1 in the cache */
static const nir_search_expression search964 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &replace806.value, &search939_1.value },
   NULL,
};

   /* replace964_0 -> search101_0_0 in the cache */

/* replace964_1_0 -> search699_1 in the cache */
/* replace964_1 -> search927_1 in the cache */
static const nir_search_expression replace964 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &search101_0_0.value, &search927_1.value },
   NULL,
};

   /* search965_0_0 -> search101_0_0 in the cache */
/* search965_0 -> replace806 in the cache */

/* search965_1_0 -> search699_1 in the cache */
/* search965_1 -> search939_1 in the cache */
static const nir_search_expression search965 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &replace806.value, &search939_1.value },
   NULL,
};

   /* replace965_0 -> search101_0_0 in the cache */

/* replace965_1_0 -> search699_1 in the cache */
/* replace965_1 -> search927_1 in the cache */
static const nir_search_expression replace965 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search101_0_0.value, &search927_1.value },
   NULL,
};

   /* search966_0_0 -> search101_0_0 in the cache */
/* search966_0 -> replace806 in the cache */

/* search966_1_0 -> search699_1 in the cache */
/* search966_1 -> search939_1 in the cache */
static const nir_search_expression search966 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &replace806.value, &search939_1.value },
   NULL,
};

   /* replace966_0 -> search101_0_0 in the cache */

/* replace966_1_0 -> search699_1 in the cache */
/* replace966_1 -> search927_1 in the cache */
static const nir_search_expression replace966 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search101_0_0.value, &search927_1.value },
   NULL,
};

   /* search967_0_0 -> search835_0_0 in the cache */
/* search967_0 -> search943_0 in the cache */

/* search967_1_0 -> search871_1_0 in the cache */
static const nir_search_expression search967_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_u2u32,
   { &search871_1_0.value },
   NULL,
};
static const nir_search_expression search967 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search943_0.value, &search967_1.value },
   NULL,
};

   /* replace967_0_0 -> search835_0_0 in the cache */
/* replace967_0 -> search931_0 in the cache */

/* replace967_1 -> search871_1_0 in the cache */
static const nir_search_expression replace967 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search931_0.value, &search871_1_0.value },
   NULL,
};

   /* search968_0_0 -> search835_0_0 in the cache */
/* search968_0 -> search943_0 in the cache */

/* search968_1_0 -> search871_1_0 in the cache */
/* search968_1 -> search967_1 in the cache */
static const nir_search_expression search968 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search943_0.value, &search967_1.value },
   NULL,
};

   /* replace968_0_0 -> search835_0_0 in the cache */
/* replace968_0 -> search931_0 in the cache */

/* replace968_1 -> search871_1_0 in the cache */
static const nir_search_expression replace968 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search931_0.value, &search871_1_0.value },
   NULL,
};

   /* search969_0_0 -> search101_0_0 in the cache */
/* search969_0 -> replace806 in the cache */

/* search969_1_0 -> replace564_1_0 in the cache */
static const nir_search_expression search969_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_u2u32,
   { &replace564_1_0.value },
   NULL,
};
static const nir_search_expression search969 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &replace806.value, &search969_1.value },
   NULL,
};

   /* replace969_0 -> search101_0_0 in the cache */

/* replace969_1_0 -> replace564_1_0 in the cache */
static const nir_search_expression replace969_1 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_u2u16,
   { &replace564_1_0.value },
   NULL,
};
static const nir_search_expression replace969 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &search101_0_0.value, &replace969_1.value },
   NULL,
};

   /* search970_0_0 -> search101_0_0 in the cache */
/* search970_0 -> replace806 in the cache */

/* search970_1_0 -> replace564_1_0 in the cache */
/* search970_1 -> search969_1 in the cache */
static const nir_search_expression search970 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &replace806.value, &search969_1.value },
   NULL,
};

   /* replace970_0 -> search101_0_0 in the cache */

/* replace970_1_0 -> replace564_1_0 in the cache */
/* replace970_1 -> replace969_1 in the cache */
static const nir_search_expression replace970 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &search101_0_0.value, &replace969_1.value },
   NULL,
};

   /* search971_0_0 -> search101_0_0 in the cache */
/* search971_0 -> replace806 in the cache */

/* search971_1_0 -> replace564_1_0 in the cache */
/* search971_1 -> search969_1 in the cache */
static const nir_search_expression search971 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &replace806.value, &search969_1.value },
   NULL,
};

   /* replace971_0 -> search101_0_0 in the cache */

/* replace971_1_0 -> replace564_1_0 in the cache */
/* replace971_1 -> replace969_1 in the cache */
static const nir_search_expression replace971 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search101_0_0.value, &replace969_1.value },
   NULL,
};

   /* search972_0_0 -> search101_0_0 in the cache */
/* search972_0 -> replace806 in the cache */

/* search972_1_0 -> replace564_1_0 in the cache */
/* search972_1 -> search969_1 in the cache */
static const nir_search_expression search972 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &replace806.value, &search969_1.value },
   NULL,
};

   /* replace972_0 -> search101_0_0 in the cache */

/* replace972_1_0 -> replace564_1_0 in the cache */
/* replace972_1 -> replace969_1 in the cache */
static const nir_search_expression replace972 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search101_0_0.value, &replace969_1.value },
   NULL,
};

   /* search973_0_0 -> search877_0_0 in the cache */
static const nir_search_expression search973_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_u2u32,
   { &search877_0_0.value },
   NULL,
};

/* search973_1_0 -> search871_1_0 in the cache */
/* search973_1 -> search967_1 in the cache */
static const nir_search_expression search973 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search973_0.value, &search967_1.value },
   NULL,
};

   /* replace973_0_0 -> search877_0_0 in the cache */
static const nir_search_expression replace973_0 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_u2u16,
   { &search877_0_0.value },
   NULL,
};

/* replace973_1 -> search871_1_0 in the cache */
static const nir_search_expression replace973 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &replace973_0.value, &search871_1_0.value },
   NULL,
};

   /* search974_0_0 -> search877_0_0 in the cache */
/* search974_0 -> search973_0 in the cache */

/* search974_1_0 -> search871_1_0 in the cache */
/* search974_1 -> search967_1 in the cache */
static const nir_search_expression search974 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search973_0.value, &search967_1.value },
   NULL,
};

   /* replace974_0_0 -> search877_0_0 in the cache */
/* replace974_0 -> replace973_0 in the cache */

/* replace974_1 -> search871_1_0 in the cache */
static const nir_search_expression replace974 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &replace973_0.value, &search871_1_0.value },
   NULL,
};

   /* search975_0_0 -> search101_0_0 in the cache */
/* search975_0 -> replace806 in the cache */

/* search975_1 -> search2_1 in the cache */
static const nir_search_expression search975 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &replace806.value, &search2_1.value },
   NULL,
};

   /* replace975_0_0 -> search101_0_0 in the cache */

/* replace975_0_1_0 -> replace0_1_0 in the cache */
static const nir_search_expression replace975_0_1 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_u2u16,
   { &replace0_1_0.value },
   NULL,
};
static const nir_search_expression replace975_0 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ieq,
   { &search101_0_0.value, &replace975_0_1.value },
   NULL,
};

/* replace975_1_0_0_0 -> replace0_1_0 in the cache */
/* replace975_1_0_0 -> replace975_0_1 in the cache */
static const nir_search_expression replace975_1_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_u2u32,
   { &replace975_0_1.value },
   NULL,
};

/* replace975_1_1 -> replace0_1_0 in the cache */
static const nir_search_expression replace975_1 = {
   { nir_search_value_expression, 1 },
   false,
   2, 1,
   nir_op_ieq,
   { &replace975_1_0.value, &replace0_1_0.value },
   NULL,
};
static const nir_search_expression replace975 = {
   { nir_search_value_expression, 1 },
   false,
   0, 3,
   nir_op_iand,
   { &replace975_0.value, &replace975_1.value },
   NULL,
};

   /* search976_0_0 -> search101_0_0 in the cache */
/* search976_0 -> replace806 in the cache */

/* search976_1 -> search2_1 in the cache */
static const nir_search_expression search976 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &replace806.value, &search2_1.value },
   NULL,
};

   /* replace976_0_0 -> search101_0_0 in the cache */

/* replace976_0_1_0 -> replace0_1_0 in the cache */
/* replace976_0_1 -> replace975_0_1 in the cache */
static const nir_search_expression replace976_0 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ine,
   { &search101_0_0.value, &replace975_0_1.value },
   NULL,
};

/* replace976_1_0_0_0 -> replace0_1_0 in the cache */
/* replace976_1_0_0 -> replace975_0_1 in the cache */
/* replace976_1_0 -> replace975_1_0 in the cache */

/* replace976_1_1 -> replace0_1_0 in the cache */
static const nir_search_expression replace976_1 = {
   { nir_search_value_expression, 1 },
   false,
   2, 1,
   nir_op_ine,
   { &replace975_1_0.value, &replace0_1_0.value },
   NULL,
};
static const nir_search_expression replace976 = {
   { nir_search_value_expression, 1 },
   false,
   0, 3,
   nir_op_ior,
   { &replace976_0.value, &replace976_1.value },
   NULL,
};

   /* search977_0_0 -> search101_0_0 in the cache */
/* search977_0 -> replace806 in the cache */

/* search977_1 -> search2_1 in the cache */
static const nir_search_expression search977 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &replace806.value, &search2_1.value },
   NULL,
};

   /* replace977_0_0 -> search26_1 in the cache */

/* replace977_0_1 -> replace0_1_0 in the cache */
/* replace977_0 -> replace947_0 in the cache */

/* replace977_1_0_0 -> replace101_0_0_0_1 in the cache */

/* replace977_1_0_1 -> replace0_1_0 in the cache */
static const nir_search_expression replace977_1_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &replace101_0_0_0_1.value, &replace0_1_0.value },
   NULL,
};

/* replace977_1_1_0 -> search101_0_0 in the cache */

/* replace977_1_1_1_0 -> replace0_1_0 in the cache */
/* replace977_1_1_1 -> replace975_0_1 in the cache */
static const nir_search_expression replace977_1_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search101_0_0.value, &replace975_0_1.value },
   NULL,
};
static const nir_search_expression replace977_1 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ior,
   { &replace977_1_0.value, &replace977_1_1.value },
   NULL,
};
static const nir_search_expression replace977 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &replace947_0.value, &replace977_1.value },
   NULL,
};

   /* search978_0 -> search852_0 in the cache */

/* search978_1_0 -> replace564_1_0 in the cache */
/* search978_1 -> search969_1 in the cache */
static const nir_search_expression search978 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search852_0.value, &search969_1.value },
   NULL,
};

   /* replace978_0_0 -> search0_0 in the cache */

/* replace978_0_1 -> replace101_0_0_0_1 in the cache */
static const nir_search_expression replace978_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search0_0.value, &replace101_0_0_0_1.value },
   NULL,
};

/* replace978_1_0_0 -> search0_0 in the cache */

/* replace978_1_0_1 -> search26_1 in the cache */
/* replace978_1_0 -> replace948_1_0 in the cache */

/* replace978_1_1_0_0 -> search0_0 in the cache */
static const nir_search_expression replace978_1_1_0 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_u2u16,
   { &search0_0.value },
   NULL,
};

/* replace978_1_1_1 -> replace564_1_0 in the cache */
static const nir_search_expression replace978_1_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &replace978_1_1_0.value, &replace564_1_0.value },
   NULL,
};
static const nir_search_expression replace978_1 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ior,
   { &replace948_1_0.value, &replace978_1_1.value },
   NULL,
};
static const nir_search_expression replace978 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &replace978_0.value, &replace978_1.value },
   NULL,
};

   /* search979_0_0 -> search101_0_0 in the cache */
/* search979_0 -> replace806 in the cache */

/* search979_1 -> search2_1 in the cache */
static const nir_search_expression search979 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &replace806.value, &search2_1.value },
   NULL,
};

   /* replace979_0_0 -> replace101_0_0_0_1 in the cache */

/* replace979_0_1 -> replace0_1_0 in the cache */
static const nir_search_expression replace979_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &replace101_0_0_0_1.value, &replace0_1_0.value },
   NULL,
};

/* replace979_1_0_0 -> search26_1 in the cache */

/* replace979_1_0_1 -> replace0_1_0 in the cache */
/* replace979_1_0 -> replace949_1_0 in the cache */

/* replace979_1_1_0 -> search101_0_0 in the cache */

/* replace979_1_1_1_0 -> replace0_1_0 in the cache */
/* replace979_1_1_1 -> replace975_0_1 in the cache */
static const nir_search_expression replace979_1_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search101_0_0.value, &replace975_0_1.value },
   NULL,
};
static const nir_search_expression replace979_1 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ior,
   { &replace949_1_0.value, &replace979_1_1.value },
   NULL,
};
static const nir_search_expression replace979 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &replace979_0.value, &replace979_1.value },
   NULL,
};

   /* search980_0 -> search852_0 in the cache */

/* search980_1_0 -> replace564_1_0 in the cache */
/* search980_1 -> search969_1 in the cache */
static const nir_search_expression search980 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search852_0.value, &search969_1.value },
   NULL,
};

   /* replace980_0_0 -> search0_0 in the cache */

/* replace980_0_1 -> search26_1 in the cache */
/* replace980_0 -> replace950_0 in the cache */

/* replace980_1_0_0 -> search0_0 in the cache */

/* replace980_1_0_1 -> replace101_0_0_0_1 in the cache */
static const nir_search_expression replace980_1_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search0_0.value, &replace101_0_0_0_1.value },
   NULL,
};

/* replace980_1_1_0_0 -> search0_0 in the cache */
/* replace980_1_1_0 -> replace978_1_1_0 in the cache */

/* replace980_1_1_1 -> replace564_1_0 in the cache */
static const nir_search_expression replace980_1_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &replace978_1_1_0.value, &replace564_1_0.value },
   NULL,
};
static const nir_search_expression replace980_1 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ior,
   { &replace980_1_0.value, &replace980_1_1.value },
   NULL,
};
static const nir_search_expression replace980 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &replace950_0.value, &replace980_1.value },
   NULL,
};

   /* search981_0_0 -> search101_0_0 in the cache */
/* search981_0 -> replace822 in the cache */

/* search981_1_0 -> search699_1 in the cache */
/* search981_1 -> search951_1 in the cache */
static const nir_search_expression search981 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &replace822.value, &search951_1.value },
   NULL,
};

   /* replace981_0 -> search101_0_0 in the cache */

/* replace981_1_0 -> search699_1 in the cache */
/* replace981_1 -> search927_1 in the cache */
/* replace981 -> replace963 in the cache */

   /* search982_0_0 -> search101_0_0 in the cache */
/* search982_0 -> replace822 in the cache */

/* search982_1_0 -> search699_1 in the cache */
/* search982_1 -> search951_1 in the cache */
static const nir_search_expression search982 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &replace822.value, &search951_1.value },
   NULL,
};

   /* replace982_0 -> search101_0_0 in the cache */

/* replace982_1_0 -> search699_1 in the cache */
/* replace982_1 -> search927_1 in the cache */
/* replace982 -> replace964 in the cache */

   /* search983_0_0 -> search101_0_0 in the cache */
/* search983_0 -> replace822 in the cache */

/* search983_1_0 -> search699_1 in the cache */
/* search983_1 -> search951_1 in the cache */
static const nir_search_expression search983 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &replace822.value, &search951_1.value },
   NULL,
};

   /* replace983_0 -> search101_0_0 in the cache */

/* replace983_1_0 -> search699_1 in the cache */
/* replace983_1 -> search927_1 in the cache */
/* replace983 -> replace965 in the cache */

   /* search984_0_0 -> search101_0_0 in the cache */
/* search984_0 -> replace822 in the cache */

/* search984_1_0 -> search699_1 in the cache */
/* search984_1 -> search951_1 in the cache */
static const nir_search_expression search984 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &replace822.value, &search951_1.value },
   NULL,
};

   /* replace984_0 -> search101_0_0 in the cache */

/* replace984_1_0 -> search699_1 in the cache */
/* replace984_1 -> search927_1 in the cache */
/* replace984 -> replace966 in the cache */

   /* search985_0_0 -> search835_0_0 in the cache */
/* search985_0 -> search955_0 in the cache */

/* search985_1_0 -> search871_1_0 in the cache */
static const nir_search_expression search985_1 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_u2u64,
   { &search871_1_0.value },
   NULL,
};
static const nir_search_expression search985 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search955_0.value, &search985_1.value },
   NULL,
};

   /* replace985_0_0 -> search835_0_0 in the cache */
/* replace985_0 -> search931_0 in the cache */

/* replace985_1 -> search871_1_0 in the cache */
/* replace985 -> replace967 in the cache */

   /* search986_0_0 -> search835_0_0 in the cache */
/* search986_0 -> search955_0 in the cache */

/* search986_1_0 -> search871_1_0 in the cache */
/* search986_1 -> search985_1 in the cache */
static const nir_search_expression search986 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search955_0.value, &search985_1.value },
   NULL,
};

   /* replace986_0_0 -> search835_0_0 in the cache */
/* replace986_0 -> search931_0 in the cache */

/* replace986_1 -> search871_1_0 in the cache */
/* replace986 -> replace968 in the cache */

   /* search987_0_0 -> search101_0_0 in the cache */
/* search987_0 -> replace822 in the cache */

/* search987_1_0 -> replace564_1_0 in the cache */
static const nir_search_expression search987_1 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_u2u64,
   { &replace564_1_0.value },
   NULL,
};
static const nir_search_expression search987 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &replace822.value, &search987_1.value },
   NULL,
};

   /* replace987_0 -> search101_0_0 in the cache */

/* replace987_1_0 -> replace564_1_0 in the cache */
/* replace987_1 -> replace969_1 in the cache */
/* replace987 -> replace969 in the cache */

   /* search988_0_0 -> search101_0_0 in the cache */
/* search988_0 -> replace822 in the cache */

/* search988_1_0 -> replace564_1_0 in the cache */
/* search988_1 -> search987_1 in the cache */
static const nir_search_expression search988 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &replace822.value, &search987_1.value },
   NULL,
};

   /* replace988_0 -> search101_0_0 in the cache */

/* replace988_1_0 -> replace564_1_0 in the cache */
/* replace988_1 -> replace969_1 in the cache */
/* replace988 -> replace970 in the cache */

   /* search989_0_0 -> search101_0_0 in the cache */
/* search989_0 -> replace822 in the cache */

/* search989_1_0 -> replace564_1_0 in the cache */
/* search989_1 -> search987_1 in the cache */
static const nir_search_expression search989 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &replace822.value, &search987_1.value },
   NULL,
};

   /* replace989_0 -> search101_0_0 in the cache */

/* replace989_1_0 -> replace564_1_0 in the cache */
/* replace989_1 -> replace969_1 in the cache */
/* replace989 -> replace971 in the cache */

   /* search990_0_0 -> search101_0_0 in the cache */
/* search990_0 -> replace822 in the cache */

/* search990_1_0 -> replace564_1_0 in the cache */
/* search990_1 -> search987_1 in the cache */
static const nir_search_expression search990 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &replace822.value, &search987_1.value },
   NULL,
};

   /* replace990_0 -> search101_0_0 in the cache */

/* replace990_1_0 -> replace564_1_0 in the cache */
/* replace990_1 -> replace969_1 in the cache */
/* replace990 -> replace972 in the cache */

   /* search991_0_0 -> search877_0_0 in the cache */
static const nir_search_expression search991_0 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_u2u64,
   { &search877_0_0.value },
   NULL,
};

/* search991_1_0 -> search871_1_0 in the cache */
/* search991_1 -> search985_1 in the cache */
static const nir_search_expression search991 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search991_0.value, &search985_1.value },
   NULL,
};

   /* replace991_0_0 -> search877_0_0 in the cache */
/* replace991_0 -> replace973_0 in the cache */

/* replace991_1 -> search871_1_0 in the cache */
/* replace991 -> replace973 in the cache */

   /* search992_0_0 -> search877_0_0 in the cache */
/* search992_0 -> search991_0 in the cache */

/* search992_1_0 -> search871_1_0 in the cache */
/* search992_1 -> search985_1 in the cache */
static const nir_search_expression search992 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search991_0.value, &search985_1.value },
   NULL,
};

   /* replace992_0_0 -> search877_0_0 in the cache */
/* replace992_0 -> replace973_0 in the cache */

/* replace992_1 -> search871_1_0 in the cache */
/* replace992 -> replace974 in the cache */

   /* search993_0_0 -> search101_0_0 in the cache */
/* search993_0 -> replace822 in the cache */

/* search993_1 -> search861_1 in the cache */
static const nir_search_expression search993 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &replace822.value, &search861_1.value },
   NULL,
};

   /* replace993_0_0 -> search101_0_0 in the cache */

/* replace993_0_1_0 -> search57_1_1 in the cache */
static const nir_search_expression replace993_0_1 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_u2u16,
   { &search57_1_1.value },
   NULL,
};
static const nir_search_expression replace993_0 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ieq,
   { &search101_0_0.value, &replace993_0_1.value },
   NULL,
};

/* replace993_1_0_0_0 -> search57_1_1 in the cache */
/* replace993_1_0_0 -> replace993_0_1 in the cache */
static const nir_search_expression replace993_1_0 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_u2u64,
   { &replace993_0_1.value },
   NULL,
};

/* replace993_1_1 -> search57_1_1 in the cache */
static const nir_search_expression replace993_1 = {
   { nir_search_value_expression, 1 },
   false,
   2, 1,
   nir_op_ieq,
   { &replace993_1_0.value, &search57_1_1.value },
   NULL,
};
static const nir_search_expression replace993 = {
   { nir_search_value_expression, 1 },
   false,
   0, 3,
   nir_op_iand,
   { &replace993_0.value, &replace993_1.value },
   NULL,
};

   /* search994_0_0 -> search101_0_0 in the cache */
/* search994_0 -> replace822 in the cache */

/* search994_1 -> search861_1 in the cache */
static const nir_search_expression search994 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &replace822.value, &search861_1.value },
   NULL,
};

   /* replace994_0_0 -> search101_0_0 in the cache */

/* replace994_0_1_0 -> search57_1_1 in the cache */
/* replace994_0_1 -> replace993_0_1 in the cache */
static const nir_search_expression replace994_0 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ine,
   { &search101_0_0.value, &replace993_0_1.value },
   NULL,
};

/* replace994_1_0_0_0 -> search57_1_1 in the cache */
/* replace994_1_0_0 -> replace993_0_1 in the cache */
/* replace994_1_0 -> replace993_1_0 in the cache */

/* replace994_1_1 -> search57_1_1 in the cache */
static const nir_search_expression replace994_1 = {
   { nir_search_value_expression, 1 },
   false,
   2, 1,
   nir_op_ine,
   { &replace993_1_0.value, &search57_1_1.value },
   NULL,
};
static const nir_search_expression replace994 = {
   { nir_search_value_expression, 1 },
   false,
   0, 3,
   nir_op_ior,
   { &replace994_0.value, &replace994_1.value },
   NULL,
};

   /* search995_0_0 -> search101_0_0 in the cache */
/* search995_0 -> replace822 in the cache */

/* search995_1 -> search861_1 in the cache */
static const nir_search_expression search995 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &replace822.value, &search861_1.value },
   NULL,
};

   /* replace995_0_0 -> replace107_2 in the cache */

/* replace995_0_1 -> search57_1_1 in the cache */
/* replace995_0 -> replace959_0 in the cache */

static const nir_search_constant replace995_1_0_0 = {
   { nir_search_value_constant, 64 },
   nir_type_int, { 0xffff /* 65535 */ },
};

/* replace995_1_0_1 -> search57_1_1 in the cache */
static const nir_search_expression replace995_1_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &replace995_1_0_0.value, &search57_1_1.value },
   NULL,
};

/* replace995_1_1_0 -> search101_0_0 in the cache */

/* replace995_1_1_1_0 -> search57_1_1 in the cache */
/* replace995_1_1_1 -> replace993_0_1 in the cache */
static const nir_search_expression replace995_1_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search101_0_0.value, &replace993_0_1.value },
   NULL,
};
static const nir_search_expression replace995_1 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ior,
   { &replace995_1_0.value, &replace995_1_1.value },
   NULL,
};
static const nir_search_expression replace995 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &replace959_0.value, &replace995_1.value },
   NULL,
};

   /* search996_0 -> search864_0 in the cache */

/* search996_1_0 -> replace564_1_0 in the cache */
/* search996_1 -> search987_1 in the cache */
static const nir_search_expression search996 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search864_0.value, &search987_1.value },
   NULL,
};

   /* replace996_0_0 -> search57_0 in the cache */

/* replace996_0_1 -> replace995_1_0_0 in the cache */
static const nir_search_expression replace996_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search57_0.value, &replace995_1_0_0.value },
   NULL,
};

/* replace996_1_0_0 -> search57_0 in the cache */

/* replace996_1_0_1 -> replace107_2 in the cache */
/* replace996_1_0 -> replace960_1_0 in the cache */

/* replace996_1_1_0_0 -> search57_0 in the cache */
static const nir_search_expression replace996_1_1_0 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_u2u16,
   { &search57_0.value },
   NULL,
};

/* replace996_1_1_1 -> replace564_1_0 in the cache */
static const nir_search_expression replace996_1_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &replace996_1_1_0.value, &replace564_1_0.value },
   NULL,
};
static const nir_search_expression replace996_1 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ior,
   { &replace960_1_0.value, &replace996_1_1.value },
   NULL,
};
static const nir_search_expression replace996 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &replace996_0.value, &replace996_1.value },
   NULL,
};

   /* search997_0_0 -> search101_0_0 in the cache */
/* search997_0 -> replace822 in the cache */

/* search997_1 -> search861_1 in the cache */
static const nir_search_expression search997 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &replace822.value, &search861_1.value },
   NULL,
};

   /* replace997_0_0 -> replace995_1_0_0 in the cache */

/* replace997_0_1 -> search57_1_1 in the cache */
static const nir_search_expression replace997_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &replace995_1_0_0.value, &search57_1_1.value },
   NULL,
};

/* replace997_1_0_0 -> replace107_2 in the cache */

/* replace997_1_0_1 -> search57_1_1 in the cache */
/* replace997_1_0 -> replace961_1_0 in the cache */

/* replace997_1_1_0 -> search101_0_0 in the cache */

/* replace997_1_1_1_0 -> search57_1_1 in the cache */
/* replace997_1_1_1 -> replace993_0_1 in the cache */
static const nir_search_expression replace997_1_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search101_0_0.value, &replace993_0_1.value },
   NULL,
};
static const nir_search_expression replace997_1 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ior,
   { &replace961_1_0.value, &replace997_1_1.value },
   NULL,
};
static const nir_search_expression replace997 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &replace997_0.value, &replace997_1.value },
   NULL,
};

   /* search998_0 -> search864_0 in the cache */

/* search998_1_0 -> replace564_1_0 in the cache */
/* search998_1 -> search987_1 in the cache */
static const nir_search_expression search998 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search864_0.value, &search987_1.value },
   NULL,
};

   /* replace998_0_0 -> search57_0 in the cache */

/* replace998_0_1 -> replace107_2 in the cache */
/* replace998_0 -> replace962_0 in the cache */

/* replace998_1_0_0 -> search57_0 in the cache */

/* replace998_1_0_1 -> replace995_1_0_0 in the cache */
static const nir_search_expression replace998_1_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search57_0.value, &replace995_1_0_0.value },
   NULL,
};

/* replace998_1_1_0_0 -> search57_0 in the cache */
/* replace998_1_1_0 -> replace996_1_1_0 in the cache */

/* replace998_1_1_1 -> replace564_1_0 in the cache */
static const nir_search_expression replace998_1_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &replace996_1_1_0.value, &replace564_1_0.value },
   NULL,
};
static const nir_search_expression replace998_1 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ior,
   { &replace998_1_0.value, &replace998_1_1.value },
   NULL,
};
static const nir_search_expression replace998 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &replace962_0.value, &replace998_1.value },
   NULL,
};

   /* search999_0_0 -> search0_0 in the cache */
/* search999_0 -> replace830 in the cache */

/* search999_1_0 -> search699_1 in the cache */
/* search999_1 -> search951_1 in the cache */
static const nir_search_expression search999 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &replace830.value, &search951_1.value },
   NULL,
};

   /* replace999_0 -> search0_0 in the cache */

/* replace999_1_0 -> search699_1 in the cache */
/* replace999_1 -> search939_1 in the cache */
static const nir_search_expression replace999 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &search0_0.value, &search939_1.value },
   NULL,
};

   /* search1000_0_0 -> search0_0 in the cache */
/* search1000_0 -> replace830 in the cache */

/* search1000_1_0 -> search699_1 in the cache */
/* search1000_1 -> search951_1 in the cache */
static const nir_search_expression search1000 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &replace830.value, &search951_1.value },
   NULL,
};

   /* replace1000_0 -> search0_0 in the cache */

/* replace1000_1_0 -> search699_1 in the cache */
/* replace1000_1 -> search939_1 in the cache */
static const nir_search_expression replace1000 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &search0_0.value, &search939_1.value },
   NULL,
};

   /* search1001_0_0 -> search0_0 in the cache */
/* search1001_0 -> replace830 in the cache */

/* search1001_1_0 -> search699_1 in the cache */
/* search1001_1 -> search951_1 in the cache */
static const nir_search_expression search1001 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &replace830.value, &search951_1.value },
   NULL,
};

   /* replace1001_0 -> search0_0 in the cache */

/* replace1001_1_0 -> search699_1 in the cache */
/* replace1001_1 -> search939_1 in the cache */
static const nir_search_expression replace1001 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search0_0.value, &search939_1.value },
   NULL,
};

   /* search1002_0_0 -> search0_0 in the cache */
/* search1002_0 -> replace830 in the cache */

/* search1002_1_0 -> search699_1 in the cache */
/* search1002_1 -> search951_1 in the cache */
static const nir_search_expression search1002 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &replace830.value, &search951_1.value },
   NULL,
};

   /* replace1002_0 -> search0_0 in the cache */

/* replace1002_1_0 -> search699_1 in the cache */
/* replace1002_1 -> search939_1 in the cache */
static const nir_search_expression replace1002 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search0_0.value, &search939_1.value },
   NULL,
};

   /* search1003_0_0 -> search835_0_0 in the cache */
/* search1003_0 -> search955_0 in the cache */

/* search1003_1_0 -> search907_1_0 in the cache */
static const nir_search_expression search1003_1 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_u2u64,
   { &search907_1_0.value },
   NULL,
};
static const nir_search_expression search1003 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search955_0.value, &search1003_1.value },
   NULL,
};

   /* replace1003_0_0 -> search835_0_0 in the cache */
/* replace1003_0 -> search943_0 in the cache */

/* replace1003_1 -> search907_1_0 in the cache */
static const nir_search_expression replace1003 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search943_0.value, &search907_1_0.value },
   NULL,
};

   /* search1004_0_0 -> search835_0_0 in the cache */
/* search1004_0 -> search955_0 in the cache */

/* search1004_1_0 -> search907_1_0 in the cache */
/* search1004_1 -> search1003_1 in the cache */
static const nir_search_expression search1004 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search955_0.value, &search1003_1.value },
   NULL,
};

   /* replace1004_0_0 -> search835_0_0 in the cache */
/* replace1004_0 -> search943_0 in the cache */

/* replace1004_1 -> search907_1_0 in the cache */
static const nir_search_expression replace1004 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search943_0.value, &search907_1_0.value },
   NULL,
};

   /* search1005_0_0 -> search0_0 in the cache */
/* search1005_0 -> replace830 in the cache */

/* search1005_1_0 -> replace564_1_0 in the cache */
/* search1005_1 -> search987_1 in the cache */
static const nir_search_expression search1005 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &replace830.value, &search987_1.value },
   NULL,
};

   /* replace1005_0 -> search0_0 in the cache */

/* replace1005_1_0 -> replace564_1_0 in the cache */
/* replace1005_1 -> search969_1 in the cache */
static const nir_search_expression replace1005 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &search0_0.value, &search969_1.value },
   NULL,
};

   /* search1006_0_0 -> search0_0 in the cache */
/* search1006_0 -> replace830 in the cache */

/* search1006_1_0 -> replace564_1_0 in the cache */
/* search1006_1 -> search987_1 in the cache */
static const nir_search_expression search1006 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &replace830.value, &search987_1.value },
   NULL,
};

   /* replace1006_0 -> search0_0 in the cache */

/* replace1006_1_0 -> replace564_1_0 in the cache */
/* replace1006_1 -> search969_1 in the cache */
static const nir_search_expression replace1006 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &search0_0.value, &search969_1.value },
   NULL,
};

   /* search1007_0_0 -> search0_0 in the cache */
/* search1007_0 -> replace830 in the cache */

/* search1007_1_0 -> replace564_1_0 in the cache */
/* search1007_1 -> search987_1 in the cache */
static const nir_search_expression search1007 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &replace830.value, &search987_1.value },
   NULL,
};

   /* replace1007_0 -> search0_0 in the cache */

/* replace1007_1_0 -> replace564_1_0 in the cache */
/* replace1007_1 -> search969_1 in the cache */
static const nir_search_expression replace1007 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search0_0.value, &search969_1.value },
   NULL,
};

   /* search1008_0_0 -> search0_0 in the cache */
/* search1008_0 -> replace830 in the cache */

/* search1008_1_0 -> replace564_1_0 in the cache */
/* search1008_1 -> search987_1 in the cache */
static const nir_search_expression search1008 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &replace830.value, &search987_1.value },
   NULL,
};

   /* replace1008_0 -> search0_0 in the cache */

/* replace1008_1_0 -> replace564_1_0 in the cache */
/* replace1008_1 -> search969_1 in the cache */
static const nir_search_expression replace1008 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search0_0.value, &search969_1.value },
   NULL,
};

   /* search1009_0_0 -> search877_0_0 in the cache */
/* search1009_0 -> search991_0 in the cache */

/* search1009_1_0 -> search907_1_0 in the cache */
/* search1009_1 -> search1003_1 in the cache */
static const nir_search_expression search1009 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search991_0.value, &search1003_1.value },
   NULL,
};

   /* replace1009_0_0 -> search877_0_0 in the cache */
/* replace1009_0 -> search973_0 in the cache */

/* replace1009_1 -> search907_1_0 in the cache */
static const nir_search_expression replace1009 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search973_0.value, &search907_1_0.value },
   NULL,
};

   /* search1010_0_0 -> search877_0_0 in the cache */
/* search1010_0 -> search991_0 in the cache */

/* search1010_1_0 -> search907_1_0 in the cache */
/* search1010_1 -> search1003_1 in the cache */
static const nir_search_expression search1010 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search991_0.value, &search1003_1.value },
   NULL,
};

   /* replace1010_0_0 -> search877_0_0 in the cache */
/* replace1010_0 -> search973_0 in the cache */

/* replace1010_1 -> search907_1_0 in the cache */
static const nir_search_expression replace1010 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search973_0.value, &search907_1_0.value },
   NULL,
};

   /* search1011_0_0 -> search0_0 in the cache */
/* search1011_0 -> replace830 in the cache */

/* search1011_1_0 -> replace0_1_0 in the cache */
static const nir_search_expression search1011_1 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_u2u64,
   { &replace0_1_0.value },
   NULL,
};
static const nir_search_expression search1011 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &replace830.value, &search1011_1.value },
   NULL,
};

   /* replace1011_0 -> search0_0 in the cache */

/* replace1011_1_0 -> replace0_1_0 in the cache */
static const nir_search_expression replace1011_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_u2u32,
   { &replace0_1_0.value },
   NULL,
};
static const nir_search_expression replace1011 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &search0_0.value, &replace1011_1.value },
   NULL,
};

   /* search1012_0_0 -> search0_0 in the cache */
/* search1012_0 -> replace830 in the cache */

/* search1012_1_0 -> replace0_1_0 in the cache */
/* search1012_1 -> search1011_1 in the cache */
static const nir_search_expression search1012 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &replace830.value, &search1011_1.value },
   NULL,
};

   /* replace1012_0 -> search0_0 in the cache */

/* replace1012_1_0 -> replace0_1_0 in the cache */
/* replace1012_1 -> replace1011_1 in the cache */
static const nir_search_expression replace1012 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &search0_0.value, &replace1011_1.value },
   NULL,
};

   /* search1013_0_0 -> search0_0 in the cache */
/* search1013_0 -> replace830 in the cache */

/* search1013_1_0 -> replace0_1_0 in the cache */
/* search1013_1 -> search1011_1 in the cache */
static const nir_search_expression search1013 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &replace830.value, &search1011_1.value },
   NULL,
};

   /* replace1013_0 -> search0_0 in the cache */

/* replace1013_1_0 -> replace0_1_0 in the cache */
/* replace1013_1 -> replace1011_1 in the cache */
static const nir_search_expression replace1013 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search0_0.value, &replace1011_1.value },
   NULL,
};

   /* search1014_0_0 -> search0_0 in the cache */
/* search1014_0 -> replace830 in the cache */

/* search1014_1_0 -> replace0_1_0 in the cache */
/* search1014_1 -> search1011_1 in the cache */
static const nir_search_expression search1014 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &replace830.value, &search1011_1.value },
   NULL,
};

   /* replace1014_0 -> search0_0 in the cache */

/* replace1014_1_0 -> replace0_1_0 in the cache */
/* replace1014_1 -> replace1011_1 in the cache */
static const nir_search_expression replace1014 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search0_0.value, &replace1011_1.value },
   NULL,
};

   /* search1015_0_0 -> search919_0_0 in the cache */
static const nir_search_expression search1015_0 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_u2u64,
   { &search919_0_0.value },
   NULL,
};

/* search1015_1_0 -> search907_1_0 in the cache */
/* search1015_1 -> search1003_1 in the cache */
static const nir_search_expression search1015 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search1015_0.value, &search1003_1.value },
   NULL,
};

   /* replace1015_0_0 -> search919_0_0 in the cache */
static const nir_search_expression replace1015_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_u2u32,
   { &search919_0_0.value },
   NULL,
};

/* replace1015_1 -> search907_1_0 in the cache */
static const nir_search_expression replace1015 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &replace1015_0.value, &search907_1_0.value },
   NULL,
};

   /* search1016_0_0 -> search919_0_0 in the cache */
/* search1016_0 -> search1015_0 in the cache */

/* search1016_1_0 -> search907_1_0 in the cache */
/* search1016_1 -> search1003_1 in the cache */
static const nir_search_expression search1016 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search1015_0.value, &search1003_1.value },
   NULL,
};

   /* replace1016_0_0 -> search919_0_0 in the cache */
/* replace1016_0 -> replace1015_0 in the cache */

/* replace1016_1 -> search907_1_0 in the cache */
static const nir_search_expression replace1016 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &replace1015_0.value, &search907_1_0.value },
   NULL,
};

   /* search1017_0_0 -> search0_0 in the cache */
/* search1017_0 -> replace830 in the cache */

/* search1017_1 -> search861_1 in the cache */
static const nir_search_expression search1017 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &replace830.value, &search861_1.value },
   NULL,
};

   /* replace1017_0_0 -> search0_0 in the cache */

/* replace1017_0_1_0 -> search57_1_1 in the cache */
static const nir_search_expression replace1017_0_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_u2u32,
   { &search57_1_1.value },
   NULL,
};
static const nir_search_expression replace1017_0 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ieq,
   { &search0_0.value, &replace1017_0_1.value },
   NULL,
};

/* replace1017_1_0_0_0 -> search57_1_1 in the cache */
/* replace1017_1_0_0 -> replace1017_0_1 in the cache */
static const nir_search_expression replace1017_1_0 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_u2u64,
   { &replace1017_0_1.value },
   NULL,
};

/* replace1017_1_1 -> search57_1_1 in the cache */
static const nir_search_expression replace1017_1 = {
   { nir_search_value_expression, 1 },
   false,
   2, 1,
   nir_op_ieq,
   { &replace1017_1_0.value, &search57_1_1.value },
   NULL,
};
static const nir_search_expression replace1017 = {
   { nir_search_value_expression, 1 },
   false,
   0, 3,
   nir_op_iand,
   { &replace1017_0.value, &replace1017_1.value },
   NULL,
};

   /* search1018_0_0 -> search0_0 in the cache */
/* search1018_0 -> replace830 in the cache */

/* search1018_1 -> search861_1 in the cache */
static const nir_search_expression search1018 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &replace830.value, &search861_1.value },
   NULL,
};

   /* replace1018_0_0 -> search0_0 in the cache */

/* replace1018_0_1_0 -> search57_1_1 in the cache */
/* replace1018_0_1 -> replace1017_0_1 in the cache */
static const nir_search_expression replace1018_0 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ine,
   { &search0_0.value, &replace1017_0_1.value },
   NULL,
};

/* replace1018_1_0_0_0 -> search57_1_1 in the cache */
/* replace1018_1_0_0 -> replace1017_0_1 in the cache */
/* replace1018_1_0 -> replace1017_1_0 in the cache */

/* replace1018_1_1 -> search57_1_1 in the cache */
static const nir_search_expression replace1018_1 = {
   { nir_search_value_expression, 1 },
   false,
   2, 1,
   nir_op_ine,
   { &replace1017_1_0.value, &search57_1_1.value },
   NULL,
};
static const nir_search_expression replace1018 = {
   { nir_search_value_expression, 1 },
   false,
   0, 3,
   nir_op_ior,
   { &replace1018_0.value, &replace1018_1.value },
   NULL,
};

   /* search1019_0_0 -> search0_0 in the cache */
/* search1019_0 -> replace830 in the cache */

/* search1019_1 -> search861_1 in the cache */
static const nir_search_expression search1019 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &replace830.value, &search861_1.value },
   NULL,
};

   /* replace1019_0_0 -> replace107_2 in the cache */

/* replace1019_0_1 -> search57_1_1 in the cache */
/* replace1019_0 -> replace959_0 in the cache */

/* replace1019_1_0_0 -> search574_0_1 in the cache */

/* replace1019_1_0_1 -> search57_1_1 in the cache */
static const nir_search_expression replace1019_1_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search574_0_1.value, &search57_1_1.value },
   NULL,
};

/* replace1019_1_1_0 -> search0_0 in the cache */

/* replace1019_1_1_1_0 -> search57_1_1 in the cache */
/* replace1019_1_1_1 -> replace1017_0_1 in the cache */
static const nir_search_expression replace1019_1_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search0_0.value, &replace1017_0_1.value },
   NULL,
};
static const nir_search_expression replace1019_1 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ior,
   { &replace1019_1_0.value, &replace1019_1_1.value },
   NULL,
};
static const nir_search_expression replace1019 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &replace959_0.value, &replace1019_1.value },
   NULL,
};

   /* search1020_0 -> search864_0 in the cache */

/* search1020_1_0 -> replace0_1_0 in the cache */
/* search1020_1 -> search1011_1 in the cache */
static const nir_search_expression search1020 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search864_0.value, &search1011_1.value },
   NULL,
};

   /* replace1020_0_0 -> search57_0 in the cache */

/* replace1020_0_1 -> search574_0_1 in the cache */
static const nir_search_expression replace1020_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search57_0.value, &search574_0_1.value },
   NULL,
};

/* replace1020_1_0_0 -> search57_0 in the cache */

/* replace1020_1_0_1 -> replace107_2 in the cache */
/* replace1020_1_0 -> replace960_1_0 in the cache */

/* replace1020_1_1_0_0 -> search57_0 in the cache */
static const nir_search_expression replace1020_1_1_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_u2u32,
   { &search57_0.value },
   NULL,
};

/* replace1020_1_1_1 -> replace0_1_0 in the cache */
static const nir_search_expression replace1020_1_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &replace1020_1_1_0.value, &replace0_1_0.value },
   NULL,
};
static const nir_search_expression replace1020_1 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ior,
   { &replace960_1_0.value, &replace1020_1_1.value },
   NULL,
};
static const nir_search_expression replace1020 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &replace1020_0.value, &replace1020_1.value },
   NULL,
};

   /* search1021_0_0 -> search0_0 in the cache */
/* search1021_0 -> replace830 in the cache */

/* search1021_1 -> search861_1 in the cache */
static const nir_search_expression search1021 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &replace830.value, &search861_1.value },
   NULL,
};

   /* replace1021_0_0 -> search574_0_1 in the cache */

/* replace1021_0_1 -> search57_1_1 in the cache */
static const nir_search_expression replace1021_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search574_0_1.value, &search57_1_1.value },
   NULL,
};

/* replace1021_1_0_0 -> replace107_2 in the cache */

/* replace1021_1_0_1 -> search57_1_1 in the cache */
/* replace1021_1_0 -> replace961_1_0 in the cache */

/* replace1021_1_1_0 -> search0_0 in the cache */

/* replace1021_1_1_1_0 -> search57_1_1 in the cache */
/* replace1021_1_1_1 -> replace1017_0_1 in the cache */
static const nir_search_expression replace1021_1_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search0_0.value, &replace1017_0_1.value },
   NULL,
};
static const nir_search_expression replace1021_1 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ior,
   { &replace961_1_0.value, &replace1021_1_1.value },
   NULL,
};
static const nir_search_expression replace1021 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &replace1021_0.value, &replace1021_1.value },
   NULL,
};

   /* search1022_0 -> search864_0 in the cache */

/* search1022_1_0 -> replace0_1_0 in the cache */
/* search1022_1 -> search1011_1 in the cache */
static const nir_search_expression search1022 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search864_0.value, &search1011_1.value },
   NULL,
};

   /* replace1022_0_0 -> search57_0 in the cache */

/* replace1022_0_1 -> replace107_2 in the cache */
/* replace1022_0 -> replace962_0 in the cache */

/* replace1022_1_0_0 -> search57_0 in the cache */

/* replace1022_1_0_1 -> search574_0_1 in the cache */
static const nir_search_expression replace1022_1_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search57_0.value, &search574_0_1.value },
   NULL,
};

/* replace1022_1_1_0_0 -> search57_0 in the cache */
/* replace1022_1_1_0 -> replace1020_1_1_0 in the cache */

/* replace1022_1_1_1 -> replace0_1_0 in the cache */
static const nir_search_expression replace1022_1_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &replace1020_1_1_0.value, &replace0_1_0.value },
   NULL,
};
static const nir_search_expression replace1022_1 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ior,
   { &replace1022_1_0.value, &replace1022_1_1.value },
   NULL,
};
static const nir_search_expression replace1022 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &replace962_0.value, &replace1022_1.value },
   NULL,
};

   /* search1023_0_0 -> search101_0_0 in the cache */
static const nir_search_expression search1023_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_f2f32,
   { &search101_0_0.value },
   NULL,
};

/* search1023_1_0 -> replace564_1_0 in the cache */
static const nir_search_expression search1023_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_f2f32,
   { &replace564_1_0.value },
   NULL,
};
static const nir_search_expression search1023 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_feq,
   { &search1023_0.value, &search1023_1.value },
   NULL,
};

   /* replace1023_0 -> search101_0_0 in the cache */

/* replace1023_1_0 -> replace564_1_0 in the cache */
static const nir_search_expression replace1023_1 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_f2f16,
   { &replace564_1_0.value },
   NULL,
};
static const nir_search_expression replace1023 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_feq,
   { &search101_0_0.value, &replace1023_1.value },
   NULL,
};

   /* search1024_0_0 -> search101_0_0 in the cache */
/* search1024_0 -> search1023_0 in the cache */

/* search1024_1_0 -> replace564_1_0 in the cache */
/* search1024_1 -> search1023_1 in the cache */
static const nir_search_expression search1024 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_fne,
   { &search1023_0.value, &search1023_1.value },
   NULL,
};

   /* replace1024_0 -> search101_0_0 in the cache */

/* replace1024_1_0 -> replace564_1_0 in the cache */
/* replace1024_1 -> replace1023_1 in the cache */
static const nir_search_expression replace1024 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_fne,
   { &search101_0_0.value, &replace1023_1.value },
   NULL,
};

   /* search1025_0_0 -> search101_0_0 in the cache */
/* search1025_0 -> search1023_0 in the cache */

/* search1025_1_0 -> replace564_1_0 in the cache */
/* search1025_1 -> search1023_1 in the cache */
static const nir_search_expression search1025 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search1023_0.value, &search1023_1.value },
   NULL,
};

   /* replace1025_0 -> search101_0_0 in the cache */

/* replace1025_1_0 -> replace564_1_0 in the cache */
/* replace1025_1 -> replace1023_1 in the cache */
static const nir_search_expression replace1025 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search101_0_0.value, &replace1023_1.value },
   NULL,
};

   /* search1026_0_0 -> search101_0_0 in the cache */
/* search1026_0 -> search1023_0 in the cache */

/* search1026_1_0 -> replace564_1_0 in the cache */
/* search1026_1 -> search1023_1 in the cache */
static const nir_search_expression search1026 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search1023_0.value, &search1023_1.value },
   NULL,
};

   /* replace1026_0 -> search101_0_0 in the cache */

/* replace1026_1_0 -> replace564_1_0 in the cache */
/* replace1026_1 -> replace1023_1 in the cache */
static const nir_search_expression replace1026 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search101_0_0.value, &replace1023_1.value },
   NULL,
};

   /* search1027_0_0 -> search877_0_0 in the cache */
static const nir_search_expression search1027_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_f2f32,
   { &search877_0_0.value },
   NULL,
};

/* search1027_1_0 -> search871_1_0 in the cache */
static const nir_search_expression search1027_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_f2f32,
   { &search871_1_0.value },
   NULL,
};
static const nir_search_expression search1027 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search1027_0.value, &search1027_1.value },
   NULL,
};

   /* replace1027_0_0 -> search877_0_0 in the cache */
static const nir_search_expression replace1027_0 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_f2f16,
   { &search877_0_0.value },
   NULL,
};

/* replace1027_1 -> search871_1_0 in the cache */
static const nir_search_expression replace1027 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &replace1027_0.value, &search871_1_0.value },
   NULL,
};

   /* search1028_0_0 -> search877_0_0 in the cache */
/* search1028_0 -> search1027_0 in the cache */

/* search1028_1_0 -> search871_1_0 in the cache */
/* search1028_1 -> search1027_1 in the cache */
static const nir_search_expression search1028 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search1027_0.value, &search1027_1.value },
   NULL,
};

   /* replace1028_0_0 -> search877_0_0 in the cache */
/* replace1028_0 -> replace1027_0 in the cache */

/* replace1028_1 -> search871_1_0 in the cache */
static const nir_search_expression replace1028 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &replace1027_0.value, &search871_1_0.value },
   NULL,
};

   /* search1029_0_0 -> search101_0_0 in the cache */
static const nir_search_expression search1029_0 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_f2f64,
   { &search101_0_0.value },
   NULL,
};

/* search1029_1_0 -> replace564_1_0 in the cache */
static const nir_search_expression search1029_1 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_f2f64,
   { &replace564_1_0.value },
   NULL,
};
static const nir_search_expression search1029 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_feq,
   { &search1029_0.value, &search1029_1.value },
   NULL,
};

   /* replace1029_0 -> search101_0_0 in the cache */

/* replace1029_1_0 -> replace564_1_0 in the cache */
/* replace1029_1 -> replace1023_1 in the cache */
/* replace1029 -> replace1023 in the cache */

   /* search1030_0_0 -> search101_0_0 in the cache */
/* search1030_0 -> search1029_0 in the cache */

/* search1030_1_0 -> replace564_1_0 in the cache */
/* search1030_1 -> search1029_1 in the cache */
static const nir_search_expression search1030 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_fne,
   { &search1029_0.value, &search1029_1.value },
   NULL,
};

   /* replace1030_0 -> search101_0_0 in the cache */

/* replace1030_1_0 -> replace564_1_0 in the cache */
/* replace1030_1 -> replace1023_1 in the cache */
/* replace1030 -> replace1024 in the cache */

   /* search1031_0_0 -> search101_0_0 in the cache */
/* search1031_0 -> search1029_0 in the cache */

/* search1031_1_0 -> replace564_1_0 in the cache */
/* search1031_1 -> search1029_1 in the cache */
static const nir_search_expression search1031 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search1029_0.value, &search1029_1.value },
   NULL,
};

   /* replace1031_0 -> search101_0_0 in the cache */

/* replace1031_1_0 -> replace564_1_0 in the cache */
/* replace1031_1 -> replace1023_1 in the cache */
/* replace1031 -> replace1025 in the cache */

   /* search1032_0_0 -> search101_0_0 in the cache */
/* search1032_0 -> search1029_0 in the cache */

/* search1032_1_0 -> replace564_1_0 in the cache */
/* search1032_1 -> search1029_1 in the cache */
static const nir_search_expression search1032 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search1029_0.value, &search1029_1.value },
   NULL,
};

   /* replace1032_0 -> search101_0_0 in the cache */

/* replace1032_1_0 -> replace564_1_0 in the cache */
/* replace1032_1 -> replace1023_1 in the cache */
/* replace1032 -> replace1026 in the cache */

   /* search1033_0_0 -> search877_0_0 in the cache */
static const nir_search_expression search1033_0 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_f2f64,
   { &search877_0_0.value },
   NULL,
};

/* search1033_1_0 -> search871_1_0 in the cache */
static const nir_search_expression search1033_1 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_f2f64,
   { &search871_1_0.value },
   NULL,
};
static const nir_search_expression search1033 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search1033_0.value, &search1033_1.value },
   NULL,
};

   /* replace1033_0_0 -> search877_0_0 in the cache */
/* replace1033_0 -> replace1027_0 in the cache */

/* replace1033_1 -> search871_1_0 in the cache */
/* replace1033 -> replace1027 in the cache */

   /* search1034_0_0 -> search877_0_0 in the cache */
/* search1034_0 -> search1033_0 in the cache */

/* search1034_1_0 -> search871_1_0 in the cache */
/* search1034_1 -> search1033_1 in the cache */
static const nir_search_expression search1034 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search1033_0.value, &search1033_1.value },
   NULL,
};

   /* replace1034_0_0 -> search877_0_0 in the cache */
/* replace1034_0 -> replace1027_0 in the cache */

/* replace1034_1 -> search871_1_0 in the cache */
/* replace1034 -> replace1028 in the cache */

   /* search1035_0_0 -> search0_0 in the cache */
static const nir_search_expression search1035_0 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_f2f64,
   { &search0_0.value },
   NULL,
};

/* search1035_1_0 -> replace564_1_0 in the cache */
/* search1035_1 -> search1029_1 in the cache */
static const nir_search_expression search1035 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_feq,
   { &search1035_0.value, &search1029_1.value },
   NULL,
};

   /* replace1035_0 -> search0_0 in the cache */

/* replace1035_1_0 -> replace564_1_0 in the cache */
/* replace1035_1 -> search1023_1 in the cache */
static const nir_search_expression replace1035 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_feq,
   { &search0_0.value, &search1023_1.value },
   NULL,
};

   /* search1036_0_0 -> search0_0 in the cache */
/* search1036_0 -> search1035_0 in the cache */

/* search1036_1_0 -> replace564_1_0 in the cache */
/* search1036_1 -> search1029_1 in the cache */
static const nir_search_expression search1036 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_fne,
   { &search1035_0.value, &search1029_1.value },
   NULL,
};

   /* replace1036_0 -> search0_0 in the cache */

/* replace1036_1_0 -> replace564_1_0 in the cache */
/* replace1036_1 -> search1023_1 in the cache */
static const nir_search_expression replace1036 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_fne,
   { &search0_0.value, &search1023_1.value },
   NULL,
};

   /* search1037_0_0 -> search0_0 in the cache */
/* search1037_0 -> search1035_0 in the cache */

/* search1037_1_0 -> replace564_1_0 in the cache */
/* search1037_1 -> search1029_1 in the cache */
static const nir_search_expression search1037 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search1035_0.value, &search1029_1.value },
   NULL,
};

   /* replace1037_0 -> search0_0 in the cache */

/* replace1037_1_0 -> replace564_1_0 in the cache */
/* replace1037_1 -> search1023_1 in the cache */
static const nir_search_expression replace1037 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search0_0.value, &search1023_1.value },
   NULL,
};

   /* search1038_0_0 -> search0_0 in the cache */
/* search1038_0 -> search1035_0 in the cache */

/* search1038_1_0 -> replace564_1_0 in the cache */
/* search1038_1 -> search1029_1 in the cache */
static const nir_search_expression search1038 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search1035_0.value, &search1029_1.value },
   NULL,
};

   /* replace1038_0 -> search0_0 in the cache */

/* replace1038_1_0 -> replace564_1_0 in the cache */
/* replace1038_1 -> search1023_1 in the cache */
static const nir_search_expression replace1038 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search0_0.value, &search1023_1.value },
   NULL,
};

   /* search1039_0_0 -> search877_0_0 in the cache */
/* search1039_0 -> search1033_0 in the cache */

/* search1039_1_0 -> search907_1_0 in the cache */
static const nir_search_expression search1039_1 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_f2f64,
   { &search907_1_0.value },
   NULL,
};
static const nir_search_expression search1039 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search1033_0.value, &search1039_1.value },
   NULL,
};

   /* replace1039_0_0 -> search877_0_0 in the cache */
/* replace1039_0 -> search1027_0 in the cache */

/* replace1039_1 -> search907_1_0 in the cache */
static const nir_search_expression replace1039 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search1027_0.value, &search907_1_0.value },
   NULL,
};

   /* search1040_0_0 -> search877_0_0 in the cache */
/* search1040_0 -> search1033_0 in the cache */

/* search1040_1_0 -> search907_1_0 in the cache */
/* search1040_1 -> search1039_1 in the cache */
static const nir_search_expression search1040 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search1033_0.value, &search1039_1.value },
   NULL,
};

   /* replace1040_0_0 -> search877_0_0 in the cache */
/* replace1040_0 -> search1027_0 in the cache */

/* replace1040_1 -> search907_1_0 in the cache */
static const nir_search_expression replace1040 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search1027_0.value, &search907_1_0.value },
   NULL,
};

   /* search1041_0_0 -> search0_0 in the cache */
/* search1041_0 -> search1035_0 in the cache */

/* search1041_1_0 -> replace0_1_0 in the cache */
static const nir_search_expression search1041_1 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_f2f64,
   { &replace0_1_0.value },
   NULL,
};
static const nir_search_expression search1041 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_feq,
   { &search1035_0.value, &search1041_1.value },
   NULL,
};

   /* replace1041_0 -> search0_0 in the cache */

/* replace1041_1_0 -> replace0_1_0 in the cache */
static const nir_search_expression replace1041_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_f2f32,
   { &replace0_1_0.value },
   NULL,
};
static const nir_search_expression replace1041 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_feq,
   { &search0_0.value, &replace1041_1.value },
   NULL,
};

   /* search1042_0_0 -> search0_0 in the cache */
/* search1042_0 -> search1035_0 in the cache */

/* search1042_1_0 -> replace0_1_0 in the cache */
/* search1042_1 -> search1041_1 in the cache */
static const nir_search_expression search1042 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_fne,
   { &search1035_0.value, &search1041_1.value },
   NULL,
};

   /* replace1042_0 -> search0_0 in the cache */

/* replace1042_1_0 -> replace0_1_0 in the cache */
/* replace1042_1 -> replace1041_1 in the cache */
static const nir_search_expression replace1042 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_fne,
   { &search0_0.value, &replace1041_1.value },
   NULL,
};

   /* search1043_0_0 -> search0_0 in the cache */
/* search1043_0 -> search1035_0 in the cache */

/* search1043_1_0 -> replace0_1_0 in the cache */
/* search1043_1 -> search1041_1 in the cache */
static const nir_search_expression search1043 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search1035_0.value, &search1041_1.value },
   NULL,
};

   /* replace1043_0 -> search0_0 in the cache */

/* replace1043_1_0 -> replace0_1_0 in the cache */
/* replace1043_1 -> replace1041_1 in the cache */
static const nir_search_expression replace1043 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search0_0.value, &replace1041_1.value },
   NULL,
};

   /* search1044_0_0 -> search0_0 in the cache */
/* search1044_0 -> search1035_0 in the cache */

/* search1044_1_0 -> replace0_1_0 in the cache */
/* search1044_1 -> search1041_1 in the cache */
static const nir_search_expression search1044 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search1035_0.value, &search1041_1.value },
   NULL,
};

   /* replace1044_0 -> search0_0 in the cache */

/* replace1044_1_0 -> replace0_1_0 in the cache */
/* replace1044_1 -> replace1041_1 in the cache */
static const nir_search_expression replace1044 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search0_0.value, &replace1041_1.value },
   NULL,
};

   /* search1045_0_0 -> search919_0_0 in the cache */
static const nir_search_expression search1045_0 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_f2f64,
   { &search919_0_0.value },
   NULL,
};

/* search1045_1_0 -> search907_1_0 in the cache */
/* search1045_1 -> search1039_1 in the cache */
static const nir_search_expression search1045 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search1045_0.value, &search1039_1.value },
   NULL,
};

   /* replace1045_0_0 -> search919_0_0 in the cache */
static const nir_search_expression replace1045_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_f2f32,
   { &search919_0_0.value },
   NULL,
};

/* replace1045_1 -> search907_1_0 in the cache */
static const nir_search_expression replace1045 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &replace1045_0.value, &search907_1_0.value },
   NULL,
};

   /* search1046_0_0 -> search919_0_0 in the cache */
/* search1046_0 -> search1045_0 in the cache */

/* search1046_1_0 -> search907_1_0 in the cache */
/* search1046_1 -> search1039_1 in the cache */
static const nir_search_expression search1046 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search1045_0.value, &search1039_1.value },
   NULL,
};

   /* replace1046_0_0 -> search919_0_0 in the cache */
/* replace1046_0 -> replace1045_0 in the cache */

/* replace1046_1 -> search907_1_0 in the cache */
static const nir_search_expression replace1046 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &replace1045_0.value, &search907_1_0.value },
   NULL,
};

   static const nir_search_variable search1047_0 = {
   { nir_search_value_variable, 16 },
   0, /* x */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

static const nir_search_variable search1047_1 = {
   { nir_search_value_variable, 32 },
   1, /* exp */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search1047 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 0,
   nir_op_ldexp,
   { &search1047_0.value, &search1047_1.value },
   NULL,
};

   /* replace1047_0_0 -> search1047_0 in the cache */

/* replace1047_0_1_0_0_0_0_0_0 -> search1047_1 in the cache */

static const nir_search_constant replace1047_0_1_0_0_0_0_0_1 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { -0x1c /* -28 */ },
};
static const nir_search_expression replace1047_0_1_0_0_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   4, 1,
   nir_op_imax,
   { &search1047_1.value, &replace1047_0_1_0_0_0_0_0_1.value },
   NULL,
};

static const nir_search_constant replace1047_0_1_0_0_0_0_1 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { 0x1e /* 30 */ },
};
static const nir_search_expression replace1047_0_1_0_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   3, 2,
   nir_op_imin,
   { &replace1047_0_1_0_0_0_0_0.value, &replace1047_0_1_0_0_0_0_1.value },
   NULL,
};

/* replace1047_0_1_0_0_0_1 -> replace579_1 in the cache */
static const nir_search_expression replace1047_0_1_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 2,
   nir_op_ishr,
   { &replace1047_0_1_0_0_0_0.value, &replace579_1.value },
   NULL,
};

/* replace1047_0_1_0_0_1 -> replace103_1_1 in the cache */
static const nir_search_expression replace1047_0_1_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   2, 3,
   nir_op_iadd,
   { &replace1047_0_1_0_0_0.value, &replace103_1_1.value },
   NULL,
};

static const nir_search_constant replace1047_0_1_0_1 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { 0xa /* 10 */ },
};
static const nir_search_expression replace1047_0_1_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 3,
   nir_op_ishl,
   { &replace1047_0_1_0_0.value, &replace1047_0_1_0_1.value },
   NULL,
};
static const nir_search_expression replace1047_0_1 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 3,
   nir_op_i2i16,
   { &replace1047_0_1_0.value },
   NULL,
};
static const nir_search_expression replace1047_0 = {
   { nir_search_value_expression, 16 },
   false,
   1, 4,
   nir_op_fmul,
   { &search1047_0.value, &replace1047_0_1.value },
   NULL,
};

/* replace1047_1_0_0_0_0_0_0 -> search1047_1 in the cache */

/* replace1047_1_0_0_0_0_0_1 -> replace1047_0_1_0_0_0_0_0_1 in the cache */
static const nir_search_expression replace1047_1_0_0_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   7, 1,
   nir_op_imax,
   { &search1047_1.value, &replace1047_0_1_0_0_0_0_0_1.value },
   NULL,
};

/* replace1047_1_0_0_0_0_1 -> replace1047_0_1_0_0_0_0_1 in the cache */
static const nir_search_expression replace1047_1_0_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   6, 2,
   nir_op_imin,
   { &replace1047_1_0_0_0_0_0.value, &replace1047_0_1_0_0_0_0_1.value },
   NULL,
};

/* replace1047_1_0_0_0_1_0_0_0 -> search1047_1 in the cache */

/* replace1047_1_0_0_0_1_0_0_1 -> replace1047_0_1_0_0_0_0_0_1 in the cache */
static const nir_search_expression replace1047_1_0_0_0_1_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   9, 1,
   nir_op_imax,
   { &search1047_1.value, &replace1047_0_1_0_0_0_0_0_1.value },
   NULL,
};

/* replace1047_1_0_0_0_1_0_1 -> replace1047_0_1_0_0_0_0_1 in the cache */
static const nir_search_expression replace1047_1_0_0_0_1_0 = {
   { nir_search_value_expression, 32 },
   false,
   8, 2,
   nir_op_imin,
   { &replace1047_1_0_0_0_1_0_0.value, &replace1047_0_1_0_0_0_0_1.value },
   NULL,
};

/* replace1047_1_0_0_0_1_1 -> replace579_1 in the cache */
static const nir_search_expression replace1047_1_0_0_0_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 2,
   nir_op_ishr,
   { &replace1047_1_0_0_0_1_0.value, &replace579_1.value },
   NULL,
};
static const nir_search_expression replace1047_1_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 4,
   nir_op_isub,
   { &replace1047_1_0_0_0_0.value, &replace1047_1_0_0_0_1.value },
   NULL,
};

/* replace1047_1_0_0_1 -> replace103_1_1 in the cache */
static const nir_search_expression replace1047_1_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   5, 5,
   nir_op_iadd,
   { &replace1047_1_0_0_0.value, &replace103_1_1.value },
   NULL,
};

/* replace1047_1_0_1 -> replace1047_0_1_0_1 in the cache */
static const nir_search_expression replace1047_1_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 5,
   nir_op_ishl,
   { &replace1047_1_0_0.value, &replace1047_0_1_0_1.value },
   NULL,
};
static const nir_search_expression replace1047_1 = {
   { nir_search_value_expression, 16 },
   false,
   -1, 5,
   nir_op_i2i16,
   { &replace1047_1_0.value },
   NULL,
};
static const nir_search_expression replace1047 = {
   { nir_search_value_expression, 16 },
   false,
   0, 10,
   nir_op_fmul,
   { &replace1047_0.value, &replace1047_1.value },
   NULL,
};

   static const nir_search_variable search1048_0 = {
   { nir_search_value_variable, 32 },
   0, /* x */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

/* search1048_1 -> search1047_1 in the cache */
static const nir_search_expression search1048 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_ldexp,
   { &search1048_0.value, &search1047_1.value },
   NULL,
};

   /* replace1048_0_0 -> search1048_0 in the cache */

/* replace1048_0_1_0_0_0_0_0 -> search1047_1 in the cache */

static const nir_search_constant replace1048_0_1_0_0_0_0_1 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { -0xfc /* -252 */ },
};
static const nir_search_expression replace1048_0_1_0_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   4, 1,
   nir_op_imax,
   { &search1047_1.value, &replace1048_0_1_0_0_0_0_1.value },
   NULL,
};

static const nir_search_constant replace1048_0_1_0_0_0_1 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { 0xfe /* 254 */ },
};
static const nir_search_expression replace1048_0_1_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   3, 2,
   nir_op_imin,
   { &replace1048_0_1_0_0_0_0.value, &replace1048_0_1_0_0_0_1.value },
   NULL,
};

/* replace1048_0_1_0_0_1 -> replace579_1 in the cache */
static const nir_search_expression replace1048_0_1_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 2,
   nir_op_ishr,
   { &replace1048_0_1_0_0_0.value, &replace579_1.value },
   NULL,
};

/* replace1048_0_1_0_1 -> replace851_1_0_0 in the cache */
static const nir_search_expression replace1048_0_1_0 = {
   { nir_search_value_expression, 32 },
   false,
   2, 3,
   nir_op_iadd,
   { &replace1048_0_1_0_0.value, &replace851_1_0_0.value },
   NULL,
};

static const nir_search_constant replace1048_0_1_1 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { 0x17 /* 23 */ },
};
static const nir_search_expression replace1048_0_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 3,
   nir_op_ishl,
   { &replace1048_0_1_0.value, &replace1048_0_1_1.value },
   NULL,
};
static const nir_search_expression replace1048_0 = {
   { nir_search_value_expression, 32 },
   false,
   1, 4,
   nir_op_fmul,
   { &search1048_0.value, &replace1048_0_1.value },
   NULL,
};

/* replace1048_1_0_0_0_0_0 -> search1047_1 in the cache */

/* replace1048_1_0_0_0_0_1 -> replace1048_0_1_0_0_0_0_1 in the cache */
static const nir_search_expression replace1048_1_0_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   7, 1,
   nir_op_imax,
   { &search1047_1.value, &replace1048_0_1_0_0_0_0_1.value },
   NULL,
};

/* replace1048_1_0_0_0_1 -> replace1048_0_1_0_0_0_1 in the cache */
static const nir_search_expression replace1048_1_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   6, 2,
   nir_op_imin,
   { &replace1048_1_0_0_0_0.value, &replace1048_0_1_0_0_0_1.value },
   NULL,
};

/* replace1048_1_0_0_1_0_0_0 -> search1047_1 in the cache */

/* replace1048_1_0_0_1_0_0_1 -> replace1048_0_1_0_0_0_0_1 in the cache */
static const nir_search_expression replace1048_1_0_0_1_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   9, 1,
   nir_op_imax,
   { &search1047_1.value, &replace1048_0_1_0_0_0_0_1.value },
   NULL,
};

/* replace1048_1_0_0_1_0_1 -> replace1048_0_1_0_0_0_1 in the cache */
static const nir_search_expression replace1048_1_0_0_1_0 = {
   { nir_search_value_expression, 32 },
   false,
   8, 2,
   nir_op_imin,
   { &replace1048_1_0_0_1_0_0.value, &replace1048_0_1_0_0_0_1.value },
   NULL,
};

/* replace1048_1_0_0_1_1 -> replace579_1 in the cache */
static const nir_search_expression replace1048_1_0_0_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 2,
   nir_op_ishr,
   { &replace1048_1_0_0_1_0.value, &replace579_1.value },
   NULL,
};
static const nir_search_expression replace1048_1_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 4,
   nir_op_isub,
   { &replace1048_1_0_0_0.value, &replace1048_1_0_0_1.value },
   NULL,
};

/* replace1048_1_0_1 -> replace851_1_0_0 in the cache */
static const nir_search_expression replace1048_1_0 = {
   { nir_search_value_expression, 32 },
   false,
   5, 5,
   nir_op_iadd,
   { &replace1048_1_0_0.value, &replace851_1_0_0.value },
   NULL,
};

/* replace1048_1_1 -> replace1048_0_1_1 in the cache */
static const nir_search_expression replace1048_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 5,
   nir_op_ishl,
   { &replace1048_1_0.value, &replace1048_0_1_1.value },
   NULL,
};
static const nir_search_expression replace1048 = {
   { nir_search_value_expression, 32 },
   false,
   0, 10,
   nir_op_fmul,
   { &replace1048_0.value, &replace1048_1.value },
   NULL,
};

   static const nir_search_variable search1049_0 = {
   { nir_search_value_variable, 64 },
   0, /* x */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

/* search1049_1 -> search1047_1 in the cache */
static const nir_search_expression search1049 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_ldexp,
   { &search1049_0.value, &search1047_1.value },
   NULL,
};

   /* replace1049_0_0 -> search1049_0 in the cache */

/* replace1049_0_1_0 -> search26_1 in the cache */

/* replace1049_0_1_1_0_0_0_0_0 -> search1047_1 in the cache */

static const nir_search_constant replace1049_0_1_1_0_0_0_0_1 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { -0x7fc /* -2044 */ },
};
static const nir_search_expression replace1049_0_1_1_0_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   4, 1,
   nir_op_imax,
   { &search1047_1.value, &replace1049_0_1_1_0_0_0_0_1.value },
   NULL,
};

static const nir_search_constant replace1049_0_1_1_0_0_0_1 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { 0x7fe /* 2046 */ },
};
static const nir_search_expression replace1049_0_1_1_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   3, 2,
   nir_op_imin,
   { &replace1049_0_1_1_0_0_0_0.value, &replace1049_0_1_1_0_0_0_1.value },
   NULL,
};

/* replace1049_0_1_1_0_0_1 -> replace579_1 in the cache */
static const nir_search_expression replace1049_0_1_1_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 2,
   nir_op_ishr,
   { &replace1049_0_1_1_0_0_0.value, &replace579_1.value },
   NULL,
};

static const nir_search_constant replace1049_0_1_1_0_1 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { 0x3ff /* 1023 */ },
};
static const nir_search_expression replace1049_0_1_1_0 = {
   { nir_search_value_expression, 32 },
   false,
   2, 3,
   nir_op_iadd,
   { &replace1049_0_1_1_0_0.value, &replace1049_0_1_1_0_1.value },
   NULL,
};

static const nir_search_constant replace1049_0_1_1_1 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { 0x14 /* 20 */ },
};
static const nir_search_expression replace1049_0_1_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 3,
   nir_op_ishl,
   { &replace1049_0_1_1_0.value, &replace1049_0_1_1_1.value },
   NULL,
};
static const nir_search_expression replace1049_0_1 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 3,
   nir_op_pack_64_2x32_split,
   { &search26_1.value, &replace1049_0_1_1.value },
   NULL,
};
static const nir_search_expression replace1049_0 = {
   { nir_search_value_expression, 64 },
   false,
   1, 4,
   nir_op_fmul,
   { &search1049_0.value, &replace1049_0_1.value },
   NULL,
};

/* replace1049_1_0 -> search26_1 in the cache */

/* replace1049_1_1_0_0_0_0_0 -> search1047_1 in the cache */

/* replace1049_1_1_0_0_0_0_1 -> replace1049_0_1_1_0_0_0_0_1 in the cache */
static const nir_search_expression replace1049_1_1_0_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   7, 1,
   nir_op_imax,
   { &search1047_1.value, &replace1049_0_1_1_0_0_0_0_1.value },
   NULL,
};

/* replace1049_1_1_0_0_0_1 -> replace1049_0_1_1_0_0_0_1 in the cache */
static const nir_search_expression replace1049_1_1_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   6, 2,
   nir_op_imin,
   { &replace1049_1_1_0_0_0_0.value, &replace1049_0_1_1_0_0_0_1.value },
   NULL,
};

/* replace1049_1_1_0_0_1_0_0_0 -> search1047_1 in the cache */

/* replace1049_1_1_0_0_1_0_0_1 -> replace1049_0_1_1_0_0_0_0_1 in the cache */
static const nir_search_expression replace1049_1_1_0_0_1_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   9, 1,
   nir_op_imax,
   { &search1047_1.value, &replace1049_0_1_1_0_0_0_0_1.value },
   NULL,
};

/* replace1049_1_1_0_0_1_0_1 -> replace1049_0_1_1_0_0_0_1 in the cache */
static const nir_search_expression replace1049_1_1_0_0_1_0 = {
   { nir_search_value_expression, 32 },
   false,
   8, 2,
   nir_op_imin,
   { &replace1049_1_1_0_0_1_0_0.value, &replace1049_0_1_1_0_0_0_1.value },
   NULL,
};

/* replace1049_1_1_0_0_1_1 -> replace579_1 in the cache */
static const nir_search_expression replace1049_1_1_0_0_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 2,
   nir_op_ishr,
   { &replace1049_1_1_0_0_1_0.value, &replace579_1.value },
   NULL,
};
static const nir_search_expression replace1049_1_1_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 4,
   nir_op_isub,
   { &replace1049_1_1_0_0_0.value, &replace1049_1_1_0_0_1.value },
   NULL,
};

/* replace1049_1_1_0_1 -> replace1049_0_1_1_0_1 in the cache */
static const nir_search_expression replace1049_1_1_0 = {
   { nir_search_value_expression, 32 },
   false,
   5, 5,
   nir_op_iadd,
   { &replace1049_1_1_0_0.value, &replace1049_0_1_1_0_1.value },
   NULL,
};

/* replace1049_1_1_1 -> replace1049_0_1_1_1 in the cache */
static const nir_search_expression replace1049_1_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 5,
   nir_op_ishl,
   { &replace1049_1_1_0.value, &replace1049_0_1_1_1.value },
   NULL,
};
static const nir_search_expression replace1049_1 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 5,
   nir_op_pack_64_2x32_split,
   { &search26_1.value, &replace1049_1_1.value },
   NULL,
};
static const nir_search_expression replace1049 = {
   { nir_search_value_expression, 64 },
   false,
   0, 10,
   nir_op_fmul,
   { &replace1049_0.value, &replace1049_1.value },
   NULL,
};

   /* search1050_0_0_0_0_0_0_0_0_0_0_0_0_0_0 -> search1048_0 in the cache */

/* search1050_0_0_0_0_0_0_0_0_0_0_0_0_0_1 -> replace101_0_1 in the cache */
static const nir_search_expression search1050_0_0_0_0_0_0_0_0_0_0_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_ishl,
   { &search1048_0.value, &replace101_0_1.value },
   NULL,
};

/* search1050_0_0_0_0_0_0_0_0_0_0_0_0_1_0 -> search1048_0 in the cache */

/* search1050_0_0_0_0_0_0_0_0_0_0_0_0_1_1 -> replace101_0_1 in the cache */
static const nir_search_expression search1050_0_0_0_0_0_0_0_0_0_0_0_0_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_ushr,
   { &search1048_0.value, &replace101_0_1.value },
   NULL,
};
static const nir_search_expression search1050_0_0_0_0_0_0_0_0_0_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   8, 1,
   nir_op_ior,
   { &search1050_0_0_0_0_0_0_0_0_0_0_0_0_0.value, &search1050_0_0_0_0_0_0_0_0_0_0_0_0_1.value },
   NULL,
};

static const nir_search_constant search1050_0_0_0_0_0_0_0_0_0_0_0_1 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { 0xff00ff /* 16711935 */ },
};
static const nir_search_expression search1050_0_0_0_0_0_0_0_0_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   7, 2,
   nir_op_iand,
   { &search1050_0_0_0_0_0_0_0_0_0_0_0_0.value, &search1050_0_0_0_0_0_0_0_0_0_0_0_1.value },
   NULL,
};

/* search1050_0_0_0_0_0_0_0_0_0_0_1 -> replace98_0_1 in the cache */
static const nir_search_expression search1050_0_0_0_0_0_0_0_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 2,
   nir_op_ishl,
   { &search1050_0_0_0_0_0_0_0_0_0_0_0.value, &replace98_0_1.value },
   NULL,
};

/* search1050_0_0_0_0_0_0_0_0_0_1_0_0_0_0 -> search1048_0 in the cache */

/* search1050_0_0_0_0_0_0_0_0_0_1_0_0_0_1 -> replace101_0_1 in the cache */
/* search1050_0_0_0_0_0_0_0_0_0_1_0_0_0 -> search1050_0_0_0_0_0_0_0_0_0_0_0_0_0 in the cache */

/* search1050_0_0_0_0_0_0_0_0_0_1_0_0_1_0 -> search1048_0 in the cache */

/* search1050_0_0_0_0_0_0_0_0_0_1_0_0_1_1 -> replace101_0_1 in the cache */
/* search1050_0_0_0_0_0_0_0_0_0_1_0_0_1 -> search1050_0_0_0_0_0_0_0_0_0_0_0_0_1 in the cache */
static const nir_search_expression search1050_0_0_0_0_0_0_0_0_0_1_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   10, 1,
   nir_op_ior,
   { &search1050_0_0_0_0_0_0_0_0_0_0_0_0_0.value, &search1050_0_0_0_0_0_0_0_0_0_0_0_0_1.value },
   NULL,
};

static const nir_search_constant search1050_0_0_0_0_0_0_0_0_0_1_0_1 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { 0xff00ff00 /* 4278255360 */ },
};
static const nir_search_expression search1050_0_0_0_0_0_0_0_0_0_1_0 = {
   { nir_search_value_expression, 32 },
   false,
   9, 2,
   nir_op_iand,
   { &search1050_0_0_0_0_0_0_0_0_0_1_0_0.value, &search1050_0_0_0_0_0_0_0_0_0_1_0_1.value },
   NULL,
};

/* search1050_0_0_0_0_0_0_0_0_0_1_1 -> replace98_0_1 in the cache */
static const nir_search_expression search1050_0_0_0_0_0_0_0_0_0_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 2,
   nir_op_ushr,
   { &search1050_0_0_0_0_0_0_0_0_0_1_0.value, &replace98_0_1.value },
   NULL,
};
static const nir_search_expression search1050_0_0_0_0_0_0_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   6, 5,
   nir_op_ior,
   { &search1050_0_0_0_0_0_0_0_0_0_0.value, &search1050_0_0_0_0_0_0_0_0_0_1.value },
   NULL,
};

static const nir_search_constant search1050_0_0_0_0_0_0_0_0_1 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { 0xf0f0f0f /* 252645135 */ },
};
static const nir_search_expression search1050_0_0_0_0_0_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   5, 6,
   nir_op_iand,
   { &search1050_0_0_0_0_0_0_0_0_0.value, &search1050_0_0_0_0_0_0_0_0_1.value },
   NULL,
};

static const nir_search_constant search1050_0_0_0_0_0_0_0_1 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { 0x4 /* 4 */ },
};
static const nir_search_expression search1050_0_0_0_0_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 6,
   nir_op_ishl,
   { &search1050_0_0_0_0_0_0_0_0.value, &search1050_0_0_0_0_0_0_0_1.value },
   NULL,
};

/* search1050_0_0_0_0_0_0_1_0_0_0_0_0_0_0 -> search1048_0 in the cache */

/* search1050_0_0_0_0_0_0_1_0_0_0_0_0_0_1 -> replace101_0_1 in the cache */
/* search1050_0_0_0_0_0_0_1_0_0_0_0_0_0 -> search1050_0_0_0_0_0_0_0_0_0_0_0_0_0 in the cache */

/* search1050_0_0_0_0_0_0_1_0_0_0_0_0_1_0 -> search1048_0 in the cache */

/* search1050_0_0_0_0_0_0_1_0_0_0_0_0_1_1 -> replace101_0_1 in the cache */
/* search1050_0_0_0_0_0_0_1_0_0_0_0_0_1 -> search1050_0_0_0_0_0_0_0_0_0_0_0_0_1 in the cache */
static const nir_search_expression search1050_0_0_0_0_0_0_1_0_0_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   14, 1,
   nir_op_ior,
   { &search1050_0_0_0_0_0_0_0_0_0_0_0_0_0.value, &search1050_0_0_0_0_0_0_0_0_0_0_0_0_1.value },
   NULL,
};

/* search1050_0_0_0_0_0_0_1_0_0_0_0_1 -> search1050_0_0_0_0_0_0_0_0_0_0_0_1 in the cache */
static const nir_search_expression search1050_0_0_0_0_0_0_1_0_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   13, 2,
   nir_op_iand,
   { &search1050_0_0_0_0_0_0_1_0_0_0_0_0.value, &search1050_0_0_0_0_0_0_0_0_0_0_0_1.value },
   NULL,
};

/* search1050_0_0_0_0_0_0_1_0_0_0_1 -> replace98_0_1 in the cache */
static const nir_search_expression search1050_0_0_0_0_0_0_1_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 2,
   nir_op_ishl,
   { &search1050_0_0_0_0_0_0_1_0_0_0_0.value, &replace98_0_1.value },
   NULL,
};

/* search1050_0_0_0_0_0_0_1_0_0_1_0_0_0_0 -> search1048_0 in the cache */

/* search1050_0_0_0_0_0_0_1_0_0_1_0_0_0_1 -> replace101_0_1 in the cache */
/* search1050_0_0_0_0_0_0_1_0_0_1_0_0_0 -> search1050_0_0_0_0_0_0_0_0_0_0_0_0_0 in the cache */

/* search1050_0_0_0_0_0_0_1_0_0_1_0_0_1_0 -> search1048_0 in the cache */

/* search1050_0_0_0_0_0_0_1_0_0_1_0_0_1_1 -> replace101_0_1 in the cache */
/* search1050_0_0_0_0_0_0_1_0_0_1_0_0_1 -> search1050_0_0_0_0_0_0_0_0_0_0_0_0_1 in the cache */
static const nir_search_expression search1050_0_0_0_0_0_0_1_0_0_1_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   16, 1,
   nir_op_ior,
   { &search1050_0_0_0_0_0_0_0_0_0_0_0_0_0.value, &search1050_0_0_0_0_0_0_0_0_0_0_0_0_1.value },
   NULL,
};

/* search1050_0_0_0_0_0_0_1_0_0_1_0_1 -> search1050_0_0_0_0_0_0_0_0_0_1_0_1 in the cache */
static const nir_search_expression search1050_0_0_0_0_0_0_1_0_0_1_0 = {
   { nir_search_value_expression, 32 },
   false,
   15, 2,
   nir_op_iand,
   { &search1050_0_0_0_0_0_0_1_0_0_1_0_0.value, &search1050_0_0_0_0_0_0_0_0_0_1_0_1.value },
   NULL,
};

/* search1050_0_0_0_0_0_0_1_0_0_1_1 -> replace98_0_1 in the cache */
static const nir_search_expression search1050_0_0_0_0_0_0_1_0_0_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 2,
   nir_op_ushr,
   { &search1050_0_0_0_0_0_0_1_0_0_1_0.value, &replace98_0_1.value },
   NULL,
};
static const nir_search_expression search1050_0_0_0_0_0_0_1_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   12, 5,
   nir_op_ior,
   { &search1050_0_0_0_0_0_0_1_0_0_0.value, &search1050_0_0_0_0_0_0_1_0_0_1.value },
   NULL,
};

static const nir_search_constant search1050_0_0_0_0_0_0_1_0_1 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { 0xf0f0f0f0 /* 4042322160 */ },
};
static const nir_search_expression search1050_0_0_0_0_0_0_1_0 = {
   { nir_search_value_expression, 32 },
   false,
   11, 6,
   nir_op_iand,
   { &search1050_0_0_0_0_0_0_1_0_0.value, &search1050_0_0_0_0_0_0_1_0_1.value },
   NULL,
};

/* search1050_0_0_0_0_0_0_1_1 -> search1050_0_0_0_0_0_0_0_1 in the cache */
static const nir_search_expression search1050_0_0_0_0_0_0_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 6,
   nir_op_ushr,
   { &search1050_0_0_0_0_0_0_1_0.value, &search1050_0_0_0_0_0_0_0_1.value },
   NULL,
};
static const nir_search_expression search1050_0_0_0_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   4, 13,
   nir_op_ior,
   { &search1050_0_0_0_0_0_0_0.value, &search1050_0_0_0_0_0_0_1.value },
   NULL,
};

static const nir_search_constant search1050_0_0_0_0_0_1 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { 0x33333333 /* 858993459 */ },
};
static const nir_search_expression search1050_0_0_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   3, 14,
   nir_op_iand,
   { &search1050_0_0_0_0_0_0.value, &search1050_0_0_0_0_0_1.value },
   NULL,
};

/* search1050_0_0_0_0_1 -> replace580_1 in the cache */
static const nir_search_expression search1050_0_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 14,
   nir_op_ishl,
   { &search1050_0_0_0_0_0.value, &replace580_1.value },
   NULL,
};

/* search1050_0_0_0_1_0_0_0_0_0_0_0_0_0_0 -> search1048_0 in the cache */

/* search1050_0_0_0_1_0_0_0_0_0_0_0_0_0_1 -> replace101_0_1 in the cache */
/* search1050_0_0_0_1_0_0_0_0_0_0_0_0_0 -> search1050_0_0_0_0_0_0_0_0_0_0_0_0_0 in the cache */

/* search1050_0_0_0_1_0_0_0_0_0_0_0_0_1_0 -> search1048_0 in the cache */

/* search1050_0_0_0_1_0_0_0_0_0_0_0_0_1_1 -> replace101_0_1 in the cache */
/* search1050_0_0_0_1_0_0_0_0_0_0_0_0_1 -> search1050_0_0_0_0_0_0_0_0_0_0_0_0_1 in the cache */
static const nir_search_expression search1050_0_0_0_1_0_0_0_0_0_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   22, 1,
   nir_op_ior,
   { &search1050_0_0_0_0_0_0_0_0_0_0_0_0_0.value, &search1050_0_0_0_0_0_0_0_0_0_0_0_0_1.value },
   NULL,
};

/* search1050_0_0_0_1_0_0_0_0_0_0_0_1 -> search1050_0_0_0_0_0_0_0_0_0_0_0_1 in the cache */
static const nir_search_expression search1050_0_0_0_1_0_0_0_0_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   21, 2,
   nir_op_iand,
   { &search1050_0_0_0_1_0_0_0_0_0_0_0_0.value, &search1050_0_0_0_0_0_0_0_0_0_0_0_1.value },
   NULL,
};

/* search1050_0_0_0_1_0_0_0_0_0_0_1 -> replace98_0_1 in the cache */
static const nir_search_expression search1050_0_0_0_1_0_0_0_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 2,
   nir_op_ishl,
   { &search1050_0_0_0_1_0_0_0_0_0_0_0.value, &replace98_0_1.value },
   NULL,
};

/* search1050_0_0_0_1_0_0_0_0_0_1_0_0_0_0 -> search1048_0 in the cache */

/* search1050_0_0_0_1_0_0_0_0_0_1_0_0_0_1 -> replace101_0_1 in the cache */
/* search1050_0_0_0_1_0_0_0_0_0_1_0_0_0 -> search1050_0_0_0_0_0_0_0_0_0_0_0_0_0 in the cache */

/* search1050_0_0_0_1_0_0_0_0_0_1_0_0_1_0 -> search1048_0 in the cache */

/* search1050_0_0_0_1_0_0_0_0_0_1_0_0_1_1 -> replace101_0_1 in the cache */
/* search1050_0_0_0_1_0_0_0_0_0_1_0_0_1 -> search1050_0_0_0_0_0_0_0_0_0_0_0_0_1 in the cache */
static const nir_search_expression search1050_0_0_0_1_0_0_0_0_0_1_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   24, 1,
   nir_op_ior,
   { &search1050_0_0_0_0_0_0_0_0_0_0_0_0_0.value, &search1050_0_0_0_0_0_0_0_0_0_0_0_0_1.value },
   NULL,
};

/* search1050_0_0_0_1_0_0_0_0_0_1_0_1 -> search1050_0_0_0_0_0_0_0_0_0_1_0_1 in the cache */
static const nir_search_expression search1050_0_0_0_1_0_0_0_0_0_1_0 = {
   { nir_search_value_expression, 32 },
   false,
   23, 2,
   nir_op_iand,
   { &search1050_0_0_0_1_0_0_0_0_0_1_0_0.value, &search1050_0_0_0_0_0_0_0_0_0_1_0_1.value },
   NULL,
};

/* search1050_0_0_0_1_0_0_0_0_0_1_1 -> replace98_0_1 in the cache */
static const nir_search_expression search1050_0_0_0_1_0_0_0_0_0_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 2,
   nir_op_ushr,
   { &search1050_0_0_0_1_0_0_0_0_0_1_0.value, &replace98_0_1.value },
   NULL,
};
static const nir_search_expression search1050_0_0_0_1_0_0_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   20, 5,
   nir_op_ior,
   { &search1050_0_0_0_1_0_0_0_0_0_0.value, &search1050_0_0_0_1_0_0_0_0_0_1.value },
   NULL,
};

/* search1050_0_0_0_1_0_0_0_0_1 -> search1050_0_0_0_0_0_0_0_0_1 in the cache */
static const nir_search_expression search1050_0_0_0_1_0_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   19, 6,
   nir_op_iand,
   { &search1050_0_0_0_1_0_0_0_0_0.value, &search1050_0_0_0_0_0_0_0_0_1.value },
   NULL,
};

/* search1050_0_0_0_1_0_0_0_1 -> search1050_0_0_0_0_0_0_0_1 in the cache */
static const nir_search_expression search1050_0_0_0_1_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 6,
   nir_op_ishl,
   { &search1050_0_0_0_1_0_0_0_0.value, &search1050_0_0_0_0_0_0_0_1.value },
   NULL,
};

/* search1050_0_0_0_1_0_0_1_0_0_0_0_0_0_0 -> search1048_0 in the cache */

/* search1050_0_0_0_1_0_0_1_0_0_0_0_0_0_1 -> replace101_0_1 in the cache */
/* search1050_0_0_0_1_0_0_1_0_0_0_0_0_0 -> search1050_0_0_0_0_0_0_0_0_0_0_0_0_0 in the cache */

/* search1050_0_0_0_1_0_0_1_0_0_0_0_0_1_0 -> search1048_0 in the cache */

/* search1050_0_0_0_1_0_0_1_0_0_0_0_0_1_1 -> replace101_0_1 in the cache */
/* search1050_0_0_0_1_0_0_1_0_0_0_0_0_1 -> search1050_0_0_0_0_0_0_0_0_0_0_0_0_1 in the cache */
static const nir_search_expression search1050_0_0_0_1_0_0_1_0_0_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   28, 1,
   nir_op_ior,
   { &search1050_0_0_0_0_0_0_0_0_0_0_0_0_0.value, &search1050_0_0_0_0_0_0_0_0_0_0_0_0_1.value },
   NULL,
};

/* search1050_0_0_0_1_0_0_1_0_0_0_0_1 -> search1050_0_0_0_0_0_0_0_0_0_0_0_1 in the cache */
static const nir_search_expression search1050_0_0_0_1_0_0_1_0_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   27, 2,
   nir_op_iand,
   { &search1050_0_0_0_1_0_0_1_0_0_0_0_0.value, &search1050_0_0_0_0_0_0_0_0_0_0_0_1.value },
   NULL,
};

/* search1050_0_0_0_1_0_0_1_0_0_0_1 -> replace98_0_1 in the cache */
static const nir_search_expression search1050_0_0_0_1_0_0_1_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 2,
   nir_op_ishl,
   { &search1050_0_0_0_1_0_0_1_0_0_0_0.value, &replace98_0_1.value },
   NULL,
};

/* search1050_0_0_0_1_0_0_1_0_0_1_0_0_0_0 -> search1048_0 in the cache */

/* search1050_0_0_0_1_0_0_1_0_0_1_0_0_0_1 -> replace101_0_1 in the cache */
/* search1050_0_0_0_1_0_0_1_0_0_1_0_0_0 -> search1050_0_0_0_0_0_0_0_0_0_0_0_0_0 in the cache */

/* search1050_0_0_0_1_0_0_1_0_0_1_0_0_1_0 -> search1048_0 in the cache */

/* search1050_0_0_0_1_0_0_1_0_0_1_0_0_1_1 -> replace101_0_1 in the cache */
/* search1050_0_0_0_1_0_0_1_0_0_1_0_0_1 -> search1050_0_0_0_0_0_0_0_0_0_0_0_0_1 in the cache */
static const nir_search_expression search1050_0_0_0_1_0_0_1_0_0_1_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   30, 1,
   nir_op_ior,
   { &search1050_0_0_0_0_0_0_0_0_0_0_0_0_0.value, &search1050_0_0_0_0_0_0_0_0_0_0_0_0_1.value },
   NULL,
};

/* search1050_0_0_0_1_0_0_1_0_0_1_0_1 -> search1050_0_0_0_0_0_0_0_0_0_1_0_1 in the cache */
static const nir_search_expression search1050_0_0_0_1_0_0_1_0_0_1_0 = {
   { nir_search_value_expression, 32 },
   false,
   29, 2,
   nir_op_iand,
   { &search1050_0_0_0_1_0_0_1_0_0_1_0_0.value, &search1050_0_0_0_0_0_0_0_0_0_1_0_1.value },
   NULL,
};

/* search1050_0_0_0_1_0_0_1_0_0_1_1 -> replace98_0_1 in the cache */
static const nir_search_expression search1050_0_0_0_1_0_0_1_0_0_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 2,
   nir_op_ushr,
   { &search1050_0_0_0_1_0_0_1_0_0_1_0.value, &replace98_0_1.value },
   NULL,
};
static const nir_search_expression search1050_0_0_0_1_0_0_1_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   26, 5,
   nir_op_ior,
   { &search1050_0_0_0_1_0_0_1_0_0_0.value, &search1050_0_0_0_1_0_0_1_0_0_1.value },
   NULL,
};

/* search1050_0_0_0_1_0_0_1_0_1 -> search1050_0_0_0_0_0_0_1_0_1 in the cache */
static const nir_search_expression search1050_0_0_0_1_0_0_1_0 = {
   { nir_search_value_expression, 32 },
   false,
   25, 6,
   nir_op_iand,
   { &search1050_0_0_0_1_0_0_1_0_0.value, &search1050_0_0_0_0_0_0_1_0_1.value },
   NULL,
};

/* search1050_0_0_0_1_0_0_1_1 -> search1050_0_0_0_0_0_0_0_1 in the cache */
static const nir_search_expression search1050_0_0_0_1_0_0_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 6,
   nir_op_ushr,
   { &search1050_0_0_0_1_0_0_1_0.value, &search1050_0_0_0_0_0_0_0_1.value },
   NULL,
};
static const nir_search_expression search1050_0_0_0_1_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   18, 13,
   nir_op_ior,
   { &search1050_0_0_0_1_0_0_0.value, &search1050_0_0_0_1_0_0_1.value },
   NULL,
};

static const nir_search_constant search1050_0_0_0_1_0_1 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { 0xcccccccc /* 3435973836 */ },
};
static const nir_search_expression search1050_0_0_0_1_0 = {
   { nir_search_value_expression, 32 },
   false,
   17, 14,
   nir_op_iand,
   { &search1050_0_0_0_1_0_0.value, &search1050_0_0_0_1_0_1.value },
   NULL,
};

/* search1050_0_0_0_1_1 -> replace580_1 in the cache */
static const nir_search_expression search1050_0_0_0_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 14,
   nir_op_ushr,
   { &search1050_0_0_0_1_0.value, &replace580_1.value },
   NULL,
};
static const nir_search_expression search1050_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   2, 29,
   nir_op_ior,
   { &search1050_0_0_0_0.value, &search1050_0_0_0_1.value },
   NULL,
};

static const nir_search_constant search1050_0_0_1 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { 0x55555555 /* 1431655765 */ },
};
static const nir_search_expression search1050_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   1, 30,
   nir_op_iand,
   { &search1050_0_0_0.value, &search1050_0_0_1.value },
   NULL,
};

/* search1050_0_1 -> replace579_1 in the cache */
static const nir_search_expression search1050_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 30,
   nir_op_ishl,
   { &search1050_0_0.value, &replace579_1.value },
   NULL,
};

/* search1050_1_0_0_0_0_0_0_0_0_0_0_0_0_0 -> search1048_0 in the cache */

/* search1050_1_0_0_0_0_0_0_0_0_0_0_0_0_1 -> replace101_0_1 in the cache */
/* search1050_1_0_0_0_0_0_0_0_0_0_0_0_0 -> search1050_0_0_0_0_0_0_0_0_0_0_0_0_0 in the cache */

/* search1050_1_0_0_0_0_0_0_0_0_0_0_0_1_0 -> search1048_0 in the cache */

/* search1050_1_0_0_0_0_0_0_0_0_0_0_0_1_1 -> replace101_0_1 in the cache */
/* search1050_1_0_0_0_0_0_0_0_0_0_0_0_1 -> search1050_0_0_0_0_0_0_0_0_0_0_0_0_1 in the cache */
static const nir_search_expression search1050_1_0_0_0_0_0_0_0_0_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   38, 1,
   nir_op_ior,
   { &search1050_0_0_0_0_0_0_0_0_0_0_0_0_0.value, &search1050_0_0_0_0_0_0_0_0_0_0_0_0_1.value },
   NULL,
};

/* search1050_1_0_0_0_0_0_0_0_0_0_0_1 -> search1050_0_0_0_0_0_0_0_0_0_0_0_1 in the cache */
static const nir_search_expression search1050_1_0_0_0_0_0_0_0_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   37, 2,
   nir_op_iand,
   { &search1050_1_0_0_0_0_0_0_0_0_0_0_0.value, &search1050_0_0_0_0_0_0_0_0_0_0_0_1.value },
   NULL,
};

/* search1050_1_0_0_0_0_0_0_0_0_0_1 -> replace98_0_1 in the cache */
static const nir_search_expression search1050_1_0_0_0_0_0_0_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 2,
   nir_op_ishl,
   { &search1050_1_0_0_0_0_0_0_0_0_0_0.value, &replace98_0_1.value },
   NULL,
};

/* search1050_1_0_0_0_0_0_0_0_0_1_0_0_0_0 -> search1048_0 in the cache */

/* search1050_1_0_0_0_0_0_0_0_0_1_0_0_0_1 -> replace101_0_1 in the cache */
/* search1050_1_0_0_0_0_0_0_0_0_1_0_0_0 -> search1050_0_0_0_0_0_0_0_0_0_0_0_0_0 in the cache */

/* search1050_1_0_0_0_0_0_0_0_0_1_0_0_1_0 -> search1048_0 in the cache */

/* search1050_1_0_0_0_0_0_0_0_0_1_0_0_1_1 -> replace101_0_1 in the cache */
/* search1050_1_0_0_0_0_0_0_0_0_1_0_0_1 -> search1050_0_0_0_0_0_0_0_0_0_0_0_0_1 in the cache */
static const nir_search_expression search1050_1_0_0_0_0_0_0_0_0_1_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   40, 1,
   nir_op_ior,
   { &search1050_0_0_0_0_0_0_0_0_0_0_0_0_0.value, &search1050_0_0_0_0_0_0_0_0_0_0_0_0_1.value },
   NULL,
};

/* search1050_1_0_0_0_0_0_0_0_0_1_0_1 -> search1050_0_0_0_0_0_0_0_0_0_1_0_1 in the cache */
static const nir_search_expression search1050_1_0_0_0_0_0_0_0_0_1_0 = {
   { nir_search_value_expression, 32 },
   false,
   39, 2,
   nir_op_iand,
   { &search1050_1_0_0_0_0_0_0_0_0_1_0_0.value, &search1050_0_0_0_0_0_0_0_0_0_1_0_1.value },
   NULL,
};

/* search1050_1_0_0_0_0_0_0_0_0_1_1 -> replace98_0_1 in the cache */
static const nir_search_expression search1050_1_0_0_0_0_0_0_0_0_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 2,
   nir_op_ushr,
   { &search1050_1_0_0_0_0_0_0_0_0_1_0.value, &replace98_0_1.value },
   NULL,
};
static const nir_search_expression search1050_1_0_0_0_0_0_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   36, 5,
   nir_op_ior,
   { &search1050_1_0_0_0_0_0_0_0_0_0.value, &search1050_1_0_0_0_0_0_0_0_0_1.value },
   NULL,
};

/* search1050_1_0_0_0_0_0_0_0_1 -> search1050_0_0_0_0_0_0_0_0_1 in the cache */
static const nir_search_expression search1050_1_0_0_0_0_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   35, 6,
   nir_op_iand,
   { &search1050_1_0_0_0_0_0_0_0_0.value, &search1050_0_0_0_0_0_0_0_0_1.value },
   NULL,
};

/* search1050_1_0_0_0_0_0_0_1 -> search1050_0_0_0_0_0_0_0_1 in the cache */
static const nir_search_expression search1050_1_0_0_0_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 6,
   nir_op_ishl,
   { &search1050_1_0_0_0_0_0_0_0.value, &search1050_0_0_0_0_0_0_0_1.value },
   NULL,
};

/* search1050_1_0_0_0_0_0_1_0_0_0_0_0_0_0 -> search1048_0 in the cache */

/* search1050_1_0_0_0_0_0_1_0_0_0_0_0_0_1 -> replace101_0_1 in the cache */
/* search1050_1_0_0_0_0_0_1_0_0_0_0_0_0 -> search1050_0_0_0_0_0_0_0_0_0_0_0_0_0 in the cache */

/* search1050_1_0_0_0_0_0_1_0_0_0_0_0_1_0 -> search1048_0 in the cache */

/* search1050_1_0_0_0_0_0_1_0_0_0_0_0_1_1 -> replace101_0_1 in the cache */
/* search1050_1_0_0_0_0_0_1_0_0_0_0_0_1 -> search1050_0_0_0_0_0_0_0_0_0_0_0_0_1 in the cache */
static const nir_search_expression search1050_1_0_0_0_0_0_1_0_0_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   44, 1,
   nir_op_ior,
   { &search1050_0_0_0_0_0_0_0_0_0_0_0_0_0.value, &search1050_0_0_0_0_0_0_0_0_0_0_0_0_1.value },
   NULL,
};

/* search1050_1_0_0_0_0_0_1_0_0_0_0_1 -> search1050_0_0_0_0_0_0_0_0_0_0_0_1 in the cache */
static const nir_search_expression search1050_1_0_0_0_0_0_1_0_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   43, 2,
   nir_op_iand,
   { &search1050_1_0_0_0_0_0_1_0_0_0_0_0.value, &search1050_0_0_0_0_0_0_0_0_0_0_0_1.value },
   NULL,
};

/* search1050_1_0_0_0_0_0_1_0_0_0_1 -> replace98_0_1 in the cache */
static const nir_search_expression search1050_1_0_0_0_0_0_1_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 2,
   nir_op_ishl,
   { &search1050_1_0_0_0_0_0_1_0_0_0_0.value, &replace98_0_1.value },
   NULL,
};

/* search1050_1_0_0_0_0_0_1_0_0_1_0_0_0_0 -> search1048_0 in the cache */

/* search1050_1_0_0_0_0_0_1_0_0_1_0_0_0_1 -> replace101_0_1 in the cache */
/* search1050_1_0_0_0_0_0_1_0_0_1_0_0_0 -> search1050_0_0_0_0_0_0_0_0_0_0_0_0_0 in the cache */

/* search1050_1_0_0_0_0_0_1_0_0_1_0_0_1_0 -> search1048_0 in the cache */

/* search1050_1_0_0_0_0_0_1_0_0_1_0_0_1_1 -> replace101_0_1 in the cache */
/* search1050_1_0_0_0_0_0_1_0_0_1_0_0_1 -> search1050_0_0_0_0_0_0_0_0_0_0_0_0_1 in the cache */
static const nir_search_expression search1050_1_0_0_0_0_0_1_0_0_1_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   46, 1,
   nir_op_ior,
   { &search1050_0_0_0_0_0_0_0_0_0_0_0_0_0.value, &search1050_0_0_0_0_0_0_0_0_0_0_0_0_1.value },
   NULL,
};

/* search1050_1_0_0_0_0_0_1_0_0_1_0_1 -> search1050_0_0_0_0_0_0_0_0_0_1_0_1 in the cache */
static const nir_search_expression search1050_1_0_0_0_0_0_1_0_0_1_0 = {
   { nir_search_value_expression, 32 },
   false,
   45, 2,
   nir_op_iand,
   { &search1050_1_0_0_0_0_0_1_0_0_1_0_0.value, &search1050_0_0_0_0_0_0_0_0_0_1_0_1.value },
   NULL,
};

/* search1050_1_0_0_0_0_0_1_0_0_1_1 -> replace98_0_1 in the cache */
static const nir_search_expression search1050_1_0_0_0_0_0_1_0_0_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 2,
   nir_op_ushr,
   { &search1050_1_0_0_0_0_0_1_0_0_1_0.value, &replace98_0_1.value },
   NULL,
};
static const nir_search_expression search1050_1_0_0_0_0_0_1_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   42, 5,
   nir_op_ior,
   { &search1050_1_0_0_0_0_0_1_0_0_0.value, &search1050_1_0_0_0_0_0_1_0_0_1.value },
   NULL,
};

/* search1050_1_0_0_0_0_0_1_0_1 -> search1050_0_0_0_0_0_0_1_0_1 in the cache */
static const nir_search_expression search1050_1_0_0_0_0_0_1_0 = {
   { nir_search_value_expression, 32 },
   false,
   41, 6,
   nir_op_iand,
   { &search1050_1_0_0_0_0_0_1_0_0.value, &search1050_0_0_0_0_0_0_1_0_1.value },
   NULL,
};

/* search1050_1_0_0_0_0_0_1_1 -> search1050_0_0_0_0_0_0_0_1 in the cache */
static const nir_search_expression search1050_1_0_0_0_0_0_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 6,
   nir_op_ushr,
   { &search1050_1_0_0_0_0_0_1_0.value, &search1050_0_0_0_0_0_0_0_1.value },
   NULL,
};
static const nir_search_expression search1050_1_0_0_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   34, 13,
   nir_op_ior,
   { &search1050_1_0_0_0_0_0_0.value, &search1050_1_0_0_0_0_0_1.value },
   NULL,
};

/* search1050_1_0_0_0_0_1 -> search1050_0_0_0_0_0_1 in the cache */
static const nir_search_expression search1050_1_0_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   33, 14,
   nir_op_iand,
   { &search1050_1_0_0_0_0_0.value, &search1050_0_0_0_0_0_1.value },
   NULL,
};

/* search1050_1_0_0_0_1 -> replace580_1 in the cache */
static const nir_search_expression search1050_1_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 14,
   nir_op_ishl,
   { &search1050_1_0_0_0_0.value, &replace580_1.value },
   NULL,
};

/* search1050_1_0_0_1_0_0_0_0_0_0_0_0_0_0 -> search1048_0 in the cache */

/* search1050_1_0_0_1_0_0_0_0_0_0_0_0_0_1 -> replace101_0_1 in the cache */
/* search1050_1_0_0_1_0_0_0_0_0_0_0_0_0 -> search1050_0_0_0_0_0_0_0_0_0_0_0_0_0 in the cache */

/* search1050_1_0_0_1_0_0_0_0_0_0_0_0_1_0 -> search1048_0 in the cache */

/* search1050_1_0_0_1_0_0_0_0_0_0_0_0_1_1 -> replace101_0_1 in the cache */
/* search1050_1_0_0_1_0_0_0_0_0_0_0_0_1 -> search1050_0_0_0_0_0_0_0_0_0_0_0_0_1 in the cache */
static const nir_search_expression search1050_1_0_0_1_0_0_0_0_0_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   52, 1,
   nir_op_ior,
   { &search1050_0_0_0_0_0_0_0_0_0_0_0_0_0.value, &search1050_0_0_0_0_0_0_0_0_0_0_0_0_1.value },
   NULL,
};

/* search1050_1_0_0_1_0_0_0_0_0_0_0_1 -> search1050_0_0_0_0_0_0_0_0_0_0_0_1 in the cache */
static const nir_search_expression search1050_1_0_0_1_0_0_0_0_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   51, 2,
   nir_op_iand,
   { &search1050_1_0_0_1_0_0_0_0_0_0_0_0.value, &search1050_0_0_0_0_0_0_0_0_0_0_0_1.value },
   NULL,
};

/* search1050_1_0_0_1_0_0_0_0_0_0_1 -> replace98_0_1 in the cache */
static const nir_search_expression search1050_1_0_0_1_0_0_0_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 2,
   nir_op_ishl,
   { &search1050_1_0_0_1_0_0_0_0_0_0_0.value, &replace98_0_1.value },
   NULL,
};

/* search1050_1_0_0_1_0_0_0_0_0_1_0_0_0_0 -> search1048_0 in the cache */

/* search1050_1_0_0_1_0_0_0_0_0_1_0_0_0_1 -> replace101_0_1 in the cache */
/* search1050_1_0_0_1_0_0_0_0_0_1_0_0_0 -> search1050_0_0_0_0_0_0_0_0_0_0_0_0_0 in the cache */

/* search1050_1_0_0_1_0_0_0_0_0_1_0_0_1_0 -> search1048_0 in the cache */

/* search1050_1_0_0_1_0_0_0_0_0_1_0_0_1_1 -> replace101_0_1 in the cache */
/* search1050_1_0_0_1_0_0_0_0_0_1_0_0_1 -> search1050_0_0_0_0_0_0_0_0_0_0_0_0_1 in the cache */
static const nir_search_expression search1050_1_0_0_1_0_0_0_0_0_1_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   54, 1,
   nir_op_ior,
   { &search1050_0_0_0_0_0_0_0_0_0_0_0_0_0.value, &search1050_0_0_0_0_0_0_0_0_0_0_0_0_1.value },
   NULL,
};

/* search1050_1_0_0_1_0_0_0_0_0_1_0_1 -> search1050_0_0_0_0_0_0_0_0_0_1_0_1 in the cache */
static const nir_search_expression search1050_1_0_0_1_0_0_0_0_0_1_0 = {
   { nir_search_value_expression, 32 },
   false,
   53, 2,
   nir_op_iand,
   { &search1050_1_0_0_1_0_0_0_0_0_1_0_0.value, &search1050_0_0_0_0_0_0_0_0_0_1_0_1.value },
   NULL,
};

/* search1050_1_0_0_1_0_0_0_0_0_1_1 -> replace98_0_1 in the cache */
static const nir_search_expression search1050_1_0_0_1_0_0_0_0_0_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 2,
   nir_op_ushr,
   { &search1050_1_0_0_1_0_0_0_0_0_1_0.value, &replace98_0_1.value },
   NULL,
};
static const nir_search_expression search1050_1_0_0_1_0_0_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   50, 5,
   nir_op_ior,
   { &search1050_1_0_0_1_0_0_0_0_0_0.value, &search1050_1_0_0_1_0_0_0_0_0_1.value },
   NULL,
};

/* search1050_1_0_0_1_0_0_0_0_1 -> search1050_0_0_0_0_0_0_0_0_1 in the cache */
static const nir_search_expression search1050_1_0_0_1_0_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   49, 6,
   nir_op_iand,
   { &search1050_1_0_0_1_0_0_0_0_0.value, &search1050_0_0_0_0_0_0_0_0_1.value },
   NULL,
};

/* search1050_1_0_0_1_0_0_0_1 -> search1050_0_0_0_0_0_0_0_1 in the cache */
static const nir_search_expression search1050_1_0_0_1_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 6,
   nir_op_ishl,
   { &search1050_1_0_0_1_0_0_0_0.value, &search1050_0_0_0_0_0_0_0_1.value },
   NULL,
};

/* search1050_1_0_0_1_0_0_1_0_0_0_0_0_0_0 -> search1048_0 in the cache */

/* search1050_1_0_0_1_0_0_1_0_0_0_0_0_0_1 -> replace101_0_1 in the cache */
/* search1050_1_0_0_1_0_0_1_0_0_0_0_0_0 -> search1050_0_0_0_0_0_0_0_0_0_0_0_0_0 in the cache */

/* search1050_1_0_0_1_0_0_1_0_0_0_0_0_1_0 -> search1048_0 in the cache */

/* search1050_1_0_0_1_0_0_1_0_0_0_0_0_1_1 -> replace101_0_1 in the cache */
/* search1050_1_0_0_1_0_0_1_0_0_0_0_0_1 -> search1050_0_0_0_0_0_0_0_0_0_0_0_0_1 in the cache */
static const nir_search_expression search1050_1_0_0_1_0_0_1_0_0_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   58, 1,
   nir_op_ior,
   { &search1050_0_0_0_0_0_0_0_0_0_0_0_0_0.value, &search1050_0_0_0_0_0_0_0_0_0_0_0_0_1.value },
   NULL,
};

/* search1050_1_0_0_1_0_0_1_0_0_0_0_1 -> search1050_0_0_0_0_0_0_0_0_0_0_0_1 in the cache */
static const nir_search_expression search1050_1_0_0_1_0_0_1_0_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   57, 2,
   nir_op_iand,
   { &search1050_1_0_0_1_0_0_1_0_0_0_0_0.value, &search1050_0_0_0_0_0_0_0_0_0_0_0_1.value },
   NULL,
};

/* search1050_1_0_0_1_0_0_1_0_0_0_1 -> replace98_0_1 in the cache */
static const nir_search_expression search1050_1_0_0_1_0_0_1_0_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 2,
   nir_op_ishl,
   { &search1050_1_0_0_1_0_0_1_0_0_0_0.value, &replace98_0_1.value },
   NULL,
};

/* search1050_1_0_0_1_0_0_1_0_0_1_0_0_0_0 -> search1048_0 in the cache */

/* search1050_1_0_0_1_0_0_1_0_0_1_0_0_0_1 -> replace101_0_1 in the cache */
/* search1050_1_0_0_1_0_0_1_0_0_1_0_0_0 -> search1050_0_0_0_0_0_0_0_0_0_0_0_0_0 in the cache */

/* search1050_1_0_0_1_0_0_1_0_0_1_0_0_1_0 -> search1048_0 in the cache */

/* search1050_1_0_0_1_0_0_1_0_0_1_0_0_1_1 -> replace101_0_1 in the cache */
/* search1050_1_0_0_1_0_0_1_0_0_1_0_0_1 -> search1050_0_0_0_0_0_0_0_0_0_0_0_0_1 in the cache */
static const nir_search_expression search1050_1_0_0_1_0_0_1_0_0_1_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   60, 1,
   nir_op_ior,
   { &search1050_0_0_0_0_0_0_0_0_0_0_0_0_0.value, &search1050_0_0_0_0_0_0_0_0_0_0_0_0_1.value },
   NULL,
};

/* search1050_1_0_0_1_0_0_1_0_0_1_0_1 -> search1050_0_0_0_0_0_0_0_0_0_1_0_1 in the cache */
static const nir_search_expression search1050_1_0_0_1_0_0_1_0_0_1_0 = {
   { nir_search_value_expression, 32 },
   false,
   59, 2,
   nir_op_iand,
   { &search1050_1_0_0_1_0_0_1_0_0_1_0_0.value, &search1050_0_0_0_0_0_0_0_0_0_1_0_1.value },
   NULL,
};

/* search1050_1_0_0_1_0_0_1_0_0_1_1 -> replace98_0_1 in the cache */
static const nir_search_expression search1050_1_0_0_1_0_0_1_0_0_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 2,
   nir_op_ushr,
   { &search1050_1_0_0_1_0_0_1_0_0_1_0.value, &replace98_0_1.value },
   NULL,
};
static const nir_search_expression search1050_1_0_0_1_0_0_1_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   56, 5,
   nir_op_ior,
   { &search1050_1_0_0_1_0_0_1_0_0_0.value, &search1050_1_0_0_1_0_0_1_0_0_1.value },
   NULL,
};

/* search1050_1_0_0_1_0_0_1_0_1 -> search1050_0_0_0_0_0_0_1_0_1 in the cache */
static const nir_search_expression search1050_1_0_0_1_0_0_1_0 = {
   { nir_search_value_expression, 32 },
   false,
   55, 6,
   nir_op_iand,
   { &search1050_1_0_0_1_0_0_1_0_0.value, &search1050_0_0_0_0_0_0_1_0_1.value },
   NULL,
};

/* search1050_1_0_0_1_0_0_1_1 -> search1050_0_0_0_0_0_0_0_1 in the cache */
static const nir_search_expression search1050_1_0_0_1_0_0_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 6,
   nir_op_ushr,
   { &search1050_1_0_0_1_0_0_1_0.value, &search1050_0_0_0_0_0_0_0_1.value },
   NULL,
};
static const nir_search_expression search1050_1_0_0_1_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   48, 13,
   nir_op_ior,
   { &search1050_1_0_0_1_0_0_0.value, &search1050_1_0_0_1_0_0_1.value },
   NULL,
};

/* search1050_1_0_0_1_0_1 -> search1050_0_0_0_1_0_1 in the cache */
static const nir_search_expression search1050_1_0_0_1_0 = {
   { nir_search_value_expression, 32 },
   false,
   47, 14,
   nir_op_iand,
   { &search1050_1_0_0_1_0_0.value, &search1050_0_0_0_1_0_1.value },
   NULL,
};

/* search1050_1_0_0_1_1 -> replace580_1 in the cache */
static const nir_search_expression search1050_1_0_0_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 14,
   nir_op_ushr,
   { &search1050_1_0_0_1_0.value, &replace580_1.value },
   NULL,
};
static const nir_search_expression search1050_1_0_0 = {
   { nir_search_value_expression, 32 },
   false,
   32, 29,
   nir_op_ior,
   { &search1050_1_0_0_0.value, &search1050_1_0_0_1.value },
   NULL,
};

static const nir_search_constant search1050_1_0_1 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { 0xaaaaaaaa /* 2863311530 */ },
};
static const nir_search_expression search1050_1_0 = {
   { nir_search_value_expression, 32 },
   false,
   31, 30,
   nir_op_iand,
   { &search1050_1_0_0.value, &search1050_1_0_1.value },
   NULL,
};

/* search1050_1_1 -> replace579_1 in the cache */
static const nir_search_expression search1050_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 30,
   nir_op_ushr,
   { &search1050_1_0.value, &replace579_1.value },
   NULL,
};
static const nir_search_expression search1050 = {
   { nir_search_value_expression, 32 },
   false,
   0, 61,
   nir_op_ior,
   { &search1050_0.value, &search1050_1.value },
   NULL,
};

   /* replace1050_0 -> search1048_0 in the cache */
static const nir_search_expression replace1050 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_bitfield_reverse,
   { &search1048_0.value },
   NULL,
};

   /* search1051_0_0 -> search14_0 in the cache */

/* search1051_0_1 -> search14_0 in the cache */
static const nir_search_expression search1051_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_feq,
   { &search14_0.value, &search14_0.value },
   NULL,
};

/* search1051_1_0 -> search14_0 in the cache */

/* search1051_1_1 -> replace14_1_0 in the cache */
/* search1051_1 -> search111_0 in the cache */
static const nir_search_expression search1051 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_iand,
   { &search1051_0.value, &search111_0.value },
   NULL,
};

   /* replace1051_0 -> search14_0 in the cache */

/* replace1051_1 -> replace14_1_0 in the cache */
/* replace1051 -> search111_0 in the cache */

   /* search1052_0_0 -> search2_0 in the cache */

/* search1052_0_1 -> search2_0 in the cache */
static const nir_search_expression search1052_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_feq,
   { &search2_0.value, &search2_0.value },
   NULL,
};

/* search1052_1_0 -> search329_1_0 in the cache */

/* search1052_1_1 -> search2_0 in the cache */
static const nir_search_expression search1052_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search329_1_0.value, &search2_0.value },
   NULL,
};
static const nir_search_expression search1052 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_iand,
   { &search1052_0.value, &search1052_1.value },
   NULL,
};

   /* replace1052_0 -> search329_1_0 in the cache */

/* replace1052_1 -> search2_0 in the cache */
/* replace1052 -> search1052_1 in the cache */

   /* search1053_0_0 -> search14_0 in the cache */

/* search1053_0_1 -> search14_0 in the cache */
/* search1053_0 -> search1051_0 in the cache */

/* search1053_1_0 -> search14_0 in the cache */

/* search1053_1_1 -> replace14_1_0 in the cache */
/* search1053_1 -> replace111 in the cache */
static const nir_search_expression search1053 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_iand,
   { &search1051_0.value, &replace111.value },
   NULL,
};

   /* replace1053_0 -> search14_0 in the cache */

/* replace1053_1 -> replace14_1_0 in the cache */
/* replace1053 -> replace111 in the cache */

   /* search1054_0_0 -> search2_0 in the cache */

/* search1054_0_1 -> search2_0 in the cache */
/* search1054_0 -> search1052_0 in the cache */

/* search1054_1_0 -> search329_1_0 in the cache */

/* search1054_1_1 -> search2_0 in the cache */
static const nir_search_expression search1054_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search329_1_0.value, &search2_0.value },
   NULL,
};
static const nir_search_expression search1054 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_iand,
   { &search1052_0.value, &search1054_1.value },
   NULL,
};

   /* replace1054_0 -> search329_1_0 in the cache */

/* replace1054_1 -> search2_0 in the cache */
/* replace1054 -> search1054_1 in the cache */

   /* search1055_0_0 -> search14_0 in the cache */

/* search1055_0_1 -> search14_0 in the cache */
/* search1055_0 -> search1051_0 in the cache */

/* search1055_1_0 -> search14_0 in the cache */

/* search1055_1_1 -> replace14_1_0 in the cache */
/* search1055_1 -> search121_0 in the cache */
static const nir_search_expression search1055 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &search1051_0.value, &search121_0.value },
   NULL,
};

   /* replace1055_0 -> search14_0 in the cache */

/* replace1055_1 -> replace14_1_0 in the cache */
/* replace1055 -> search113_0 in the cache */

   /* search1056_0_0 -> search2_0 in the cache */

/* search1056_0_1 -> search2_0 in the cache */
/* search1056_0 -> search1052_0 in the cache */

/* search1056_1_0 -> search329_1_0 in the cache */

/* search1056_1_1 -> search2_0 in the cache */
static const nir_search_expression search1056_1 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_feq,
   { &search329_1_0.value, &search2_0.value },
   NULL,
};
static const nir_search_expression search1056 = {
   { nir_search_value_expression, 1 },
   false,
   0, 2,
   nir_op_iand,
   { &search1052_0.value, &search1056_1.value },
   NULL,
};

   /* replace1056_0 -> search329_1_0 in the cache */

/* replace1056_1 -> search2_0 in the cache */
static const nir_search_expression replace1056 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_feq,
   { &search329_1_0.value, &search2_0.value },
   NULL,
};

   /* search1057_0_0 -> replace80_0 in the cache */

static const nir_search_variable search1057_0_1 = {
   { nir_search_value_variable, -4 },
   1, /* b */
   true,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

static const nir_search_variable search1057_0_2 = {
   { nir_search_value_variable, -4 },
   2, /* c */
   true,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search1057_0 = {
   { nir_search_value_expression, -4 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace80_0.value, &search1057_0_1.value, &search1057_0_2.value },
   NULL,
};

static const nir_search_variable search1057_1 = {
   { nir_search_value_variable, -4 },
   3, /* d */
   true,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search1057 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search1057_0.value, &search1057_1.value },
   NULL,
};

   /* replace1057_0 -> replace80_0 in the cache */

/* replace1057_1_0 -> search62_0_1 in the cache */

/* replace1057_1_1 -> search62_2 in the cache */
static const nir_search_expression replace1057_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search62_0_1.value, &search62_2.value },
   NULL,
};

/* replace1057_2_0 -> search62_1_1 in the cache */

/* replace1057_2_1 -> search62_2 in the cache */
/* replace1057_2 -> replace711_1 in the cache */
static const nir_search_expression replace1057 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace80_0.value, &replace1057_1.value, &replace711_1.value },
   NULL,
};

   static const nir_search_variable search1058_0 = {
   { nir_search_value_variable, -4 },
   0, /* d */
   true,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

/* search1058_1_0 -> search174_0_1_0_0_0 in the cache */

static const nir_search_variable search1058_1_1 = {
   { nir_search_value_variable, -4 },
   2, /* b */
   true,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

static const nir_search_variable search1058_1_2 = {
   { nir_search_value_variable, -4 },
   3, /* c */
   true,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search1058_1 = {
   { nir_search_value_expression, -4 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &search174_0_1_0_0_0.value, &search1058_1_1.value, &search1058_1_2.value },
   NULL,
};
static const nir_search_expression search1058 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search1058_0.value, &search1058_1.value },
   NULL,
};

   /* replace1058_0 -> search174_0_1_0_0_0 in the cache */

static const nir_search_variable replace1058_1_0 = {
   { nir_search_value_variable, -4 },
   0, /* d */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

static const nir_search_variable replace1058_1_1 = {
   { nir_search_value_variable, -4 },
   2, /* b */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression replace1058_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &replace1058_1_0.value, &replace1058_1_1.value },
   NULL,
};

/* replace1058_2_0 -> replace1058_1_0 in the cache */

static const nir_search_variable replace1058_2_1 = {
   { nir_search_value_variable, -4 },
   3, /* c */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression replace1058_2 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &replace1058_1_0.value, &replace1058_2_1.value },
   NULL,
};
static const nir_search_expression replace1058 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &search174_0_1_0_0_0.value, &replace1058_1.value, &replace1058_2.value },
   NULL,
};

   /* search1059_0_0 -> replace80_0 in the cache */

/* search1059_0_1 -> search1057_0_1 in the cache */

/* search1059_0_2 -> search1057_0_2 in the cache */
/* search1059_0 -> search1057_0 in the cache */

/* search1059_1 -> search1057_1 in the cache */
static const nir_search_expression search1059 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search1057_0.value, &search1057_1.value },
   NULL,
};

   /* replace1059_0 -> replace80_0 in the cache */

/* replace1059_1_0 -> search62_0_1 in the cache */

/* replace1059_1_1 -> search62_2 in the cache */
static const nir_search_expression replace1059_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search62_0_1.value, &search62_2.value },
   NULL,
};

/* replace1059_2_0 -> search62_1_1 in the cache */

/* replace1059_2_1 -> search62_2 in the cache */
/* replace1059_2 -> search711_0_1 in the cache */
static const nir_search_expression replace1059 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace80_0.value, &replace1059_1.value, &search711_0_1.value },
   NULL,
};

   /* search1060_0 -> search1058_0 in the cache */

/* search1060_1_0 -> search174_0_1_0_0_0 in the cache */

/* search1060_1_1 -> search1058_1_1 in the cache */

/* search1060_1_2 -> search1058_1_2 in the cache */
/* search1060_1 -> search1058_1 in the cache */
static const nir_search_expression search1060 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search1058_0.value, &search1058_1.value },
   NULL,
};

   /* replace1060_0 -> search174_0_1_0_0_0 in the cache */

/* replace1060_1_0 -> replace1058_1_0 in the cache */

/* replace1060_1_1 -> replace1058_1_1 in the cache */
static const nir_search_expression replace1060_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &replace1058_1_0.value, &replace1058_1_1.value },
   NULL,
};

/* replace1060_2_0 -> replace1058_1_0 in the cache */

/* replace1060_2_1 -> replace1058_2_1 in the cache */
static const nir_search_expression replace1060_2 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &replace1058_1_0.value, &replace1058_2_1.value },
   NULL,
};
static const nir_search_expression replace1060 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &search174_0_1_0_0_0.value, &replace1060_1.value, &replace1060_2.value },
   NULL,
};

   /* search1061_0_0 -> replace80_0 in the cache */

/* search1061_0_1 -> search1057_0_1 in the cache */

/* search1061_0_2 -> search1057_0_2 in the cache */
/* search1061_0 -> search1057_0 in the cache */

/* search1061_1 -> search1057_1 in the cache */
static const nir_search_expression search1061 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_feq,
   { &search1057_0.value, &search1057_1.value },
   NULL,
};

   /* replace1061_0 -> replace80_0 in the cache */

/* replace1061_1_0 -> search62_0_1 in the cache */

/* replace1061_1_1 -> search62_2 in the cache */
static const nir_search_expression replace1061_1 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_feq,
   { &search62_0_1.value, &search62_2.value },
   NULL,
};

/* replace1061_2_0 -> search62_1_1 in the cache */

/* replace1061_2_1 -> search62_2 in the cache */
static const nir_search_expression replace1061_2 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_feq,
   { &search62_1_1.value, &search62_2.value },
   NULL,
};
static const nir_search_expression replace1061 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 2,
   nir_op_bcsel,
   { &replace80_0.value, &replace1061_1.value, &replace1061_2.value },
   NULL,
};

   /* search1062_0 -> search1058_0 in the cache */

/* search1062_1_0 -> search174_0_1_0_0_0 in the cache */

/* search1062_1_1 -> search1058_1_1 in the cache */

/* search1062_1_2 -> search1058_1_2 in the cache */
/* search1062_1 -> search1058_1 in the cache */
static const nir_search_expression search1062 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_feq,
   { &search1058_0.value, &search1058_1.value },
   NULL,
};

   /* replace1062_0 -> search174_0_1_0_0_0 in the cache */

/* replace1062_1_0 -> replace1058_1_0 in the cache */

/* replace1062_1_1 -> replace1058_1_1 in the cache */
static const nir_search_expression replace1062_1 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_feq,
   { &replace1058_1_0.value, &replace1058_1_1.value },
   NULL,
};

/* replace1062_2_0 -> replace1058_1_0 in the cache */

/* replace1062_2_1 -> replace1058_2_1 in the cache */
static const nir_search_expression replace1062_2 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_feq,
   { &replace1058_1_0.value, &replace1058_2_1.value },
   NULL,
};
static const nir_search_expression replace1062 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 2,
   nir_op_bcsel,
   { &search174_0_1_0_0_0.value, &replace1062_1.value, &replace1062_2.value },
   NULL,
};

   /* search1063_0_0 -> replace80_0 in the cache */

/* search1063_0_1 -> search1057_0_1 in the cache */

/* search1063_0_2 -> search1057_0_2 in the cache */
/* search1063_0 -> search1057_0 in the cache */

/* search1063_1 -> search1057_1 in the cache */
static const nir_search_expression search1063 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_fne,
   { &search1057_0.value, &search1057_1.value },
   NULL,
};

   /* replace1063_0 -> replace80_0 in the cache */

/* replace1063_1_0 -> search62_0_1 in the cache */

/* replace1063_1_1 -> search62_2 in the cache */
static const nir_search_expression replace1063_1 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_fne,
   { &search62_0_1.value, &search62_2.value },
   NULL,
};

/* replace1063_2_0 -> search62_1_1 in the cache */

/* replace1063_2_1 -> search62_2 in the cache */
static const nir_search_expression replace1063_2 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_fne,
   { &search62_1_1.value, &search62_2.value },
   NULL,
};
static const nir_search_expression replace1063 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 2,
   nir_op_bcsel,
   { &replace80_0.value, &replace1063_1.value, &replace1063_2.value },
   NULL,
};

   /* search1064_0 -> search1058_0 in the cache */

/* search1064_1_0 -> search174_0_1_0_0_0 in the cache */

/* search1064_1_1 -> search1058_1_1 in the cache */

/* search1064_1_2 -> search1058_1_2 in the cache */
/* search1064_1 -> search1058_1 in the cache */
static const nir_search_expression search1064 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_fne,
   { &search1058_0.value, &search1058_1.value },
   NULL,
};

   /* replace1064_0 -> search174_0_1_0_0_0 in the cache */

/* replace1064_1_0 -> replace1058_1_0 in the cache */

/* replace1064_1_1 -> replace1058_1_1 in the cache */
static const nir_search_expression replace1064_1 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_fne,
   { &replace1058_1_0.value, &replace1058_1_1.value },
   NULL,
};

/* replace1064_2_0 -> replace1058_1_0 in the cache */

/* replace1064_2_1 -> replace1058_2_1 in the cache */
static const nir_search_expression replace1064_2 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_fne,
   { &replace1058_1_0.value, &replace1058_2_1.value },
   NULL,
};
static const nir_search_expression replace1064 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 2,
   nir_op_bcsel,
   { &search174_0_1_0_0_0.value, &replace1064_1.value, &replace1064_2.value },
   NULL,
};

   /* search1065_0_0 -> replace80_0 in the cache */

/* search1065_0_1 -> search1057_0_1 in the cache */

/* search1065_0_2 -> search1057_0_2 in the cache */
/* search1065_0 -> search1057_0 in the cache */

/* search1065_1 -> search1057_1 in the cache */
static const nir_search_expression search1065 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search1057_0.value, &search1057_1.value },
   NULL,
};

   /* replace1065_0 -> replace80_0 in the cache */

/* replace1065_1_0 -> search62_0_1 in the cache */

/* replace1065_1_1 -> search62_2 in the cache */
static const nir_search_expression replace1065_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search62_0_1.value, &search62_2.value },
   NULL,
};

/* replace1065_2_0 -> search62_1_1 in the cache */

/* replace1065_2_1 -> search62_2 in the cache */
static const nir_search_expression replace1065_2 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search62_1_1.value, &search62_2.value },
   NULL,
};
static const nir_search_expression replace1065 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace80_0.value, &replace1065_1.value, &replace1065_2.value },
   NULL,
};

   /* search1066_0 -> search1058_0 in the cache */

/* search1066_1_0 -> search174_0_1_0_0_0 in the cache */

/* search1066_1_1 -> search1058_1_1 in the cache */

/* search1066_1_2 -> search1058_1_2 in the cache */
/* search1066_1 -> search1058_1 in the cache */
static const nir_search_expression search1066 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &search1058_0.value, &search1058_1.value },
   NULL,
};

   /* replace1066_0 -> search174_0_1_0_0_0 in the cache */

/* replace1066_1_0 -> replace1058_1_0 in the cache */

/* replace1066_1_1 -> replace1058_1_1 in the cache */
static const nir_search_expression replace1066_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &replace1058_1_0.value, &replace1058_1_1.value },
   NULL,
};

/* replace1066_2_0 -> replace1058_1_0 in the cache */

/* replace1066_2_1 -> replace1058_2_1 in the cache */
static const nir_search_expression replace1066_2 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ilt,
   { &replace1058_1_0.value, &replace1058_2_1.value },
   NULL,
};
static const nir_search_expression replace1066 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &search174_0_1_0_0_0.value, &replace1066_1.value, &replace1066_2.value },
   NULL,
};

   /* search1067_0_0 -> replace80_0 in the cache */

/* search1067_0_1 -> search1057_0_1 in the cache */

/* search1067_0_2 -> search1057_0_2 in the cache */
/* search1067_0 -> search1057_0 in the cache */

/* search1067_1 -> search1057_1 in the cache */
static const nir_search_expression search1067 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search1057_0.value, &search1057_1.value },
   NULL,
};

   /* replace1067_0 -> replace80_0 in the cache */

/* replace1067_1_0 -> search62_0_1 in the cache */

/* replace1067_1_1 -> search62_2 in the cache */
static const nir_search_expression replace1067_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search62_0_1.value, &search62_2.value },
   NULL,
};

/* replace1067_2_0 -> search62_1_1 in the cache */

/* replace1067_2_1 -> search62_2 in the cache */
static const nir_search_expression replace1067_2 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search62_1_1.value, &search62_2.value },
   NULL,
};
static const nir_search_expression replace1067 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace80_0.value, &replace1067_1.value, &replace1067_2.value },
   NULL,
};

   /* search1068_0 -> search1058_0 in the cache */

/* search1068_1_0 -> search174_0_1_0_0_0 in the cache */

/* search1068_1_1 -> search1058_1_1 in the cache */

/* search1068_1_2 -> search1058_1_2 in the cache */
/* search1068_1 -> search1058_1 in the cache */
static const nir_search_expression search1068 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &search1058_0.value, &search1058_1.value },
   NULL,
};

   /* replace1068_0 -> search174_0_1_0_0_0 in the cache */

/* replace1068_1_0 -> replace1058_1_0 in the cache */

/* replace1068_1_1 -> replace1058_1_1 in the cache */
static const nir_search_expression replace1068_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &replace1058_1_0.value, &replace1058_1_1.value },
   NULL,
};

/* replace1068_2_0 -> replace1058_1_0 in the cache */

/* replace1068_2_1 -> replace1058_2_1 in the cache */
static const nir_search_expression replace1068_2 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ige,
   { &replace1058_1_0.value, &replace1058_2_1.value },
   NULL,
};
static const nir_search_expression replace1068 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &search174_0_1_0_0_0.value, &replace1068_1.value, &replace1068_2.value },
   NULL,
};

   /* search1069_0_0 -> replace80_0 in the cache */

/* search1069_0_1 -> search1057_0_1 in the cache */

/* search1069_0_2 -> search1057_0_2 in the cache */
/* search1069_0 -> search1057_0 in the cache */

/* search1069_1 -> search1057_1 in the cache */
static const nir_search_expression search1069 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &search1057_0.value, &search1057_1.value },
   NULL,
};

   /* replace1069_0 -> replace80_0 in the cache */

/* replace1069_1_0 -> search62_0_1 in the cache */

/* replace1069_1_1 -> search62_2 in the cache */
static const nir_search_expression replace1069_1 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &search62_0_1.value, &search62_2.value },
   NULL,
};

/* replace1069_2_0 -> search62_1_1 in the cache */

/* replace1069_2_1 -> search62_2 in the cache */
static const nir_search_expression replace1069_2 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ieq,
   { &search62_1_1.value, &search62_2.value },
   NULL,
};
static const nir_search_expression replace1069 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 2,
   nir_op_bcsel,
   { &replace80_0.value, &replace1069_1.value, &replace1069_2.value },
   NULL,
};

   /* search1070_0 -> search1058_0 in the cache */

/* search1070_1_0 -> search174_0_1_0_0_0 in the cache */

/* search1070_1_1 -> search1058_1_1 in the cache */

/* search1070_1_2 -> search1058_1_2 in the cache */
/* search1070_1 -> search1058_1 in the cache */
static const nir_search_expression search1070 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &search1058_0.value, &search1058_1.value },
   NULL,
};

   /* replace1070_0 -> search174_0_1_0_0_0 in the cache */

/* replace1070_1_0 -> replace1058_1_0 in the cache */

/* replace1070_1_1 -> replace1058_1_1 in the cache */
static const nir_search_expression replace1070_1 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ieq,
   { &replace1058_1_0.value, &replace1058_1_1.value },
   NULL,
};

/* replace1070_2_0 -> replace1058_1_0 in the cache */

/* replace1070_2_1 -> replace1058_2_1 in the cache */
static const nir_search_expression replace1070_2 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ieq,
   { &replace1058_1_0.value, &replace1058_2_1.value },
   NULL,
};
static const nir_search_expression replace1070 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 2,
   nir_op_bcsel,
   { &search174_0_1_0_0_0.value, &replace1070_1.value, &replace1070_2.value },
   NULL,
};

   /* search1071_0_0 -> replace80_0 in the cache */

/* search1071_0_1 -> search1057_0_1 in the cache */

/* search1071_0_2 -> search1057_0_2 in the cache */
/* search1071_0 -> search1057_0 in the cache */

/* search1071_1 -> search1057_1 in the cache */
static const nir_search_expression search1071 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &search1057_0.value, &search1057_1.value },
   NULL,
};

   /* replace1071_0 -> replace80_0 in the cache */

/* replace1071_1_0 -> search62_0_1 in the cache */

/* replace1071_1_1 -> search62_2 in the cache */
static const nir_search_expression replace1071_1 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &search62_0_1.value, &search62_2.value },
   NULL,
};

/* replace1071_2_0 -> search62_1_1 in the cache */

/* replace1071_2_1 -> search62_2 in the cache */
static const nir_search_expression replace1071_2 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ine,
   { &search62_1_1.value, &search62_2.value },
   NULL,
};
static const nir_search_expression replace1071 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 2,
   nir_op_bcsel,
   { &replace80_0.value, &replace1071_1.value, &replace1071_2.value },
   NULL,
};

   /* search1072_0 -> search1058_0 in the cache */

/* search1072_1_0 -> search174_0_1_0_0_0 in the cache */

/* search1072_1_1 -> search1058_1_1 in the cache */

/* search1072_1_2 -> search1058_1_2 in the cache */
/* search1072_1 -> search1058_1 in the cache */
static const nir_search_expression search1072 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &search1058_0.value, &search1058_1.value },
   NULL,
};

   /* replace1072_0 -> search174_0_1_0_0_0 in the cache */

/* replace1072_1_0 -> replace1058_1_0 in the cache */

/* replace1072_1_1 -> replace1058_1_1 in the cache */
static const nir_search_expression replace1072_1 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ine,
   { &replace1058_1_0.value, &replace1058_1_1.value },
   NULL,
};

/* replace1072_2_0 -> replace1058_1_0 in the cache */

/* replace1072_2_1 -> replace1058_2_1 in the cache */
static const nir_search_expression replace1072_2 = {
   { nir_search_value_expression, 1 },
   false,
   1, 1,
   nir_op_ine,
   { &replace1058_1_0.value, &replace1058_2_1.value },
   NULL,
};
static const nir_search_expression replace1072 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 2,
   nir_op_bcsel,
   { &search174_0_1_0_0_0.value, &replace1072_1.value, &replace1072_2.value },
   NULL,
};

   /* search1073_0_0 -> replace80_0 in the cache */

/* search1073_0_1 -> search1057_0_1 in the cache */

/* search1073_0_2 -> search1057_0_2 in the cache */
/* search1073_0 -> search1057_0 in the cache */

/* search1073_1 -> search1057_1 in the cache */
static const nir_search_expression search1073 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search1057_0.value, &search1057_1.value },
   NULL,
};

   /* replace1073_0 -> replace80_0 in the cache */

/* replace1073_1_0 -> search62_0_1 in the cache */

/* replace1073_1_1 -> search62_2 in the cache */
static const nir_search_expression replace1073_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search62_0_1.value, &search62_2.value },
   NULL,
};

/* replace1073_2_0 -> search62_1_1 in the cache */

/* replace1073_2_1 -> search62_2 in the cache */
static const nir_search_expression replace1073_2 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search62_1_1.value, &search62_2.value },
   NULL,
};
static const nir_search_expression replace1073 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace80_0.value, &replace1073_1.value, &replace1073_2.value },
   NULL,
};

   /* search1074_0 -> search1058_0 in the cache */

/* search1074_1_0 -> search174_0_1_0_0_0 in the cache */

/* search1074_1_1 -> search1058_1_1 in the cache */

/* search1074_1_2 -> search1058_1_2 in the cache */
/* search1074_1 -> search1058_1 in the cache */
static const nir_search_expression search1074 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &search1058_0.value, &search1058_1.value },
   NULL,
};

   /* replace1074_0 -> search174_0_1_0_0_0 in the cache */

/* replace1074_1_0 -> replace1058_1_0 in the cache */

/* replace1074_1_1 -> replace1058_1_1 in the cache */
static const nir_search_expression replace1074_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &replace1058_1_0.value, &replace1058_1_1.value },
   NULL,
};

/* replace1074_2_0 -> replace1058_1_0 in the cache */

/* replace1074_2_1 -> replace1058_2_1 in the cache */
static const nir_search_expression replace1074_2 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_ult,
   { &replace1058_1_0.value, &replace1058_2_1.value },
   NULL,
};
static const nir_search_expression replace1074 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &search174_0_1_0_0_0.value, &replace1074_1.value, &replace1074_2.value },
   NULL,
};

   /* search1075_0_0 -> replace80_0 in the cache */

/* search1075_0_1 -> search1057_0_1 in the cache */

/* search1075_0_2 -> search1057_0_2 in the cache */
/* search1075_0 -> search1057_0 in the cache */

/* search1075_1 -> search1057_1 in the cache */
static const nir_search_expression search1075 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search1057_0.value, &search1057_1.value },
   NULL,
};

   /* replace1075_0 -> replace80_0 in the cache */

/* replace1075_1_0 -> search62_0_1 in the cache */

/* replace1075_1_1 -> search62_2 in the cache */
static const nir_search_expression replace1075_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search62_0_1.value, &search62_2.value },
   NULL,
};

/* replace1075_2_0 -> search62_1_1 in the cache */

/* replace1075_2_1 -> search62_2 in the cache */
static const nir_search_expression replace1075_2 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search62_1_1.value, &search62_2.value },
   NULL,
};
static const nir_search_expression replace1075 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace80_0.value, &replace1075_1.value, &replace1075_2.value },
   NULL,
};

   /* search1076_0 -> search1058_0 in the cache */

/* search1076_1_0 -> search174_0_1_0_0_0 in the cache */

/* search1076_1_1 -> search1058_1_1 in the cache */

/* search1076_1_2 -> search1058_1_2 in the cache */
/* search1076_1 -> search1058_1 in the cache */
static const nir_search_expression search1076 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &search1058_0.value, &search1058_1.value },
   NULL,
};

   /* replace1076_0 -> search174_0_1_0_0_0 in the cache */

/* replace1076_1_0 -> replace1058_1_0 in the cache */

/* replace1076_1_1 -> replace1058_1_1 in the cache */
static const nir_search_expression replace1076_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &replace1058_1_0.value, &replace1058_1_1.value },
   NULL,
};

/* replace1076_2_0 -> replace1058_1_0 in the cache */

/* replace1076_2_1 -> replace1058_2_1 in the cache */
static const nir_search_expression replace1076_2 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_uge,
   { &replace1058_1_0.value, &replace1058_2_1.value },
   NULL,
};
static const nir_search_expression replace1076 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &search174_0_1_0_0_0.value, &replace1076_1.value, &replace1076_2.value },
   NULL,
};

   /* search1077_0_0 -> replace80_0 in the cache */

/* search1077_0_1 -> search1057_0_1 in the cache */

/* search1077_0_2 -> search62_1_1 in the cache */
static const nir_search_expression search1077_0 = {
   { nir_search_value_expression, -4 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &replace80_0.value, &search1057_0_1.value, &search62_1_1.value },
   (is_used_once),
};

/* search1077_1 -> search1057_1 in the cache */
static const nir_search_expression search1077 = {
   { nir_search_value_expression, -4 },
   false,
   0, 1,
   nir_op_fadd,
   { &search1077_0.value, &search1057_1.value },
   NULL,
};

   /* replace1077_0 -> replace80_0 in the cache */

/* replace1077_1_0 -> search62_0_1 in the cache */

/* replace1077_1_1 -> search62_2 in the cache */
static const nir_search_expression replace1077_1 = {
   { nir_search_value_expression, -4 },
   false,
   0, 1,
   nir_op_fadd,
   { &search62_0_1.value, &search62_2.value },
   NULL,
};

/* replace1077_2_0 -> search62_1_1 in the cache */

/* replace1077_2_1 -> search62_2 in the cache */
static const nir_search_expression replace1077_2 = {
   { nir_search_value_expression, -4 },
   false,
   1, 1,
   nir_op_fadd,
   { &search62_1_1.value, &search62_2.value },
   NULL,
};
static const nir_search_expression replace1077 = {
   { nir_search_value_expression, -4 },
   false,
   -1, 2,
   nir_op_bcsel,
   { &replace80_0.value, &replace1077_1.value, &replace1077_2.value },
   NULL,
};

   /* search1078_0_0 -> replace80_0 in the cache */

/* search1078_0_1 -> search1057_0_1 in the cache */

/* search1078_0_2 -> search62_1_1 in the cache */
/* search1078_0 -> search1077_0 in the cache */

/* search1078_1 -> search1057_1 in the cache */
static const nir_search_expression search1078 = {
   { nir_search_value_expression, -4 },
   false,
   0, 1,
   nir_op_fmul,
   { &search1077_0.value, &search1057_1.value },
   NULL,
};

   /* replace1078_0 -> replace80_0 in the cache */

/* replace1078_1_0 -> search62_0_1 in the cache */

/* replace1078_1_1 -> search62_2 in the cache */
static const nir_search_expression replace1078_1 = {
   { nir_search_value_expression, -4 },
   false,
   0, 1,
   nir_op_fmul,
   { &search62_0_1.value, &search62_2.value },
   NULL,
};

/* replace1078_2_0 -> search62_1_1 in the cache */

/* replace1078_2_1 -> search62_2 in the cache */
static const nir_search_expression replace1078_2 = {
   { nir_search_value_expression, -4 },
   false,
   1, 1,
   nir_op_fmul,
   { &search62_1_1.value, &search62_2.value },
   NULL,
};
static const nir_search_expression replace1078 = {
   { nir_search_value_expression, -4 },
   false,
   -1, 2,
   nir_op_bcsel,
   { &replace80_0.value, &replace1078_1.value, &replace1078_2.value },
   NULL,
};

   /* search1079_0_0 -> replace80_0 in the cache */

/* search1079_0_1 -> search1057_0_1 in the cache */

/* search1079_0_2 -> search62_1_1 in the cache */
/* search1079_0 -> search1077_0 in the cache */

/* search1079_1 -> search1057_1 in the cache */
static const nir_search_expression search1079 = {
   { nir_search_value_expression, -4 },
   false,
   0, 1,
   nir_op_iadd,
   { &search1077_0.value, &search1057_1.value },
   NULL,
};

   /* replace1079_0 -> replace80_0 in the cache */

/* replace1079_1_0 -> search62_0_1 in the cache */

/* replace1079_1_1 -> search62_2 in the cache */
static const nir_search_expression replace1079_1 = {
   { nir_search_value_expression, -4 },
   false,
   0, 1,
   nir_op_iadd,
   { &search62_0_1.value, &search62_2.value },
   NULL,
};

/* replace1079_2_0 -> search62_1_1 in the cache */

/* replace1079_2_1 -> search62_2 in the cache */
static const nir_search_expression replace1079_2 = {
   { nir_search_value_expression, -4 },
   false,
   1, 1,
   nir_op_iadd,
   { &search62_1_1.value, &search62_2.value },
   NULL,
};
static const nir_search_expression replace1079 = {
   { nir_search_value_expression, -4 },
   false,
   -1, 2,
   nir_op_bcsel,
   { &replace80_0.value, &replace1079_1.value, &replace1079_2.value },
   NULL,
};

   /* search1080_0_0 -> replace80_0 in the cache */

/* search1080_0_1 -> search1057_0_1 in the cache */

/* search1080_0_2 -> search62_1_1 in the cache */
/* search1080_0 -> search1077_0 in the cache */

/* search1080_1 -> search1057_1 in the cache */
static const nir_search_expression search1080 = {
   { nir_search_value_expression, -4 },
   false,
   0, 1,
   nir_op_imul,
   { &search1077_0.value, &search1057_1.value },
   NULL,
};

   /* replace1080_0 -> replace80_0 in the cache */

/* replace1080_1_0 -> search62_0_1 in the cache */

/* replace1080_1_1 -> search62_2 in the cache */
static const nir_search_expression replace1080_1 = {
   { nir_search_value_expression, -4 },
   false,
   0, 1,
   nir_op_imul,
   { &search62_0_1.value, &search62_2.value },
   NULL,
};

/* replace1080_2_0 -> search62_1_1 in the cache */

/* replace1080_2_1 -> search62_2 in the cache */
static const nir_search_expression replace1080_2 = {
   { nir_search_value_expression, -4 },
   false,
   1, 1,
   nir_op_imul,
   { &search62_1_1.value, &search62_2.value },
   NULL,
};
static const nir_search_expression replace1080 = {
   { nir_search_value_expression, -4 },
   false,
   -1, 2,
   nir_op_bcsel,
   { &replace80_0.value, &replace1080_1.value, &replace1080_2.value },
   NULL,
};

   /* search1081_0 -> search2_0 in the cache */
static const nir_search_expression search1081 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fddx,
   { &search2_0.value },
   NULL,
};

   /* replace1081 -> search24_1 in the cache */

   /* search1082_0 -> search2_0 in the cache */
static const nir_search_expression search1082 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fddx_fine,
   { &search2_0.value },
   NULL,
};

   /* replace1082 -> search24_1 in the cache */

   /* search1083_0 -> search2_0 in the cache */
static const nir_search_expression search1083 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fddx_coarse,
   { &search2_0.value },
   NULL,
};

   /* replace1083 -> search24_1 in the cache */

   /* search1084_0 -> search2_0 in the cache */
static const nir_search_expression search1084 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fddy,
   { &search2_0.value },
   NULL,
};

   /* replace1084 -> search24_1 in the cache */

   /* search1085_0 -> search2_0 in the cache */
static const nir_search_expression search1085 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fddy_fine,
   { &search2_0.value },
   NULL,
};

   /* replace1085 -> search24_1 in the cache */

   /* search1086_0 -> search2_0 in the cache */
static const nir_search_expression search1086 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fddy_coarse,
   { &search2_0.value },
   NULL,
};

   /* replace1086 -> search24_1 in the cache */

   static const nir_search_variable search1087_0 = {
   { nir_search_value_variable, 32 },
   0, /* a */
   true,
   nir_type_invalid,
   (is_lower_half_zero),
   {0, 1, 2, 3},
};

/* search1087_1 -> replace0_1_0 in the cache */
static const nir_search_expression search1087 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_umul_low,
   { &search1087_0.value, &replace0_1_0.value },
   NULL,
};

   /* replace1087 -> search26_1 in the cache */

   /* search1088_0 -> search1087_0 in the cache */

/* search1088_1 -> replace0_1_0 in the cache */

/* search1088_2 -> search56_2 in the cache */
static const nir_search_expression search1088 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_imadsh_mix16,
   { &search1087_0.value, &replace0_1_0.value, &search56_2.value },
   NULL,
};

   /* replace1088 -> search56_2 in the cache */

   /* search1089_0 -> search0_0 in the cache */

static const nir_search_variable search1089_1 = {
   { nir_search_value_variable, 32 },
   1, /* b */
   true,
   nir_type_invalid,
   (is_upper_half_zero),
   {0, 1, 2, 3},
};

/* search1089_2 -> search56_2 in the cache */
static const nir_search_expression search1089 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_imadsh_mix16,
   { &search0_0.value, &search1089_1.value, &search56_2.value },
   NULL,
};

   /* replace1089 -> search56_2 in the cache */


static const struct transform nir_opt_algebraic_state3_xforms[] = {
  { &search0, &replace0.value, 1 },
  { &search1, &replace1.value, 1 },
  { &search38, &replace9.value, 0 },
  { &search42, &search2_0.value, 0 },
  { &search44, &search16_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state5_xforms[] = {
  { &search2, &replace2.value, 2 },
  { &search436, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state6_xforms[] = {
  { &search435, &search193_1.value, 0 },
};
static const struct transform nir_opt_algebraic_state7_xforms[] = {
  { &search2, &replace2.value, 2 },
  { &search435, &search193_1.value, 0 },
  { &search436, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state9_xforms[] = {
  { &search5, &replace5.value, 3 },
};
static const struct transform nir_opt_algebraic_state10_xforms[] = {
  { &search6, &replace6.value, 3 },
};
static const struct transform nir_opt_algebraic_state11_xforms[] = {
  { &search7, &search2_0.value, 0 },
  { &search11, &replace11.value, 1 },
};
static const struct transform nir_opt_algebraic_state12_xforms[] = {
  { &search8, &search2_0.value, 0 },
  { &search12, &replace12.value, 4 },
  { &search13, &replace13.value, 4 },
};
static const struct transform nir_opt_algebraic_state13_xforms[] = {
  { &search9, &replace9.value, 0 },
  { &search14, &replace14.value, 0 },
};
static const struct transform nir_opt_algebraic_state14_xforms[] = {
  { &search10, &replace9.value, 0 },
};
static const struct transform nir_opt_algebraic_state15_xforms[] = {
  { &search15_0, &replace634.value, 35 },
};
static const struct transform nir_opt_algebraic_state16_xforms[] = {
  { &search16_0, &replace635.value, 35 },
};
static const struct transform nir_opt_algebraic_state17_xforms[] = {
  { &search528, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state19_xforms[] = {
  { &search529, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state21_xforms[] = {
  { &search485, &replace485.value, 0 },
  { &search486, &replace195.value, 0 },
};
static const struct transform nir_opt_algebraic_state23_xforms[] = {
  { &search24, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state25_xforms[] = {
  { &search25, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state26_xforms[] = {
  { &search26, &search0_0.value, 0 },
  { &search27, &search27_1.value, 0 },
};
static const struct transform nir_opt_algebraic_state28_xforms[] = {
  { &search37, &search24_1.value, 0 },
  { &search41, &search2_0.value, 0 },
  { &search43, &search15_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state29_xforms[] = {
  { &search36_0, &replace269.value, 21 },
  { &search530, &search24_1.value, 0 },
};
static const struct transform nir_opt_algebraic_state30_xforms[] = {
  { &search39, &search26_1.value, 0 },
  { &search40, &search0_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state31_xforms[] = {
  { &search45_0, &replace698.value, 59 },
};
static const struct transform nir_opt_algebraic_state32_xforms[] = {
  { &search78, &replace78.value, 14 },
};
static const struct transform nir_opt_algebraic_state33_xforms[] = {
  { &search48, &replace48.value, 0 },
  { &search78, &replace78.value, 14 },
};
static const struct transform nir_opt_algebraic_state34_xforms[] = {
  { &search47, &replace14_1_0.value, 0 },
  { &search49, &replace49.value, 0 },
  { &search50, &replace50.value, 0 },
  { &search78, &replace78.value, 14 },
};
static const struct transform nir_opt_algebraic_state35_xforms[] = {
  { &search47, &replace14_1_0.value, 0 },
  { &search48, &replace48.value, 0 },
  { &search49, &replace49.value, 0 },
  { &search50, &replace50.value, 0 },
  { &search78, &replace78.value, 14 },
};
static const struct transform nir_opt_algebraic_state36_xforms[] = {
  { &search53, &search14_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state37_xforms[] = {
  { &search51, &search14_0.value, 0 },
  { &search52, &replace14_1_0.value, 0 },
  { &search53, &search14_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state38_xforms[] = {
  { &search53, &search14_0.value, 0 },
  { &search64, &replace64.value, 0 },
};
static const struct transform nir_opt_algebraic_state39_xforms[] = {
  { &search51, &search14_0.value, 0 },
  { &search52, &replace14_1_0.value, 0 },
  { &search53, &search14_0.value, 0 },
  { &search64, &replace64.value, 0 },
};
static const struct transform nir_opt_algebraic_state40_xforms[] = {
  { &search53, &search14_0.value, 0 },
  { &search54, &replace48.value, 0 },
};
static const struct transform nir_opt_algebraic_state41_xforms[] = {
  { &search51, &search14_0.value, 0 },
  { &search52, &replace14_1_0.value, 0 },
  { &search53, &search14_0.value, 0 },
  { &search54, &replace48.value, 0 },
};
static const struct transform nir_opt_algebraic_state42_xforms[] = {
  { &search53, &search14_0.value, 0 },
  { &search54, &replace48.value, 0 },
  { &search64, &replace64.value, 0 },
};
static const struct transform nir_opt_algebraic_state43_xforms[] = {
  { &search51, &search14_0.value, 0 },
  { &search52, &replace14_1_0.value, 0 },
  { &search53, &search14_0.value, 0 },
  { &search54, &replace48.value, 0 },
  { &search64, &replace64.value, 0 },
};
static const struct transform nir_opt_algebraic_state45_xforms[] = {
  { &search65, &replace65.value, 7 },
  { &search526, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state46_xforms[] = {
  { &search66, &replace66.value, 8 },
  { &search524, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state47_xforms[] = {
  { &replace66_1, &replace68.value, 10 },
  { &search527, &search24_1.value, 0 },
};
static const struct transform nir_opt_algebraic_state48_xforms[] = {
  { &search69, &replace69.value, 11 },
  { &search525, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state49_xforms[] = {
  { &search420, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state50_xforms[] = {
  { &search410, &replace410.value, 0 },
  { &search420, &search2_0.value, 0 },
  { &search421, &search2_0.value, 0 },
  { &search422, &replace9.value, 0 },
  { &search571, &replace571.value, 32 },
  { &search627, &replace627.value, 33 },
};
static const struct transform nir_opt_algebraic_state52_xforms[] = {
  { &search81, &replace81.value, 16 },
};
static const struct transform nir_opt_algebraic_state53_xforms[] = {
  { &search92, &replace92.value, 18 },
};
static const struct transform nir_opt_algebraic_state57_xforms[] = {
  { &search91, &replace91.value, 18 },
};
static const struct transform nir_opt_algebraic_state60_xforms[] = {
  { &search90, &replace90.value, 18 },
};
static const struct transform nir_opt_algebraic_state61_xforms[] = {
  { &search89, &replace89.value, 0 },
  { &search90, &replace90.value, 18 },
};
static const struct transform nir_opt_algebraic_state63_xforms[] = {
  { &search93, &replace89.value, 18 },
};
static const struct transform nir_opt_algebraic_state65_xforms[] = {
  { &search440, &search2_0.value, 0 },
  { &search565, &replace565.value, 32 },
  { &search441_1, &replace566.value, 32 },
  { &search567, &replace567.value, 32 },
  { &search442_1, &replace624.value, 33 },
};
static const struct transform nir_opt_algebraic_state66_xforms[] = {
  { &search439, &search193_1.value, 0 },
};
static const struct transform nir_opt_algebraic_state67_xforms[] = {
  { &search439, &search193_1.value, 0 },
  { &search440, &search2_0.value, 0 },
  { &search565, &replace565.value, 32 },
  { &search441_1, &replace566.value, 32 },
  { &search567, &replace567.value, 32 },
  { &search442_1, &replace624.value, 33 },
};
static const struct transform nir_opt_algebraic_state69_xforms[] = {
  { &search438, &search2_0.value, 0 },
  { &search568, &replace568.value, 32 },
  { &search569, &replace569.value, 32 },
  { &search570, &replace570.value, 32 },
  { &search591_0, &replace626.value, 33 },
};
static const struct transform nir_opt_algebraic_state70_xforms[] = {
  { &search437, &search193_1.value, 0 },
};
static const struct transform nir_opt_algebraic_state71_xforms[] = {
  { &search437, &search193_1.value, 0 },
  { &search438, &search2_0.value, 0 },
  { &search568, &replace568.value, 32 },
  { &search569, &replace569.value, 32 },
  { &search570, &replace570.value, 32 },
  { &search591_0, &replace626.value, 33 },
};
static const struct transform nir_opt_algebraic_state73_xforms[] = {
  { &search546, &replace121.value, 0 },
  { &search547, &replace197.value, 0 },
  { &search548, &replace197.value, 0 },
  { &search549, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state74_xforms[] = {
  { &search546, &replace121.value, 0 },
  { &search547, &replace197.value, 0 },
  { &search548, &replace197.value, 0 },
  { &search549, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state75_xforms[] = {
  { &search546, &replace121.value, 0 },
  { &search547, &replace197.value, 0 },
  { &search548, &replace197.value, 0 },
  { &search549, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state76_xforms[] = {
  { &search546, &replace121.value, 0 },
  { &search547, &replace197.value, 0 },
  { &search548, &replace197.value, 0 },
  { &search549, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state77_xforms[] = {
  { &search542, &replace197.value, 0 },
  { &search543, &replace121.value, 0 },
  { &search544, &replace121.value, 0 },
  { &search545, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state78_xforms[] = {
  { &search542, &replace197.value, 0 },
  { &search543, &replace121.value, 0 },
  { &search544, &replace121.value, 0 },
  { &search545, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state79_xforms[] = {
  { &search542, &replace197.value, 0 },
  { &search543, &replace121.value, 0 },
  { &search544, &replace121.value, 0 },
  { &search545, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state80_xforms[] = {
  { &search542, &replace197.value, 0 },
  { &search543, &replace121.value, 0 },
  { &search544, &replace121.value, 0 },
  { &search545, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state82_xforms[] = {
  { &search541, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state84_xforms[] = {
  { &search540, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state85_xforms[] = {
  { &search414, &replace121.value, 0 },
  { &search556, &replace121.value, 0 },
  { &search557, &replace197.value, 0 },
  { &search558, &replace197.value, 0 },
  { &search559, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state86_xforms[] = {
  { &search414, &replace121.value, 0 },
  { &search556, &replace121.value, 0 },
  { &search557, &replace197.value, 0 },
  { &search558, &replace197.value, 0 },
  { &search559, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state87_xforms[] = {
  { &search418, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state88_xforms[] = {
  { &search418, &replace121.value, 0 },
  { &search560, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state89_xforms[] = {
  { &search415, &replace197.value, 0 },
  { &search552, &replace197.value, 0 },
  { &search553, &replace121.value, 0 },
  { &search554, &replace121.value, 0 },
  { &search555, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state90_xforms[] = {
  { &search419, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state91_xforms[] = {
  { &search419, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state92_xforms[] = {
  { &search416, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state93_xforms[] = {
  { &search416, &replace197.value, 0 },
  { &search487, &replace80_0.value, 0 },
  { &search490, &replace146.value, 0 },
  { &search551, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state94_xforms[] = {
  { &search417, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state95_xforms[] = {
  { &search417, &replace121.value, 0 },
  { &search488, &replace146.value, 0 },
  { &search489, &replace80_0.value, 0 },
  { &search550, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state96_xforms[] = {
  { &search237, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state97_xforms[] = {
  { &search237, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state98_xforms[] = {
  { &search233, &replace148.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state99_xforms[] = {
  { &search233, &replace148.value, 0 },
  { &search234, &replace152.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state100_xforms[] = {
  { &search232, &replace148.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state101_xforms[] = {
  { &search232, &replace148.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search234, &replace152.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search491, &replace80_0.value, 0 },
  { &search492, &replace146.value, 0 },
  { &search493, &replace493.value, 0 },
  { &search494, &replace494.value, 0 },
  { &search495, &replace495.value, 0 },
  { &search496, &replace496.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
  { &search502, &replace502.value, 0 },
  { &search503, &replace503.value, 0 },
};
static const struct transform nir_opt_algebraic_state102_xforms[] = {
  { &search233, &replace148.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search497, &replace137_0.value, 0 },
  { &search498, &search64_2.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state103_xforms[] = {
  { &search233, &replace148.value, 0 },
  { &search234, &replace152.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search497, &replace137_0.value, 0 },
  { &search498, &search64_2.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state104_xforms[] = {
  { &search232, &replace148.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search497, &replace137_0.value, 0 },
  { &search498, &search64_2.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state105_xforms[] = {
  { &search232, &replace148.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search234, &replace152.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search491, &replace80_0.value, 0 },
  { &search492, &replace146.value, 0 },
  { &search493, &replace493.value, 0 },
  { &search494, &replace494.value, 0 },
  { &search495, &replace495.value, 0 },
  { &search496, &replace496.value, 0 },
  { &search497, &replace137_0.value, 0 },
  { &search498, &search64_2.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
  { &search502, &replace502.value, 0 },
  { &search503, &replace503.value, 0 },
};
static const struct transform nir_opt_algebraic_state106_xforms[] = {
  { &search236, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state107_xforms[] = {
  { &search236, &search2_0.value, 0 },
  { &search535, &search36_0.value, 19 },
};
static const struct transform nir_opt_algebraic_state109_xforms[] = {
  { &search423, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state110_xforms[] = {
  { &search423, &search2_0.value, 0 },
  { &search424, &search2_0.value, 0 },
  { &search425, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state111_xforms[] = {
  { &search238, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state112_xforms[] = {
  { &search238, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state113_xforms[] = {
  { &search239, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state114_xforms[] = {
  { &search239, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state115_xforms[] = {
  { &search240, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state116_xforms[] = {
  { &search240, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state117_xforms[] = {
  { &search241, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state118_xforms[] = {
  { &search241, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state119_xforms[] = {
  { &search686, &replace686.value, 48 },
};
static const struct transform nir_opt_algebraic_state120_xforms[] = {
  { &search375_0, &replace379.value, 22 },
};
static const struct transform nir_opt_algebraic_state121_xforms[] = {
  { &search376_0, &replace380.value, 22 },
};
static const struct transform nir_opt_algebraic_state122_xforms[] = {
  { &search377_0, &replace381.value, 22 },
};
static const struct transform nir_opt_algebraic_state123_xforms[] = {
  { &search378_0, &replace382.value, 22 },
};
static const struct transform nir_opt_algebraic_state124_xforms[] = {
  { &search399, &replace399.value, 23 },
};
static const struct transform nir_opt_algebraic_state125_xforms[] = {
  { &search400, &replace400.value, 23 },
};
static const struct transform nir_opt_algebraic_state126_xforms[] = {
  { &search401, &replace401.value, 23 },
};
static const struct transform nir_opt_algebraic_state127_xforms[] = {
  { &search402, &replace402.value, 23 },
};
static const struct transform nir_opt_algebraic_state128_xforms[] = {
  { &search403, &replace403.value, 23 },
};
static const struct transform nir_opt_algebraic_state129_xforms[] = {
  { &search404, &replace404.value, 23 },
};
static const struct transform nir_opt_algebraic_state130_xforms[] = {
  { &search632, &replace632.value, 34 },
};
static const struct transform nir_opt_algebraic_state131_xforms[] = {
  { &search632, &replace632.value, 34 },
};
static const struct transform nir_opt_algebraic_state132_xforms[] = {
  { &search426, &replace9.value, 0 },
};
static const struct transform nir_opt_algebraic_state133_xforms[] = {
  { &search426, &replace9.value, 0 },
  { &search427, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state134_xforms[] = {
  { &search633, &replace633.value, 34 },
};
static const struct transform nir_opt_algebraic_state135_xforms[] = {
  { &search633, &replace633.value, 34 },
};
static const struct transform nir_opt_algebraic_state136_xforms[] = {
  { &replace443, &search444.value, 25 },
  { &replace445, &search446.value, 25 },
};
static const struct transform nir_opt_algebraic_state137_xforms[] = {
  { &replace447, &search448.value, 25 },
  { &replace449, &search450.value, 25 },
};
static const struct transform nir_opt_algebraic_state140_xforms[] = {
  { &search457, &replace457.value, 26 },
};
static const struct transform nir_opt_algebraic_state141_xforms[] = {
  { &search457, &replace457.value, 26 },
  { &search462, &search2_0.value, 0 },
  { &search463, &search45_1.value, 0 },
  { &search464, &replace461.value, 0 },
};
static const struct transform nir_opt_algebraic_state142_xforms[] = {
  { &search457, &replace457.value, 26 },
  { &search465, &search456_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state143_xforms[] = {
  { &search457, &replace457.value, 26 },
  { &search462, &search2_0.value, 0 },
  { &search463, &search45_1.value, 0 },
  { &search464, &replace461.value, 0 },
  { &search465, &search456_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state144_xforms[] = {
  { &search471_0, &replace481.value, 29 },
};
static const struct transform nir_opt_algebraic_state147_xforms[] = {
  { &search478, &replace478.value, 28 },
};
static const struct transform nir_opt_algebraic_state148_xforms[] = {
  { &search477, &search472_0.value, 0 },
  { &search478, &replace478.value, 28 },
};
static const struct transform nir_opt_algebraic_state149_xforms[] = {
  { &search483, &replace483.value, 31 },
};
static const struct transform nir_opt_algebraic_state150_xforms[] = {
  { &search484, &replace484.value, 31 },
};
static const struct transform nir_opt_algebraic_state151_xforms[] = {
  { &search501, &replace0_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state157_xforms[] = {
  { &search688, &replace688.value, 49 },
};
static const struct transform nir_opt_algebraic_state158_xforms[] = {
  { &search688, &replace688.value, 49 },
};
static const struct transform nir_opt_algebraic_state159_xforms[] = {
  { &search685, &replace685.value, 48 },
};
static const struct transform nir_opt_algebraic_state160_xforms[] = {
  { &search630, &search0_0.value, 0 },
  { &search631, &search26_1.value, 0 },
};
static const struct transform nir_opt_algebraic_state161_xforms[] = {
  { &search684, &replace684.value, 47 },
};
static const struct transform nir_opt_algebraic_state162_xforms[] = {
  { &search683, &replace683.value, 46 },
};
static const struct transform nir_opt_algebraic_state164_xforms[] = {
  { &search659, &replace659.value, 36 },
  { &search660, &replace660.value, 36 },
};
static const struct transform nir_opt_algebraic_state165_xforms[] = {
  { &search661, &replace661.value, 36 },
};
static const struct transform nir_opt_algebraic_state166_xforms[] = {
  { &search662, &replace662.value, 37 },
};
static const struct transform nir_opt_algebraic_state167_xforms[] = {
  { &search663, &replace663.value, 38 },
};
static const struct transform nir_opt_algebraic_state168_xforms[] = {
  { &search664, &replace664.value, 39 },
  { &search664, &replace671.value, 42 },
  { &search664, &replace672.value, 43 },
};
static const struct transform nir_opt_algebraic_state169_xforms[] = {
  { &search665, &replace665.value, 40 },
};
static const struct transform nir_opt_algebraic_state170_xforms[] = {
  { &search666, &replace666.value, 40 },
};
static const struct transform nir_opt_algebraic_state171_xforms[] = {
  { &search667, &replace667.value, 40 },
};
static const struct transform nir_opt_algebraic_state172_xforms[] = {
  { &search668, &replace668.value, 40 },
};
static const struct transform nir_opt_algebraic_state173_xforms[] = {
  { &search669, &replace669.value, 41 },
};
static const struct transform nir_opt_algebraic_state174_xforms[] = {
  { &search670, &replace670.value, 41 },
};
static const struct transform nir_opt_algebraic_state175_xforms[] = {
  { &search673, &replace673.value, 44 },
  { &search673, &replace681.value, 45 },
};
static const struct transform nir_opt_algebraic_state176_xforms[] = {
  { &search674, &replace674.value, 44 },
  { &search674, &replace682.value, 45 },
};
static const struct transform nir_opt_algebraic_state177_xforms[] = {
  { &search687, &replace687.value, 49 },
};
static const struct transform nir_opt_algebraic_state178_xforms[] = {
  { &search689, &replace689.value, 50 },
};
static const struct transform nir_opt_algebraic_state179_xforms[] = {
  { &search690, &replace690.value, 51 },
};
static const struct transform nir_opt_algebraic_state180_xforms[] = {
  { &search691, &replace691.value, 52 },
};
static const struct transform nir_opt_algebraic_state181_xforms[] = {
  { &search692, &replace692.value, 53 },
};
static const struct transform nir_opt_algebraic_state182_xforms[] = {
  { &search693, &replace693.value, 54 },
};
static const struct transform nir_opt_algebraic_state183_xforms[] = {
  { &search694, &replace694.value, 55 },
};
static const struct transform nir_opt_algebraic_state184_xforms[] = {
  { &search695, &replace695.value, 56 },
};
static const struct transform nir_opt_algebraic_state185_xforms[] = {
  { &search696, &replace696.value, 57 },
};
static const struct transform nir_opt_algebraic_state186_xforms[] = {
  { &search697, &replace697.value, 58 },
};
static const struct transform nir_opt_algebraic_state187_xforms[] = {
  { &search699, &replace699.value, 41 },
  { &search701, &replace701.value, 41 },
  { &search703, &replace703.value, 41 },
  { &search705, &replace705.value, 41 },
};
static const struct transform nir_opt_algebraic_state188_xforms[] = {
  { &search700, &replace700.value, 41 },
  { &search702, &replace702.value, 41 },
  { &search704, &replace704.value, 41 },
  { &search706, &replace706.value, 41 },
};
static const struct transform nir_opt_algebraic_state189_xforms[] = {
  { &search748, &search101_0_0.value, 0 },
  { &search749, &search0_0.value, 0 },
  { &search750, &search57_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state190_xforms[] = {
  { &search743, &replace80_0.value, 0 },
  { &search744, &search98_0_0.value, 0 },
  { &search745, &search101_0_0.value, 0 },
  { &search746, &search0_0.value, 0 },
  { &search747, &search57_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state191_xforms[] = {
  { &search738, &replace80_0.value, 0 },
  { &search739, &search98_0_0.value, 0 },
  { &search740, &search101_0_0.value, 0 },
  { &search741, &search0_0.value, 0 },
  { &search742, &search57_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state192_xforms[] = {
  { &search1047, &replace1047.value, 60 },
  { &search1048, &replace1048.value, 60 },
  { &search1049, &replace1049.value, 60 },
};
static const struct transform nir_opt_algebraic_state193_xforms[] = {
  { &search1081, &search24_1.value, 62 },
};
static const struct transform nir_opt_algebraic_state194_xforms[] = {
  { &search1082, &search24_1.value, 62 },
};
static const struct transform nir_opt_algebraic_state195_xforms[] = {
  { &search1083, &search24_1.value, 62 },
};
static const struct transform nir_opt_algebraic_state196_xforms[] = {
  { &search1084, &search24_1.value, 62 },
};
static const struct transform nir_opt_algebraic_state197_xforms[] = {
  { &search1085, &search24_1.value, 62 },
};
static const struct transform nir_opt_algebraic_state198_xforms[] = {
  { &search1086, &search24_1.value, 62 },
};
static const struct transform nir_opt_algebraic_state199_xforms[] = {
  { &search1087, &search26_1.value, 0 },
};
static const struct transform nir_opt_algebraic_state200_xforms[] = {
  { &search1089, &search56_2.value, 0 },
};
static const struct transform nir_opt_algebraic_state201_xforms[] = {
  { &search1088, &search56_2.value, 0 },
};
static const struct transform nir_opt_algebraic_state202_xforms[] = {
  { &search1088, &search56_2.value, 0 },
  { &search1089, &search56_2.value, 0 },
};
static const struct transform nir_opt_algebraic_state203_xforms[] = {
  { &search641, &replace641.value, 0 },
};
static const struct transform nir_opt_algebraic_state204_xforms[] = {
  { &search0, &replace0.value, 1 },
  { &search1, &replace1.value, 1 },
  { &search38, &replace9.value, 0 },
  { &search42, &search2_0.value, 0 },
  { &search44, &search16_0.value, 0 },
  { &search643, &replace643.value, 0 },
};
static const struct transform nir_opt_algebraic_state205_xforms[] = {
  { &search0, &replace0.value, 1 },
  { &search1, &replace1.value, 1 },
  { &search38, &replace9.value, 0 },
  { &search42, &search2_0.value, 0 },
  { &search44, &search16_0.value, 0 },
  { &search643, &replace643.value, 0 },
  { &search647, &replace643.value, 0 },
};
static const struct transform nir_opt_algebraic_state206_xforms[] = {
  { &search0, &replace0.value, 1 },
  { &search1, &replace1.value, 1 },
  { &search38, &replace9.value, 0 },
  { &search42, &search2_0.value, 0 },
  { &search44, &search16_0.value, 0 },
  { &search641, &replace641.value, 0 },
};
static const struct transform nir_opt_algebraic_state207_xforms[] = {
  { &search0, &replace0.value, 1 },
  { &search1, &replace1.value, 1 },
  { &search38, &replace9.value, 0 },
  { &search42, &search2_0.value, 0 },
  { &search44, &search16_0.value, 0 },
  { &search1080, &replace1080.value, 0 },
};
static const struct transform nir_opt_algebraic_state208_xforms[] = {
  { &search407, &replace407.value, 0 },
};
static const struct transform nir_opt_algebraic_state209_xforms[] = {
  { &search651, &search14_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state210_xforms[] = {
  { &search8, &search2_0.value, 0 },
  { &search12, &replace12.value, 4 },
  { &search13, &replace13.value, 4 },
  { &search651, &search14_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state211_xforms[] = {
  { &search31, &replace9.value, 0 },
};
static const struct transform nir_opt_algebraic_state212_xforms[] = {
  { &search637, &search633.value, 0 },
};
static const struct transform nir_opt_algebraic_state213_xforms[] = {
  { &search25, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state214_xforms[] = {
  { &search25, &search2_0.value, 0 },
  { &search31, &replace9.value, 0 },
};
static const struct transform nir_opt_algebraic_state215_xforms[] = {
  { &search25, &search2_0.value, 0 },
  { &search645, &replace645.value, 0 },
};
static const struct transform nir_opt_algebraic_state216_xforms[] = {
  { &search25, &search2_0.value, 0 },
  { &search645, &replace645.value, 0 },
  { &search650, &replace645.value, 0 },
};
static const struct transform nir_opt_algebraic_state217_xforms[] = {
  { &search25, &search2_0.value, 0 },
  { &search1079, &replace1079.value, 0 },
};
static const struct transform nir_opt_algebraic_state218_xforms[] = {
  { &search25, &search2_0.value, 0 },
  { &search637, &search633.value, 0 },
};
static const struct transform nir_opt_algebraic_state219_xforms[] = {
  { &search29, &replace29.value, 0 },
};
static const struct transform nir_opt_algebraic_state220_xforms[] = {
  { &search31, &replace9.value, 0 },
  { &search32, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state221_xforms[] = {
  { &search31, &replace9.value, 0 },
  { &search637, &search633.value, 0 },
};
static const struct transform nir_opt_algebraic_state222_xforms[] = {
  { &search511, &search445_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state224_xforms[] = {
  { &search435, &search193_1.value, 0 },
  { &search511, &search445_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state225_xforms[] = {
  { &search435, &search193_1.value, 0 },
};
static const struct transform nir_opt_algebraic_state226_xforms[] = {
  { &search2, &replace2.value, 2 },
  { &search97, &replace97.value, 0 },
  { &search436, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state227_xforms[] = {
  { &search2, &replace2.value, 2 },
  { &search98, &replace98.value, 0 },
  { &search101, &replace101.value, 0 },
  { &search104, &replace104.value, 0 },
  { &search107, &replace107.value, 0 },
  { &search436, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state228_xforms[] = {
  { &search2, &replace2.value, 2 },
  { &search110, &replace110.value, 0 },
  { &search436, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state229_xforms[] = {
  { &search423, &search2_0.value, 0 },
  { &search429, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state230_xforms[] = {
  { &search325, &search44_1.value, 0 },
  { &search423, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state231_xforms[] = {
  { &search324, &replace197.value, 0 },
  { &search423, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state232_xforms[] = {
  { &search423, &search2_0.value, 0 },
  { &search430, &search354_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state233_xforms[] = {
  { &search423, &search2_0.value, 0 },
  { &search424, &search2_0.value, 0 },
  { &search425, &replace197.value, 0 },
  { &search429, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state234_xforms[] = {
  { &search325, &search44_1.value, 0 },
  { &search423, &search2_0.value, 0 },
  { &search424, &search2_0.value, 0 },
  { &search425, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state235_xforms[] = {
  { &search324, &replace197.value, 0 },
  { &search423, &search2_0.value, 0 },
  { &search424, &search2_0.value, 0 },
  { &search425, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state236_xforms[] = {
  { &search423, &search2_0.value, 0 },
  { &search424, &search2_0.value, 0 },
  { &search425, &replace197.value, 0 },
  { &search430, &search354_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state237_xforms[] = {
  { &search423, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state238_xforms[] = {
  { &search325, &search44_1.value, 0 },
  { &search423, &search2_0.value, 0 },
  { &search429, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state239_xforms[] = {
  { &search324, &replace197.value, 0 },
  { &search423, &search2_0.value, 0 },
  { &search429, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state240_xforms[] = {
  { &search423, &search2_0.value, 0 },
  { &search429, &replace14_1_0.value, 0 },
  { &search430, &search354_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state241_xforms[] = {
  { &search325, &search44_1.value, 0 },
  { &search423, &search2_0.value, 0 },
  { &search434, &replace434.value, 0 },
};
static const struct transform nir_opt_algebraic_state242_xforms[] = {
  { &search324, &replace197.value, 0 },
  { &search325, &search44_1.value, 0 },
  { &search423, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state243_xforms[] = {
  { &search325, &search44_1.value, 0 },
  { &search423, &search2_0.value, 0 },
  { &search430, &search354_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state244_xforms[] = {
  { &search280, &replace280.value, 0 },
  { &search281, &replace281.value, 0 },
  { &search423, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state245_xforms[] = {
  { &search423, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state246_xforms[] = {
  { &search423, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state247_xforms[] = {
  { &search423, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state248_xforms[] = {
  { &search280, &replace280.value, 0 },
  { &search281, &replace281.value, 0 },
  { &search284, &replace280.value, 0 },
  { &search423, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state249_xforms[] = {
  { &search212, &replace212.value, 19 },
  { &search280, &replace280.value, 0 },
  { &search281, &replace281.value, 0 },
  { &search312, &replace312.value, 0 },
  { &search313, &replace312.value, 0 },
  { &search423, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state250_xforms[] = {
  { &search212, &replace212.value, 19 },
  { &search280, &replace280.value, 0 },
  { &search281, &replace281.value, 0 },
  { &search284, &replace280.value, 0 },
  { &search312, &replace312.value, 0 },
  { &search313, &replace312.value, 0 },
  { &search423, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state251_xforms[] = {
  { &search280, &replace280.value, 0 },
  { &search281, &replace281.value, 0 },
  { &search285, &replace281.value, 0 },
  { &search423, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state252_xforms[] = {
  { &search212, &replace212.value, 19 },
  { &search280, &replace280.value, 0 },
  { &search281, &replace281.value, 0 },
  { &search285, &replace281.value, 0 },
  { &search312, &replace312.value, 0 },
  { &search313, &replace312.value, 0 },
  { &search423, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state253_xforms[] = {
  { &search212, &replace212.value, 19 },
  { &search280, &replace280.value, 0 },
  { &search281, &replace281.value, 0 },
  { &search284, &replace280.value, 0 },
  { &search285, &replace281.value, 0 },
  { &search312, &replace312.value, 0 },
  { &search313, &replace312.value, 0 },
  { &search423, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state254_xforms[] = {
  { &search282, &replace282.value, 0 },
  { &search283, &replace283.value, 0 },
  { &search423, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state255_xforms[] = {
  { &search423, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state256_xforms[] = {
  { &search423, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state257_xforms[] = {
  { &search282, &replace282.value, 0 },
  { &search283, &replace283.value, 0 },
  { &search286, &replace282.value, 0 },
  { &search423, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state258_xforms[] = {
  { &search282, &replace282.value, 0 },
  { &search283, &replace283.value, 0 },
  { &search314, &replace314.value, 0 },
  { &search315, &replace314.value, 0 },
  { &search423, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state259_xforms[] = {
  { &search282, &replace282.value, 0 },
  { &search283, &replace283.value, 0 },
  { &search286, &replace282.value, 0 },
  { &search314, &replace314.value, 0 },
  { &search315, &replace314.value, 0 },
  { &search423, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state260_xforms[] = {
  { &search282, &replace282.value, 0 },
  { &search283, &replace283.value, 0 },
  { &search287, &replace283.value, 0 },
  { &search423, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state261_xforms[] = {
  { &search282, &replace282.value, 0 },
  { &search283, &replace283.value, 0 },
  { &search287, &replace283.value, 0 },
  { &search314, &replace314.value, 0 },
  { &search315, &replace314.value, 0 },
  { &search423, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state262_xforms[] = {
  { &search282, &replace282.value, 0 },
  { &search283, &replace283.value, 0 },
  { &search286, &replace282.value, 0 },
  { &search287, &replace283.value, 0 },
  { &search314, &replace314.value, 0 },
  { &search315, &replace314.value, 0 },
  { &search423, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state263_xforms[] = {
  { &search423, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state264_xforms[] = {
  { &search423, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state265_xforms[] = {
  { &search423, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state266_xforms[] = {
  { &search296, &replace296.value, 0 },
  { &search297, &replace297.value, 0 },
  { &search423, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state267_xforms[] = {
  { &search300, &replace300.value, 0 },
  { &search301, &replace301.value, 0 },
  { &search423, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state268_xforms[] = {
  { &search298, &replace298.value, 0 },
  { &search299, &replace299.value, 0 },
  { &search423, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state269_xforms[] = {
  { &search302, &replace302.value, 0 },
  { &search303, &replace303.value, 0 },
  { &search423, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state270_xforms[] = {
  { &search321, &replace321.value, 0 },
  { &search322, &replace322.value, 0 },
  { &search324, &replace197.value, 0 },
  { &search423, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state271_xforms[] = {
  { &search320, &replace320.value, 0 },
  { &search324, &replace197.value, 0 },
  { &search423, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state272_xforms[] = {
  { &search324, &replace197.value, 0 },
  { &search423, &search2_0.value, 0 },
  { &search430, &search354_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state273_xforms[] = {
  { &search513, &search449_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state275_xforms[] = {
  { &search439, &search193_1.value, 0 },
  { &search513, &search449_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state276_xforms[] = {
  { &search439, &search193_1.value, 0 },
};
static const struct transform nir_opt_algebraic_state277_xforms[] = {
  { &search440, &search2_0.value, 0 },
  { &search565, &replace565.value, 32 },
  { &search441_1, &replace566.value, 32 },
  { &search567, &replace567.value, 32 },
  { &search623, &replace623.value, 33 },
  { &search442_1, &replace624.value, 33 },
};
static const struct transform nir_opt_algebraic_state278_xforms[] = {
  { &search99, &replace99.value, 0 },
  { &search102, &replace102.value, 0 },
  { &search105, &replace105.value, 0 },
  { &search108, &replace108.value, 0 },
  { &search440, &search2_0.value, 0 },
  { &search565, &replace565.value, 32 },
  { &search441_1, &replace566.value, 32 },
  { &search567, &replace567.value, 32 },
  { &search442_1, &replace624.value, 33 },
};
static const struct transform nir_opt_algebraic_state279_xforms[] = {
  { &search512, &replace512.value, 0 },
};
static const struct transform nir_opt_algebraic_state280_xforms[] = {
  { &search437, &search193_1.value, 0 },
  { &search512, &replace512.value, 0 },
};
static const struct transform nir_opt_algebraic_state281_xforms[] = {
  { &search438, &search2_0.value, 0 },
  { &search568, &replace568.value, 32 },
  { &search569, &replace569.value, 32 },
  { &search570, &replace570.value, 32 },
  { &search625, &replace625.value, 33 },
  { &search591_0, &replace626.value, 33 },
};
static const struct transform nir_opt_algebraic_state283_xforms[] = {
  { &search438, &search2_0.value, 0 },
  { &search568, &replace568.value, 32 },
  { &search569, &replace569.value, 32 },
  { &search570, &replace570.value, 32 },
  { &search591_0, &replace626.value, 33 },
};
static const struct transform nir_opt_algebraic_state284_xforms[] = {
  { &search512, &replace512.value, 0 },
};
static const struct transform nir_opt_algebraic_state285_xforms[] = {
  { &search100, &replace100.value, 0 },
  { &search103, &replace103.value, 0 },
  { &search106, &replace106.value, 0 },
  { &search109, &replace109.value, 0 },
  { &search438, &search2_0.value, 0 },
  { &search568, &replace568.value, 32 },
  { &search569, &replace569.value, 32 },
  { &search570, &replace570.value, 32 },
  { &search591_0, &replace626.value, 33 },
};
static const struct transform nir_opt_algebraic_state286_xforms[] = {
  { &search601, &replace601.value, 0 },
  { &search602, &replace580.value, 0 },
  { &search603, &replace579.value, 0 },
  { &search604, &replace604.value, 0 },
  { &search605, &replace587.value, 0 },
  { &search606, &replace586.value, 0 },
  { &search607, &replace585.value, 0 },
  { &search608, &replace584.value, 0 },
  { &search609, &replace583.value, 0 },
  { &search610, &replace582.value, 0 },
  { &search611, &replace611.value, 0 },
  { &search686, &replace686.value, 48 },
};
static const struct transform nir_opt_algebraic_state287_xforms[] = {
  { &search578, &replace565.value, 0 },
  { &search579, &replace579.value, 0 },
  { &search580, &replace580.value, 0 },
  { &search581, &replace566.value, 0 },
  { &search582, &replace582.value, 0 },
  { &search583, &replace583.value, 0 },
  { &search584, &replace584.value, 0 },
  { &search585, &replace585.value, 0 },
  { &search586, &replace586.value, 0 },
  { &search587, &replace587.value, 0 },
  { &search588, &replace567.value, 0 },
  { &search686, &replace686.value, 48 },
};
static const struct transform nir_opt_algebraic_state288_xforms[] = {
  { &search589, &replace565.value, 0 },
  { &search590, &replace579.value, 0 },
  { &search591, &replace580.value, 0 },
  { &search592, &replace566.value, 0 },
  { &search593, &replace582.value, 0 },
  { &search594, &replace583.value, 0 },
  { &search595, &replace584.value, 0 },
  { &search596, &replace585.value, 0 },
  { &search597, &replace586.value, 0 },
  { &search598, &replace587.value, 0 },
  { &search599, &replace567.value, 0 },
  { &search686, &replace686.value, 48 },
};
static const struct transform nir_opt_algebraic_state289_xforms[] = {
  { &search600, &replace600.value, 0 },
  { &search686, &replace686.value, 48 },
};
static const struct transform nir_opt_algebraic_state290_xforms[] = {
  { &search612, &replace612.value, 0 },
  { &search613, &replace613.value, 0 },
  { &search614, &replace614.value, 0 },
  { &search615, &replace615.value, 0 },
  { &search616, &replace616.value, 0 },
  { &search617, &replace617.value, 0 },
  { &search618, &replace618.value, 0 },
  { &search619, &replace619.value, 0 },
  { &search620, &replace620.value, 0 },
  { &search621, &replace621.value, 0 },
  { &search622, &replace622.value, 0 },
  { &search685, &replace685.value, 48 },
};
static const struct transform nir_opt_algebraic_state291_xforms[] = {
  { &search563, &search57_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state292_xforms[] = {
  { &search3, &replace3.value, 0 },
};
static const struct transform nir_opt_algebraic_state293_xforms[] = {
  { &search4, &replace3.value, 0 },
};
static const struct transform nir_opt_algebraic_state294_xforms[] = {
  { &search574, &search563_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state295_xforms[] = {
  { &search561, &search0_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state296_xforms[] = {
  { &search15, &search2_0.value, 0 },
  { &search15_0, &replace634.value, 35 },
};
static const struct transform nir_opt_algebraic_state297_xforms[] = {
  { &search15_0, &replace634.value, 35 },
};
static const struct transform nir_opt_algebraic_state298_xforms[] = {
  { &search15_0, &replace634.value, 35 },
};
static const struct transform nir_opt_algebraic_state299_xforms[] = {
  { &search15_0, &replace634.value, 35 },
};
static const struct transform nir_opt_algebraic_state300_xforms[] = {
  { &search15_0, &replace634.value, 35 },
};
static const struct transform nir_opt_algebraic_state301_xforms[] = {
  { &search15_0, &replace634.value, 35 },
};
static const struct transform nir_opt_algebraic_state302_xforms[] = {
  { &search15_0, &replace634.value, 35 },
};
static const struct transform nir_opt_algebraic_state303_xforms[] = {
  { &search15_0, &replace634.value, 35 },
};
static const struct transform nir_opt_algebraic_state304_xforms[] = {
  { &search18, &search17_0.value, 0 },
  { &search528, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state305_xforms[] = {
  { &search17, &search17_0.value, 0 },
  { &search528, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state306_xforms[] = {
  { &search19, &search19_0.value, 0 },
  { &search528, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state307_xforms[] = {
  { &search528, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state308_xforms[] = {
  { &search375, &search375_0.value, 0 },
  { &search528, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state309_xforms[] = {
  { &search376, &search376_0.value, 0 },
  { &search528, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state310_xforms[] = {
  { &search377, &search377_0.value, 0 },
  { &search528, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state311_xforms[] = {
  { &search378, &search378_0.value, 0 },
  { &search528, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state312_xforms[] = {
  { &search528, &search2_0.value, 0 },
  { &search638, &search17_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state313_xforms[] = {
  { &search528, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state314_xforms[] = {
  { &search22, &replace22.value, 0 },
};
static const struct transform nir_opt_algebraic_state315_xforms[] = {
  { &search727, &replace80_0.value, 0 },
  { &search729, &search0_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state316_xforms[] = {
  { &search30, &search24_1.value, 0 },
};
static const struct transform nir_opt_algebraic_state317_xforms[] = {
  { &search79, &search78.value, 15 },
};
static const struct transform nir_opt_algebraic_state318_xforms[] = {
  { &search636, &search632.value, 0 },
};
static const struct transform nir_opt_algebraic_state319_xforms[] = {
  { &search24, &search2_0.value, 0 },
  { &search30, &search24_1.value, 0 },
};
static const struct transform nir_opt_algebraic_state320_xforms[] = {
  { &search24, &search2_0.value, 0 },
  { &search644, &replace644.value, 0 },
};
static const struct transform nir_opt_algebraic_state321_xforms[] = {
  { &search24, &search2_0.value, 0 },
  { &search644, &replace644.value, 0 },
  { &search648, &replace644.value, 0 },
};
static const struct transform nir_opt_algebraic_state322_xforms[] = {
  { &search24, &search2_0.value, 0 },
  { &search79, &search78.value, 15 },
};
static const struct transform nir_opt_algebraic_state323_xforms[] = {
  { &search24, &search2_0.value, 0 },
  { &search1077, &replace1077.value, 0 },
};
static const struct transform nir_opt_algebraic_state324_xforms[] = {
  { &search24, &search2_0.value, 0 },
  { &search636, &search632.value, 0 },
};
static const struct transform nir_opt_algebraic_state325_xforms[] = {
  { &search30, &search24_1.value, 0 },
  { &search34, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state326_xforms[] = {
  { &search30, &search24_1.value, 0 },
  { &search79, &search78.value, 15 },
};
static const struct transform nir_opt_algebraic_state327_xforms[] = {
  { &search30, &search24_1.value, 0 },
  { &search636, &search632.value, 0 },
};
static const struct transform nir_opt_algebraic_state328_xforms[] = {
  { &search28, &replace28.value, 0 },
  { &search79, &search78.value, 15 },
};
static const struct transform nir_opt_algebraic_state329_xforms[] = {
  { &search79, &search78.value, 15 },
  { &search636, &search632.value, 0 },
};
static const struct transform nir_opt_algebraic_state331_xforms[] = {
  { &search640, &replace640.value, 0 },
};
static const struct transform nir_opt_algebraic_state336_xforms[] = {
  { &search37, &search24_1.value, 0 },
  { &search41, &search2_0.value, 0 },
  { &search43, &search15_0.value, 0 },
  { &search640, &replace640.value, 0 },
};
static const struct transform nir_opt_algebraic_state337_xforms[] = {
  { &search37, &search24_1.value, 0 },
  { &search41, &search2_0.value, 0 },
  { &search43, &search15_0.value, 0 },
  { &search642, &replace642.value, 0 },
};
static const struct transform nir_opt_algebraic_state338_xforms[] = {
  { &search37, &search24_1.value, 0 },
  { &search41, &search2_0.value, 0 },
  { &search43, &search15_0.value, 0 },
  { &search642, &replace642.value, 0 },
  { &search646, &replace642.value, 0 },
};
static const struct transform nir_opt_algebraic_state339_xforms[] = {
  { &search37, &search24_1.value, 0 },
  { &search41, &search2_0.value, 0 },
  { &search43, &search15_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state340_xforms[] = {
  { &search37, &search24_1.value, 0 },
  { &search41, &search2_0.value, 0 },
  { &search43, &search15_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state341_xforms[] = {
  { &search37, &search24_1.value, 0 },
  { &search41, &search2_0.value, 0 },
  { &search43, &search15_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state342_xforms[] = {
  { &search37, &search24_1.value, 0 },
  { &search41, &search2_0.value, 0 },
  { &search43, &search15_0.value, 0 },
  { &search1078, &replace1078.value, 0 },
};
static const struct transform nir_opt_algebraic_state343_xforms[] = {
  { &search37, &search24_1.value, 0 },
  { &search41, &search2_0.value, 0 },
  { &search43, &search15_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state344_xforms[] = {
  { &search640, &replace640.value, 0 },
};
static const struct transform nir_opt_algebraic_state345_xforms[] = {
  { &search640, &replace640.value, 0 },
};
static const struct transform nir_opt_algebraic_state346_xforms[] = {
  { &search640, &replace640.value, 0 },
};
static const struct transform nir_opt_algebraic_state347_xforms[] = {
  { &search640, &replace640.value, 0 },
};
static const struct transform nir_opt_algebraic_state348_xforms[] = {
  { &search45, &replace45.value, 0 },
};
static const struct transform nir_opt_algebraic_state355_xforms[] = {
  { &search408, &replace215.value, 0 },
};
static const struct transform nir_opt_algebraic_state357_xforms[] = {
  { &search475, &replace475.value, 0 },
};
static const struct transform nir_opt_algebraic_state358_xforms[] = {
  { &search36_0, &replace269.value, 21 },
  { &search530, &search24_1.value, 0 },
};
static const struct transform nir_opt_algebraic_state359_xforms[] = {
  { &search36_0, &replace269.value, 21 },
  { &search270, &search36_0.value, 0 },
  { &search530, &search24_1.value, 0 },
};
static const struct transform nir_opt_algebraic_state360_xforms[] = {
  { &search267, &replace267.value, 0 },
  { &search36_0, &replace269.value, 21 },
  { &search530, &search24_1.value, 0 },
};
static const struct transform nir_opt_algebraic_state361_xforms[] = {
  { &search268, &search268_0.value, 0 },
  { &search36_0, &replace269.value, 21 },
  { &search530, &search24_1.value, 0 },
};
static const struct transform nir_opt_algebraic_state362_xforms[] = {
  { &search172, &replace65_0.value, 0 },
  { &search546, &replace121.value, 0 },
  { &search547, &replace197.value, 0 },
  { &search548, &replace197.value, 0 },
  { &search549, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state363_xforms[] = {
  { &search329, &replace329.value, 0 },
  { &search546, &replace121.value, 0 },
  { &search547, &replace197.value, 0 },
  { &search548, &replace197.value, 0 },
  { &search549, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state364_xforms[] = {
  { &search333, &replace121.value, 0 },
  { &search546, &replace121.value, 0 },
  { &search547, &replace197.value, 0 },
  { &search548, &replace197.value, 0 },
  { &search549, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state365_xforms[] = {
  { &search131, &replace131.value, 0 },
  { &search172, &replace65_0.value, 0 },
  { &search546, &replace121.value, 0 },
  { &search547, &replace197.value, 0 },
  { &search548, &replace197.value, 0 },
  { &search549, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state366_xforms[] = {
  { &search207, &replace207.value, 0 },
  { &search546, &replace121.value, 0 },
  { &search547, &replace197.value, 0 },
  { &search548, &replace197.value, 0 },
  { &search549, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state367_xforms[] = {
  { &search200, &replace200.value, 0 },
  { &search546, &replace121.value, 0 },
  { &search547, &replace197.value, 0 },
  { &search548, &replace197.value, 0 },
  { &search549, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state368_xforms[] = {
  { &search137, &replace137.value, 0 },
  { &search145, &replace145.value, 0 },
  { &search546, &replace121.value, 0 },
  { &search547, &replace197.value, 0 },
  { &search548, &replace197.value, 0 },
  { &search549, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state369_xforms[] = {
  { &search329, &replace329.value, 0 },
  { &search546, &replace121.value, 0 },
  { &search547, &replace197.value, 0 },
  { &search548, &replace197.value, 0 },
  { &search549, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state370_xforms[] = {
  { &search546, &replace121.value, 0 },
  { &search547, &replace197.value, 0 },
  { &search548, &replace197.value, 0 },
  { &search549, &replace121.value, 0 },
  { &search1058, &replace1058.value, 0 },
};
static const struct transform nir_opt_algebraic_state371_xforms[] = {
  { &search333, &replace121.value, 0 },
  { &search546, &replace121.value, 0 },
  { &search547, &replace197.value, 0 },
  { &search548, &replace197.value, 0 },
  { &search549, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state372_xforms[] = {
  { &search206, &replace206.value, 0 },
  { &search546, &replace121.value, 0 },
  { &search547, &replace197.value, 0 },
  { &search548, &replace197.value, 0 },
  { &search549, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state373_xforms[] = {
  { &search130, &replace130.value, 0 },
  { &search546, &replace121.value, 0 },
  { &search547, &replace197.value, 0 },
  { &search548, &replace197.value, 0 },
  { &search549, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state374_xforms[] = {
  { &search126, &search122_1.value, 0 },
  { &search172, &replace65_0.value, 0 },
  { &search546, &replace121.value, 0 },
  { &search547, &replace197.value, 0 },
  { &search548, &replace197.value, 0 },
  { &search549, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state375_xforms[] = {
  { &search199, &replace121.value, 0 },
  { &search546, &replace121.value, 0 },
  { &search547, &replace197.value, 0 },
  { &search548, &replace197.value, 0 },
  { &search549, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state376_xforms[] = {
  { &search175, &replace175.value, 0 },
  { &search546, &replace121.value, 0 },
  { &search547, &replace197.value, 0 },
  { &search548, &replace197.value, 0 },
  { &search549, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state377_xforms[] = {
  { &search175, &replace175.value, 0 },
  { &search546, &replace121.value, 0 },
  { &search547, &replace197.value, 0 },
  { &search548, &replace197.value, 0 },
  { &search549, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state378_xforms[] = {
  { &search172, &replace65_0.value, 0 },
  { &search175, &replace175.value, 0 },
  { &search546, &replace121.value, 0 },
  { &search547, &replace197.value, 0 },
  { &search548, &replace197.value, 0 },
  { &search549, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state379_xforms[] = {
  { &search175, &replace175.value, 0 },
  { &search329, &replace329.value, 0 },
  { &search546, &replace121.value, 0 },
  { &search547, &replace197.value, 0 },
  { &search548, &replace197.value, 0 },
  { &search549, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state380_xforms[] = {
  { &search175, &replace175.value, 0 },
  { &search333, &replace121.value, 0 },
  { &search546, &replace121.value, 0 },
  { &search547, &replace197.value, 0 },
  { &search548, &replace197.value, 0 },
  { &search549, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state381_xforms[] = {
  { &search175, &replace175.value, 0 },
  { &search179, &replace179.value, 0 },
  { &search546, &replace121.value, 0 },
  { &search547, &replace197.value, 0 },
  { &search548, &replace197.value, 0 },
  { &search549, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state382_xforms[] = {
  { &search136, &search111_0.value, 0 },
  { &search143, &replace131.value, 0 },
  { &search546, &replace121.value, 0 },
  { &search547, &replace197.value, 0 },
  { &search548, &replace197.value, 0 },
  { &search549, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state383_xforms[] = {
  { &search334, &replace121.value, 0 },
  { &search546, &replace121.value, 0 },
  { &search547, &replace197.value, 0 },
  { &search548, &replace197.value, 0 },
  { &search549, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state384_xforms[] = {
  { &search334, &replace121.value, 0 },
  { &search546, &replace121.value, 0 },
  { &search547, &replace197.value, 0 },
  { &search548, &replace197.value, 0 },
  { &search549, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state385_xforms[] = {
  { &search172, &replace65_0.value, 0 },
  { &search334, &replace121.value, 0 },
  { &search546, &replace121.value, 0 },
  { &search547, &replace197.value, 0 },
  { &search548, &replace197.value, 0 },
  { &search549, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state386_xforms[] = {
  { &search329, &replace329.value, 0 },
  { &search334, &replace121.value, 0 },
  { &search546, &replace121.value, 0 },
  { &search547, &replace197.value, 0 },
  { &search548, &replace197.value, 0 },
  { &search549, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state387_xforms[] = {
  { &search333, &replace121.value, 0 },
  { &search334, &replace121.value, 0 },
  { &search546, &replace121.value, 0 },
  { &search547, &replace197.value, 0 },
  { &search548, &replace197.value, 0 },
  { &search549, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state388_xforms[] = {
  { &search546, &replace121.value, 0 },
  { &search547, &replace197.value, 0 },
  { &search548, &replace197.value, 0 },
  { &search549, &replace121.value, 0 },
  { &search1057, &replace1057.value, 0 },
};
static const struct transform nir_opt_algebraic_state389_xforms[] = {
  { &search330, &search122_1.value, 0 },
  { &search546, &replace121.value, 0 },
  { &search547, &replace197.value, 0 },
  { &search548, &replace197.value, 0 },
  { &search549, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state390_xforms[] = {
  { &search330, &search122_1.value, 0 },
  { &search546, &replace121.value, 0 },
  { &search547, &replace197.value, 0 },
  { &search548, &replace197.value, 0 },
  { &search549, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state391_xforms[] = {
  { &search172, &replace65_0.value, 0 },
  { &search330, &search122_1.value, 0 },
  { &search546, &replace121.value, 0 },
  { &search547, &replace197.value, 0 },
  { &search548, &replace197.value, 0 },
  { &search549, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state392_xforms[] = {
  { &search329, &replace329.value, 0 },
  { &search330, &search122_1.value, 0 },
  { &search546, &replace121.value, 0 },
  { &search547, &replace197.value, 0 },
  { &search548, &replace197.value, 0 },
  { &search549, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state393_xforms[] = {
  { &search330, &search122_1.value, 0 },
  { &search333, &replace121.value, 0 },
  { &search546, &replace121.value, 0 },
  { &search547, &replace197.value, 0 },
  { &search548, &replace197.value, 0 },
  { &search549, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state394_xforms[] = {
  { &search205, &replace205.value, 0 },
  { &search546, &replace121.value, 0 },
  { &search547, &replace197.value, 0 },
  { &search548, &replace197.value, 0 },
  { &search549, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state395_xforms[] = {
  { &search546, &replace121.value, 0 },
  { &search547, &replace197.value, 0 },
  { &search548, &replace197.value, 0 },
  { &search549, &replace121.value, 0 },
  { &search1026, &replace1026.value, 0 },
  { &search1028, &replace1028.value, 0 },
  { &search1032, &replace1026.value, 0 },
  { &search1034, &replace1028.value, 0 },
  { &search1038, &replace1038.value, 0 },
  { &search1040, &replace1040.value, 0 },
  { &search1044, &replace1044.value, 0 },
  { &search1046, &replace1046.value, 0 },
};
static const struct transform nir_opt_algebraic_state396_xforms[] = {
  { &search173, &replace173.value, 0 },
  { &search542, &replace197.value, 0 },
  { &search543, &replace121.value, 0 },
  { &search544, &replace121.value, 0 },
  { &search545, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state397_xforms[] = {
  { &search335, &replace335.value, 0 },
  { &search542, &replace197.value, 0 },
  { &search543, &replace121.value, 0 },
  { &search544, &replace121.value, 0 },
  { &search545, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state398_xforms[] = {
  { &search331, &replace197.value, 0 },
  { &search542, &replace197.value, 0 },
  { &search543, &replace121.value, 0 },
  { &search544, &replace121.value, 0 },
  { &search545, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state399_xforms[] = {
  { &search133, &replace133.value, 0 },
  { &search173, &replace173.value, 0 },
  { &search542, &replace197.value, 0 },
  { &search543, &replace121.value, 0 },
  { &search544, &replace121.value, 0 },
  { &search545, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state400_xforms[] = {
  { &search209, &replace209.value, 0 },
  { &search542, &replace197.value, 0 },
  { &search543, &replace121.value, 0 },
  { &search544, &replace121.value, 0 },
  { &search545, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state401_xforms[] = {
  { &search198, &replace198.value, 0 },
  { &search542, &replace197.value, 0 },
  { &search543, &replace121.value, 0 },
  { &search544, &replace121.value, 0 },
  { &search545, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state402_xforms[] = {
  { &search139, &replace139.value, 0 },
  { &search144, &replace144.value, 0 },
  { &search542, &replace197.value, 0 },
  { &search543, &replace121.value, 0 },
  { &search544, &replace121.value, 0 },
  { &search545, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state403_xforms[] = {
  { &search146, &replace146.value, 0 },
  { &search542, &replace197.value, 0 },
  { &search543, &replace121.value, 0 },
  { &search544, &replace121.value, 0 },
  { &search545, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state404_xforms[] = {
  { &search335, &replace335.value, 0 },
  { &search542, &replace197.value, 0 },
  { &search543, &replace121.value, 0 },
  { &search544, &replace121.value, 0 },
  { &search545, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state405_xforms[] = {
  { &search542, &replace197.value, 0 },
  { &search543, &replace121.value, 0 },
  { &search544, &replace121.value, 0 },
  { &search545, &replace197.value, 0 },
  { &search1060, &replace1060.value, 0 },
};
static const struct transform nir_opt_algebraic_state406_xforms[] = {
  { &search331, &replace197.value, 0 },
  { &search542, &replace197.value, 0 },
  { &search543, &replace121.value, 0 },
  { &search544, &replace121.value, 0 },
  { &search545, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state407_xforms[] = {
  { &search204, &replace204.value, 0 },
  { &search542, &replace197.value, 0 },
  { &search543, &replace121.value, 0 },
  { &search544, &replace121.value, 0 },
  { &search545, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state408_xforms[] = {
  { &search132, &replace132.value, 0 },
  { &search542, &replace197.value, 0 },
  { &search543, &replace121.value, 0 },
  { &search544, &replace121.value, 0 },
  { &search545, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state409_xforms[] = {
  { &search127, &replace127.value, 0 },
  { &search173, &replace173.value, 0 },
  { &search542, &replace197.value, 0 },
  { &search543, &replace121.value, 0 },
  { &search544, &replace121.value, 0 },
  { &search545, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state410_xforms[] = {
  { &search197, &replace197.value, 0 },
  { &search542, &replace197.value, 0 },
  { &search543, &replace121.value, 0 },
  { &search544, &replace121.value, 0 },
  { &search545, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state411_xforms[] = {
  { &search176, &replace176.value, 0 },
  { &search542, &replace197.value, 0 },
  { &search543, &replace121.value, 0 },
  { &search544, &replace121.value, 0 },
  { &search545, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state412_xforms[] = {
  { &search176, &replace176.value, 0 },
  { &search542, &replace197.value, 0 },
  { &search543, &replace121.value, 0 },
  { &search544, &replace121.value, 0 },
  { &search545, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state413_xforms[] = {
  { &search173, &replace173.value, 0 },
  { &search176, &replace176.value, 0 },
  { &search542, &replace197.value, 0 },
  { &search543, &replace121.value, 0 },
  { &search544, &replace121.value, 0 },
  { &search545, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state414_xforms[] = {
  { &search176, &replace176.value, 0 },
  { &search335, &replace335.value, 0 },
  { &search542, &replace197.value, 0 },
  { &search543, &replace121.value, 0 },
  { &search544, &replace121.value, 0 },
  { &search545, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state415_xforms[] = {
  { &search176, &replace176.value, 0 },
  { &search331, &replace197.value, 0 },
  { &search542, &replace197.value, 0 },
  { &search543, &replace121.value, 0 },
  { &search544, &replace121.value, 0 },
  { &search545, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state416_xforms[] = {
  { &search176, &replace176.value, 0 },
  { &search181, &replace181.value, 0 },
  { &search542, &replace197.value, 0 },
  { &search543, &replace121.value, 0 },
  { &search544, &replace121.value, 0 },
  { &search545, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state417_xforms[] = {
  { &search138, &replace111.value, 0 },
  { &search142, &replace133.value, 0 },
  { &search542, &replace197.value, 0 },
  { &search543, &replace121.value, 0 },
  { &search544, &replace121.value, 0 },
  { &search545, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state418_xforms[] = {
  { &search332, &replace197.value, 0 },
  { &search542, &replace197.value, 0 },
  { &search543, &replace121.value, 0 },
  { &search544, &replace121.value, 0 },
  { &search545, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state419_xforms[] = {
  { &search332, &replace197.value, 0 },
  { &search542, &replace197.value, 0 },
  { &search543, &replace121.value, 0 },
  { &search544, &replace121.value, 0 },
  { &search545, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state420_xforms[] = {
  { &search173, &replace173.value, 0 },
  { &search332, &replace197.value, 0 },
  { &search542, &replace197.value, 0 },
  { &search543, &replace121.value, 0 },
  { &search544, &replace121.value, 0 },
  { &search545, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state421_xforms[] = {
  { &search332, &replace197.value, 0 },
  { &search335, &replace335.value, 0 },
  { &search542, &replace197.value, 0 },
  { &search543, &replace121.value, 0 },
  { &search544, &replace121.value, 0 },
  { &search545, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state422_xforms[] = {
  { &search331, &replace197.value, 0 },
  { &search332, &replace197.value, 0 },
  { &search542, &replace197.value, 0 },
  { &search543, &replace121.value, 0 },
  { &search544, &replace121.value, 0 },
  { &search545, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state423_xforms[] = {
  { &search542, &replace197.value, 0 },
  { &search543, &replace121.value, 0 },
  { &search544, &replace121.value, 0 },
  { &search545, &replace197.value, 0 },
  { &search1059, &replace1059.value, 0 },
};
static const struct transform nir_opt_algebraic_state424_xforms[] = {
  { &search336, &replace127.value, 0 },
  { &search542, &replace197.value, 0 },
  { &search543, &replace121.value, 0 },
  { &search544, &replace121.value, 0 },
  { &search545, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state425_xforms[] = {
  { &search336, &replace127.value, 0 },
  { &search542, &replace197.value, 0 },
  { &search543, &replace121.value, 0 },
  { &search544, &replace121.value, 0 },
  { &search545, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state426_xforms[] = {
  { &search173, &replace173.value, 0 },
  { &search336, &replace127.value, 0 },
  { &search542, &replace197.value, 0 },
  { &search543, &replace121.value, 0 },
  { &search544, &replace121.value, 0 },
  { &search545, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state427_xforms[] = {
  { &search335, &replace335.value, 0 },
  { &search336, &replace127.value, 0 },
  { &search542, &replace197.value, 0 },
  { &search543, &replace121.value, 0 },
  { &search544, &replace121.value, 0 },
  { &search545, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state428_xforms[] = {
  { &search331, &replace197.value, 0 },
  { &search336, &replace127.value, 0 },
  { &search542, &replace197.value, 0 },
  { &search543, &replace121.value, 0 },
  { &search544, &replace121.value, 0 },
  { &search545, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state429_xforms[] = {
  { &search203, &replace203.value, 0 },
  { &search542, &replace197.value, 0 },
  { &search543, &replace121.value, 0 },
  { &search544, &replace121.value, 0 },
  { &search545, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state430_xforms[] = {
  { &search542, &replace197.value, 0 },
  { &search543, &replace121.value, 0 },
  { &search544, &replace121.value, 0 },
  { &search545, &replace197.value, 0 },
  { &search1025, &replace1025.value, 0 },
  { &search1027, &replace1027.value, 0 },
  { &search1031, &replace1025.value, 0 },
  { &search1033, &replace1027.value, 0 },
  { &search1037, &replace1037.value, 0 },
  { &search1039, &replace1039.value, 0 },
  { &search1043, &replace1043.value, 0 },
  { &search1045, &replace1045.value, 0 },
};
static const struct transform nir_opt_algebraic_state431_xforms[] = {
  { &search406, &replace209.value, 0 },
};
static const struct transform nir_opt_algebraic_state432_xforms[] = {
  { &search177, &replace177.value, 0 },
};
static const struct transform nir_opt_algebraic_state433_xforms[] = {
  { &search135, &replace135.value, 0 },
  { &search406, &replace209.value, 0 },
  { &search541, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state434_xforms[] = {
  { &search196, &replace196.value, 0 },
  { &search541, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state435_xforms[] = {
  { &search177, &replace177.value, 0 },
  { &search541, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state436_xforms[] = {
  { &search177, &replace177.value, 0 },
  { &search183, &replace183.value, 0 },
  { &search541, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state437_xforms[] = {
  { &search140, &search113_0.value, 0 },
  { &search541, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state438_xforms[] = {
  { &search191, &replace146.value, 0 },
  { &search541, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state439_xforms[] = {
  { &search541, &replace121.value, 0 },
  { &search1061, &replace1061.value, 0 },
  { &search1062, &replace1062.value, 0 },
};
static const struct transform nir_opt_algebraic_state440_xforms[] = {
  { &search202, &replace196.value, 0 },
  { &search541, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state441_xforms[] = {
  { &search128, &replace128.value, 0 },
  { &search406, &replace209.value, 0 },
};
static const struct transform nir_opt_algebraic_state442_xforms[] = {
  { &search177, &replace177.value, 0 },
  { &search406, &replace209.value, 0 },
};
static const struct transform nir_opt_algebraic_state443_xforms[] = {
  { &search166, &replace165.value, 0 },
};
static const struct transform nir_opt_algebraic_state444_xforms[] = {
  { &search1023, &replace1023.value, 0 },
  { &search1029, &replace1023.value, 0 },
  { &search1035, &replace1035.value, 0 },
  { &search1041, &replace1041.value, 0 },
};
static const struct transform nir_opt_algebraic_state445_xforms[] = {
  { &search405, &replace207.value, 0 },
};
static const struct transform nir_opt_algebraic_state446_xforms[] = {
  { &search178, &replace178.value, 0 },
};
static const struct transform nir_opt_algebraic_state447_xforms[] = {
  { &search134, &replace134.value, 0 },
  { &search405, &replace207.value, 0 },
  { &search540, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state448_xforms[] = {
  { &search195, &replace195.value, 0 },
  { &search540, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state449_xforms[] = {
  { &search178, &replace178.value, 0 },
  { &search540, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state450_xforms[] = {
  { &search178, &replace178.value, 0 },
  { &search185, &replace185.value, 0 },
  { &search540, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state451_xforms[] = {
  { &search141, &replace113.value, 0 },
  { &search540, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state452_xforms[] = {
  { &search192, &replace80_0.value, 0 },
  { &search540, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state453_xforms[] = {
  { &search540, &replace197.value, 0 },
  { &search1063, &replace1063.value, 0 },
  { &search1064, &replace1064.value, 0 },
};
static const struct transform nir_opt_algebraic_state454_xforms[] = {
  { &search201, &replace195.value, 0 },
  { &search540, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state455_xforms[] = {
  { &search129, &replace129.value, 0 },
  { &search405, &replace207.value, 0 },
};
static const struct transform nir_opt_algebraic_state456_xforms[] = {
  { &search178, &replace178.value, 0 },
  { &search405, &replace207.value, 0 },
};
static const struct transform nir_opt_algebraic_state457_xforms[] = {
  { &search156, &replace155.value, 0 },
};
static const struct transform nir_opt_algebraic_state458_xforms[] = {
  { &search1024, &replace1024.value, 0 },
  { &search1030, &replace1024.value, 0 },
  { &search1036, &replace1036.value, 0 },
  { &search1042, &replace1042.value, 0 },
};
static const struct transform nir_opt_algebraic_state459_xforms[] = {
  { &search237, &search2_0.value, 0 },
  { &search248, &search17_0.value, 0 },
  { &search248, &search17_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state460_xforms[] = {
  { &search237, &search2_0.value, 0 },
  { &search258, &search17_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state461_xforms[] = {
  { &search237, &search2_0.value, 0 },
  { &search262, &search17_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state462_xforms[] = {
  { &search237, &search2_0.value, 0 },
  { &search277, &replace277.value, 0 },
};
static const struct transform nir_opt_algebraic_state463_xforms[] = {
  { &search213, &replace213.value, 0 },
  { &search237, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state464_xforms[] = {
  { &search237, &search2_0.value, 0 },
  { &search242, &replace221.value, 0 },
};
static const struct transform nir_opt_algebraic_state465_xforms[] = {
  { &search237, &search2_0.value, 0 },
  { &search242, &replace221.value, 0 },
};
static const struct transform nir_opt_algebraic_state466_xforms[] = {
  { &search237, &search2_0.value, 0 },
  { &search242, &replace221.value, 0 },
  { &search248, &search17_0.value, 0 },
  { &search248, &search17_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state467_xforms[] = {
  { &search237, &search2_0.value, 0 },
  { &search242, &replace221.value, 0 },
  { &search258, &search17_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state468_xforms[] = {
  { &search237, &search2_0.value, 0 },
  { &search264, &search36_0.value, 19 },
  { &search266, &replace265.value, 20 },
};
static const struct transform nir_opt_algebraic_state469_xforms[] = {
  { &search236, &search2_0.value, 0 },
  { &search250, &search208_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state470_xforms[] = {
  { &search236, &search2_0.value, 0 },
  { &search254, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state471_xforms[] = {
  { &search236, &search2_0.value, 0 },
  { &search278, &replace278.value, 0 },
  { &search535, &search36_0.value, 19 },
};
static const struct transform nir_opt_algebraic_state472_xforms[] = {
  { &search217, &replace217.value, 0 },
  { &search236, &search2_0.value, 0 },
  { &search535, &search36_0.value, 19 },
};
static const struct transform nir_opt_algebraic_state473_xforms[] = {
  { &search215, &replace215.value, 0 },
  { &search236, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state474_xforms[] = {
  { &search236, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state475_xforms[] = {
  { &search236, &search2_0.value, 0 },
  { &search535, &search36_0.value, 19 },
};
static const struct transform nir_opt_algebraic_state476_xforms[] = {
  { &search236, &search2_0.value, 0 },
  { &search250, &search208_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state477_xforms[] = {
  { &search236, &search2_0.value, 0 },
  { &search254, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state478_xforms[] = {
  { &search236, &search2_0.value, 0 },
  { &search263, &search36_0.value, 19 },
  { &search265, &replace265.value, 20 },
  { &search535, &search36_0.value, 19 },
};
static const struct transform nir_opt_algebraic_state479_xforms[] = {
  { &search236, &search2_0.value, 0 },
  { &search245, &replace222.value, 0 },
};
static const struct transform nir_opt_algebraic_state480_xforms[] = {
  { &search236, &search2_0.value, 0 },
  { &search245, &replace222.value, 0 },
  { &search535, &search36_0.value, 19 },
};
static const struct transform nir_opt_algebraic_state481_xforms[] = {
  { &search236, &search2_0.value, 0 },
  { &search245, &replace222.value, 0 },
  { &search250, &search208_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state482_xforms[] = {
  { &search236, &search2_0.value, 0 },
  { &search245, &replace222.value, 0 },
  { &search254, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state483_xforms[] = {
  { &search16, &search2_0.value, 0 },
  { &search16_0, &replace635.value, 35 },
};
static const struct transform nir_opt_algebraic_state484_xforms[] = {
  { &search16_0, &replace635.value, 35 },
};
static const struct transform nir_opt_algebraic_state485_xforms[] = {
  { &search411, &search0_0.value, 0 },
  { &search16_0, &replace635.value, 35 },
};
static const struct transform nir_opt_algebraic_state486_xforms[] = {
  { &search16_0, &replace635.value, 35 },
};
static const struct transform nir_opt_algebraic_state487_xforms[] = {
  { &search21, &search20_0.value, 0 },
  { &search529, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state488_xforms[] = {
  { &search20, &search20_0.value, 0 },
  { &search529, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state489_xforms[] = {
  { &search529, &search2_0.value, 0 },
  { &search639, &search20_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state490_xforms[] = {
  { &search23, &replace23.value, 0 },
  { &search485, &replace485.value, 0 },
  { &search486, &replace195.value, 0 },
  { &search23, &replace23.value, 0 },
};
static const struct transform nir_opt_algebraic_state491_xforms[] = {
  { &search485, &replace485.value, 0 },
  { &search486, &replace195.value, 0 },
  { &search518, &replace23.value, 0 },
};
static const struct transform nir_opt_algebraic_state492_xforms[] = {
  { &search485, &replace485.value, 0 },
  { &search486, &replace195.value, 0 },
  { &search514, &search0_0.value, 0 },
  { &search728, &replace80_0.value, 0 },
  { &search514, &search0_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state493_xforms[] = {
  { &search238, &search2_0.value, 0 },
  { &search251, &replace251.value, 0 },
};
static const struct transform nir_opt_algebraic_state494_xforms[] = {
  { &search238, &search2_0.value, 0 },
  { &search255, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state495_xforms[] = {
  { &search238, &search2_0.value, 0 },
  { &search247, &replace247.value, 0 },
};
static const struct transform nir_opt_algebraic_state496_xforms[] = {
  { &search238, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state497_xforms[] = {
  { &search238, &search2_0.value, 0 },
  { &search251, &replace251.value, 0 },
};
static const struct transform nir_opt_algebraic_state498_xforms[] = {
  { &search238, &search2_0.value, 0 },
  { &search255, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state499_xforms[] = {
  { &search238, &search2_0.value, 0 },
  { &search247, &replace247.value, 0 },
};
static const struct transform nir_opt_algebraic_state500_xforms[] = {
  { &search238, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state501_xforms[] = {
  { &search238, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state502_xforms[] = {
  { &search238, &search2_0.value, 0 },
  { &search251, &replace251.value, 0 },
  { &search255, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state503_xforms[] = {
  { &search238, &search2_0.value, 0 },
  { &search247, &replace247.value, 0 },
  { &search251, &replace251.value, 0 },
};
static const struct transform nir_opt_algebraic_state504_xforms[] = {
  { &search238, &search2_0.value, 0 },
  { &search251, &replace251.value, 0 },
};
static const struct transform nir_opt_algebraic_state505_xforms[] = {
  { &search238, &search2_0.value, 0 },
  { &search247, &replace247.value, 0 },
  { &search255, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state506_xforms[] = {
  { &search238, &search2_0.value, 0 },
  { &search255, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state507_xforms[] = {
  { &search238, &search2_0.value, 0 },
  { &search247, &replace247.value, 0 },
};
static const struct transform nir_opt_algebraic_state508_xforms[] = {
  { &search239, &search2_0.value, 0 },
  { &search249, &search20_0.value, 0 },
  { &search249, &search20_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state509_xforms[] = {
  { &search239, &search2_0.value, 0 },
  { &search259, &search20_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state510_xforms[] = {
  { &search239, &search2_0.value, 0 },
  { &search244, &replace244.value, 0 },
};
static const struct transform nir_opt_algebraic_state511_xforms[] = {
  { &search239, &search2_0.value, 0 },
  { &search249, &search20_0.value, 0 },
  { &search249, &search20_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state512_xforms[] = {
  { &search239, &search2_0.value, 0 },
  { &search259, &search20_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state513_xforms[] = {
  { &search239, &search2_0.value, 0 },
  { &search244, &replace244.value, 0 },
};
static const struct transform nir_opt_algebraic_state514_xforms[] = {
  { &search239, &search2_0.value, 0 },
  { &search249, &search20_0.value, 0 },
  { &search259, &search20_0.value, 0 },
  { &search249, &search20_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state515_xforms[] = {
  { &search239, &search2_0.value, 0 },
  { &search244, &replace244.value, 0 },
  { &search249, &search20_0.value, 0 },
  { &search249, &search20_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state516_xforms[] = {
  { &search239, &search2_0.value, 0 },
  { &search244, &replace244.value, 0 },
  { &search259, &search20_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state517_xforms[] = {
  { &search521, &search0_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state518_xforms[] = {
  { &search733, &search510_0_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state519_xforms[] = {
  { &search515, &replace515.value, 0 },
};
static const struct transform nir_opt_algebraic_state520_xforms[] = {
  { &search520, &search0_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state521_xforms[] = {
  { &search523, &search0_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state522_xforms[] = {
  { &search732, &search510_0_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state523_xforms[] = {
  { &search516, &replace516.value, 0 },
};
static const struct transform nir_opt_algebraic_state524_xforms[] = {
  { &search522, &search0_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state525_xforms[] = {
  { &search519, &replace209.value, 0 },
};
static const struct transform nir_opt_algebraic_state526_xforms[] = {
  { &search428, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state527_xforms[] = {
  { &search111, &replace111.value, 0 },
};
static const struct transform nir_opt_algebraic_state528_xforms[] = {
  { &search112, &search111_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state529_xforms[] = {
  { &search113, &replace113.value, 0 },
};
static const struct transform nir_opt_algebraic_state530_xforms[] = {
  { &search114, &search113_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state531_xforms[] = {
  { &search115, &replace115.value, 0 },
};
static const struct transform nir_opt_algebraic_state532_xforms[] = {
  { &search116, &replace116.value, 0 },
};
static const struct transform nir_opt_algebraic_state533_xforms[] = {
  { &search117, &search115_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state534_xforms[] = {
  { &search118, &search116_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state535_xforms[] = {
  { &search119, &replace119.value, 0 },
};
static const struct transform nir_opt_algebraic_state536_xforms[] = {
  { &search120, &search119_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state537_xforms[] = {
  { &search227, &replace226.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state538_xforms[] = {
  { &search232, &replace148.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state539_xforms[] = {
  { &search227, &replace226.value, 0 },
  { &search232, &replace148.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state540_xforms[] = {
  { &search233, &replace148.value, 0 },
  { &search234, &replace152.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state541_xforms[] = {
  { &search233, &replace148.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search499, &replace499.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state542_xforms[] = {
  { &search226, &replace226.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state543_xforms[] = {
  { &search226, &replace226.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search234, &replace152.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state544_xforms[] = {
  { &search226, &replace226.value, 0 },
  { &search227, &replace226.value, 0 },
  { &search228, &replace228.value, 0 },
  { &search229, &replace228.value, 0 },
  { &search230, &replace230.value, 0 },
  { &search231, &replace230.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state545_xforms[] = {
  { &search227, &replace226.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search497, &replace137_0.value, 0 },
  { &search498, &search64_2.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state546_xforms[] = {
  { &search232, &replace148.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search497, &replace137_0.value, 0 },
  { &search498, &search64_2.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state547_xforms[] = {
  { &search227, &replace226.value, 0 },
  { &search232, &replace148.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search497, &replace137_0.value, 0 },
  { &search498, &search64_2.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state548_xforms[] = {
  { &search233, &replace148.value, 0 },
  { &search234, &replace152.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search497, &replace137_0.value, 0 },
  { &search498, &search64_2.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state549_xforms[] = {
  { &search233, &replace148.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search497, &replace137_0.value, 0 },
  { &search498, &search64_2.value, 0 },
  { &search499, &replace499.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state550_xforms[] = {
  { &search226, &replace226.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search497, &replace137_0.value, 0 },
  { &search498, &search64_2.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state551_xforms[] = {
  { &search226, &replace226.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search234, &replace152.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search497, &replace137_0.value, 0 },
  { &search498, &search64_2.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state552_xforms[] = {
  { &search226, &replace226.value, 0 },
  { &search227, &replace226.value, 0 },
  { &search228, &replace228.value, 0 },
  { &search229, &replace228.value, 0 },
  { &search230, &replace230.value, 0 },
  { &search231, &replace230.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search497, &replace137_0.value, 0 },
  { &search498, &search64_2.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state553_xforms[] = {
  { &search224, &replace224.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state554_xforms[] = {
  { &search224, &replace224.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search234, &replace152.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state555_xforms[] = {
  { &search224, &replace224.value, 0 },
  { &search227, &replace226.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state556_xforms[] = {
  { &search224, &replace224.value, 0 },
  { &search232, &replace148.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state557_xforms[] = {
  { &search224, &replace224.value, 0 },
  { &search232, &replace148.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search234, &replace152.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search491, &replace80_0.value, 0 },
  { &search492, &replace146.value, 0 },
  { &search493, &replace493.value, 0 },
  { &search494, &replace494.value, 0 },
  { &search495, &replace495.value, 0 },
  { &search496, &replace496.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
  { &search502, &replace502.value, 0 },
  { &search503, &replace503.value, 0 },
};
static const struct transform nir_opt_algebraic_state558_xforms[] = {
  { &search224, &replace224.value, 0 },
  { &search232, &replace148.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state559_xforms[] = {
  { &search224, &replace224.value, 0 },
  { &search227, &replace226.value, 0 },
  { &search232, &replace148.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state560_xforms[] = {
  { &search224, &replace224.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search234, &replace152.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state561_xforms[] = {
  { &search224, &replace224.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search499, &replace499.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state562_xforms[] = {
  { &search224, &replace224.value, 0 },
  { &search226, &replace226.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state563_xforms[] = {
  { &search224, &replace224.value, 0 },
  { &search226, &replace226.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search234, &replace152.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state564_xforms[] = {
  { &search224, &replace224.value, 0 },
  { &search226, &replace226.value, 0 },
  { &search227, &replace226.value, 0 },
  { &search228, &replace228.value, 0 },
  { &search229, &replace228.value, 0 },
  { &search230, &replace230.value, 0 },
  { &search231, &replace230.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state565_xforms[] = {
  { &search225, &replace225.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state566_xforms[] = {
  { &search225, &replace225.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search234, &replace152.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state567_xforms[] = {
  { &search225, &replace225.value, 0 },
  { &search227, &replace226.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state568_xforms[] = {
  { &search225, &replace225.value, 0 },
  { &search232, &replace148.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state569_xforms[] = {
  { &search225, &replace225.value, 0 },
  { &search232, &replace148.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search234, &replace152.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search491, &replace80_0.value, 0 },
  { &search492, &replace146.value, 0 },
  { &search493, &replace493.value, 0 },
  { &search494, &replace494.value, 0 },
  { &search495, &replace495.value, 0 },
  { &search496, &replace496.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
  { &search502, &replace502.value, 0 },
  { &search503, &replace503.value, 0 },
};
static const struct transform nir_opt_algebraic_state570_xforms[] = {
  { &search225, &replace225.value, 0 },
  { &search232, &replace148.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state571_xforms[] = {
  { &search225, &replace225.value, 0 },
  { &search227, &replace226.value, 0 },
  { &search232, &replace148.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state572_xforms[] = {
  { &search225, &replace225.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search234, &replace152.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state573_xforms[] = {
  { &search225, &replace225.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search499, &replace499.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state574_xforms[] = {
  { &search225, &replace225.value, 0 },
  { &search226, &replace226.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state575_xforms[] = {
  { &search225, &replace225.value, 0 },
  { &search226, &replace226.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search234, &replace152.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state576_xforms[] = {
  { &search225, &replace225.value, 0 },
  { &search226, &replace226.value, 0 },
  { &search227, &replace226.value, 0 },
  { &search228, &replace228.value, 0 },
  { &search229, &replace228.value, 0 },
  { &search230, &replace230.value, 0 },
  { &search231, &replace230.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state577_xforms[] = {
  { &search220, &replace220.value, 0 },
  { &search221, &replace221.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state578_xforms[] = {
  { &search220, &replace220.value, 0 },
  { &search221, &replace221.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search234, &replace152.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state579_xforms[] = {
  { &search220, &replace220.value, 0 },
  { &search221, &replace221.value, 0 },
  { &search227, &replace226.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state580_xforms[] = {
  { &search220, &replace220.value, 0 },
  { &search221, &replace221.value, 0 },
  { &search232, &replace148.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state581_xforms[] = {
  { &search220, &replace220.value, 0 },
  { &search221, &replace221.value, 0 },
  { &search232, &replace148.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search234, &replace152.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search491, &replace80_0.value, 0 },
  { &search492, &replace146.value, 0 },
  { &search493, &replace493.value, 0 },
  { &search494, &replace494.value, 0 },
  { &search495, &replace495.value, 0 },
  { &search496, &replace496.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
  { &search502, &replace502.value, 0 },
  { &search503, &replace503.value, 0 },
};
static const struct transform nir_opt_algebraic_state582_xforms[] = {
  { &search220, &replace220.value, 0 },
  { &search221, &replace221.value, 0 },
  { &search232, &replace148.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state583_xforms[] = {
  { &search220, &replace220.value, 0 },
  { &search221, &replace221.value, 0 },
  { &search227, &replace226.value, 0 },
  { &search232, &replace148.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state584_xforms[] = {
  { &search220, &replace220.value, 0 },
  { &search221, &replace221.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search234, &replace152.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state585_xforms[] = {
  { &search220, &replace220.value, 0 },
  { &search221, &replace221.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search499, &replace499.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state586_xforms[] = {
  { &search220, &replace220.value, 0 },
  { &search221, &replace221.value, 0 },
  { &search226, &replace226.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state587_xforms[] = {
  { &search220, &replace220.value, 0 },
  { &search221, &replace221.value, 0 },
  { &search226, &replace226.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search234, &replace152.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state588_xforms[] = {
  { &search220, &replace220.value, 0 },
  { &search221, &replace221.value, 0 },
  { &search226, &replace226.value, 0 },
  { &search227, &replace226.value, 0 },
  { &search228, &replace228.value, 0 },
  { &search229, &replace228.value, 0 },
  { &search230, &replace230.value, 0 },
  { &search231, &replace230.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state589_xforms[] = {
  { &search220, &replace220.value, 0 },
  { &search221, &replace221.value, 0 },
  { &search232, &replace148.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search476, &replace476.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state590_xforms[] = {
  { &search222, &replace222.value, 0 },
  { &search223, &replace223.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state591_xforms[] = {
  { &search222, &replace222.value, 0 },
  { &search223, &replace223.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search234, &replace152.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state592_xforms[] = {
  { &search222, &replace222.value, 0 },
  { &search223, &replace223.value, 0 },
  { &search227, &replace226.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state593_xforms[] = {
  { &search222, &replace222.value, 0 },
  { &search223, &replace223.value, 0 },
  { &search232, &replace148.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state594_xforms[] = {
  { &search222, &replace222.value, 0 },
  { &search223, &replace223.value, 0 },
  { &search232, &replace148.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search234, &replace152.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search491, &replace80_0.value, 0 },
  { &search492, &replace146.value, 0 },
  { &search493, &replace493.value, 0 },
  { &search494, &replace494.value, 0 },
  { &search495, &replace495.value, 0 },
  { &search496, &replace496.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
  { &search502, &replace502.value, 0 },
  { &search503, &replace503.value, 0 },
};
static const struct transform nir_opt_algebraic_state595_xforms[] = {
  { &search222, &replace222.value, 0 },
  { &search223, &replace223.value, 0 },
  { &search232, &replace148.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state596_xforms[] = {
  { &search222, &replace222.value, 0 },
  { &search223, &replace223.value, 0 },
  { &search227, &replace226.value, 0 },
  { &search232, &replace148.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state597_xforms[] = {
  { &search222, &replace222.value, 0 },
  { &search223, &replace223.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search234, &replace152.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state598_xforms[] = {
  { &search222, &replace222.value, 0 },
  { &search223, &replace223.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search499, &replace499.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state599_xforms[] = {
  { &search222, &replace222.value, 0 },
  { &search223, &replace223.value, 0 },
  { &search226, &replace226.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state600_xforms[] = {
  { &search222, &replace222.value, 0 },
  { &search223, &replace223.value, 0 },
  { &search226, &replace226.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search234, &replace152.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state601_xforms[] = {
  { &search222, &replace222.value, 0 },
  { &search223, &replace223.value, 0 },
  { &search226, &replace226.value, 0 },
  { &search227, &replace226.value, 0 },
  { &search228, &replace228.value, 0 },
  { &search229, &replace228.value, 0 },
  { &search230, &replace230.value, 0 },
  { &search231, &replace230.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state602_xforms[] = {
  { &search233, &replace148.value, 0 },
  { &search234, &replace152.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
  { &search655, &search652_0_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state603_xforms[] = {
  { &search233, &replace148.value, 0 },
  { &search234, &replace152.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
  { &search656, &search653_0_0.value, 0 },
  { &search658, &search653_0_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state604_xforms[] = {
  { &search233, &replace148.value, 0 },
  { &search234, &replace152.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
  { &search657, &search654_0_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state605_xforms[] = {
  { &search53, &search14_0.value, 0 },
  { &search63, &replace63.value, 5 },
};
static const struct transform nir_opt_algebraic_state606_xforms[] = {
  { &search53, &search14_0.value, 0 },
  { &search63, &replace63.value, 5 },
  { &search64, &replace64.value, 0 },
};
static const struct transform nir_opt_algebraic_state607_xforms[] = {
  { &search53, &search14_0.value, 0 },
  { &search55, &replace55.value, 0 },
  { &search56, &replace56.value, 5 },
  { &search57, &replace57.value, 6 },
};
static const struct transform nir_opt_algebraic_state608_xforms[] = {
  { &search51, &search14_0.value, 0 },
  { &search52, &replace14_1_0.value, 0 },
  { &search53, &search14_0.value, 0 },
  { &search55, &replace55.value, 0 },
  { &search56, &replace56.value, 5 },
  { &search57, &replace57.value, 6 },
};
static const struct transform nir_opt_algebraic_state609_xforms[] = {
  { &search53, &search14_0.value, 0 },
  { &search55, &replace55.value, 0 },
  { &search56, &replace56.value, 5 },
  { &search57, &replace57.value, 6 },
  { &search63, &replace63.value, 5 },
};
static const struct transform nir_opt_algebraic_state610_xforms[] = {
  { &search53, &search14_0.value, 0 },
  { &search60, &replace60.value, 5 },
  { &search61, &replace61.value, 6 },
};
static const struct transform nir_opt_algebraic_state611_xforms[] = {
  { &search51, &search14_0.value, 0 },
  { &search52, &replace14_1_0.value, 0 },
  { &search53, &search14_0.value, 0 },
  { &search60, &replace60.value, 5 },
  { &search61, &replace61.value, 6 },
};
static const struct transform nir_opt_algebraic_state612_xforms[] = {
  { &search53, &search14_0.value, 0 },
  { &search60, &replace60.value, 5 },
  { &search61, &replace61.value, 6 },
  { &search63, &replace63.value, 5 },
};
static const struct transform nir_opt_algebraic_state613_xforms[] = {
  { &search53, &search14_0.value, 0 },
  { &search54, &replace48.value, 0 },
  { &search63, &replace63.value, 5 },
};
static const struct transform nir_opt_algebraic_state614_xforms[] = {
  { &search53, &search14_0.value, 0 },
  { &search54, &replace48.value, 0 },
  { &search63, &replace63.value, 5 },
  { &search64, &replace64.value, 0 },
};
static const struct transform nir_opt_algebraic_state615_xforms[] = {
  { &search53, &search14_0.value, 0 },
  { &search54, &replace48.value, 0 },
  { &search55, &replace55.value, 0 },
  { &search56, &replace56.value, 5 },
  { &search57, &replace57.value, 6 },
};
static const struct transform nir_opt_algebraic_state616_xforms[] = {
  { &search51, &search14_0.value, 0 },
  { &search52, &replace14_1_0.value, 0 },
  { &search53, &search14_0.value, 0 },
  { &search54, &replace48.value, 0 },
  { &search55, &replace55.value, 0 },
  { &search56, &replace56.value, 5 },
  { &search57, &replace57.value, 6 },
};
static const struct transform nir_opt_algebraic_state617_xforms[] = {
  { &search53, &search14_0.value, 0 },
  { &search54, &replace48.value, 0 },
  { &search55, &replace55.value, 0 },
  { &search56, &replace56.value, 5 },
  { &search57, &replace57.value, 6 },
  { &search63, &replace63.value, 5 },
};
static const struct transform nir_opt_algebraic_state618_xforms[] = {
  { &search53, &search14_0.value, 0 },
  { &search54, &replace48.value, 0 },
  { &search60, &replace60.value, 5 },
  { &search61, &replace61.value, 6 },
};
static const struct transform nir_opt_algebraic_state619_xforms[] = {
  { &search51, &search14_0.value, 0 },
  { &search52, &replace14_1_0.value, 0 },
  { &search53, &search14_0.value, 0 },
  { &search54, &replace48.value, 0 },
  { &search60, &replace60.value, 5 },
  { &search61, &replace61.value, 6 },
};
static const struct transform nir_opt_algebraic_state620_xforms[] = {
  { &search53, &search14_0.value, 0 },
  { &search54, &replace48.value, 0 },
  { &search60, &replace60.value, 5 },
  { &search61, &replace61.value, 6 },
  { &search63, &replace63.value, 5 },
};
static const struct transform nir_opt_algebraic_state621_xforms[] = {
  { &search53, &search14_0.value, 0 },
  { &search55, &replace55.value, 0 },
  { &search56, &replace56.value, 5 },
  { &search57, &replace57.value, 6 },
  { &search58, &replace58.value, 5 },
  { &search59, &replace59.value, 6 },
};
static const struct transform nir_opt_algebraic_state622_xforms[] = {
  { &search51, &search14_0.value, 0 },
  { &search52, &replace14_1_0.value, 0 },
  { &search53, &search14_0.value, 0 },
  { &search55, &replace55.value, 0 },
  { &search56, &replace56.value, 5 },
  { &search57, &replace57.value, 6 },
  { &search58, &replace58.value, 5 },
  { &search59, &replace59.value, 6 },
};
static const struct transform nir_opt_algebraic_state623_xforms[] = {
  { &search53, &search14_0.value, 0 },
  { &search55, &replace55.value, 0 },
  { &search56, &replace56.value, 5 },
  { &search57, &replace57.value, 6 },
  { &search58, &replace58.value, 5 },
  { &search59, &replace59.value, 6 },
  { &search63, &replace63.value, 5 },
};
static const struct transform nir_opt_algebraic_state624_xforms[] = {
  { &search53, &search14_0.value, 0 },
  { &search60, &replace60.value, 5 },
  { &search61, &replace61.value, 6 },
  { &search62, &replace62.value, 0 },
};
static const struct transform nir_opt_algebraic_state625_xforms[] = {
  { &search51, &search14_0.value, 0 },
  { &search52, &replace14_1_0.value, 0 },
  { &search53, &search14_0.value, 0 },
  { &search60, &replace60.value, 5 },
  { &search61, &replace61.value, 6 },
  { &search62, &replace62.value, 0 },
};
static const struct transform nir_opt_algebraic_state626_xforms[] = {
  { &search53, &search14_0.value, 0 },
  { &search60, &replace60.value, 5 },
  { &search61, &replace61.value, 6 },
  { &search62, &replace62.value, 0 },
  { &search63, &replace63.value, 5 },
};
static const struct transform nir_opt_algebraic_state627_xforms[] = {
  { &search187, &replace187.value, 0 },
  { &search416, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state628_xforms[] = {
  { &search187, &replace187.value, 0 },
  { &search416, &replace197.value, 0 },
  { &search487, &replace80_0.value, 0 },
  { &search490, &replace146.value, 0 },
  { &search551, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state629_xforms[] = {
  { &search193, &replace146.value, 0 },
  { &search416, &replace197.value, 0 },
  { &search487, &replace80_0.value, 0 },
  { &search490, &replace146.value, 0 },
  { &search551, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state630_xforms[] = {
  { &search416, &replace197.value, 0 },
  { &search487, &replace80_0.value, 0 },
  { &search490, &replace146.value, 0 },
  { &search551, &replace121.value, 0 },
  { &search1069, &replace1069.value, 0 },
  { &search1070, &replace1070.value, 0 },
};
static const struct transform nir_opt_algebraic_state631_xforms[] = {
  { &search416, &replace197.value, 0 },
  { &search487, &replace80_0.value, 0 },
  { &search490, &replace146.value, 0 },
  { &search551, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state632_xforms[] = {
  { &search416, &replace197.value, 0 },
  { &search487, &replace80_0.value, 0 },
  { &search490, &replace146.value, 0 },
  { &search551, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state633_xforms[] = {
  { &search416, &replace197.value, 0 },
  { &search487, &replace80_0.value, 0 },
  { &search490, &replace146.value, 0 },
  { &search551, &replace121.value, 0 },
  { &search933, &replace933.value, 0 },
  { &search945, &replace945.value, 0 },
  { &search957, &replace957.value, 0 },
  { &search975, &replace975.value, 0 },
  { &search993, &replace993.value, 0 },
  { &search1017, &replace1017.value, 0 },
};
static const struct transform nir_opt_algebraic_state634_xforms[] = {
  { &search416, &replace197.value, 0 },
  { &search487, &replace80_0.value, 0 },
  { &search490, &replace146.value, 0 },
  { &search551, &replace121.value, 0 },
  { &search837, &replace837.value, 0 },
  { &search849, &replace849.value, 0 },
  { &search861, &replace861.value, 0 },
  { &search879, &replace879.value, 0 },
  { &search897, &replace897.value, 0 },
  { &search921, &replace921.value, 0 },
};
static const struct transform nir_opt_algebraic_state635_xforms[] = {
  { &search416, &replace197.value, 0 },
  { &search927, &replace927.value, 0 },
  { &search939, &replace927.value, 0 },
  { &search951, &replace927.value, 0 },
  { &search963, &replace963.value, 0 },
  { &search969, &replace969.value, 0 },
  { &search981, &replace963.value, 0 },
  { &search987, &replace969.value, 0 },
  { &search999, &replace999.value, 0 },
  { &search1005, &replace1005.value, 0 },
  { &search1011, &replace1011.value, 0 },
};
static const struct transform nir_opt_algebraic_state636_xforms[] = {
  { &search416, &replace197.value, 0 },
  { &search831, &replace831.value, 0 },
  { &search843, &replace831.value, 0 },
  { &search855, &replace831.value, 0 },
  { &search867, &replace867.value, 0 },
  { &search873, &replace873.value, 0 },
  { &search885, &replace867.value, 0 },
  { &search891, &replace873.value, 0 },
  { &search903, &replace903.value, 0 },
  { &search909, &replace909.value, 0 },
  { &search915, &replace915.value, 0 },
};
static const struct transform nir_opt_algebraic_state637_xforms[] = {
  { &search188, &replace188.value, 0 },
  { &search417, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state638_xforms[] = {
  { &search188, &replace188.value, 0 },
  { &search417, &replace121.value, 0 },
  { &search488, &replace146.value, 0 },
  { &search489, &replace80_0.value, 0 },
  { &search550, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state639_xforms[] = {
  { &search194, &replace80_0.value, 0 },
  { &search417, &replace121.value, 0 },
  { &search488, &replace146.value, 0 },
  { &search489, &replace80_0.value, 0 },
  { &search550, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state640_xforms[] = {
  { &search417, &replace121.value, 0 },
  { &search488, &replace146.value, 0 },
  { &search489, &replace80_0.value, 0 },
  { &search550, &replace197.value, 0 },
  { &search1071, &replace1071.value, 0 },
  { &search1072, &replace1072.value, 0 },
};
static const struct transform nir_opt_algebraic_state641_xforms[] = {
  { &search417, &replace121.value, 0 },
  { &search488, &replace146.value, 0 },
  { &search489, &replace80_0.value, 0 },
  { &search550, &replace197.value, 0 },
  { &search934, &replace934.value, 0 },
  { &search946, &replace946.value, 0 },
  { &search958, &replace958.value, 0 },
  { &search976, &replace976.value, 0 },
  { &search994, &replace994.value, 0 },
  { &search1018, &replace1018.value, 0 },
};
static const struct transform nir_opt_algebraic_state642_xforms[] = {
  { &search417, &replace121.value, 0 },
  { &search488, &replace146.value, 0 },
  { &search489, &replace80_0.value, 0 },
  { &search550, &replace197.value, 0 },
  { &search838, &replace838.value, 0 },
  { &search850, &replace850.value, 0 },
  { &search862, &replace862.value, 0 },
  { &search880, &replace880.value, 0 },
  { &search898, &replace898.value, 0 },
  { &search922, &replace922.value, 0 },
};
static const struct transform nir_opt_algebraic_state643_xforms[] = {
  { &search417, &replace121.value, 0 },
  { &search928, &replace928.value, 0 },
  { &search940, &replace928.value, 0 },
  { &search952, &replace928.value, 0 },
  { &search964, &replace964.value, 0 },
  { &search970, &replace970.value, 0 },
  { &search982, &replace964.value, 0 },
  { &search988, &replace970.value, 0 },
  { &search1000, &replace1000.value, 0 },
  { &search1006, &replace1006.value, 0 },
  { &search1012, &replace1012.value, 0 },
};
static const struct transform nir_opt_algebraic_state644_xforms[] = {
  { &search417, &replace121.value, 0 },
  { &search832, &replace832.value, 0 },
  { &search844, &replace832.value, 0 },
  { &search856, &replace832.value, 0 },
  { &search868, &replace868.value, 0 },
  { &search874, &replace874.value, 0 },
  { &search886, &replace868.value, 0 },
  { &search892, &replace874.value, 0 },
  { &search904, &replace904.value, 0 },
  { &search910, &replace910.value, 0 },
  { &search916, &replace916.value, 0 },
};
static const struct transform nir_opt_algebraic_state645_xforms[] = {
  { &search420, &search2_0.value, 0 },
  { &search432, &replace432.value, 0 },
};
static const struct transform nir_opt_algebraic_state646_xforms[] = {
  { &search420, &search2_0.value, 0 },
  { &search431, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state647_xforms[] = {
  { &search410, &replace410.value, 0 },
  { &search420, &search2_0.value, 0 },
  { &search421, &search2_0.value, 0 },
  { &search422, &replace9.value, 0 },
  { &search432, &replace432.value, 0 },
  { &search571, &replace571.value, 32 },
  { &search627, &replace627.value, 33 },
};
static const struct transform nir_opt_algebraic_state648_xforms[] = {
  { &search410, &replace410.value, 0 },
  { &search420, &search2_0.value, 0 },
  { &search421, &search2_0.value, 0 },
  { &search422, &replace9.value, 0 },
  { &search441, &search441_1.value, 0 },
  { &search442, &search442_1.value, 0 },
  { &search571, &replace571.value, 32 },
  { &search627, &replace627.value, 33 },
};
static const struct transform nir_opt_algebraic_state649_xforms[] = {
  { &search410, &replace410.value, 0 },
  { &search420, &search2_0.value, 0 },
  { &search421, &search2_0.value, 0 },
  { &search422, &replace9.value, 0 },
  { &search431, &replace14_1_0.value, 0 },
  { &search571, &replace571.value, 32 },
  { &search627, &replace627.value, 33 },
};
static const struct transform nir_opt_algebraic_state650_xforms[] = {
  { &search420, &search2_0.value, 0 },
  { &search431, &replace14_1_0.value, 0 },
  { &search432, &replace432.value, 0 },
};
static const struct transform nir_opt_algebraic_state651_xforms[] = {
  { &search420, &search2_0.value, 0 },
  { &search433, &replace433.value, 0 },
};
static const struct transform nir_opt_algebraic_state652_xforms[] = {
  { &search122, &replace121.value, 0 },
  { &search288, &replace288.value, 0 },
  { &search289, &replace289.value, 0 },
  { &search420, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state653_xforms[] = {
  { &search420, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state654_xforms[] = {
  { &search420, &search2_0.value, 0 },
  { &search1051, &search111_0.value, 0 },
  { &search1052, &search1052_1.value, 0 },
};
static const struct transform nir_opt_algebraic_state655_xforms[] = {
  { &search420, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state656_xforms[] = {
  { &search122, &replace121.value, 0 },
  { &search288, &replace288.value, 0 },
  { &search289, &replace289.value, 0 },
  { &search292, &replace288.value, 0 },
  { &search420, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state657_xforms[] = {
  { &search122, &replace121.value, 0 },
  { &search288, &replace288.value, 0 },
  { &search289, &replace289.value, 0 },
  { &search316, &replace316.value, 0 },
  { &search317, &replace316.value, 0 },
  { &search420, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state658_xforms[] = {
  { &search122, &replace121.value, 0 },
  { &search288, &replace288.value, 0 },
  { &search289, &replace289.value, 0 },
  { &search292, &replace288.value, 0 },
  { &search316, &replace316.value, 0 },
  { &search317, &replace316.value, 0 },
  { &search420, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state659_xforms[] = {
  { &search122, &replace121.value, 0 },
  { &search288, &replace288.value, 0 },
  { &search289, &replace289.value, 0 },
  { &search293, &replace289.value, 0 },
  { &search420, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state660_xforms[] = {
  { &search122, &replace121.value, 0 },
  { &search288, &replace288.value, 0 },
  { &search289, &replace289.value, 0 },
  { &search293, &replace289.value, 0 },
  { &search316, &replace316.value, 0 },
  { &search317, &replace316.value, 0 },
  { &search420, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state661_xforms[] = {
  { &search122, &replace121.value, 0 },
  { &search288, &replace288.value, 0 },
  { &search289, &replace289.value, 0 },
  { &search292, &replace288.value, 0 },
  { &search293, &replace289.value, 0 },
  { &search316, &replace316.value, 0 },
  { &search317, &replace316.value, 0 },
  { &search420, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state662_xforms[] = {
  { &search290, &replace290.value, 0 },
  { &search291, &replace291.value, 0 },
  { &search420, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state663_xforms[] = {
  { &search420, &search2_0.value, 0 },
  { &search1053, &replace111.value, 0 },
  { &search1054, &search1054_1.value, 0 },
};
static const struct transform nir_opt_algebraic_state664_xforms[] = {
  { &search420, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state665_xforms[] = {
  { &search290, &replace290.value, 0 },
  { &search291, &replace291.value, 0 },
  { &search294, &replace290.value, 0 },
  { &search420, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state666_xforms[] = {
  { &search211, &replace211.value, 19 },
  { &search290, &replace290.value, 0 },
  { &search291, &replace291.value, 0 },
  { &search318, &replace318.value, 0 },
  { &search319, &replace318.value, 0 },
  { &search420, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state667_xforms[] = {
  { &search211, &replace211.value, 19 },
  { &search290, &replace290.value, 0 },
  { &search291, &replace291.value, 0 },
  { &search294, &replace290.value, 0 },
  { &search318, &replace318.value, 0 },
  { &search319, &replace318.value, 0 },
  { &search420, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state668_xforms[] = {
  { &search290, &replace290.value, 0 },
  { &search291, &replace291.value, 0 },
  { &search295, &replace291.value, 0 },
  { &search420, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state669_xforms[] = {
  { &search211, &replace211.value, 19 },
  { &search290, &replace290.value, 0 },
  { &search291, &replace291.value, 0 },
  { &search295, &replace291.value, 0 },
  { &search318, &replace318.value, 0 },
  { &search319, &replace318.value, 0 },
  { &search420, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state670_xforms[] = {
  { &search211, &replace211.value, 19 },
  { &search290, &replace290.value, 0 },
  { &search291, &replace291.value, 0 },
  { &search294, &replace290.value, 0 },
  { &search295, &replace291.value, 0 },
  { &search318, &replace318.value, 0 },
  { &search319, &replace318.value, 0 },
  { &search420, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state671_xforms[] = {
  { &search420, &search2_0.value, 0 },
  { &search1055, &search113_0.value, 0 },
  { &search1056, &replace1056.value, 0 },
};
static const struct transform nir_opt_algebraic_state672_xforms[] = {
  { &search121, &replace121.value, 0 },
  { &search420, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state673_xforms[] = {
  { &search420, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state674_xforms[] = {
  { &search124, &replace121.value, 0 },
  { &search304, &replace304.value, 0 },
  { &search305, &replace305.value, 0 },
  { &search420, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state675_xforms[] = {
  { &search125, &replace121.value, 0 },
  { &search308, &replace308.value, 0 },
  { &search309, &replace309.value, 0 },
  { &search420, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state676_xforms[] = {
  { &search306, &replace306.value, 0 },
  { &search307, &replace307.value, 0 },
  { &search420, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state677_xforms[] = {
  { &search310, &replace310.value, 0 },
  { &search311, &replace311.value, 0 },
  { &search420, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state678_xforms[] = {
  { &search123, &replace121.value, 0 },
  { &search420, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state679_xforms[] = {
  { &search328, &replace328.value, 1 },
  { &search420, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state680_xforms[] = {
  { &search628, &replace49.value, 0 },
  { &search632, &replace632.value, 34 },
};
static const struct transform nir_opt_algebraic_state681_xforms[] = {
  { &search632, &replace632.value, 34 },
};
static const struct transform nir_opt_algebraic_state682_xforms[] = {
  { &search628, &replace49.value, 0 },
  { &search632, &replace632.value, 34 },
};
static const struct transform nir_opt_algebraic_state683_xforms[] = {
  { &search731, &search268_0.value, 0 },
  { &search748, &search101_0_0.value, 0 },
  { &search749, &search0_0.value, 0 },
  { &search750, &search57_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state684_xforms[] = {
  { &search353, &replace121.value, 0 },
  { &search418, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state685_xforms[] = {
  { &search349, &replace121.value, 0 },
  { &search418, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state686_xforms[] = {
  { &search341, &replace341.value, 0 },
  { &search418, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state687_xforms[] = {
  { &search353, &replace121.value, 0 },
  { &search418, &replace121.value, 0 },
  { &search560, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state688_xforms[] = {
  { &search418, &replace121.value, 0 },
  { &search560, &replace197.value, 0 },
  { &search1074, &replace1074.value, 0 },
};
static const struct transform nir_opt_algebraic_state689_xforms[] = {
  { &search349, &replace121.value, 0 },
  { &search418, &replace121.value, 0 },
  { &search560, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state690_xforms[] = {
  { &search349, &replace121.value, 0 },
  { &search369, &replace369.value, 0 },
  { &search418, &replace121.value, 0 },
  { &search560, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state691_xforms[] = {
  { &search341, &replace341.value, 0 },
  { &search418, &replace121.value, 0 },
  { &search560, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state692_xforms[] = {
  { &search341, &replace341.value, 0 },
  { &search361, &replace361.value, 0 },
  { &search418, &replace121.value, 0 },
  { &search560, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state693_xforms[] = {
  { &search418, &replace121.value, 0 },
  { &search560, &replace197.value, 0 },
  { &search936, &replace936.value, 0 },
  { &search948, &replace948.value, 0 },
  { &search960, &replace960.value, 0 },
  { &search978, &replace978.value, 0 },
  { &search996, &replace996.value, 0 },
  { &search1020, &replace1020.value, 0 },
};
static const struct transform nir_opt_algebraic_state694_xforms[] = {
  { &search418, &replace121.value, 0 },
  { &search1073, &replace1073.value, 0 },
};
static const struct transform nir_opt_algebraic_state695_xforms[] = {
  { &search354, &replace121.value, 0 },
  { &search418, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state696_xforms[] = {
  { &search353, &replace121.value, 0 },
  { &search354, &replace121.value, 0 },
  { &search418, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state697_xforms[] = {
  { &search349, &replace121.value, 0 },
  { &search354, &replace121.value, 0 },
  { &search418, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state698_xforms[] = {
  { &search341, &replace341.value, 0 },
  { &search354, &replace121.value, 0 },
  { &search418, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state699_xforms[] = {
  { &search342, &search125_1.value, 0 },
  { &search418, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state700_xforms[] = {
  { &search342, &search125_1.value, 0 },
  { &search353, &replace121.value, 0 },
  { &search418, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state701_xforms[] = {
  { &search342, &search125_1.value, 0 },
  { &search349, &replace121.value, 0 },
  { &search418, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state702_xforms[] = {
  { &search341, &replace341.value, 0 },
  { &search342, &search125_1.value, 0 },
  { &search418, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state703_xforms[] = {
  { &search342, &search125_1.value, 0 },
  { &search362, &replace362.value, 0 },
  { &search418, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state704_xforms[] = {
  { &search350, &replace121.value, 0 },
  { &search418, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state705_xforms[] = {
  { &search350, &replace121.value, 0 },
  { &search353, &replace121.value, 0 },
  { &search418, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state706_xforms[] = {
  { &search349, &replace121.value, 0 },
  { &search350, &replace121.value, 0 },
  { &search418, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state707_xforms[] = {
  { &search341, &replace341.value, 0 },
  { &search350, &replace121.value, 0 },
  { &search418, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state708_xforms[] = {
  { &search350, &replace121.value, 0 },
  { &search370, &replace370.value, 0 },
  { &search418, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state709_xforms[] = {
  { &search418, &replace121.value, 0 },
  { &search935, &replace935.value, 0 },
  { &search947, &replace947.value, 0 },
  { &search959, &replace959.value, 0 },
  { &search977, &replace977.value, 0 },
  { &search995, &replace995.value, 0 },
  { &search1019, &replace1019.value, 0 },
};
static const struct transform nir_opt_algebraic_state710_xforms[] = {
  { &search418, &replace121.value, 0 },
  { &search930, &replace930.value, 0 },
  { &search932, &replace932.value, 0 },
  { &search942, &replace930.value, 0 },
  { &search944, &replace932.value, 0 },
  { &search954, &replace930.value, 0 },
  { &search956, &replace932.value, 0 },
  { &search966, &replace966.value, 0 },
  { &search968, &replace968.value, 0 },
  { &search972, &replace972.value, 0 },
  { &search974, &replace974.value, 0 },
  { &search984, &replace966.value, 0 },
  { &search986, &replace968.value, 0 },
  { &search990, &replace972.value, 0 },
  { &search992, &replace974.value, 0 },
  { &search1002, &replace1002.value, 0 },
  { &search1004, &replace1004.value, 0 },
  { &search1008, &replace1008.value, 0 },
  { &search1010, &replace1010.value, 0 },
  { &search1014, &replace1014.value, 0 },
  { &search1016, &replace1016.value, 0 },
};
static const struct transform nir_opt_algebraic_state711_xforms[] = {
  { &search355, &replace197.value, 0 },
  { &search419, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state712_xforms[] = {
  { &search343, &replace197.value, 0 },
  { &search419, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state713_xforms[] = {
  { &search351, &replace351.value, 0 },
  { &search419, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state714_xforms[] = {
  { &search355, &replace197.value, 0 },
  { &search419, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state715_xforms[] = {
  { &search419, &replace197.value, 0 },
  { &search1076, &replace1076.value, 0 },
};
static const struct transform nir_opt_algebraic_state716_xforms[] = {
  { &search343, &replace197.value, 0 },
  { &search419, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state717_xforms[] = {
  { &search343, &replace197.value, 0 },
  { &search363, &replace363.value, 0 },
  { &search419, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state718_xforms[] = {
  { &search351, &replace351.value, 0 },
  { &search419, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state719_xforms[] = {
  { &search351, &replace351.value, 0 },
  { &search371, &replace371.value, 0 },
  { &search419, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state720_xforms[] = {
  { &search419, &replace197.value, 0 },
  { &search938, &replace938.value, 0 },
  { &search950, &replace950.value, 0 },
  { &search962, &replace962.value, 0 },
  { &search980, &replace980.value, 0 },
  { &search998, &replace998.value, 0 },
  { &search1022, &replace1022.value, 0 },
};
static const struct transform nir_opt_algebraic_state721_xforms[] = {
  { &search419, &replace197.value, 0 },
  { &search1075, &replace1075.value, 0 },
};
static const struct transform nir_opt_algebraic_state722_xforms[] = {
  { &search356, &replace197.value, 0 },
  { &search419, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state723_xforms[] = {
  { &search355, &replace197.value, 0 },
  { &search356, &replace197.value, 0 },
  { &search419, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state724_xforms[] = {
  { &search343, &replace197.value, 0 },
  { &search356, &replace197.value, 0 },
  { &search419, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state725_xforms[] = {
  { &search351, &replace351.value, 0 },
  { &search356, &replace197.value, 0 },
  { &search419, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state726_xforms[] = {
  { &search352, &replace352.value, 0 },
  { &search419, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state727_xforms[] = {
  { &search352, &replace352.value, 0 },
  { &search355, &replace197.value, 0 },
  { &search419, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state728_xforms[] = {
  { &search343, &replace197.value, 0 },
  { &search352, &replace352.value, 0 },
  { &search419, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state729_xforms[] = {
  { &search351, &replace351.value, 0 },
  { &search352, &replace352.value, 0 },
  { &search419, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state730_xforms[] = {
  { &search352, &replace352.value, 0 },
  { &search372, &replace372.value, 0 },
  { &search419, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state731_xforms[] = {
  { &search344, &replace197.value, 0 },
  { &search419, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state732_xforms[] = {
  { &search344, &replace197.value, 0 },
  { &search355, &replace197.value, 0 },
  { &search419, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state733_xforms[] = {
  { &search343, &replace197.value, 0 },
  { &search344, &replace197.value, 0 },
  { &search419, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state734_xforms[] = {
  { &search344, &replace197.value, 0 },
  { &search351, &replace351.value, 0 },
  { &search419, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state735_xforms[] = {
  { &search344, &replace197.value, 0 },
  { &search364, &replace364.value, 0 },
  { &search419, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state736_xforms[] = {
  { &search419, &replace197.value, 0 },
  { &search937, &replace937.value, 0 },
  { &search949, &replace949.value, 0 },
  { &search961, &replace961.value, 0 },
  { &search979, &replace979.value, 0 },
  { &search997, &replace997.value, 0 },
  { &search1021, &replace1021.value, 0 },
};
static const struct transform nir_opt_algebraic_state737_xforms[] = {
  { &search419, &replace197.value, 0 },
  { &search929, &replace929.value, 0 },
  { &search931, &replace931.value, 0 },
  { &search941, &replace929.value, 0 },
  { &search943, &replace931.value, 0 },
  { &search953, &replace929.value, 0 },
  { &search955, &replace931.value, 0 },
  { &search965, &replace965.value, 0 },
  { &search967, &replace967.value, 0 },
  { &search971, &replace971.value, 0 },
  { &search973, &replace973.value, 0 },
  { &search983, &replace965.value, 0 },
  { &search985, &replace967.value, 0 },
  { &search989, &replace971.value, 0 },
  { &search991, &replace973.value, 0 },
  { &search1001, &replace1001.value, 0 },
  { &search1003, &replace1003.value, 0 },
  { &search1007, &replace1007.value, 0 },
  { &search1009, &replace1009.value, 0 },
  { &search1013, &replace1013.value, 0 },
  { &search1015, &replace1015.value, 0 },
};
static const struct transform nir_opt_algebraic_state738_xforms[] = {
  { &search577, &search563_1.value, 0 },
};
static const struct transform nir_opt_algebraic_state739_xforms[] = {
  { &search562, &replace0_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state740_xforms[] = {
  { &search573, &search564_0_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state741_xforms[] = {
  { &search576, &search564_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state742_xforms[] = {
  { &search572, &replace572.value, 0 },
};
static const struct transform nir_opt_algebraic_state743_xforms[] = {
  { &search575, &replace575.value, 0 },
};
static const struct transform nir_opt_algebraic_state744_xforms[] = {
  { &search675, &replace674_2.value, 0 },
};
static const struct transform nir_opt_algebraic_state745_xforms[] = {
  { &search676, &replace674_2.value, 0 },
};
static const struct transform nir_opt_algebraic_state746_xforms[] = {
  { &search675, &replace674_2.value, 0 },
  { &search676, &replace674_2.value, 0 },
};
static const struct transform nir_opt_algebraic_state747_xforms[] = {
  { &search677, &replace673_2.value, 0 },
};
static const struct transform nir_opt_algebraic_state748_xforms[] = {
  { &search678, &replace673_2.value, 0 },
};
static const struct transform nir_opt_algebraic_state749_xforms[] = {
  { &search677, &replace673_2.value, 0 },
  { &search678, &replace673_2.value, 0 },
};
static const struct transform nir_opt_algebraic_state750_xforms[] = {
  { &search679, &replace679.value, 0 },
};
static const struct transform nir_opt_algebraic_state751_xforms[] = {
  { &search680, &replace679.value, 0 },
};
static const struct transform nir_opt_algebraic_state752_xforms[] = {
  { &search679, &replace679.value, 0 },
  { &search680, &replace679.value, 0 },
};
static const struct transform nir_opt_algebraic_state753_xforms[] = {
  { &search734, &search268_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state754_xforms[] = {
  { &search736, &search268_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state755_xforms[] = {
  { &search735, &search510_0_0.value, 0 },
  { &search743, &replace80_0.value, 0 },
  { &search744, &search98_0_0.value, 0 },
  { &search745, &search101_0_0.value, 0 },
  { &search746, &search0_0.value, 0 },
  { &search747, &search57_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state756_xforms[] = {
  { &search743, &replace80_0.value, 0 },
  { &search744, &search98_0_0.value, 0 },
  { &search745, &search101_0_0.value, 0 },
  { &search746, &search0_0.value, 0 },
  { &search747, &search57_0.value, 0 },
  { &search754, &replace752.value, 0 },
  { &search758, &replace752.value, 0 },
  { &search762, &replace752.value, 0 },
  { &search766, &replace752.value, 0 },
  { &search768, &replace768.value, 0 },
  { &search772, &search752_0.value, 0 },
  { &search776, &search752_0.value, 0 },
  { &search780, &search752_0.value, 0 },
  { &search782, &replace782.value, 0 },
  { &search784, &replace782.value, 0 },
  { &search786, &replace786.value, 0 },
  { &search790, &search756_0.value, 0 },
  { &search794, &search756_0.value, 0 },
  { &search796, &replace796.value, 0 },
  { &search798, &replace796.value, 0 },
  { &search800, &replace800.value, 0 },
  { &search802, &replace796.value, 0 },
  { &search804, &replace800.value, 0 },
  { &search806, &replace806.value, 0 },
  { &search810, &search760_0.value, 0 },
  { &search812, &replace812.value, 0 },
  { &search814, &replace812.value, 0 },
  { &search816, &replace816.value, 0 },
  { &search818, &replace812.value, 0 },
  { &search820, &replace816.value, 0 },
  { &search822, &replace822.value, 0 },
  { &search824, &replace812.value, 0 },
  { &search826, &replace816.value, 0 },
  { &search828, &replace822.value, 0 },
  { &search830, &replace830.value, 0 },
};
static const struct transform nir_opt_algebraic_state757_xforms[] = {
  { &search743, &replace80_0.value, 0 },
  { &search744, &search98_0_0.value, 0 },
  { &search745, &search101_0_0.value, 0 },
  { &search746, &search0_0.value, 0 },
  { &search747, &search57_0.value, 0 },
  { &search753, &replace751.value, 0 },
  { &search757, &replace751.value, 0 },
  { &search761, &replace751.value, 0 },
  { &search765, &replace751.value, 0 },
  { &search771, &search751_0.value, 0 },
  { &search775, &search751_0.value, 0 },
  { &search779, &search751_0.value, 0 },
  { &search789, &search755_0.value, 0 },
  { &search793, &search755_0.value, 0 },
  { &search809, &search759_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state758_xforms[] = {
  { &search737, &search510_0_0.value, 0 },
  { &search738, &replace80_0.value, 0 },
  { &search739, &search98_0_0.value, 0 },
  { &search740, &search101_0_0.value, 0 },
  { &search741, &search0_0.value, 0 },
  { &search742, &search57_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state759_xforms[] = {
  { &search738, &replace80_0.value, 0 },
  { &search739, &search98_0_0.value, 0 },
  { &search740, &search101_0_0.value, 0 },
  { &search741, &search0_0.value, 0 },
  { &search742, &search57_0.value, 0 },
  { &search752, &replace752.value, 0 },
  { &search756, &replace752.value, 0 },
  { &search760, &replace752.value, 0 },
  { &search764, &replace752.value, 0 },
  { &search770, &search752_0.value, 0 },
  { &search774, &search752_0.value, 0 },
  { &search778, &search752_0.value, 0 },
  { &search788, &search756_0.value, 0 },
  { &search792, &search756_0.value, 0 },
  { &search808, &search760_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state760_xforms[] = {
  { &search738, &replace80_0.value, 0 },
  { &search739, &search98_0_0.value, 0 },
  { &search740, &search101_0_0.value, 0 },
  { &search741, &search0_0.value, 0 },
  { &search742, &search57_0.value, 0 },
  { &search751, &replace751.value, 0 },
  { &search755, &replace751.value, 0 },
  { &search759, &replace751.value, 0 },
  { &search763, &replace751.value, 0 },
  { &search767, &replace767.value, 0 },
  { &search769, &search751_0.value, 0 },
  { &search773, &search751_0.value, 0 },
  { &search777, &search751_0.value, 0 },
  { &search781, &replace781.value, 0 },
  { &search783, &replace781.value, 0 },
  { &search785, &replace785.value, 0 },
  { &search787, &search755_0.value, 0 },
  { &search791, &search755_0.value, 0 },
  { &search795, &replace795.value, 0 },
  { &search797, &replace795.value, 0 },
  { &search799, &replace799.value, 0 },
  { &search801, &replace795.value, 0 },
  { &search803, &replace799.value, 0 },
  { &search805, &replace805.value, 0 },
  { &search807, &search759_0.value, 0 },
  { &search811, &replace811.value, 0 },
  { &search813, &replace811.value, 0 },
  { &search815, &replace815.value, 0 },
  { &search817, &replace811.value, 0 },
  { &search819, &replace815.value, 0 },
  { &search821, &replace821.value, 0 },
  { &search823, &replace811.value, 0 },
  { &search825, &replace815.value, 0 },
  { &search827, &replace821.value, 0 },
  { &search829, &replace829.value, 0 },
};
static const struct transform nir_opt_algebraic_state761_xforms[] = {
  { &search82, &replace82.value, 17 },
  { &search85, &replace85.value, 0 },
  { &search92, &replace92.value, 18 },
};
static const struct transform nir_opt_algebraic_state762_xforms[] = {
  { &search82, &replace82.value, 17 },
  { &search84, &replace84.value, 0 },
  { &search85, &replace85.value, 0 },
  { &search92, &replace92.value, 18 },
};
static const struct transform nir_opt_algebraic_state763_xforms[] = {
  { &search82, &replace82.value, 17 },
  { &search83, &replace48.value, 0 },
  { &search84, &replace84.value, 0 },
  { &search85, &replace85.value, 0 },
  { &search92, &replace92.value, 18 },
};
static const struct transform nir_opt_algebraic_state764_xforms[] = {
  { &search87, &replace84.value, 0 },
  { &search91, &replace91.value, 18 },
};
static const struct transform nir_opt_algebraic_state765_xforms[] = {
  { &search86, &replace48.value, 0 },
  { &search87, &replace84.value, 0 },
  { &search91, &replace91.value, 18 },
};
static const struct transform nir_opt_algebraic_state766_xforms[] = {
  { &search88, &replace48.value, 0 },
  { &search90, &replace90.value, 18 },
};
static const struct transform nir_opt_algebraic_state767_xforms[] = {
  { &search88, &replace48.value, 0 },
  { &search89, &replace89.value, 0 },
  { &search90, &replace90.value, 18 },
};
static const struct transform nir_opt_algebraic_state771_xforms[] = {
  { &search327, &replace327.value, 0 },
};
static const struct transform nir_opt_algebraic_state772_xforms[] = {
  { &search345, &replace121.value, 0 },
  { &search414, &replace121.value, 0 },
  { &search556, &replace121.value, 0 },
  { &search557, &replace197.value, 0 },
  { &search558, &replace197.value, 0 },
  { &search559, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state773_xforms[] = {
  { &search337, &replace337.value, 0 },
  { &search414, &replace121.value, 0 },
  { &search556, &replace121.value, 0 },
  { &search557, &replace197.value, 0 },
  { &search558, &replace197.value, 0 },
  { &search559, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state774_xforms[] = {
  { &search414, &replace121.value, 0 },
  { &search534, &replace534.value, 0 },
  { &search556, &replace121.value, 0 },
  { &search557, &replace197.value, 0 },
  { &search558, &replace197.value, 0 },
  { &search559, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state775_xforms[] = {
  { &search414, &replace121.value, 0 },
  { &search556, &replace121.value, 0 },
  { &search557, &replace197.value, 0 },
  { &search558, &replace197.value, 0 },
  { &search559, &replace121.value, 0 },
  { &search1066, &replace1066.value, 0 },
};
static const struct transform nir_opt_algebraic_state776_xforms[] = {
  { &search345, &replace121.value, 0 },
  { &search365, &replace365.value, 0 },
  { &search414, &replace121.value, 0 },
  { &search556, &replace121.value, 0 },
  { &search557, &replace197.value, 0 },
  { &search558, &replace197.value, 0 },
  { &search559, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state777_xforms[] = {
  { &search337, &replace337.value, 0 },
  { &search357, &replace357.value, 0 },
  { &search414, &replace121.value, 0 },
  { &search556, &replace121.value, 0 },
  { &search557, &replace197.value, 0 },
  { &search558, &replace197.value, 0 },
  { &search559, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state778_xforms[] = {
  { &search414, &replace121.value, 0 },
  { &search556, &replace121.value, 0 },
  { &search557, &replace197.value, 0 },
  { &search558, &replace197.value, 0 },
  { &search559, &replace121.value, 0 },
  { &search840, &replace840.value, 0 },
  { &search852, &replace852.value, 0 },
  { &search864, &replace864.value, 0 },
  { &search882, &replace882.value, 0 },
  { &search900, &replace900.value, 0 },
  { &search924, &replace924.value, 0 },
};
static const struct transform nir_opt_algebraic_state779_xforms[] = {
  { &search414, &replace121.value, 0 },
  { &search556, &replace121.value, 0 },
  { &search557, &replace197.value, 0 },
  { &search558, &replace197.value, 0 },
  { &search559, &replace121.value, 0 },
  { &search1065, &replace1065.value, 0 },
};
static const struct transform nir_opt_algebraic_state780_xforms[] = {
  { &search338, &search124_1.value, 0 },
  { &search414, &replace121.value, 0 },
  { &search556, &replace121.value, 0 },
  { &search557, &replace197.value, 0 },
  { &search558, &replace197.value, 0 },
  { &search559, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state781_xforms[] = {
  { &search338, &search124_1.value, 0 },
  { &search414, &replace121.value, 0 },
  { &search556, &replace121.value, 0 },
  { &search557, &replace197.value, 0 },
  { &search558, &replace197.value, 0 },
  { &search559, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state782_xforms[] = {
  { &search338, &search124_1.value, 0 },
  { &search345, &replace121.value, 0 },
  { &search414, &replace121.value, 0 },
  { &search556, &replace121.value, 0 },
  { &search557, &replace197.value, 0 },
  { &search558, &replace197.value, 0 },
  { &search559, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state783_xforms[] = {
  { &search337, &replace337.value, 0 },
  { &search338, &search124_1.value, 0 },
  { &search414, &replace121.value, 0 },
  { &search556, &replace121.value, 0 },
  { &search557, &replace197.value, 0 },
  { &search558, &replace197.value, 0 },
  { &search559, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state784_xforms[] = {
  { &search338, &search124_1.value, 0 },
  { &search414, &replace121.value, 0 },
  { &search534, &replace534.value, 0 },
  { &search556, &replace121.value, 0 },
  { &search557, &replace197.value, 0 },
  { &search558, &replace197.value, 0 },
  { &search559, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state785_xforms[] = {
  { &search338, &search124_1.value, 0 },
  { &search358, &replace358.value, 0 },
  { &search414, &replace121.value, 0 },
  { &search556, &replace121.value, 0 },
  { &search557, &replace197.value, 0 },
  { &search558, &replace197.value, 0 },
  { &search559, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state786_xforms[] = {
  { &search346, &replace121.value, 0 },
  { &search414, &replace121.value, 0 },
  { &search556, &replace121.value, 0 },
  { &search557, &replace197.value, 0 },
  { &search558, &replace197.value, 0 },
  { &search559, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state787_xforms[] = {
  { &search346, &replace121.value, 0 },
  { &search414, &replace121.value, 0 },
  { &search556, &replace121.value, 0 },
  { &search557, &replace197.value, 0 },
  { &search558, &replace197.value, 0 },
  { &search559, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state788_xforms[] = {
  { &search345, &replace121.value, 0 },
  { &search346, &replace121.value, 0 },
  { &search414, &replace121.value, 0 },
  { &search556, &replace121.value, 0 },
  { &search557, &replace197.value, 0 },
  { &search558, &replace197.value, 0 },
  { &search559, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state789_xforms[] = {
  { &search337, &replace337.value, 0 },
  { &search346, &replace121.value, 0 },
  { &search414, &replace121.value, 0 },
  { &search556, &replace121.value, 0 },
  { &search557, &replace197.value, 0 },
  { &search558, &replace197.value, 0 },
  { &search559, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state790_xforms[] = {
  { &search346, &replace121.value, 0 },
  { &search414, &replace121.value, 0 },
  { &search534, &replace534.value, 0 },
  { &search556, &replace121.value, 0 },
  { &search557, &replace197.value, 0 },
  { &search558, &replace197.value, 0 },
  { &search559, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state791_xforms[] = {
  { &search346, &replace121.value, 0 },
  { &search366, &replace366.value, 0 },
  { &search414, &replace121.value, 0 },
  { &search556, &replace121.value, 0 },
  { &search557, &replace197.value, 0 },
  { &search558, &replace197.value, 0 },
  { &search559, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state792_xforms[] = {
  { &search414, &replace121.value, 0 },
  { &search533, &replace533.value, 0 },
  { &search556, &replace121.value, 0 },
  { &search557, &replace197.value, 0 },
  { &search558, &replace197.value, 0 },
  { &search559, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state793_xforms[] = {
  { &search414, &replace121.value, 0 },
  { &search533, &replace533.value, 0 },
  { &search556, &replace121.value, 0 },
  { &search557, &replace197.value, 0 },
  { &search558, &replace197.value, 0 },
  { &search559, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state794_xforms[] = {
  { &search345, &replace121.value, 0 },
  { &search414, &replace121.value, 0 },
  { &search533, &replace533.value, 0 },
  { &search556, &replace121.value, 0 },
  { &search557, &replace197.value, 0 },
  { &search558, &replace197.value, 0 },
  { &search559, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state795_xforms[] = {
  { &search337, &replace337.value, 0 },
  { &search414, &replace121.value, 0 },
  { &search533, &replace533.value, 0 },
  { &search556, &replace121.value, 0 },
  { &search557, &replace197.value, 0 },
  { &search558, &replace197.value, 0 },
  { &search559, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state796_xforms[] = {
  { &search414, &replace121.value, 0 },
  { &search533, &replace533.value, 0 },
  { &search534, &replace534.value, 0 },
  { &search556, &replace121.value, 0 },
  { &search557, &replace197.value, 0 },
  { &search558, &replace197.value, 0 },
  { &search559, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state797_xforms[] = {
  { &search414, &replace121.value, 0 },
  { &search556, &replace121.value, 0 },
  { &search557, &replace197.value, 0 },
  { &search558, &replace197.value, 0 },
  { &search559, &replace121.value, 0 },
  { &search839, &replace839.value, 0 },
  { &search851, &replace851.value, 0 },
  { &search863, &replace863.value, 0 },
  { &search881, &replace881.value, 0 },
  { &search899, &replace899.value, 0 },
  { &search923, &replace923.value, 0 },
};
static const struct transform nir_opt_algebraic_state798_xforms[] = {
  { &search414, &replace121.value, 0 },
  { &search556, &replace121.value, 0 },
  { &search557, &replace197.value, 0 },
  { &search558, &replace197.value, 0 },
  { &search559, &replace121.value, 0 },
  { &search834, &replace834.value, 0 },
  { &search836, &replace836.value, 0 },
  { &search846, &replace834.value, 0 },
  { &search848, &replace836.value, 0 },
  { &search858, &replace834.value, 0 },
  { &search860, &replace836.value, 0 },
  { &search870, &replace870.value, 0 },
  { &search872, &replace872.value, 0 },
  { &search876, &replace876.value, 0 },
  { &search878, &replace878.value, 0 },
  { &search888, &replace870.value, 0 },
  { &search890, &replace872.value, 0 },
  { &search894, &replace876.value, 0 },
  { &search896, &replace878.value, 0 },
  { &search906, &replace906.value, 0 },
  { &search908, &replace908.value, 0 },
  { &search912, &replace912.value, 0 },
  { &search914, &replace914.value, 0 },
  { &search918, &replace918.value, 0 },
  { &search920, &replace920.value, 0 },
};
static const struct transform nir_opt_algebraic_state799_xforms[] = {
  { &search339, &replace197.value, 0 },
  { &search415, &replace197.value, 0 },
  { &search552, &replace197.value, 0 },
  { &search553, &replace121.value, 0 },
  { &search554, &replace121.value, 0 },
  { &search555, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state800_xforms[] = {
  { &search347, &replace347.value, 0 },
  { &search415, &replace197.value, 0 },
  { &search552, &replace197.value, 0 },
  { &search553, &replace121.value, 0 },
  { &search554, &replace121.value, 0 },
  { &search555, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state801_xforms[] = {
  { &search415, &replace197.value, 0 },
  { &search532, &replace532.value, 0 },
  { &search552, &replace197.value, 0 },
  { &search553, &replace121.value, 0 },
  { &search554, &replace121.value, 0 },
  { &search555, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state802_xforms[] = {
  { &search415, &replace197.value, 0 },
  { &search552, &replace197.value, 0 },
  { &search553, &replace121.value, 0 },
  { &search554, &replace121.value, 0 },
  { &search555, &replace197.value, 0 },
  { &search1068, &replace1068.value, 0 },
};
static const struct transform nir_opt_algebraic_state803_xforms[] = {
  { &search339, &replace197.value, 0 },
  { &search359, &replace359.value, 0 },
  { &search415, &replace197.value, 0 },
  { &search552, &replace197.value, 0 },
  { &search553, &replace121.value, 0 },
  { &search554, &replace121.value, 0 },
  { &search555, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state804_xforms[] = {
  { &search347, &replace347.value, 0 },
  { &search367, &replace367.value, 0 },
  { &search415, &replace197.value, 0 },
  { &search552, &replace197.value, 0 },
  { &search553, &replace121.value, 0 },
  { &search554, &replace121.value, 0 },
  { &search555, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state805_xforms[] = {
  { &search415, &replace197.value, 0 },
  { &search552, &replace197.value, 0 },
  { &search553, &replace121.value, 0 },
  { &search554, &replace121.value, 0 },
  { &search555, &replace197.value, 0 },
  { &search842, &replace842.value, 0 },
  { &search854, &replace854.value, 0 },
  { &search866, &replace866.value, 0 },
  { &search884, &replace884.value, 0 },
  { &search902, &replace902.value, 0 },
  { &search926, &replace926.value, 0 },
};
static const struct transform nir_opt_algebraic_state806_xforms[] = {
  { &search415, &replace197.value, 0 },
  { &search552, &replace197.value, 0 },
  { &search553, &replace121.value, 0 },
  { &search554, &replace121.value, 0 },
  { &search555, &replace197.value, 0 },
  { &search1067, &replace1067.value, 0 },
};
static const struct transform nir_opt_algebraic_state807_xforms[] = {
  { &search348, &replace348.value, 0 },
  { &search415, &replace197.value, 0 },
  { &search552, &replace197.value, 0 },
  { &search553, &replace121.value, 0 },
  { &search554, &replace121.value, 0 },
  { &search555, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state808_xforms[] = {
  { &search339, &replace197.value, 0 },
  { &search348, &replace348.value, 0 },
  { &search415, &replace197.value, 0 },
  { &search552, &replace197.value, 0 },
  { &search553, &replace121.value, 0 },
  { &search554, &replace121.value, 0 },
  { &search555, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state809_xforms[] = {
  { &search347, &replace347.value, 0 },
  { &search348, &replace348.value, 0 },
  { &search415, &replace197.value, 0 },
  { &search552, &replace197.value, 0 },
  { &search553, &replace121.value, 0 },
  { &search554, &replace121.value, 0 },
  { &search555, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state810_xforms[] = {
  { &search348, &replace348.value, 0 },
  { &search415, &replace197.value, 0 },
  { &search532, &replace532.value, 0 },
  { &search552, &replace197.value, 0 },
  { &search553, &replace121.value, 0 },
  { &search554, &replace121.value, 0 },
  { &search555, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state811_xforms[] = {
  { &search348, &replace348.value, 0 },
  { &search368, &replace368.value, 0 },
  { &search415, &replace197.value, 0 },
  { &search552, &replace197.value, 0 },
  { &search553, &replace121.value, 0 },
  { &search554, &replace121.value, 0 },
  { &search555, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state812_xforms[] = {
  { &search340, &replace197.value, 0 },
  { &search415, &replace197.value, 0 },
  { &search552, &replace197.value, 0 },
  { &search553, &replace121.value, 0 },
  { &search554, &replace121.value, 0 },
  { &search555, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state813_xforms[] = {
  { &search339, &replace197.value, 0 },
  { &search340, &replace197.value, 0 },
  { &search415, &replace197.value, 0 },
  { &search552, &replace197.value, 0 },
  { &search553, &replace121.value, 0 },
  { &search554, &replace121.value, 0 },
  { &search555, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state814_xforms[] = {
  { &search340, &replace197.value, 0 },
  { &search347, &replace347.value, 0 },
  { &search415, &replace197.value, 0 },
  { &search552, &replace197.value, 0 },
  { &search553, &replace121.value, 0 },
  { &search554, &replace121.value, 0 },
  { &search555, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state815_xforms[] = {
  { &search340, &replace197.value, 0 },
  { &search415, &replace197.value, 0 },
  { &search532, &replace532.value, 0 },
  { &search552, &replace197.value, 0 },
  { &search553, &replace121.value, 0 },
  { &search554, &replace121.value, 0 },
  { &search555, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state816_xforms[] = {
  { &search340, &replace197.value, 0 },
  { &search360, &replace360.value, 0 },
  { &search415, &replace197.value, 0 },
  { &search552, &replace197.value, 0 },
  { &search553, &replace121.value, 0 },
  { &search554, &replace121.value, 0 },
  { &search555, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state817_xforms[] = {
  { &search415, &replace197.value, 0 },
  { &search531, &replace531.value, 0 },
  { &search552, &replace197.value, 0 },
  { &search553, &replace121.value, 0 },
  { &search554, &replace121.value, 0 },
  { &search555, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state818_xforms[] = {
  { &search339, &replace197.value, 0 },
  { &search415, &replace197.value, 0 },
  { &search531, &replace531.value, 0 },
  { &search552, &replace197.value, 0 },
  { &search553, &replace121.value, 0 },
  { &search554, &replace121.value, 0 },
  { &search555, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state819_xforms[] = {
  { &search347, &replace347.value, 0 },
  { &search415, &replace197.value, 0 },
  { &search531, &replace531.value, 0 },
  { &search552, &replace197.value, 0 },
  { &search553, &replace121.value, 0 },
  { &search554, &replace121.value, 0 },
  { &search555, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state820_xforms[] = {
  { &search415, &replace197.value, 0 },
  { &search531, &replace531.value, 0 },
  { &search532, &replace532.value, 0 },
  { &search552, &replace197.value, 0 },
  { &search553, &replace121.value, 0 },
  { &search554, &replace121.value, 0 },
  { &search555, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state821_xforms[] = {
  { &search415, &replace197.value, 0 },
  { &search552, &replace197.value, 0 },
  { &search553, &replace121.value, 0 },
  { &search554, &replace121.value, 0 },
  { &search555, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state822_xforms[] = {
  { &search415, &replace197.value, 0 },
  { &search552, &replace197.value, 0 },
  { &search553, &replace121.value, 0 },
  { &search554, &replace121.value, 0 },
  { &search555, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state823_xforms[] = {
  { &search415, &replace197.value, 0 },
  { &search552, &replace197.value, 0 },
  { &search553, &replace121.value, 0 },
  { &search554, &replace121.value, 0 },
  { &search555, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state824_xforms[] = {
  { &search415, &replace197.value, 0 },
  { &search552, &replace197.value, 0 },
  { &search553, &replace121.value, 0 },
  { &search554, &replace121.value, 0 },
  { &search555, &replace197.value, 0 },
  { &search841, &replace841.value, 0 },
  { &search853, &replace853.value, 0 },
  { &search865, &replace865.value, 0 },
  { &search883, &replace883.value, 0 },
  { &search901, &replace901.value, 0 },
  { &search925, &replace925.value, 0 },
};
static const struct transform nir_opt_algebraic_state825_xforms[] = {
  { &search415, &replace197.value, 0 },
  { &search552, &replace197.value, 0 },
  { &search553, &replace121.value, 0 },
  { &search554, &replace121.value, 0 },
  { &search555, &replace197.value, 0 },
  { &search833, &replace833.value, 0 },
  { &search835, &replace835.value, 0 },
  { &search845, &replace833.value, 0 },
  { &search847, &replace835.value, 0 },
  { &search857, &replace833.value, 0 },
  { &search859, &replace835.value, 0 },
  { &search869, &replace869.value, 0 },
  { &search871, &replace871.value, 0 },
  { &search875, &replace875.value, 0 },
  { &search877, &replace877.value, 0 },
  { &search887, &replace869.value, 0 },
  { &search889, &replace871.value, 0 },
  { &search893, &replace875.value, 0 },
  { &search895, &replace877.value, 0 },
  { &search905, &replace905.value, 0 },
  { &search907, &replace907.value, 0 },
  { &search911, &replace911.value, 0 },
  { &search913, &replace913.value, 0 },
  { &search917, &replace917.value, 0 },
  { &search919, &replace919.value, 0 },
};
static const struct transform nir_opt_algebraic_state826_xforms[] = {
  { &search240, &search2_0.value, 0 },
  { &search246, &replace246.value, 0 },
};
static const struct transform nir_opt_algebraic_state827_xforms[] = {
  { &search240, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state828_xforms[] = {
  { &search240, &search2_0.value, 0 },
  { &search246, &replace246.value, 0 },
};
static const struct transform nir_opt_algebraic_state829_xforms[] = {
  { &search240, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state830_xforms[] = {
  { &search240, &search2_0.value, 0 },
  { &search246, &replace246.value, 0 },
};
static const struct transform nir_opt_algebraic_state831_xforms[] = {
  { &search241, &search2_0.value, 0 },
  { &search243, &replace243.value, 0 },
};
static const struct transform nir_opt_algebraic_state832_xforms[] = {
  { &search241, &search2_0.value, 0 },
  { &search243, &replace243.value, 0 },
};
static const struct transform nir_opt_algebraic_state833_xforms[] = {
  { &search377_0, &replace381.value, 22 },
  { &search385, &search375_0.value, 0 },
  { &search393, &search386_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state834_xforms[] = {
  { &search377_0, &replace381.value, 22 },
  { &search386, &search386_0.value, 0 },
  { &search394, &search375_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state835_xforms[] = {
  { &search377_0, &replace381.value, 22 },
  { &search383, &search377_0.value, 0 },
  { &search391, &search378_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state836_xforms[] = {
  { &search377_0, &replace381.value, 22 },
  { &search384, &search378_0.value, 0 },
  { &search392, &search377_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state837_xforms[] = {
  { &search378_0, &replace382.value, 22 },
  { &search389, &search375_0.value, 0 },
  { &search397, &search386_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state838_xforms[] = {
  { &search378_0, &replace382.value, 22 },
  { &search390, &search386_0.value, 0 },
  { &search398, &search375_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state839_xforms[] = {
  { &search378_0, &replace382.value, 22 },
  { &search387, &search377_0.value, 0 },
  { &search395, &search378_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state840_xforms[] = {
  { &search378_0, &replace382.value, 22 },
  { &search388, &search378_0.value, 0 },
  { &search396, &search377_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state841_xforms[] = {
  { &search629, &replace629.value, 0 },
  { &search633, &replace633.value, 34 },
};
static const struct transform nir_opt_algebraic_state842_xforms[] = {
  { &search629, &replace629.value, 0 },
  { &search633, &replace633.value, 34 },
};
static const struct transform nir_opt_algebraic_state843_xforms[] = {
  { &search456, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state844_xforms[] = {
  { &search474, &replace474.value, 0 },
};
static const struct transform nir_opt_algebraic_state845_xforms[] = {
  { &search471, &replace471.value, 0 },
};
static const struct transform nir_opt_algebraic_state846_xforms[] = {
  { &search472, &replace472.value, 0 },
};
static const struct transform nir_opt_algebraic_state847_xforms[] = {
  { &search473, &replace473.value, 0 },
};
static const struct transform nir_opt_algebraic_state848_xforms[] = {
  { &search468, &replace468.value, 0 },
  { &search471_0, &replace481.value, 29 },
};
static const struct transform nir_opt_algebraic_state849_xforms[] = {
  { &search469, &replace469.value, 0 },
};
static const struct transform nir_opt_algebraic_state850_xforms[] = {
  { &search480, &search473_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state851_xforms[] = {
  { &search479, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state852_xforms[] = {
  { &search482, &search471_0.value, 30 },
};
static const struct transform nir_opt_algebraic_state853_xforms[] = {
  { &search470, &replace470.value, 0 },
};
static const struct transform nir_opt_algebraic_state854_xforms[] = {
  { &search455, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state855_xforms[] = {
  { &search457, &replace457.value, 26 },
  { &search462, &search2_0.value, 0 },
  { &search463, &search45_1.value, 0 },
  { &search464, &replace461.value, 0 },
  { &search466, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state856_xforms[] = {
  { &search33, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state857_xforms[] = {
  { &search25, &search2_0.value, 0 },
  { &search33, &replace14_1_0.value, 0 },
  { &search645, &replace645.value, 0 },
};
static const struct transform nir_opt_algebraic_state858_xforms[] = {
  { &search25, &search2_0.value, 0 },
  { &search33, &replace14_1_0.value, 0 },
  { &search645, &replace645.value, 0 },
  { &search650, &replace645.value, 0 },
};
static const struct transform nir_opt_algebraic_state859_xforms[] = {
  { &search31, &replace9.value, 0 },
  { &search32, &replace14_1_0.value, 0 },
  { &search33, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state860_xforms[] = {
  { &search33, &replace14_1_0.value, 0 },
  { &search637, &search633.value, 0 },
};
static const struct transform nir_opt_algebraic_state862_xforms[] = {
  { &search435, &search193_1.value, 0 },
};
static const struct transform nir_opt_algebraic_state863_xforms[] = {
  { &search2, &replace2.value, 2 },
  { &search96, &replace96.value, 0 },
  { &search110, &replace110.value, 0 },
  { &search436, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state865_xforms[] = {
  { &search439, &search193_1.value, 0 },
};
static const struct transform nir_opt_algebraic_state866_xforms[] = {
  { &search423, &search2_0.value, 0 },
  { &search444, &replace443.value, 24 },
  { &search446, &replace445.value, 24 },
};
static const struct transform nir_opt_algebraic_state867_xforms[] = {
  { &search423, &search2_0.value, 0 },
  { &search448, &replace447.value, 24 },
  { &search450, &replace449.value, 24 },
};
static const struct transform nir_opt_algebraic_state868_xforms[] = {
  { &search423, &search2_0.value, 0 },
  { &search444, &replace443.value, 24 },
  { &search446, &replace445.value, 24 },
  { &search448, &replace447.value, 24 },
  { &search450, &replace449.value, 24 },
};
static const struct transform nir_opt_algebraic_state869_xforms[] = {
  { &search423, &search2_0.value, 0 },
  { &search505, &replace505.value, 0 },
};
static const struct transform nir_opt_algebraic_state870_xforms[] = {
  { &search410, &replace410.value, 0 },
  { &search420, &search2_0.value, 0 },
  { &search421, &search2_0.value, 0 },
  { &search422, &replace9.value, 0 },
  { &search431, &replace14_1_0.value, 0 },
  { &search571, &replace571.value, 32 },
  { &search627, &replace627.value, 33 },
};
static const struct transform nir_opt_algebraic_state871_xforms[] = {
  { &search410, &replace410.value, 0 },
  { &search420, &search2_0.value, 0 },
  { &search421, &search2_0.value, 0 },
  { &search422, &replace9.value, 0 },
  { &search510, &search268_0.value, 0 },
  { &search571, &replace571.value, 32 },
  { &search627, &replace627.value, 33 },
};
static const struct transform nir_opt_algebraic_state872_xforms[] = {
  { &search420, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state873_xforms[] = {
  { &search420, &search2_0.value, 0 },
  { &search504, &replace504.value, 0 },
};
static const struct transform nir_opt_algebraic_state874_xforms[] = {
  { &search328, &replace328.value, 1 },
  { &search420, &search2_0.value, 0 },
  { &search564, &replace564.value, 0 },
};
static const struct transform nir_opt_algebraic_state875_xforms[] = {
  { &search725, &replace725.value, 0 },
};
static const struct transform nir_opt_algebraic_state876_xforms[] = {
  { &search723, &replace723.value, 0 },
};
static const struct transform nir_opt_algebraic_state877_xforms[] = {
  { &search713, &replace713.value, 0 },
};
static const struct transform nir_opt_algebraic_state878_xforms[] = {
  { &search719, &replace719.value, 0 },
};
static const struct transform nir_opt_algebraic_state879_xforms[] = {
  { &search721, &replace721.value, 0 },
};
static const struct transform nir_opt_algebraic_state880_xforms[] = {
  { &search711, &replace711.value, 0 },
};
static const struct transform nir_opt_algebraic_state881_xforms[] = {
  { &search717, &replace717.value, 0 },
};
static const struct transform nir_opt_algebraic_state882_xforms[] = {
  { &search707, &replace707.value, 0 },
};
static const struct transform nir_opt_algebraic_state883_xforms[] = {
  { &search709, &replace709.value, 0 },
};
static const struct transform nir_opt_algebraic_state884_xforms[] = {
  { &search715, &replace715.value, 0 },
};
static const struct transform nir_opt_algebraic_state885_xforms[] = {
  { &search726, &replace726.value, 0 },
};
static const struct transform nir_opt_algebraic_state886_xforms[] = {
  { &search724, &replace724.value, 0 },
};
static const struct transform nir_opt_algebraic_state887_xforms[] = {
  { &search714, &replace714.value, 0 },
};
static const struct transform nir_opt_algebraic_state888_xforms[] = {
  { &search720, &replace720.value, 0 },
};
static const struct transform nir_opt_algebraic_state889_xforms[] = {
  { &search722, &replace722.value, 0 },
};
static const struct transform nir_opt_algebraic_state890_xforms[] = {
  { &search712, &replace712.value, 0 },
};
static const struct transform nir_opt_algebraic_state891_xforms[] = {
  { &search718, &replace718.value, 0 },
};
static const struct transform nir_opt_algebraic_state892_xforms[] = {
  { &search708, &replace708.value, 0 },
};
static const struct transform nir_opt_algebraic_state893_xforms[] = {
  { &search710, &replace710.value, 0 },
};
static const struct transform nir_opt_algebraic_state894_xforms[] = {
  { &search716, &replace716.value, 0 },
};
static const struct transform nir_opt_algebraic_state895_xforms[] = {
  { &search374, &search374_0.value, 0 },
  { &search529, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state896_xforms[] = {
  { &search169, &replace148.value, 0 },
  { &search546, &replace121.value, 0 },
  { &search547, &replace197.value, 0 },
  { &search548, &replace197.value, 0 },
  { &search549, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state897_xforms[] = {
  { &search130, &replace130.value, 0 },
  { &search208, &replace207.value, 0 },
  { &search546, &replace121.value, 0 },
  { &search547, &replace197.value, 0 },
  { &search548, &replace197.value, 0 },
  { &search549, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state898_xforms[] = {
  { &search130, &replace130.value, 0 },
  { &search180, &replace180.value, 0 },
  { &search546, &replace121.value, 0 },
  { &search547, &replace197.value, 0 },
  { &search548, &replace197.value, 0 },
  { &search549, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state899_xforms[] = {
  { &search130, &replace130.value, 0 },
  { &search412, &replace80_0.value, 0 },
  { &search546, &replace121.value, 0 },
  { &search547, &replace197.value, 0 },
  { &search548, &replace197.value, 0 },
  { &search549, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state900_xforms[] = {
  { &search175, &replace175.value, 0 },
  { &search218, &search111_0.value, 0 },
  { &search546, &replace121.value, 0 },
  { &search547, &replace197.value, 0 },
  { &search548, &replace197.value, 0 },
  { &search549, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state901_xforms[] = {
  { &search175, &replace175.value, 0 },
  { &search179, &replace179.value, 0 },
  { &search218, &search111_0.value, 0 },
  { &search546, &replace121.value, 0 },
  { &search547, &replace197.value, 0 },
  { &search548, &replace197.value, 0 },
  { &search549, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state902_xforms[] = {
  { &search413, &replace80_0.value, 0 },
  { &search546, &replace121.value, 0 },
  { &search547, &replace197.value, 0 },
  { &search548, &replace197.value, 0 },
  { &search549, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state903_xforms[] = {
  { &search171, &replace158.value, 0 },
  { &search542, &replace197.value, 0 },
  { &search543, &replace121.value, 0 },
  { &search544, &replace121.value, 0 },
  { &search545, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state904_xforms[] = {
  { &search132, &replace132.value, 0 },
  { &search210, &replace209.value, 0 },
  { &search210, &replace209.value, 0 },
  { &search542, &replace197.value, 0 },
  { &search543, &replace121.value, 0 },
  { &search544, &replace121.value, 0 },
  { &search545, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state905_xforms[] = {
  { &search132, &replace132.value, 0 },
  { &search182, &replace182.value, 0 },
  { &search542, &replace197.value, 0 },
  { &search543, &replace121.value, 0 },
  { &search544, &replace121.value, 0 },
  { &search545, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state906_xforms[] = {
  { &search132, &replace132.value, 0 },
  { &search147, &replace146.value, 0 },
  { &search542, &replace197.value, 0 },
  { &search543, &replace121.value, 0 },
  { &search544, &replace121.value, 0 },
  { &search545, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state907_xforms[] = {
  { &search237, &search2_0.value, 0 },
  { &search248, &search17_0.value, 0 },
  { &search256, &search2_0.value, 0 },
  { &search248, &search17_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state908_xforms[] = {
  { &search237, &search2_0.value, 0 },
  { &search242, &replace221.value, 0 },
  { &search248, &search17_0.value, 0 },
  { &search256, &search2_0.value, 0 },
  { &search248, &search17_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state909_xforms[] = {
  { &search214, &replace214.value, 0 },
  { &search237, &search2_0.value, 0 },
  { &search248, &search17_0.value, 0 },
  { &search248, &search17_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state910_xforms[] = {
  { &search237, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state911_xforms[] = {
  { &search237, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state912_xforms[] = {
  { &search237, &search2_0.value, 0 },
  { &search248, &search17_0.value, 0 },
  { &search248, &search17_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state913_xforms[] = {
  { &search237, &search2_0.value, 0 },
  { &search258, &search17_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state914_xforms[] = {
  { &search237, &search2_0.value, 0 },
  { &search248, &search17_0.value, 0 },
  { &search256, &search2_0.value, 0 },
  { &search248, &search17_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state915_xforms[] = {
  { &search237, &search2_0.value, 0 },
  { &search264, &search36_0.value, 19 },
  { &search266, &replace265.value, 20 },
};
static const struct transform nir_opt_algebraic_state916_xforms[] = {
  { &search236, &search2_0.value, 0 },
  { &search250, &search208_0.value, 0 },
  { &search252, &search208_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state917_xforms[] = {
  { &search236, &search2_0.value, 0 },
  { &search250, &search208_0.value, 0 },
  { &search252, &search208_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state918_xforms[] = {
  { &search236, &search2_0.value, 0 },
  { &search245, &replace222.value, 0 },
  { &search250, &search208_0.value, 0 },
  { &search252, &search208_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state919_xforms[] = {
  { &search236, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state920_xforms[] = {
  { &search236, &search2_0.value, 0 },
  { &search535, &search36_0.value, 19 },
};
static const struct transform nir_opt_algebraic_state921_xforms[] = {
  { &search236, &search2_0.value, 0 },
  { &search250, &search208_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state922_xforms[] = {
  { &search236, &search2_0.value, 0 },
  { &search254, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state923_xforms[] = {
  { &search236, &search2_0.value, 0 },
  { &search250, &search208_0.value, 0 },
  { &search252, &search208_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state924_xforms[] = {
  { &search216, &replace216.value, 0 },
  { &search236, &search2_0.value, 0 },
  { &search250, &search208_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state925_xforms[] = {
  { &search36_0, &replace269.value, 21 },
  { &search271, &replace271.value, 20 },
  { &search530, &search24_1.value, 0 },
};
static const struct transform nir_opt_algebraic_state926_xforms[] = {
  { &search36_0, &replace269.value, 21 },
  { &search272, &replace272.value, 20 },
  { &search530, &search24_1.value, 0 },
};
static const struct transform nir_opt_algebraic_state927_xforms[] = {
  { &search36_0, &replace269.value, 21 },
  { &search273, &replace273.value, 19 },
  { &search530, &search24_1.value, 0 },
};
static const struct transform nir_opt_algebraic_state928_xforms[] = {
  { &search36_0, &replace269.value, 21 },
  { &search530, &search24_1.value, 0 },
};
static const struct transform nir_opt_algebraic_state929_xforms[] = {
  { &search36_0, &replace269.value, 21 },
  { &search409, &replace213.value, 0 },
  { &search530, &search24_1.value, 0 },
};
static const struct transform nir_opt_algebraic_state930_xforms[] = {
  { &search30, &search24_1.value, 0 },
  { &search67, &search66.value, 9 },
};
static const struct transform nir_opt_algebraic_state931_xforms[] = {
  { &search35, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state932_xforms[] = {
  { &search24, &search2_0.value, 0 },
  { &search30, &search24_1.value, 0 },
  { &search649, &replace649.value, 0 },
};
static const struct transform nir_opt_algebraic_state933_xforms[] = {
  { &search24, &search2_0.value, 0 },
  { &search30, &search24_1.value, 0 },
  { &search94, &replace94.value, 0 },
};
static const struct transform nir_opt_algebraic_state934_xforms[] = {
  { &search24, &search2_0.value, 0 },
  { &search30, &search24_1.value, 0 },
};
static const struct transform nir_opt_algebraic_state935_xforms[] = {
  { &search24, &search2_0.value, 0 },
  { &search30, &search24_1.value, 0 },
  { &search67, &search66.value, 9 },
};
static const struct transform nir_opt_algebraic_state936_xforms[] = {
  { &search24, &search2_0.value, 0 },
  { &search35, &replace14_1_0.value, 0 },
  { &search644, &replace644.value, 0 },
};
static const struct transform nir_opt_algebraic_state937_xforms[] = {
  { &search24, &search2_0.value, 0 },
  { &search35, &replace14_1_0.value, 0 },
  { &search644, &replace644.value, 0 },
  { &search648, &replace644.value, 0 },
};
static const struct transform nir_opt_algebraic_state938_xforms[] = {
  { &search30, &search24_1.value, 0 },
  { &search34, &replace14_1_0.value, 0 },
  { &search35, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state939_xforms[] = {
  { &search30, &search24_1.value, 0 },
  { &search34, &replace14_1_0.value, 0 },
  { &search67, &search66.value, 9 },
};
static const struct transform nir_opt_algebraic_state940_xforms[] = {
  { &search30, &search24_1.value, 0 },
  { &search67, &search66.value, 9 },
  { &search79, &search78.value, 15 },
};
static const struct transform nir_opt_algebraic_state941_xforms[] = {
  { &search35, &replace14_1_0.value, 0 },
  { &search79, &search78.value, 15 },
};
static const struct transform nir_opt_algebraic_state942_xforms[] = {
  { &search36, &replace36.value, 0 },
};
static const struct transform nir_opt_algebraic_state943_xforms[] = {
  { &search30, &search24_1.value, 0 },
};
static const struct transform nir_opt_algebraic_state944_xforms[] = {
  { &search30, &search24_1.value, 0 },
  { &search67, &search66.value, 9 },
  { &search636, &search632.value, 0 },
};
static const struct transform nir_opt_algebraic_state945_xforms[] = {
  { &search35, &replace14_1_0.value, 0 },
  { &search636, &search632.value, 0 },
};
static const struct transform nir_opt_algebraic_state946_xforms[] = {
  { &search30, &search24_1.value, 0 },
  { &search34, &replace14_1_0.value, 0 },
  { &search35, &replace14_1_0.value, 0 },
  { &search67, &search66.value, 9 },
};
static const struct transform nir_opt_algebraic_state947_xforms[] = {
  { &search28, &replace28.value, 0 },
  { &search79, &search78.value, 15 },
};
static const struct transform nir_opt_algebraic_state948_xforms[] = {
  { &search135, &replace135.value, 0 },
  { &search184, &replace184.value, 0 },
  { &search406, &replace209.value, 0 },
  { &search541, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state949_xforms[] = {
  { &search158, &replace158.value, 0 },
  { &search177, &replace177.value, 0 },
  { &search541, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state950_xforms[] = {
  { &search162, &replace162.value, 0 },
  { &search541, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state951_xforms[] = {
  { &search159, &replace158.value, 0 },
  { &search541, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state952_xforms[] = {
  { &search163, &replace162.value, 0 },
  { &search541, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state953_xforms[] = {
  { &search160, &replace158.value, 0 },
  { &search541, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state954_xforms[] = {
  { &search164, &replace162.value, 0 },
  { &search541, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state955_xforms[] = {
  { &search161, &replace158.value, 0 },
  { &search406, &replace209.value, 0 },
};
static const struct transform nir_opt_algebraic_state956_xforms[] = {
  { &search128, &replace128.value, 0 },
  { &search167, &replace165.value, 0 },
  { &search406, &replace209.value, 0 },
};
static const struct transform nir_opt_algebraic_state957_xforms[] = {
  { &search134, &replace134.value, 0 },
  { &search186, &replace186.value, 0 },
  { &search405, &replace207.value, 0 },
  { &search540, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state958_xforms[] = {
  { &search148, &replace148.value, 0 },
  { &search178, &replace178.value, 0 },
  { &search540, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state959_xforms[] = {
  { &search152, &replace152.value, 0 },
  { &search540, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state960_xforms[] = {
  { &search149, &replace148.value, 0 },
  { &search540, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state961_xforms[] = {
  { &search153, &replace152.value, 0 },
  { &search540, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state962_xforms[] = {
  { &search150, &replace148.value, 0 },
  { &search540, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state963_xforms[] = {
  { &search154, &replace152.value, 0 },
  { &search540, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state964_xforms[] = {
  { &search151, &replace148.value, 0 },
  { &search405, &replace207.value, 0 },
};
static const struct transform nir_opt_algebraic_state965_xforms[] = {
  { &search129, &replace129.value, 0 },
  { &search157, &replace155.value, 0 },
  { &search405, &replace207.value, 0 },
};
static const struct transform nir_opt_algebraic_state968_xforms[] = {
  { &search46, &replace45.value, 0 },
};
static const struct transform nir_opt_algebraic_state969_xforms[] = {
  { &search37, &search24_1.value, 0 },
  { &search41, &search2_0.value, 0 },
  { &search43, &search15_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state970_xforms[] = {
  { &search37, &search24_1.value, 0 },
  { &search41, &search2_0.value, 0 },
  { &search43, &search15_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state971_xforms[] = {
  { &search37, &search24_1.value, 0 },
  { &search41, &search2_0.value, 0 },
  { &search43, &search15_0.value, 0 },
  { &search46, &replace45.value, 0 },
  { &search642, &replace642.value, 0 },
};
static const struct transform nir_opt_algebraic_state972_xforms[] = {
  { &search37, &search24_1.value, 0 },
  { &search41, &search2_0.value, 0 },
  { &search43, &search15_0.value, 0 },
  { &search46, &replace45.value, 0 },
  { &search642, &replace642.value, 0 },
  { &search646, &replace642.value, 0 },
};
static const struct transform nir_opt_algebraic_state973_xforms[] = {
  { &search640, &replace640.value, 0 },
};
static const struct transform nir_opt_algebraic_state974_xforms[] = {
  { &search640, &replace640.value, 0 },
};
static const struct transform nir_opt_algebraic_state975_xforms[] = {
  { &search46, &replace45.value, 0 },
  { &search640, &replace640.value, 0 },
};
static const struct transform nir_opt_algebraic_state976_xforms[] = {
  { &search640, &replace640.value, 0 },
};
static const struct transform nir_opt_algebraic_state979_xforms[] = {
  { &search46, &replace45.value, 0 },
};
static const struct transform nir_opt_algebraic_state982_xforms[] = {
  { &search45, &replace45.value, 0 },
  { &search46, &replace45.value, 0 },
};
static const struct transform nir_opt_algebraic_state985_xforms[] = {
  { &search46, &replace45.value, 0 },
};
static const struct transform nir_opt_algebraic_state988_xforms[] = {
  { &search46, &replace45.value, 0 },
};
static const struct transform nir_opt_algebraic_state989_xforms[] = {
  { &search46, &replace45.value, 0 },
};
static const struct transform nir_opt_algebraic_state991_xforms[] = {
  { &search46, &replace45.value, 0 },
};
static const struct transform nir_opt_algebraic_state992_xforms[] = {
  { &search457, &replace457.value, 26 },
  { &search462, &search2_0.value, 0 },
  { &search463, &search45_1.value, 0 },
  { &search464, &replace461.value, 0 },
  { &search467, &search17_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state993_xforms[] = {
  { &search15_0, &replace634.value, 35 },
};
static const struct transform nir_opt_algebraic_state994_xforms[] = {
  { &search15_0, &replace634.value, 35 },
};
static const struct transform nir_opt_algebraic_state995_xforms[] = {
  { &search458, &search457.value, 27 },
};
static const struct transform nir_opt_algebraic_state996_xforms[] = {
  { &search458, &search457.value, 27 },
  { &search460, &search45_1.value, 0 },
  { &search461, &replace461.value, 0 },
};
static const struct transform nir_opt_algebraic_state997_xforms[] = {
  { &search238, &search2_0.value, 0 },
  { &search251, &replace251.value, 0 },
  { &search253, &replace251.value, 0 },
};
static const struct transform nir_opt_algebraic_state998_xforms[] = {
  { &search238, &search2_0.value, 0 },
  { &search251, &replace251.value, 0 },
  { &search253, &replace251.value, 0 },
};
static const struct transform nir_opt_algebraic_state999_xforms[] = {
  { &search238, &search2_0.value, 0 },
  { &search251, &replace251.value, 0 },
  { &search253, &replace251.value, 0 },
  { &search255, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state1000_xforms[] = {
  { &search238, &search2_0.value, 0 },
  { &search247, &replace247.value, 0 },
  { &search251, &replace251.value, 0 },
  { &search253, &replace251.value, 0 },
};
static const struct transform nir_opt_algebraic_state1001_xforms[] = {
  { &search238, &search2_0.value, 0 },
  { &search251, &replace251.value, 0 },
  { &search253, &replace251.value, 0 },
};
static const struct transform nir_opt_algebraic_state1002_xforms[] = {
  { &search239, &search2_0.value, 0 },
  { &search249, &search20_0.value, 0 },
  { &search257, &search2_0.value, 0 },
  { &search249, &search20_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state1003_xforms[] = {
  { &search239, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state1004_xforms[] = {
  { &search239, &search2_0.value, 0 },
  { &search249, &search20_0.value, 0 },
  { &search257, &search2_0.value, 0 },
  { &search249, &search20_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state1005_xforms[] = {
  { &search239, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state1006_xforms[] = {
  { &search239, &search2_0.value, 0 },
  { &search249, &search20_0.value, 0 },
  { &search249, &search20_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state1007_xforms[] = {
  { &search239, &search2_0.value, 0 },
  { &search249, &search20_0.value, 0 },
  { &search257, &search2_0.value, 0 },
  { &search259, &search20_0.value, 0 },
  { &search249, &search20_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state1008_xforms[] = {
  { &search239, &search2_0.value, 0 },
  { &search259, &search20_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state1009_xforms[] = {
  { &search239, &search2_0.value, 0 },
  { &search244, &replace244.value, 0 },
  { &search249, &search20_0.value, 0 },
  { &search257, &search2_0.value, 0 },
  { &search249, &search20_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state1010_xforms[] = {
  { &search239, &search2_0.value, 0 },
  { &search244, &replace244.value, 0 },
};
static const struct transform nir_opt_algebraic_state1011_xforms[] = {
  { &search239, &search2_0.value, 0 },
  { &search249, &search20_0.value, 0 },
  { &search257, &search2_0.value, 0 },
  { &search249, &search20_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state1012_xforms[] = {
  { &search416, &replace197.value, 0 },
  { &search487, &replace80_0.value, 0 },
  { &search490, &replace146.value, 0 },
  { &search506, &replace146.value, 0 },
  { &search507, &replace80_0.value, 0 },
  { &search551, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state1013_xforms[] = {
  { &search417, &replace121.value, 0 },
  { &search488, &replace146.value, 0 },
  { &search489, &replace80_0.value, 0 },
  { &search508, &replace80_0.value, 0 },
  { &search509, &replace146.value, 0 },
  { &search550, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state1014_xforms[] = {
  { &search326, &replace326.value, 0 },
  { &search417, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state1015_xforms[] = {
  { &search233, &replace148.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search373, &replace373.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state1016_xforms[] = {
  { &search233, &replace148.value, 0 },
  { &search234, &replace152.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
  { &search652, &search652_0_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state1017_xforms[] = {
  { &search233, &replace148.value, 0 },
  { &search234, &replace152.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
  { &search653, &search653_0_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state1018_xforms[] = {
  { &search233, &replace148.value, 0 },
  { &search234, &replace152.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
  { &search654, &search654_0_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state1019_xforms[] = {
  { &search279, &search279_0.value, 0 },
  { &search686, &replace686.value, 48 },
};
static const struct transform nir_opt_algebraic_state1020_xforms[] = {
  { &search411, &search0_0.value, 0 },
  { &search16_0, &replace635.value, 35 },
};
static const struct transform nir_opt_algebraic_state1021_xforms[] = {
  { &search241, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state1022_xforms[] = {
  { &search241, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state1023_xforms[] = {
  { &search241, &search2_0.value, 0 },
  { &search243, &replace243.value, 0 },
};
static const struct transform nir_opt_algebraic_state1024_xforms[] = {
  { &search423, &search2_0.value, 0 },
  { &search443, &replace443.value, 24 },
  { &search445, &replace445.value, 24 },
};
static const struct transform nir_opt_algebraic_state1025_xforms[] = {
  { &search423, &search2_0.value, 0 },
  { &search447, &replace447.value, 24 },
  { &search449, &replace449.value, 24 },
};
static const struct transform nir_opt_algebraic_state1026_xforms[] = {
  { &search423, &search2_0.value, 0 },
  { &search443, &replace443.value, 24 },
  { &search445, &replace445.value, 24 },
  { &search448, &replace447.value, 24 },
  { &search450, &replace449.value, 24 },
};
static const struct transform nir_opt_algebraic_state1027_xforms[] = {
  { &search423, &search2_0.value, 0 },
  { &search444, &replace443.value, 24 },
  { &search446, &replace445.value, 24 },
  { &search447, &replace447.value, 24 },
  { &search449, &replace449.value, 24 },
};
static const struct transform nir_opt_algebraic_state1028_xforms[] = {
  { &search423, &search2_0.value, 0 },
  { &search443, &replace443.value, 24 },
  { &search445, &replace445.value, 24 },
  { &search447, &replace447.value, 24 },
  { &search449, &replace449.value, 24 },
};
static const struct transform nir_opt_algebraic_state1029_xforms[] = {
  { &search2, &replace2.value, 2 },
  { &search436, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state1030_xforms[] = {
  { &search440, &search2_0.value, 0 },
  { &search565, &replace565.value, 32 },
  { &search441_1, &replace566.value, 32 },
  { &search567, &replace567.value, 32 },
  { &search442_1, &replace624.value, 33 },
};
static const struct transform nir_opt_algebraic_state1031_xforms[] = {
  { &search76, &replace71.value, 12 },
  { &search77, &replace72.value, 13 },
  { &search79, &search78.value, 15 },
};
static const struct transform nir_opt_algebraic_state1032_xforms[] = {
  { &search75, &replace75.value, 5 },
  { &search76, &replace71.value, 12 },
  { &search77, &replace72.value, 13 },
  { &search79, &search78.value, 15 },
};
static const struct transform nir_opt_algebraic_state1033_xforms[] = {
  { &search24, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state1034_xforms[] = {
  { &search24, &search2_0.value, 0 },
  { &search76, &replace71.value, 12 },
  { &search77, &replace72.value, 13 },
  { &search79, &search78.value, 15 },
};
static const struct transform nir_opt_algebraic_state1035_xforms[] = {
  { &search24, &search2_0.value, 0 },
  { &search79, &search78.value, 15 },
};
static const struct transform nir_opt_algebraic_state1036_xforms[] = {
  { &search24, &search2_0.value, 0 },
  { &search75, &replace75.value, 5 },
  { &search76, &replace71.value, 12 },
  { &search77, &replace72.value, 13 },
  { &search79, &search78.value, 15 },
};
static const struct transform nir_opt_algebraic_state1037_xforms[] = {
  { &search24, &search2_0.value, 0 },
  { &search30, &search24_1.value, 0 },
};
static const struct transform nir_opt_algebraic_state1038_xforms[] = {
  { &search30, &search24_1.value, 0 },
  { &search76, &replace71.value, 12 },
  { &search77, &replace72.value, 13 },
  { &search79, &search78.value, 15 },
};
static const struct transform nir_opt_algebraic_state1039_xforms[] = {
  { &search30, &search24_1.value, 0 },
  { &search75, &replace75.value, 5 },
  { &search76, &replace71.value, 12 },
  { &search77, &replace72.value, 13 },
  { &search79, &search78.value, 15 },
};
static const struct transform nir_opt_algebraic_state1040_xforms[] = {
  { &search28, &replace28.value, 0 },
  { &search76, &replace71.value, 12 },
  { &search77, &replace72.value, 13 },
  { &search79, &search78.value, 15 },
};
static const struct transform nir_opt_algebraic_state1041_xforms[] = {
  { &search28, &replace28.value, 0 },
  { &search71, &replace71.value, 12 },
  { &search72, &replace72.value, 13 },
  { &search76, &replace71.value, 12 },
  { &search77, &replace72.value, 13 },
  { &search79, &search78.value, 15 },
};
static const struct transform nir_opt_algebraic_state1042_xforms[] = {
  { &search28, &replace28.value, 0 },
  { &search75, &replace75.value, 5 },
  { &search76, &replace71.value, 12 },
  { &search77, &replace72.value, 13 },
  { &search79, &search78.value, 15 },
};
static const struct transform nir_opt_algebraic_state1043_xforms[] = {
  { &search28, &replace28.value, 0 },
  { &search71, &replace71.value, 12 },
  { &search72, &replace72.value, 13 },
  { &search75, &replace75.value, 5 },
  { &search76, &replace71.value, 12 },
  { &search77, &replace72.value, 13 },
  { &search79, &search78.value, 15 },
};
static const struct transform nir_opt_algebraic_state1044_xforms[] = {
  { &search76, &replace71.value, 12 },
  { &search77, &replace72.value, 13 },
  { &search79, &search78.value, 15 },
  { &search636, &search632.value, 0 },
};
static const struct transform nir_opt_algebraic_state1045_xforms[] = {
  { &search75, &replace75.value, 5 },
  { &search76, &replace71.value, 12 },
  { &search77, &replace72.value, 13 },
  { &search79, &search78.value, 15 },
  { &search636, &search632.value, 0 },
};
static const struct transform nir_opt_algebraic_state1046_xforms[] = {
  { &search30, &search24_1.value, 0 },
  { &search67, &search66.value, 9 },
  { &search76, &replace71.value, 12 },
  { &search77, &replace72.value, 13 },
  { &search79, &search78.value, 15 },
};
static const struct transform nir_opt_algebraic_state1047_xforms[] = {
  { &search30, &search24_1.value, 0 },
  { &search67, &search66.value, 9 },
  { &search75, &replace75.value, 5 },
  { &search76, &replace71.value, 12 },
  { &search77, &replace72.value, 13 },
  { &search79, &search78.value, 15 },
};
static const struct transform nir_opt_algebraic_state1048_xforms[] = {
  { &search35, &replace14_1_0.value, 0 },
  { &search76, &replace71.value, 12 },
  { &search77, &replace72.value, 13 },
  { &search79, &search78.value, 15 },
};
static const struct transform nir_opt_algebraic_state1049_xforms[] = {
  { &search35, &replace14_1_0.value, 0 },
  { &search75, &replace75.value, 5 },
  { &search76, &replace71.value, 12 },
  { &search77, &replace72.value, 13 },
  { &search79, &search78.value, 15 },
};
static const struct transform nir_opt_algebraic_state1050_xforms[] = {
  { &search28, &replace28.value, 0 },
  { &search76, &replace71.value, 12 },
  { &search77, &replace72.value, 13 },
  { &search79, &search78.value, 15 },
};
static const struct transform nir_opt_algebraic_state1051_xforms[] = {
  { &search28, &replace28.value, 0 },
  { &search71, &replace71.value, 12 },
  { &search72, &replace72.value, 13 },
  { &search76, &replace71.value, 12 },
  { &search77, &replace72.value, 13 },
  { &search79, &search78.value, 15 },
};
static const struct transform nir_opt_algebraic_state1052_xforms[] = {
  { &search236, &search2_0.value, 0 },
  { &search250, &search208_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state1053_xforms[] = {
  { &search236, &search2_0.value, 0 },
  { &search250, &search208_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state1054_xforms[] = {
  { &search236, &search2_0.value, 0 },
  { &search245, &replace222.value, 0 },
  { &search250, &search208_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state1055_xforms[] = {
  { &search236, &search2_0.value, 0 },
  { &search250, &search208_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state1056_xforms[] = {
  { &search236, &search2_0.value, 0 },
  { &search274, &search274_0_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state1057_xforms[] = {
  { &search236, &search2_0.value, 0 },
  { &search274, &search274_0_0.value, 0 },
  { &search535, &search36_0.value, 19 },
};
static const struct transform nir_opt_algebraic_state1058_xforms[] = {
  { &search236, &search2_0.value, 0 },
  { &search250, &search208_0.value, 0 },
  { &search274, &search274_0_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state1059_xforms[] = {
  { &search236, &search2_0.value, 0 },
  { &search254, &search2_0.value, 0 },
  { &search274, &search274_0_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state1060_xforms[] = {
  { &search236, &search2_0.value, 0 },
  { &search250, &search208_0.value, 0 },
  { &search252, &search208_0.value, 0 },
  { &search274, &search274_0_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state1061_xforms[] = {
  { &search236, &search2_0.value, 0 },
  { &search250, &search208_0.value, 0 },
  { &search274, &search274_0_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state1062_xforms[] = {
  { &search236, &search2_0.value, 0 },
  { &search263, &search36_0.value, 19 },
  { &search265, &replace265.value, 20 },
  { &search274, &search274_0_0.value, 0 },
  { &search535, &search36_0.value, 19 },
};
static const struct transform nir_opt_algebraic_state1063_xforms[] = {
  { &search189, &replace189.value, 0 },
  { &search336, &replace127.value, 0 },
  { &search542, &replace197.value, 0 },
  { &search543, &replace121.value, 0 },
  { &search544, &replace121.value, 0 },
  { &search545, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state1064_xforms[] = {
  { &search132, &replace132.value, 0 },
  { &search170, &replace158.value, 0 },
  { &search542, &replace197.value, 0 },
  { &search543, &replace121.value, 0 },
  { &search544, &replace121.value, 0 },
  { &search545, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state1065_xforms[] = {
  { &search190, &replace189.value, 0 },
  { &search541, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state1066_xforms[] = {
  { &search165, &replace165.value, 0 },
  { &search177, &replace177.value, 0 },
  { &search541, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state1069_xforms[] = {
  { &search37, &search24_1.value, 0 },
  { &search41, &search2_0.value, 0 },
  { &search43, &search15_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state1070_xforms[] = {
  { &search37, &search24_1.value, 0 },
  { &search41, &search2_0.value, 0 },
  { &search43, &search15_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state1071_xforms[] = {
  { &search640, &replace640.value, 0 },
};
static const struct transform nir_opt_algebraic_state1072_xforms[] = {
  { &search640, &replace640.value, 0 },
};
static const struct transform nir_opt_algebraic_state1081_xforms[] = {
  { &search640, &replace640.value, 0 },
};
static const struct transform nir_opt_algebraic_state1085_xforms[] = {
  { &search46, &replace45.value, 0 },
};
static const struct transform nir_opt_algebraic_state1086_xforms[] = {
  { &search46, &replace45.value, 0 },
};
static const struct transform nir_opt_algebraic_state1088_xforms[] = {
  { &search155, &replace155.value, 0 },
  { &search178, &replace178.value, 0 },
  { &search540, &replace197.value, 0 },
};
static const struct transform nir_opt_algebraic_state1089_xforms[] = {
  { &search459, &replace459.value, 27 },
};
static const struct transform nir_opt_algebraic_state1090_xforms[] = {
  { &search15_0, &replace634.value, 35 },
};
static const struct transform nir_opt_algebraic_state1091_xforms[] = {
  { &search130, &replace130.value, 0 },
  { &search168, &replace148.value, 0 },
  { &search546, &replace121.value, 0 },
  { &search547, &replace197.value, 0 },
  { &search548, &replace197.value, 0 },
  { &search549, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state1092_xforms[] = {
  { &search238, &search2_0.value, 0 },
  { &search275, &replace275.value, 0 },
};
static const struct transform nir_opt_algebraic_state1093_xforms[] = {
  { &search238, &search2_0.value, 0 },
  { &search275, &replace275.value, 0 },
};
static const struct transform nir_opt_algebraic_state1094_xforms[] = {
  { &search238, &search2_0.value, 0 },
  { &search275, &replace275.value, 0 },
};
static const struct transform nir_opt_algebraic_state1095_xforms[] = {
  { &search238, &search2_0.value, 0 },
  { &search251, &replace251.value, 0 },
  { &search275, &replace275.value, 0 },
};
static const struct transform nir_opt_algebraic_state1096_xforms[] = {
  { &search238, &search2_0.value, 0 },
  { &search255, &search2_0.value, 0 },
  { &search275, &replace275.value, 0 },
};
static const struct transform nir_opt_algebraic_state1097_xforms[] = {
  { &search238, &search2_0.value, 0 },
  { &search247, &replace247.value, 0 },
  { &search275, &replace275.value, 0 },
};
static const struct transform nir_opt_algebraic_state1098_xforms[] = {
  { &search238, &search2_0.value, 0 },
  { &search251, &replace251.value, 0 },
  { &search253, &replace251.value, 0 },
  { &search275, &replace275.value, 0 },
};
static const struct transform nir_opt_algebraic_state1099_xforms[] = {
  { &search31, &replace9.value, 0 },
};
static const struct transform nir_opt_algebraic_state1100_xforms[] = {
  { &search240, &search2_0.value, 0 },
  { &search276, &replace276.value, 0 },
};
static const struct transform nir_opt_algebraic_state1101_xforms[] = {
  { &search240, &search2_0.value, 0 },
  { &search276, &replace276.value, 0 },
};
static const struct transform nir_opt_algebraic_state1102_xforms[] = {
  { &search240, &search2_0.value, 0 },
  { &search246, &replace246.value, 0 },
  { &search276, &replace276.value, 0 },
};
static const struct transform nir_opt_algebraic_state1103_xforms[] = {
  { &search423, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state1104_xforms[] = {
  { &search37, &search24_1.value, 0 },
  { &search41, &search2_0.value, 0 },
  { &search43, &search15_0.value, 0 },
  { &search80, &replace80.value, 0 },
};
static const struct transform nir_opt_algebraic_state1105_xforms[] = {
  { &search175, &replace175.value, 0 },
  { &search179, &replace179.value, 0 },
  { &search536, &replace121.value, 0 },
  { &search546, &replace121.value, 0 },
  { &search547, &replace197.value, 0 },
  { &search548, &replace197.value, 0 },
  { &search549, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state1106_xforms[] = {
  { &search175, &replace175.value, 0 },
  { &search179, &replace179.value, 0 },
  { &search218, &search111_0.value, 0 },
  { &search537, &replace121.value, 0 },
  { &search546, &replace121.value, 0 },
  { &search547, &replace197.value, 0 },
  { &search548, &replace197.value, 0 },
  { &search549, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state1107_xforms[] = {
  { &search174, &replace174.value, 0 },
  { &search330, &search122_1.value, 0 },
  { &search546, &replace121.value, 0 },
  { &search547, &replace197.value, 0 },
  { &search548, &replace197.value, 0 },
  { &search549, &replace121.value, 0 },
};
static const struct transform nir_opt_algebraic_state1108_xforms[] = {
  { &search237, &search2_0.value, 0 },
  { &search538, &search536_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state1109_xforms[] = {
  { &search237, &search2_0.value, 0 },
  { &search539, &search537_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state1110_xforms[] = {
  { &search24, &search2_0.value, 0 },
  { &search30, &search24_1.value, 0 },
  { &search95, &replace95.value, 12 },
};
static const struct transform nir_opt_algebraic_state1111_xforms[] = {
  { &search28, &replace28.value, 0 },
  { &search73, &replace73.value, 12 },
  { &search74, &replace74.value, 13 },
  { &search79, &search78.value, 15 },
};
static const struct transform nir_opt_algebraic_state1112_xforms[] = {
  { &search28, &replace28.value, 0 },
  { &search73, &replace73.value, 12 },
  { &search74, &replace74.value, 13 },
  { &search76, &replace71.value, 12 },
  { &search77, &replace72.value, 13 },
  { &search79, &search78.value, 15 },
};
static const struct transform nir_opt_algebraic_state1113_xforms[] = {
  { &search28, &replace28.value, 0 },
  { &search71, &replace71.value, 12 },
  { &search72, &replace72.value, 13 },
  { &search73, &replace73.value, 12 },
  { &search74, &replace74.value, 13 },
  { &search76, &replace71.value, 12 },
  { &search77, &replace72.value, 13 },
  { &search79, &search78.value, 15 },
};
static const struct transform nir_opt_algebraic_state1114_xforms[] = {
  { &search28, &replace28.value, 0 },
  { &search70, &replace70.value, 5 },
  { &search71, &replace71.value, 12 },
  { &search72, &replace72.value, 13 },
  { &search76, &replace71.value, 12 },
  { &search77, &replace72.value, 13 },
  { &search79, &search78.value, 15 },
};
static const struct transform nir_opt_algebraic_state1115_xforms[] = {
  { &search28, &replace28.value, 0 },
  { &search70, &replace70.value, 5 },
  { &search71, &replace71.value, 12 },
  { &search72, &replace72.value, 13 },
  { &search75, &replace75.value, 5 },
  { &search76, &replace71.value, 12 },
  { &search77, &replace72.value, 13 },
  { &search79, &search78.value, 15 },
};
static const struct transform nir_opt_algebraic_state1116_xforms[] = {
  { &search28, &replace28.value, 0 },
  { &search70, &replace70.value, 5 },
  { &search71, &replace71.value, 12 },
  { &search72, &replace72.value, 13 },
  { &search73, &replace73.value, 12 },
  { &search74, &replace74.value, 13 },
  { &search76, &replace71.value, 12 },
  { &search77, &replace72.value, 13 },
  { &search79, &search78.value, 15 },
};
static const struct transform nir_opt_algebraic_state1117_xforms[] = {
  { &search28, &replace28.value, 0 },
  { &search73, &replace73.value, 12 },
  { &search74, &replace74.value, 13 },
  { &search79, &search78.value, 15 },
};
static const struct transform nir_opt_algebraic_state1118_xforms[] = {
  { &search28, &replace28.value, 0 },
  { &search70, &replace70.value, 5 },
  { &search71, &replace71.value, 12 },
  { &search72, &replace72.value, 13 },
  { &search76, &replace71.value, 12 },
  { &search77, &replace72.value, 13 },
  { &search79, &search78.value, 15 },
};
static const struct transform nir_opt_algebraic_state1120_xforms[] = {
  { &search410, &replace410.value, 0 },
  { &search420, &search2_0.value, 0 },
  { &search421, &search2_0.value, 0 },
  { &search422, &replace9.value, 0 },
  { &search431, &replace14_1_0.value, 0 },
  { &search571, &replace571.value, 32 },
  { &search627, &replace627.value, 33 },
};
static const struct transform nir_opt_algebraic_state1121_xforms[] = {
  { &search232, &replace148.value, 0 },
  { &search233, &replace148.value, 0 },
  { &search235, &replace152.value, 0 },
  { &search323, &replace323.value, 0 },
  { &search500, &replace14_1_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state1122_xforms[] = {
  { &search2, &replace2.value, 2 },
  { &search436, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state1123_xforms[] = {
  { &search440, &search2_0.value, 0 },
  { &search565, &replace565.value, 32 },
  { &search441_1, &replace566.value, 32 },
  { &search567, &replace567.value, 32 },
  { &search442_1, &replace624.value, 33 },
};
static const struct transform nir_opt_algebraic_state1124_xforms[] = {
  { &search423, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state1125_xforms[] = {
  { &search410, &replace410.value, 0 },
  { &search420, &search2_0.value, 0 },
  { &search421, &search2_0.value, 0 },
  { &search422, &replace9.value, 0 },
  { &search431, &replace14_1_0.value, 0 },
  { &search571, &replace571.value, 32 },
  { &search627, &replace627.value, 33 },
};
static const struct transform nir_opt_algebraic_state1126_xforms[] = {
  { &search2, &replace2.value, 2 },
  { &search436, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state1127_xforms[] = {
  { &search440, &search2_0.value, 0 },
  { &search565, &replace565.value, 32 },
  { &search441_1, &replace566.value, 32 },
  { &search567, &replace567.value, 32 },
  { &search442_1, &replace624.value, 33 },
};
static const struct transform nir_opt_algebraic_state1128_xforms[] = {
  { &search423, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state1129_xforms[] = {
  { &search410, &replace410.value, 0 },
  { &search420, &search2_0.value, 0 },
  { &search421, &search2_0.value, 0 },
  { &search422, &replace9.value, 0 },
  { &search431, &replace14_1_0.value, 0 },
  { &search571, &replace571.value, 32 },
  { &search627, &replace627.value, 33 },
};
static const struct transform nir_opt_algebraic_state1130_xforms[] = {
  { &search2, &replace2.value, 2 },
  { &search436, &search2_0.value, 0 },
};
static const struct transform nir_opt_algebraic_state1131_xforms[] = {
  { &search440, &search2_0.value, 0 },
  { &search565, &replace565.value, 32 },
  { &search441_1, &replace566.value, 32 },
  { &search567, &replace567.value, 32 },
  { &search442_1, &replace624.value, 33 },
};
static const struct transform nir_opt_algebraic_state1132_xforms[] = {
  { &search423, &search2_0.value, 0 },
  { &search1050, &replace1050.value, 61 },
};

static const struct per_op_table nir_opt_algebraic_table[nir_num_search_ops] = {
   [nir_op_imul] = {
      .filter = (uint16_t []) {
         0,
         1,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         3,
         3,
         3,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 7,
      .table = (uint16_t []) {
      
         2,
         3,
         2,
         2,
         203,
         2,
         2,
         3,
         3,
         204,
         205,
         206,
         3,
         207,
         2,
         204,
         2,
         2,
         203,
         2,
         2,
         2,
         205,
         2,
         2,
         203,
         2,
         2,
         203,
         206,
         203,
         203,
         203,
         203,
         203,
         2,
         3,
         2,
         2,
         203,
         208,
         2,
         2,
         207,
         2,
         2,
         203,
         2,
         2,
      },
   },
   [nir_op_ishl] = {
      .filter = (uint16_t []) {
         0,
         1,
         0,
         2,
         0,
         3,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         7,
         8,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         3,
         0,
         0,
         11,
         3,
         0,
         0,
         12,
         3,
         0,
         0,
      },
      
      .num_filtered_states = 13,
      .table = (uint16_t []) {
      
         4,
         5,
         4,
         4,
         4,
         222,
         223,
         4,
         861,
         222,
         222,
         222,
         222,
         6,
         7,
         6,
         6,
         6,
         224,
         225,
         6,
         862,
         224,
         224,
         224,
         224,
         4,
         226,
         4,
         4,
         4,
         222,
         223,
         4,
         861,
         222,
         222,
         222,
         222,
         4,
         227,
         4,
         4,
         4,
         222,
         223,
         4,
         861,
         222,
         222,
         222,
         222,
         4,
         228,
         4,
         4,
         4,
         222,
         223,
         4,
         861,
         222,
         222,
         222,
         222,
         4,
         5,
         4,
         4,
         4,
         222,
         223,
         4,
         861,
         222,
         222,
         222,
         222,
         4,
         5,
         4,
         4,
         4,
         222,
         223,
         4,
         861,
         222,
         222,
         222,
         222,
         4,
         863,
         4,
         4,
         4,
         222,
         223,
         4,
         861,
         222,
         222,
         222,
         222,
         4,
         228,
         4,
         4,
         4,
         222,
         223,
         4,
         861,
         222,
         222,
         222,
         222,
         4,
         1029,
         4,
         4,
         4,
         222,
         223,
         4,
         861,
         222,
         222,
         222,
         222,
         4,
         1122,
         4,
         4,
         4,
         222,
         223,
         4,
         861,
         222,
         222,
         222,
         222,
         4,
         1126,
         4,
         4,
         4,
         222,
         223,
         4,
         861,
         222,
         222,
         222,
         222,
         4,
         1130,
         4,
         4,
         4,
         222,
         223,
         4,
         861,
         222,
         222,
         222,
         222,
      },
   },
   [nir_op_unpack_64_2x32_split_x] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (uint16_t []) {
      
         8,
         292,
         293,
         294,
         295,
      },
   },
   [nir_op_imul_2x32_64] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         9,
      },
   },
   [nir_op_umul_2x32_64] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         10,
      },
   },
   [nir_op_udiv] = {
      .filter = (uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (uint16_t []) {
      
         0,
         11,
         0,
         11,
      },
   },
   [nir_op_idiv] = {
      .filter = (uint16_t []) {
         0,
         1,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (uint16_t []) {
      
         0,
         12,
         0,
         0,
         12,
         0,
         209,
         210,
         209,
      },
   },
   [nir_op_umod] = {
      .filter = (uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (uint16_t []) {
      
         0,
         13,
         0,
         13,
      },
   },
   [nir_op_imod] = {
      .filter = (uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (uint16_t []) {
      
         0,
         14,
         0,
         14,
      },
   },
   [nir_op_fneg] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         2,
         0,
         0,
         0,
         0,
         3,
         4,
         0,
         0,
         0,
         5,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         9,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         10,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         11,
         5,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         10,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         11,
         5,
         5,
         5,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 12,
      .table = (uint16_t []) {
      
         15,
         296,
         297,
         298,
         299,
         300,
         301,
         302,
         303,
         993,
         994,
         1090,
      },
   },
   [nir_op_ineg] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         3,
         5,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (uint16_t []) {
      
         16,
         483,
         484,
         485,
         486,
         1020,
      },
   },
   [nir_op_fabs] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         10,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 11,
      .table = (uint16_t []) {
      
         17,
         304,
         305,
         306,
         307,
         308,
         309,
         310,
         311,
         312,
         313,
      },
   },
   [nir_search_op_u2f] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (uint16_t []) {
      
         18,
         753,
      },
   },
   [nir_op_iabs] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (uint16_t []) {
      
         19,
         487,
         488,
         489,
         895,
      },
   },
   [nir_search_op_f2b] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (uint16_t []) {
      
         20,
         314,
         315,
      },
   },
   [nir_search_op_i2b] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (uint16_t []) {
      
         21,
         490,
         491,
         492,
      },
   },
   [nir_op_fadd] = {
      .filter = (uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         0,
         0,
         0,
         5,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         0,
         0,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         10,
         2,
         11,
         12,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         3,
         3,
         15,
         4,
         4,
         4,
         4,
         4,
         14,
         14,
         14,
         3,
         3,
         3,
         5,
         16,
         5,
         17,
         18,
         5,
         5,
         5,
         16,
         5,
         17,
         5,
         18,
         16,
         5,
         17,
         18,
         5,
         16,
         16,
         19,
         20,
         17,
         18,
         17,
         21,
         5,
         22,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         23,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         22,
         22,
         6,
         6,
         6,
         14,
         3,
         15,
         15,
         15,
         15,
         4,
         4,
         14,
         14,
         14,
         3,
         3,
         14,
         14,
         3,
         14,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         24,
         25,
         5,
         24,
         25,
         5,
         5,
         24,
         25,
         5,
         26,
         27,
         28,
         16,
         24,
         25,
         5,
         29,
         30,
         17,
         31,
         32,
         18,
         24,
         25,
         25,
         0,
         2,
         33,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         4,
         4,
         15,
         14,
         14,
         3,
         3,
         3,
         3,
         3,
         3,
         14,
         14,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         34,
         35,
         34,
         35,
         34,
         35,
         34,
         36,
         34,
         35,
         37,
         38,
         39,
         40,
         41,
         42,
         43,
         35,
         34,
         35,
         44,
         0,
         0,
         45,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         15,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 46,
      .table = (uint16_t []) {
      
         22,
         23,
         316,
         22,
         22,
         317,
         22,
         22,
         22,
         318,
         316,
         316,
         316,
         930,
         931,
         931,
         317,
         317,
         317,
         317,
         317,
         317,
         22,
         22,
         1031,
         1031,
         317,
         1031,
         1031,
         1032,
         1032,
         1031,
         1031,
         316,
         317,
         1031,
         1031,
         317,
         1032,
         317,
         1031,
         317,
         1031,
         1031,
         1031,
         316,
         23,
         23,
         319,
         320,
         321,
         322,
         23,
         23,
         323,
         324,
         932,
         933,
         934,
         935,
         936,
         937,
         322,
         322,
         322,
         322,
         322,
         322,
         23,
         1033,
         1034,
         1034,
         1035,
         1034,
         1034,
         1036,
         1036,
         1034,
         1034,
         1037,
         322,
         1034,
         1034,
         322,
         1036,
         322,
         1034,
         1035,
         1034,
         1034,
         1034,
         1110,
         316,
         319,
         316,
         325,
         325,
         326,
         316,
         316,
         316,
         327,
         316,
         316,
         316,
         930,
         938,
         938,
         326,
         326,
         326,
         326,
         326,
         326,
         316,
         316,
         1038,
         1038,
         326,
         1038,
         1038,
         1039,
         1039,
         1038,
         1038,
         316,
         326,
         1038,
         1038,
         326,
         1039,
         326,
         1038,
         326,
         1038,
         1038,
         1038,
         316,
         22,
         320,
         325,
         22,
         22,
         317,
         22,
         22,
         22,
         318,
         325,
         325,
         325,
         939,
         931,
         931,
         317,
         317,
         317,
         317,
         317,
         317,
         22,
         22,
         1031,
         1031,
         317,
         1031,
         1031,
         1032,
         1032,
         1031,
         1031,
         325,
         317,
         1031,
         1031,
         317,
         1032,
         317,
         1031,
         317,
         1031,
         1031,
         1031,
         325,
         22,
         321,
         325,
         22,
         22,
         317,
         22,
         22,
         22,
         318,
         325,
         325,
         325,
         939,
         931,
         931,
         317,
         317,
         317,
         317,
         317,
         317,
         22,
         22,
         1031,
         1031,
         317,
         1031,
         1031,
         1032,
         1032,
         1031,
         1031,
         325,
         317,
         1031,
         1031,
         317,
         1032,
         317,
         1031,
         317,
         1031,
         1031,
         1031,
         325,
         317,
         322,
         326,
         317,
         317,
         328,
         317,
         317,
         317,
         329,
         326,
         326,
         326,
         940,
         941,
         941,
         328,
         328,
         328,
         328,
         328,
         328,
         317,
         317,
         1040,
         1041,
         328,
         1040,
         1041,
         1042,
         1043,
         1040,
         1041,
         326,
         328,
         1041,
         1041,
         328,
         1043,
         328,
         1041,
         328,
         1040,
         1041,
         1041,
         326,
         22,
         23,
         316,
         22,
         22,
         317,
         22,
         22,
         22,
         318,
         316,
         316,
         316,
         930,
         931,
         931,
         317,
         317,
         317,
         317,
         317,
         317,
         942,
         22,
         1031,
         1031,
         317,
         1031,
         1031,
         1032,
         1032,
         1031,
         1031,
         316,
         317,
         1031,
         1031,
         317,
         1032,
         317,
         1031,
         317,
         1031,
         1031,
         1031,
         316,
         22,
         23,
         316,
         22,
         22,
         317,
         22,
         330,
         22,
         318,
         316,
         316,
         943,
         930,
         931,
         931,
         317,
         317,
         317,
         317,
         317,
         317,
         22,
         22,
         1031,
         1031,
         317,
         1031,
         1031,
         1032,
         1032,
         1031,
         1031,
         316,
         317,
         1031,
         1031,
         317,
         1032,
         317,
         1031,
         317,
         1031,
         1031,
         1031,
         316,
         22,
         323,
         316,
         22,
         22,
         317,
         22,
         22,
         22,
         318,
         316,
         316,
         316,
         930,
         931,
         931,
         317,
         317,
         317,
         317,
         317,
         317,
         22,
         22,
         1031,
         1031,
         317,
         1031,
         1031,
         1032,
         1032,
         1031,
         1031,
         316,
         317,
         1031,
         1031,
         317,
         1032,
         317,
         1031,
         317,
         1031,
         1031,
         1031,
         316,
         318,
         324,
         327,
         318,
         318,
         329,
         318,
         318,
         318,
         318,
         327,
         327,
         327,
         944,
         945,
         945,
         329,
         329,
         329,
         329,
         329,
         329,
         318,
         318,
         1044,
         1044,
         329,
         1044,
         1044,
         1045,
         1045,
         1044,
         1044,
         327,
         329,
         1044,
         1044,
         329,
         1045,
         329,
         1044,
         329,
         1044,
         1044,
         1044,
         327,
         316,
         932,
         316,
         325,
         325,
         326,
         316,
         316,
         316,
         327,
         316,
         316,
         316,
         930,
         938,
         938,
         326,
         326,
         326,
         326,
         326,
         326,
         316,
         316,
         1038,
         1038,
         326,
         1038,
         1038,
         1039,
         1039,
         1038,
         1038,
         316,
         326,
         1038,
         1038,
         326,
         1039,
         326,
         1038,
         326,
         1038,
         1038,
         1038,
         316,
         316,
         933,
         316,
         325,
         325,
         326,
         316,
         316,
         316,
         327,
         316,
         316,
         316,
         930,
         938,
         938,
         326,
         326,
         326,
         326,
         326,
         326,
         316,
         316,
         1038,
         1038,
         326,
         1038,
         1038,
         1039,
         1039,
         1038,
         1038,
         316,
         326,
         1038,
         1038,
         326,
         1039,
         326,
         1038,
         326,
         1038,
         1038,
         1038,
         316,
         316,
         934,
         316,
         325,
         325,
         326,
         316,
         943,
         316,
         327,
         316,
         316,
         316,
         930,
         938,
         938,
         326,
         326,
         326,
         326,
         326,
         326,
         316,
         316,
         1038,
         1038,
         326,
         1038,
         1038,
         1039,
         1039,
         1038,
         1038,
         316,
         326,
         1038,
         1038,
         326,
         1039,
         326,
         1038,
         326,
         1038,
         1038,
         1038,
         316,
         930,
         935,
         930,
         939,
         939,
         940,
         930,
         930,
         930,
         944,
         930,
         930,
         930,
         930,
         946,
         946,
         940,
         940,
         940,
         940,
         940,
         940,
         930,
         930,
         1046,
         1046,
         940,
         1046,
         1046,
         1047,
         1047,
         1046,
         1046,
         930,
         940,
         1046,
         1046,
         940,
         1047,
         940,
         1046,
         940,
         1046,
         1046,
         1046,
         930,
         931,
         936,
         938,
         931,
         931,
         941,
         931,
         931,
         931,
         945,
         938,
         938,
         938,
         946,
         931,
         931,
         941,
         941,
         941,
         941,
         941,
         941,
         931,
         931,
         1048,
         1048,
         941,
         1048,
         1048,
         1049,
         1049,
         1048,
         1048,
         938,
         941,
         1048,
         1048,
         941,
         1049,
         941,
         1048,
         941,
         1048,
         1048,
         1048,
         938,
         931,
         937,
         938,
         931,
         931,
         941,
         931,
         931,
         931,
         945,
         938,
         938,
         938,
         946,
         931,
         931,
         941,
         941,
         941,
         941,
         941,
         941,
         931,
         931,
         1048,
         1048,
         941,
         1048,
         1048,
         1049,
         1049,
         1048,
         1048,
         938,
         941,
         1048,
         1048,
         941,
         1049,
         941,
         1048,
         941,
         1048,
         1048,
         1048,
         938,
         317,
         322,
         326,
         317,
         317,
         328,
         317,
         317,
         317,
         329,
         326,
         326,
         326,
         940,
         941,
         941,
         328,
         328,
         328,
         328,
         328,
         328,
         317,
         317,
         1040,
         1041,
         328,
         1040,
         1041,
         1042,
         1043,
         1040,
         1041,
         326,
         1111,
         1041,
         1041,
         1111,
         1043,
         1111,
         1041,
         1111,
         1112,
         1113,
         1113,
         326,
         317,
         322,
         326,
         317,
         317,
         328,
         317,
         317,
         317,
         329,
         326,
         326,
         326,
         940,
         941,
         941,
         328,
         328,
         328,
         328,
         328,
         328,
         317,
         317,
         1040,
         1041,
         328,
         1040,
         1041,
         1042,
         1043,
         1040,
         1041,
         326,
         328,
         1114,
         1114,
         328,
         1115,
         328,
         1114,
         328,
         1040,
         1041,
         1114,
         326,
         317,
         322,
         326,
         317,
         317,
         328,
         317,
         317,
         317,
         329,
         326,
         326,
         326,
         940,
         941,
         941,
         328,
         328,
         947,
         328,
         947,
         947,
         317,
         317,
         1040,
         1041,
         328,
         1040,
         1041,
         1042,
         1043,
         1050,
         1051,
         326,
         328,
         1041,
         1041,
         328,
         1043,
         947,
         1051,
         328,
         1040,
         1041,
         1041,
         326,
         317,
         322,
         326,
         317,
         317,
         328,
         317,
         317,
         317,
         329,
         326,
         326,
         326,
         940,
         941,
         941,
         328,
         328,
         328,
         328,
         328,
         328,
         317,
         317,
         1040,
         1041,
         328,
         1040,
         1041,
         1042,
         1043,
         1040,
         1041,
         326,
         1111,
         1114,
         1114,
         1111,
         1115,
         1111,
         1114,
         1111,
         1112,
         1113,
         1116,
         326,
         317,
         322,
         326,
         317,
         317,
         328,
         317,
         317,
         317,
         329,
         326,
         326,
         326,
         940,
         941,
         941,
         328,
         328,
         947,
         328,
         947,
         947,
         317,
         317,
         1040,
         1041,
         328,
         1040,
         1041,
         1042,
         1043,
         1050,
         1051,
         326,
         1111,
         1041,
         1041,
         1111,
         1043,
         1117,
         1051,
         1111,
         1112,
         1113,
         1113,
         326,
         317,
         322,
         326,
         317,
         317,
         328,
         317,
         317,
         317,
         329,
         326,
         326,
         326,
         940,
         941,
         941,
         328,
         328,
         947,
         328,
         947,
         947,
         317,
         317,
         1040,
         1041,
         328,
         1040,
         1041,
         1042,
         1043,
         1050,
         1051,
         326,
         328,
         1114,
         1114,
         328,
         1115,
         947,
         1118,
         328,
         1040,
         1041,
         1114,
         326,
         22,
         23,
         316,
         22,
         22,
         317,
         942,
         22,
         22,
         318,
         316,
         316,
         316,
         930,
         931,
         931,
         317,
         317,
         317,
         317,
         317,
         317,
         942,
         22,
         1031,
         1031,
         317,
         1031,
         1031,
         1032,
         1032,
         1031,
         1031,
         316,
         317,
         1031,
         1031,
         317,
         1032,
         317,
         1031,
         317,
         1031,
         1031,
         1031,
         316,
         22,
         1033,
         316,
         22,
         22,
         317,
         22,
         22,
         22,
         318,
         316,
         316,
         316,
         930,
         931,
         931,
         317,
         317,
         317,
         317,
         317,
         317,
         22,
         22,
         1031,
         1031,
         317,
         1031,
         1031,
         1032,
         1032,
         1031,
         1031,
         316,
         317,
         1031,
         1031,
         317,
         1032,
         317,
         1031,
         317,
         1031,
         1031,
         1031,
         316,
         1031,
         1034,
         1038,
         1031,
         1031,
         1040,
         1031,
         1031,
         1031,
         1044,
         1038,
         1038,
         1038,
         1046,
         1048,
         1048,
         1040,
         1040,
         1040,
         1040,
         1040,
         1040,
         1031,
         1031,
         1040,
         1041,
         1040,
         1040,
         1041,
         1042,
         1043,
         1040,
         1041,
         1038,
         1040,
         1041,
         1041,
         1040,
         1043,
         1040,
         1041,
         1040,
         1040,
         1041,
         1041,
         1038,
         1031,
         1034,
         1038,
         1031,
         1031,
         1041,
         1031,
         1031,
         1031,
         1044,
         1038,
         1038,
         1038,
         1046,
         1048,
         1048,
         1041,
         1041,
         1041,
         1041,
         1041,
         1041,
         1031,
         1031,
         1041,
         1041,
         1041,
         1041,
         1041,
         1043,
         1043,
         1041,
         1041,
         1038,
         1041,
         1041,
         1041,
         1041,
         1043,
         1041,
         1041,
         1041,
         1041,
         1041,
         1041,
         1038,
         317,
         1035,
         326,
         317,
         317,
         328,
         317,
         317,
         317,
         329,
         326,
         326,
         326,
         940,
         941,
         941,
         328,
         328,
         328,
         328,
         328,
         328,
         317,
         317,
         1040,
         1041,
         328,
         1040,
         1041,
         1042,
         1043,
         1040,
         1041,
         326,
         1111,
         1041,
         1041,
         1111,
         1043,
         1111,
         1041,
         1111,
         1112,
         1113,
         1113,
         326,
         1031,
         1034,
         1038,
         1031,
         1031,
         1040,
         1031,
         1031,
         1031,
         1044,
         1038,
         1038,
         1038,
         1046,
         1048,
         1048,
         1040,
         1040,
         1040,
         1040,
         1040,
         1040,
         1031,
         1031,
         1040,
         1041,
         1040,
         1040,
         1041,
         1042,
         1043,
         1040,
         1041,
         1038,
         1112,
         1041,
         1041,
         1112,
         1043,
         1112,
         1041,
         1112,
         1112,
         1113,
         1113,
         1038,
         1031,
         1034,
         1038,
         1031,
         1031,
         1041,
         1031,
         1031,
         1031,
         1044,
         1038,
         1038,
         1038,
         1046,
         1048,
         1048,
         1041,
         1041,
         1041,
         1041,
         1041,
         1041,
         1031,
         1031,
         1041,
         1041,
         1041,
         1041,
         1041,
         1043,
         1043,
         1041,
         1041,
         1038,
         1113,
         1041,
         1041,
         1113,
         1043,
         1113,
         1041,
         1113,
         1113,
         1113,
         1113,
         1038,
         1032,
         1036,
         1039,
         1032,
         1032,
         1042,
         1032,
         1032,
         1032,
         1045,
         1039,
         1039,
         1039,
         1047,
         1049,
         1049,
         1042,
         1042,
         1042,
         1042,
         1042,
         1042,
         1032,
         1032,
         1042,
         1043,
         1042,
         1042,
         1043,
         1042,
         1043,
         1042,
         1043,
         1039,
         1042,
         1115,
         1115,
         1042,
         1115,
         1042,
         1115,
         1042,
         1042,
         1043,
         1115,
         1039,
         1032,
         1036,
         1039,
         1032,
         1032,
         1043,
         1032,
         1032,
         1032,
         1045,
         1039,
         1039,
         1039,
         1047,
         1049,
         1049,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1032,
         1032,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1039,
         1043,
         1115,
         1115,
         1043,
         1115,
         1043,
         1115,
         1043,
         1043,
         1043,
         1115,
         1039,
         1031,
         1034,
         1038,
         1031,
         1031,
         1040,
         1031,
         1031,
         1031,
         1044,
         1038,
         1038,
         1038,
         1046,
         1048,
         1048,
         1040,
         1040,
         1050,
         1040,
         1050,
         1050,
         1031,
         1031,
         1040,
         1041,
         1040,
         1040,
         1041,
         1042,
         1043,
         1050,
         1051,
         1038,
         1040,
         1041,
         1041,
         1040,
         1043,
         1050,
         1051,
         1040,
         1040,
         1041,
         1041,
         1038,
         1031,
         1034,
         1038,
         1031,
         1031,
         1041,
         1031,
         1031,
         1031,
         1044,
         1038,
         1038,
         1038,
         1046,
         1048,
         1048,
         1041,
         1041,
         1051,
         1041,
         1051,
         1051,
         1031,
         1031,
         1041,
         1041,
         1041,
         1041,
         1041,
         1043,
         1043,
         1051,
         1051,
         1038,
         1041,
         1041,
         1041,
         1041,
         1043,
         1051,
         1051,
         1041,
         1041,
         1041,
         1041,
         1038,
         316,
         1037,
         316,
         325,
         325,
         326,
         316,
         316,
         316,
         327,
         316,
         316,
         316,
         930,
         938,
         938,
         326,
         326,
         326,
         326,
         326,
         326,
         316,
         316,
         1038,
         1038,
         326,
         1038,
         1038,
         1039,
         1039,
         1038,
         1038,
         316,
         326,
         1038,
         1038,
         326,
         1039,
         326,
         1038,
         326,
         1038,
         1038,
         1038,
         316,
         317,
         322,
         326,
         317,
         317,
         328,
         317,
         317,
         317,
         329,
         326,
         326,
         326,
         940,
         941,
         941,
         1111,
         328,
         328,
         1111,
         1111,
         328,
         317,
         317,
         1040,
         1041,
         1111,
         1112,
         1113,
         1042,
         1043,
         1040,
         1041,
         326,
         1111,
         1041,
         1113,
         1111,
         1043,
         1111,
         1041,
         1111,
         1112,
         1113,
         1113,
         326,
         1031,
         1034,
         1038,
         1031,
         1031,
         1041,
         1031,
         1031,
         1031,
         1044,
         1038,
         1038,
         1038,
         1046,
         1048,
         1048,
         1041,
         1114,
         1041,
         1114,
         1041,
         1114,
         1031,
         1031,
         1041,
         1041,
         1041,
         1041,
         1041,
         1115,
         1115,
         1041,
         1041,
         1038,
         1041,
         1041,
         1041,
         1114,
         1115,
         1041,
         1041,
         1041,
         1041,
         1041,
         1041,
         1038,
         1031,
         1034,
         1038,
         1031,
         1031,
         1041,
         1031,
         1031,
         1031,
         1044,
         1038,
         1038,
         1038,
         1046,
         1048,
         1048,
         1041,
         1114,
         1041,
         1114,
         1041,
         1114,
         1031,
         1031,
         1041,
         1041,
         1041,
         1041,
         1041,
         1115,
         1115,
         1041,
         1041,
         1038,
         1113,
         1041,
         1041,
         1116,
         1115,
         1113,
         1041,
         1113,
         1113,
         1113,
         1113,
         1038,
         317,
         322,
         326,
         317,
         317,
         328,
         317,
         317,
         317,
         329,
         326,
         326,
         326,
         940,
         941,
         941,
         1111,
         328,
         328,
         1111,
         1111,
         328,
         317,
         317,
         1040,
         1041,
         1111,
         1112,
         1113,
         1042,
         1043,
         1040,
         1041,
         326,
         1111,
         1114,
         1116,
         1111,
         1115,
         1111,
         1114,
         1111,
         1112,
         1113,
         1116,
         326,
         1032,
         1036,
         1039,
         1032,
         1032,
         1043,
         1032,
         1032,
         1032,
         1045,
         1039,
         1039,
         1039,
         1047,
         1049,
         1049,
         1043,
         1115,
         1043,
         1115,
         1043,
         1115,
         1032,
         1032,
         1043,
         1043,
         1043,
         1043,
         1043,
         1115,
         1115,
         1043,
         1043,
         1039,
         1043,
         1115,
         1115,
         1115,
         1115,
         1043,
         1115,
         1043,
         1043,
         1043,
         1115,
         1039,
         317,
         322,
         326,
         317,
         317,
         328,
         317,
         317,
         317,
         329,
         326,
         326,
         326,
         940,
         941,
         941,
         1111,
         328,
         947,
         1111,
         1117,
         947,
         317,
         317,
         1040,
         1041,
         1111,
         1112,
         1113,
         1042,
         1043,
         1050,
         1051,
         326,
         1111,
         1041,
         1113,
         1111,
         1043,
         1117,
         1051,
         1111,
         1112,
         1113,
         1113,
         326,
         1031,
         1034,
         1038,
         1031,
         1031,
         1041,
         1031,
         1031,
         1031,
         1044,
         1038,
         1038,
         1038,
         1046,
         1048,
         1048,
         1041,
         1114,
         1051,
         1114,
         1051,
         1118,
         1031,
         1031,
         1041,
         1041,
         1041,
         1041,
         1041,
         1115,
         1115,
         1051,
         1051,
         1038,
         1041,
         1041,
         1041,
         1114,
         1115,
         1051,
         1051,
         1041,
         1041,
         1041,
         1041,
         1038,
         317,
         1035,
         326,
         317,
         317,
         328,
         317,
         317,
         317,
         329,
         326,
         326,
         326,
         940,
         941,
         941,
         1111,
         328,
         328,
         1111,
         1111,
         328,
         317,
         317,
         1040,
         1041,
         1111,
         1112,
         1113,
         1042,
         1043,
         1040,
         1041,
         326,
         1111,
         1041,
         1113,
         1111,
         1043,
         1111,
         1041,
         1111,
         1112,
         1113,
         1113,
         326,
         1031,
         1034,
         1038,
         1031,
         1031,
         1040,
         1031,
         1031,
         1031,
         1044,
         1038,
         1038,
         1038,
         1046,
         1048,
         1048,
         1112,
         1040,
         1040,
         1112,
         1112,
         1040,
         1031,
         1031,
         1040,
         1041,
         1112,
         1112,
         1113,
         1042,
         1043,
         1040,
         1041,
         1038,
         1112,
         1041,
         1113,
         1112,
         1043,
         1112,
         1041,
         1112,
         1112,
         1113,
         1113,
         1038,
         1031,
         1034,
         1038,
         1031,
         1031,
         1041,
         1031,
         1031,
         1031,
         1044,
         1038,
         1038,
         1038,
         1046,
         1048,
         1048,
         1113,
         1041,
         1041,
         1113,
         1113,
         1041,
         1031,
         1031,
         1041,
         1041,
         1113,
         1113,
         1113,
         1043,
         1043,
         1041,
         1041,
         1038,
         1113,
         1041,
         1113,
         1113,
         1043,
         1113,
         1041,
         1113,
         1113,
         1113,
         1113,
         1038,
         1031,
         1034,
         1038,
         1031,
         1031,
         1041,
         1031,
         1031,
         1031,
         1044,
         1038,
         1038,
         1038,
         1046,
         1048,
         1048,
         1113,
         1114,
         1041,
         1116,
         1113,
         1114,
         1031,
         1031,
         1041,
         1041,
         1113,
         1113,
         1113,
         1115,
         1115,
         1041,
         1041,
         1038,
         1113,
         1041,
         1113,
         1116,
         1115,
         1113,
         1041,
         1113,
         1113,
         1113,
         1113,
         1038,
         316,
         1110,
         316,
         325,
         325,
         326,
         316,
         316,
         316,
         327,
         316,
         316,
         316,
         930,
         938,
         938,
         326,
         326,
         326,
         326,
         326,
         326,
         316,
         316,
         1038,
         1038,
         326,
         1038,
         1038,
         1039,
         1039,
         1038,
         1038,
         316,
         326,
         1038,
         1038,
         326,
         1039,
         326,
         1038,
         326,
         1038,
         1038,
         1038,
         316,
      },
   },
   [nir_op_iadd] = {
      .filter = (uint16_t []) {
         0,
         1,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         0,
         0,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         3,
         3,
         3,
         2,
         0,
         0,
         9,
         5,
         6,
         10,
         6,
         6,
         6,
         6,
         5,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         6,
         9,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 13,
      .table = (uint16_t []) {
      
         24,
         25,
         24,
         24,
         211,
         24,
         24,
         24,
         212,
         856,
         856,
         24,
         211,
         25,
         25,
         25,
         213,
         214,
         215,
         216,
         217,
         218,
         857,
         858,
         25,
         214,
         24,
         25,
         219,
         219,
         211,
         24,
         24,
         24,
         212,
         856,
         856,
         24,
         211,
         24,
         213,
         219,
         219,
         211,
         24,
         24,
         24,
         212,
         856,
         856,
         24,
         211,
         211,
         214,
         211,
         211,
         211,
         220,
         220,
         211,
         221,
         859,
         859,
         211,
         211,
         24,
         215,
         24,
         24,
         220,
         24,
         24,
         24,
         212,
         856,
         856,
         24,
         220,
         24,
         216,
         24,
         24,
         220,
         24,
         24,
         24,
         212,
         856,
         856,
         24,
         220,
         24,
         217,
         24,
         24,
         211,
         24,
         24,
         24,
         212,
         856,
         856,
         24,
         211,
         212,
         218,
         212,
         212,
         221,
         212,
         212,
         212,
         212,
         860,
         860,
         212,
         221,
         856,
         857,
         856,
         856,
         859,
         856,
         856,
         856,
         860,
         856,
         856,
         856,
         859,
         856,
         858,
         856,
         856,
         859,
         856,
         856,
         856,
         860,
         856,
         856,
         856,
         859,
         24,
         25,
         24,
         24,
         211,
         24,
         24,
         24,
         212,
         856,
         856,
         24,
         1099,
         211,
         214,
         211,
         211,
         211,
         220,
         220,
         211,
         221,
         859,
         859,
         1099,
         211,
      },
   },
   [nir_op_usadd_4x8] = {
      .filter = (uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (uint16_t []) {
      
         0,
         26,
         26,
         26,
      },
   },
   [nir_op_fmul] = {
      .filter = (uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         5,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         0,
         0,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         11,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         0,
         0,
         0,
         3,
         3,
         14,
         3,
         3,
         4,
         4,
         4,
         4,
         15,
         4,
         4,
         4,
         3,
         14,
         3,
         3,
         14,
         3,
         14,
         3,
         3,
         14,
         14,
         3,
         3,
         3,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         16,
         5,
         12,
         0,
         13,
         13,
         17,
         13,
         0,
         0,
         12,
         12,
         12,
         0,
         0,
         12,
         12,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         14,
         14,
         14,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         2,
         2,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         0,
         0,
         0,
         13,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         3,
         3,
         3,
         3,
         14,
         14,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         9,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 19,
      .table = (uint16_t []) {
      
         27,
         28,
         331,
         27,
         27,
         332,
         333,
         334,
         27,
         27,
         335,
         331,
         966,
         967,
         968,
         968,
         1067,
         1068,
         27,
         28,
         28,
         336,
         337,
         338,
         339,
         340,
         341,
         342,
         28,
         343,
         336,
         969,
         970,
         971,
         972,
         1069,
         1070,
         1104,
         331,
         336,
         331,
         331,
         331,
         344,
         345,
         346,
         331,
         331,
         347,
         331,
         973,
         974,
         975,
         975,
         1071,
         1072,
         331,
         27,
         337,
         331,
         27,
         27,
         332,
         348,
         334,
         27,
         27,
         335,
         331,
         966,
         967,
         968,
         968,
         1067,
         1068,
         27,
         27,
         338,
         331,
         27,
         27,
         332,
         348,
         334,
         27,
         27,
         335,
         331,
         966,
         967,
         968,
         968,
         1067,
         1068,
         27,
         332,
         339,
         344,
         332,
         332,
         349,
         350,
         351,
         332,
         332,
         352,
         976,
         977,
         978,
         979,
         979,
         1073,
         1074,
         332,
         333,
         340,
         345,
         348,
         348,
         350,
         333,
         353,
         333,
         333,
         354,
         345,
         980,
         981,
         982,
         982,
         1075,
         1076,
         333,
         334,
         341,
         346,
         334,
         334,
         351,
         353,
         355,
         334,
         334,
         356,
         346,
         983,
         984,
         985,
         985,
         1077,
         1078,
         334,
         27,
         342,
         331,
         27,
         27,
         332,
         333,
         334,
         27,
         27,
         335,
         331,
         966,
         967,
         968,
         968,
         1067,
         1068,
         27,
         27,
         28,
         331,
         27,
         27,
         332,
         333,
         334,
         27,
         357,
         335,
         331,
         966,
         967,
         968,
         968,
         1067,
         1068,
         27,
         335,
         343,
         347,
         335,
         335,
         352,
         354,
         356,
         335,
         335,
         335,
         347,
         986,
         987,
         988,
         988,
         1079,
         1080,
         335,
         331,
         336,
         331,
         331,
         331,
         976,
         345,
         346,
         331,
         331,
         347,
         331,
         973,
         974,
         975,
         975,
         1081,
         1072,
         331,
         966,
         969,
         973,
         966,
         966,
         977,
         980,
         983,
         966,
         966,
         986,
         973,
         966,
         967,
         989,
         989,
         1082,
         1068,
         966,
         967,
         970,
         974,
         967,
         967,
         978,
         981,
         984,
         967,
         967,
         987,
         974,
         967,
         990,
         991,
         991,
         1083,
         1084,
         967,
         968,
         971,
         975,
         968,
         968,
         979,
         982,
         985,
         968,
         968,
         988,
         975,
         989,
         991,
         968,
         968,
         1085,
         1086,
         968,
         968,
         972,
         975,
         968,
         968,
         979,
         982,
         985,
         968,
         968,
         988,
         975,
         989,
         991,
         968,
         968,
         1085,
         1086,
         968,
         1067,
         1069,
         1071,
         1067,
         1067,
         1073,
         1075,
         1077,
         1067,
         1067,
         1079,
         1081,
         1082,
         1083,
         1085,
         1085,
         1073,
         1087,
         1067,
         1068,
         1070,
         1072,
         1068,
         1068,
         1074,
         1076,
         1078,
         1068,
         1068,
         1080,
         1072,
         1068,
         1084,
         1086,
         1086,
         1087,
         1084,
         1068,
         27,
         1104,
         331,
         27,
         27,
         332,
         333,
         334,
         27,
         27,
         335,
         331,
         966,
         967,
         968,
         968,
         1067,
         1068,
         27,
      },
   },
   [nir_op_fsat] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         5,
         5,
         6,
         1,
         1,
         1,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 10,
      .table = (uint16_t []) {
      
         29,
         358,
         359,
         360,
         361,
         925,
         926,
         927,
         928,
         929,
      },
   },
   [nir_op_umul_unorm_4x8] = {
      .filter = (uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (uint16_t []) {
      
         0,
         30,
         30,
         30,
      },
   },
   [nir_op_fsign] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         31,
      },
   },
   [nir_op_ffma] = {
      .filter = (uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (uint16_t []) {
      
         32,
         33,
         34,
         35,
         34,
         35,
         34,
         35,
      },
   },
   [nir_op_flrp] = {
      .filter = (uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (uint16_t []) {
      
         36,
         37,
         36,
         36,
         605,
         38,
         39,
         38,
         38,
         606,
         607,
         608,
         607,
         607,
         609,
         610,
         611,
         610,
         610,
         612,
         36,
         37,
         36,
         36,
         605,
         40,
         41,
         40,
         40,
         613,
         42,
         43,
         42,
         42,
         614,
         615,
         616,
         615,
         615,
         617,
         618,
         619,
         618,
         618,
         620,
         40,
         41,
         40,
         40,
         613,
         36,
         37,
         36,
         36,
         605,
         38,
         39,
         38,
         38,
         606,
         621,
         622,
         621,
         621,
         623,
         610,
         611,
         610,
         610,
         612,
         36,
         37,
         36,
         36,
         605,
         36,
         37,
         36,
         36,
         605,
         38,
         39,
         38,
         38,
         606,
         607,
         608,
         607,
         607,
         609,
         624,
         625,
         624,
         624,
         626,
         36,
         37,
         36,
         36,
         605,
         36,
         37,
         36,
         36,
         605,
         38,
         39,
         38,
         38,
         606,
         607,
         608,
         607,
         607,
         609,
         610,
         611,
         610,
         610,
         612,
         36,
         37,
         36,
         36,
         605,
      },
   },
   [nir_search_op_b2f] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         44,
      },
   },
   [nir_op_ftrunc] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         45,
      },
   },
   [nir_op_ffloor] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         46,
      },
   },
   [nir_op_ffract] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         47,
      },
   },
   [nir_op_fceil] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         48,
      },
   },
   [nir_op_iand] = {
      .filter = (uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         4,
         0,
         0,
         0,
         0,
         5,
         6,
         7,
         8,
         9,
         10,
         11,
         12,
         13,
         14,
         14,
         15,
         15,
         16,
         16,
         17,
         17,
         18,
         19,
         19,
         20,
         21,
         22,
         22,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         23,
         23,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         24,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         7,
         6,
         7,
         6,
         7,
         6,
         6,
         6,
         7,
         7,
         6,
         7,
         6,
         6,
         6,
         7,
         6,
         7,
         6,
         6,
         6,
         7,
         6,
         10,
         10,
         10,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         11,
         10,
         11,
         10,
         11,
         10,
         10,
         10,
         11,
         11,
         10,
         11,
         10,
         10,
         10,
         11,
         10,
         11,
         10,
         10,
         10,
         11,
         10,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         25,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         20,
         21,
         21,
         21,
         26,
         27,
         21,
         21,
         20,
         20,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         23,
         23,
         23,
         23,
         3,
         3,
         3,
         3,
         3,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         8,
         7,
         7,
         7,
         7,
         7,
         7,
         12,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         21,
         22,
         22,
         0,
         0,
         0,
         0,
         0,
         25,
         0,
         0,
         0,
         23,
         23,
         23,
         23,
         23,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         14,
         14,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         15,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         28,
         2,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         4,
         29,
         3,
         0,
         4,
         30,
         3,
         0,
         4,
         30,
      },
      
      .num_filtered_states = 31,
      .table = (uint16_t []) {
      
         49,
         50,
         49,
         645,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         646,
         646,
         49,
         49,
         49,
         646,
         646,
         646,
         50,
         50,
         50,
         647,
         648,
         50,
         50,
         50,
         50,
         50,
         50,
         50,
         50,
         50,
         50,
         50,
         50,
         50,
         50,
         50,
         50,
         50,
         50,
         649,
         870,
         871,
         50,
         50,
         1120,
         1125,
         1129,
         49,
         50,
         49,
         645,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         646,
         646,
         872,
         49,
         49,
         646,
         646,
         646,
         645,
         647,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         645,
         650,
         650,
         645,
         645,
         645,
         650,
         650,
         650,
         49,
         648,
         49,
         645,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         646,
         646,
         49,
         49,
         49,
         646,
         646,
         646,
         49,
         50,
         49,
         645,
         49,
         651,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         646,
         646,
         49,
         49,
         49,
         646,
         646,
         646,
         49,
         50,
         49,
         645,
         49,
         49,
         652,
         652,
         652,
         652,
         653,
         653,
         653,
         653,
         654,
         655,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         646,
         646,
         49,
         49,
         49,
         646,
         646,
         646,
         49,
         50,
         49,
         645,
         49,
         49,
         652,
         656,
         657,
         658,
         653,
         653,
         653,
         653,
         654,
         655,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         646,
         646,
         49,
         49,
         49,
         646,
         646,
         646,
         49,
         50,
         49,
         645,
         49,
         49,
         652,
         657,
         659,
         660,
         653,
         653,
         653,
         653,
         654,
         655,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         646,
         646,
         49,
         49,
         49,
         646,
         646,
         646,
         49,
         50,
         49,
         645,
         49,
         49,
         652,
         658,
         660,
         661,
         653,
         653,
         653,
         653,
         654,
         655,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         646,
         646,
         49,
         49,
         49,
         646,
         646,
         646,
         49,
         50,
         49,
         645,
         49,
         49,
         653,
         653,
         653,
         653,
         662,
         662,
         662,
         662,
         663,
         664,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         646,
         646,
         49,
         49,
         49,
         646,
         646,
         646,
         49,
         50,
         49,
         645,
         49,
         49,
         653,
         653,
         653,
         653,
         662,
         665,
         666,
         667,
         663,
         664,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         646,
         646,
         49,
         49,
         49,
         646,
         646,
         646,
         49,
         50,
         49,
         645,
         49,
         49,
         653,
         653,
         653,
         653,
         662,
         666,
         668,
         669,
         663,
         664,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         646,
         646,
         49,
         49,
         49,
         646,
         646,
         646,
         49,
         50,
         49,
         645,
         49,
         49,
         653,
         653,
         653,
         653,
         662,
         667,
         669,
         670,
         663,
         664,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         646,
         646,
         49,
         49,
         49,
         646,
         646,
         646,
         49,
         50,
         49,
         645,
         49,
         49,
         654,
         654,
         654,
         654,
         663,
         663,
         663,
         663,
         671,
         672,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         646,
         646,
         49,
         49,
         49,
         646,
         646,
         646,
         49,
         50,
         49,
         645,
         49,
         49,
         655,
         655,
         655,
         655,
         664,
         664,
         664,
         664,
         672,
         673,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         646,
         646,
         49,
         49,
         49,
         646,
         646,
         646,
         49,
         50,
         49,
         645,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         674,
         49,
         49,
         49,
         49,
         49,
         49,
         646,
         646,
         49,
         49,
         49,
         646,
         646,
         646,
         49,
         50,
         49,
         645,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         675,
         49,
         49,
         49,
         49,
         49,
         646,
         646,
         49,
         49,
         49,
         646,
         646,
         646,
         49,
         50,
         49,
         645,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         676,
         49,
         49,
         49,
         49,
         646,
         646,
         49,
         49,
         49,
         646,
         646,
         646,
         49,
         50,
         49,
         645,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         677,
         49,
         49,
         49,
         646,
         646,
         49,
         49,
         49,
         646,
         646,
         646,
         49,
         50,
         49,
         645,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         678,
         646,
         646,
         49,
         49,
         49,
         646,
         646,
         646,
         49,
         50,
         49,
         645,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         679,
         678,
         646,
         646,
         49,
         679,
         679,
         646,
         646,
         646,
         49,
         50,
         49,
         645,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         678,
         678,
         49,
         646,
         646,
         49,
         678,
         678,
         646,
         646,
         646,
         646,
         649,
         646,
         650,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         870,
         646,
         650,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         49,
         871,
         872,
         645,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         646,
         646,
         873,
         49,
         49,
         646,
         646,
         646,
         49,
         50,
         49,
         645,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         679,
         678,
         646,
         646,
         49,
         679,
         874,
         646,
         646,
         646,
         49,
         50,
         49,
         645,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         49,
         679,
         678,
         646,
         646,
         49,
         874,
         679,
         646,
         646,
         646,
         646,
         1120,
         646,
         650,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         1125,
         646,
         650,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         1129,
         646,
         650,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
      },
   },
   [nir_search_op_b2i] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         1,
         0,
         1,
         0,
         1,
         0,
         0,
         0,
         1,
         1,
         0,
         1,
         0,
         0,
         0,
         1,
         0,
         1,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (uint16_t []) {
      
         51,
         768,
         769,
         770,
         771,
      },
   },
   [nir_op_fdph] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         52,
      },
   },
   [nir_op_fdot4] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (uint16_t []) {
      
         53,
         761,
         762,
         763,
         761,
         761,
         762,
         763,
         762,
         762,
         762,
         763,
         763,
         763,
         763,
         763,
      },
   },
   [nir_op_vec4] = {
      .filter = (uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (uint16_t []) {
      
         0,
         54,
         0,
         55,
         0,
         54,
         0,
         56,
         0,
         54,
         0,
         55,
         0,
         54,
         0,
         56,
      },
   },
   [nir_op_fdot3] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (uint16_t []) {
      
         57,
         764,
         765,
         764,
         764,
         765,
         765,
         765,
         765,
      },
   },
   [nir_op_vec3] = {
      .filter = (uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (uint16_t []) {
      
         0,
         58,
         0,
         59,
         0,
         58,
         0,
         59,
      },
   },
   [nir_op_fdot2] = {
      .filter = (uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (uint16_t []) {
      
         60,
         61,
         766,
         61,
         61,
         767,
         766,
         767,
         766,
      },
   },
   [nir_op_vec2] = {
      .filter = (uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (uint16_t []) {
      
         0,
         62,
         0,
         62,
      },
   },
   [nir_op_fsum2] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         63,
      },
   },
   [nir_op_ushr] = {
      .filter = (uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         2,
         4,
         0,
         9,
         2,
         4,
         0,
         10,
         2,
         4,
         0,
      },
      
      .num_filtered_states = 11,
      .table = (uint16_t []) {
      
         64,
         65,
         64,
         273,
         64,
         274,
         864,
         273,
         273,
         273,
         273,
         66,
         67,
         66,
         275,
         66,
         276,
         865,
         275,
         275,
         275,
         275,
         64,
         277,
         64,
         273,
         64,
         274,
         864,
         273,
         273,
         273,
         273,
         64,
         65,
         64,
         273,
         64,
         274,
         864,
         273,
         273,
         273,
         273,
         64,
         278,
         64,
         273,
         64,
         274,
         864,
         273,
         273,
         273,
         273,
         64,
         65,
         64,
         273,
         64,
         274,
         864,
         273,
         273,
         273,
         273,
         64,
         65,
         64,
         273,
         64,
         274,
         864,
         273,
         273,
         273,
         273,
         64,
         1030,
         64,
         273,
         64,
         274,
         864,
         273,
         273,
         273,
         273,
         64,
         1123,
         64,
         273,
         64,
         274,
         864,
         273,
         273,
         273,
         273,
         64,
         1127,
         64,
         273,
         64,
         274,
         864,
         273,
         273,
         273,
         273,
         64,
         1131,
         64,
         273,
         64,
         274,
         864,
         273,
         273,
         273,
         273,
      },
   },
   [nir_op_ishr] = {
      .filter = (uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         5,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         2,
         0,
         0,
         4,
         2,
         0,
         0,
         4,
         2,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (uint16_t []) {
      
         68,
         69,
         68,
         68,
         279,
         68,
         70,
         71,
         70,
         70,
         280,
         70,
         68,
         281,
         68,
         68,
         279,
         68,
         282,
         283,
         282,
         282,
         284,
         282,
         68,
         69,
         68,
         68,
         279,
         68,
         68,
         285,
         68,
         68,
         279,
         68,
      },
   },
   [nir_op_inot] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         5,
         5,
         6,
         6,
         7,
         7,
         8,
         8,
         9,
         10,
         10,
         11,
         11,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         14,
         15,
         16,
         13,
         13,
         13,
         13,
         13,
         13,
         17,
         18,
         19,
         17,
         17,
         17,
         17,
         17,
         17,
         20,
         21,
         22,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         23,
         24,
         25,
         26,
         23,
         23,
         23,
         23,
         23,
         23,
         27,
         28,
         29,
         27,
         27,
         27,
         27,
         27,
         27,
         30,
         31,
         32,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 33,
      .table = (uint16_t []) {
      
         72,
         525,
         526,
         527,
         528,
         529,
         530,
         531,
         532,
         533,
         534,
         535,
         536,
         875,
         876,
         877,
         878,
         879,
         880,
         881,
         882,
         883,
         884,
         885,
         886,
         887,
         888,
         889,
         890,
         891,
         892,
         893,
         894,
      },
   },
   [nir_op_flt] = {
      .filter = (uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         4,
         0,
         0,
         0,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         10,
         10,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         13,
         2,
         14,
         2,
         2,
         15,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         16,
         5,
         5,
         17,
         6,
         6,
         6,
         6,
         6,
         16,
         16,
         16,
         5,
         5,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         19,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         7,
         7,
         7,
         7,
         7,
         16,
         5,
         17,
         17,
         17,
         17,
         6,
         6,
         16,
         16,
         16,
         5,
         5,
         16,
         16,
         5,
         16,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         20,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         6,
         6,
         21,
         6,
         22,
         16,
         16,
         5,
         5,
         5,
         5,
         5,
         5,
         16,
         16,
         5,
         5,
         5,
         5,
         23,
         23,
         23,
         23,
         10,
         10,
         10,
         10,
         10,
         23,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         17,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 24,
      .table = (uint16_t []) {
      
         73,
         74,
         362,
         73,
         73,
         73,
         73,
         73,
         363,
         73,
         364,
         73,
         73,
         362,
         362,
         362,
         73,
         73,
         73,
         73,
         362,
         73,
         73,
         364,
         75,
         76,
         365,
         366,
         367,
         75,
         75,
         368,
         369,
         370,
         371,
         372,
         75,
         365,
         365,
         365,
         75,
         75,
         896,
         75,
         365,
         75,
         75,
         371,
         73,
         373,
         374,
         73,
         73,
         73,
         73,
         73,
         363,
         73,
         364,
         73,
         73,
         374,
         374,
         374,
         73,
         73,
         73,
         73,
         374,
         73,
         73,
         364,
         73,
         74,
         362,
         73,
         73,
         73,
         73,
         73,
         363,
         73,
         364,
         73,
         73,
         362,
         362,
         362,
         73,
         73,
         73,
         73,
         362,
         73,
         73,
         364,
         73,
         375,
         362,
         73,
         73,
         73,
         73,
         73,
         363,
         73,
         364,
         73,
         73,
         362,
         362,
         362,
         73,
         73,
         73,
         73,
         362,
         73,
         73,
         364,
         376,
         377,
         378,
         376,
         376,
         376,
         376,
         376,
         379,
         376,
         380,
         376,
         376,
         378,
         378,
         378,
         376,
         376,
         376,
         376,
         378,
         376,
         376,
         380,
         376,
         381,
         378,
         376,
         376,
         376,
         376,
         376,
         379,
         376,
         380,
         376,
         376,
         378,
         378,
         378,
         376,
         376,
         376,
         376,
         378,
         376,
         376,
         380,
         73,
         382,
         362,
         73,
         73,
         73,
         73,
         73,
         363,
         73,
         364,
         73,
         73,
         362,
         362,
         362,
         73,
         73,
         73,
         73,
         362,
         73,
         73,
         364,
         383,
         384,
         385,
         383,
         383,
         383,
         383,
         383,
         386,
         383,
         387,
         383,
         383,
         385,
         385,
         385,
         383,
         383,
         383,
         383,
         385,
         383,
         383,
         387,
         73,
         388,
         362,
         73,
         73,
         73,
         73,
         73,
         363,
         73,
         364,
         73,
         73,
         362,
         362,
         362,
         73,
         73,
         73,
         73,
         362,
         73,
         73,
         364,
         389,
         390,
         391,
         389,
         389,
         389,
         389,
         389,
         392,
         389,
         393,
         389,
         389,
         391,
         391,
         391,
         389,
         389,
         389,
         389,
         391,
         389,
         389,
         393,
         73,
         394,
         362,
         73,
         73,
         73,
         73,
         73,
         363,
         73,
         364,
         73,
         73,
         362,
         362,
         362,
         73,
         73,
         73,
         73,
         362,
         73,
         73,
         364,
         73,
         74,
         362,
         73,
         73,
         73,
         73,
         73,
         363,
         73,
         364,
         73,
         395,
         362,
         362,
         362,
         73,
         73,
         73,
         73,
         362,
         73,
         73,
         364,
         73,
         897,
         374,
         73,
         73,
         73,
         73,
         73,
         363,
         73,
         364,
         73,
         73,
         374,
         374,
         374,
         73,
         73,
         73,
         73,
         374,
         73,
         73,
         364,
         73,
         898,
         374,
         73,
         73,
         73,
         73,
         73,
         363,
         73,
         364,
         73,
         73,
         374,
         374,
         374,
         73,
         73,
         73,
         73,
         374,
         73,
         73,
         364,
         73,
         899,
         374,
         73,
         73,
         73,
         73,
         73,
         363,
         73,
         364,
         73,
         73,
         374,
         374,
         374,
         73,
         73,
         73,
         73,
         374,
         73,
         73,
         364,
         376,
         900,
         378,
         376,
         376,
         376,
         376,
         376,
         379,
         376,
         380,
         376,
         376,
         378,
         378,
         378,
         376,
         376,
         376,
         376,
         378,
         376,
         376,
         380,
         376,
         901,
         378,
         376,
         376,
         376,
         376,
         376,
         379,
         376,
         380,
         376,
         376,
         378,
         378,
         378,
         376,
         376,
         376,
         376,
         378,
         376,
         376,
         380,
         376,
         377,
         378,
         376,
         376,
         376,
         376,
         376,
         379,
         376,
         380,
         376,
         376,
         378,
         378,
         378,
         376,
         376,
         376,
         376,
         378,
         376,
         376,
         380,
         73,
         902,
         362,
         73,
         73,
         73,
         73,
         73,
         363,
         73,
         364,
         73,
         73,
         362,
         362,
         362,
         73,
         73,
         73,
         73,
         362,
         73,
         73,
         364,
         73,
         1091,
         374,
         73,
         73,
         73,
         73,
         73,
         363,
         73,
         364,
         73,
         73,
         374,
         374,
         374,
         73,
         73,
         73,
         73,
         374,
         73,
         73,
         364,
         376,
         1105,
         378,
         376,
         376,
         376,
         376,
         376,
         379,
         376,
         380,
         376,
         376,
         378,
         378,
         378,
         376,
         376,
         376,
         376,
         378,
         376,
         376,
         380,
         376,
         1106,
         378,
         376,
         376,
         376,
         376,
         376,
         379,
         376,
         380,
         376,
         376,
         378,
         378,
         378,
         376,
         376,
         376,
         376,
         378,
         376,
         376,
         380,
         389,
         1107,
         391,
         389,
         389,
         389,
         389,
         389,
         392,
         389,
         393,
         389,
         389,
         391,
         391,
         391,
         389,
         389,
         389,
         389,
         391,
         389,
         389,
         393,
      },
   },
   [nir_op_fge] = {
      .filter = (uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         4,
         0,
         0,
         0,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         10,
         11,
         11,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         14,
         2,
         15,
         2,
         2,
         16,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         11,
         11,
         11,
         18,
         18,
         18,
         18,
         18,
         18,
         7,
         7,
         7,
         7,
         7,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         19,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         11,
         11,
         11,
         18,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         6,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 20,
      .table = (uint16_t []) {
      
         77,
         78,
         396,
         77,
         77,
         77,
         77,
         77,
         77,
         397,
         77,
         398,
         77,
         77,
         396,
         396,
         396,
         77,
         398,
         396,
         79,
         80,
         399,
         400,
         401,
         79,
         79,
         402,
         403,
         404,
         405,
         406,
         407,
         79,
         399,
         399,
         399,
         903,
         406,
         399,
         77,
         408,
         409,
         77,
         77,
         77,
         77,
         77,
         77,
         397,
         77,
         398,
         77,
         77,
         409,
         409,
         409,
         77,
         398,
         409,
         77,
         78,
         396,
         77,
         77,
         77,
         77,
         77,
         77,
         397,
         77,
         398,
         77,
         77,
         396,
         396,
         396,
         77,
         398,
         396,
         77,
         410,
         396,
         77,
         77,
         77,
         77,
         77,
         77,
         397,
         77,
         398,
         77,
         77,
         396,
         396,
         396,
         77,
         398,
         396,
         411,
         412,
         413,
         411,
         411,
         411,
         411,
         411,
         411,
         414,
         411,
         415,
         411,
         411,
         413,
         413,
         413,
         411,
         415,
         413,
         411,
         416,
         413,
         411,
         411,
         411,
         411,
         411,
         411,
         414,
         411,
         415,
         411,
         411,
         413,
         413,
         413,
         411,
         415,
         413,
         77,
         417,
         396,
         77,
         77,
         77,
         77,
         77,
         77,
         397,
         77,
         398,
         77,
         77,
         396,
         396,
         396,
         77,
         398,
         396,
         77,
         78,
         396,
         77,
         77,
         77,
         77,
         77,
         77,
         397,
         77,
         398,
         77,
         77,
         396,
         396,
         396,
         77,
         398,
         396,
         418,
         419,
         420,
         418,
         418,
         418,
         418,
         418,
         418,
         421,
         418,
         422,
         418,
         418,
         420,
         420,
         420,
         418,
         422,
         420,
         77,
         423,
         396,
         77,
         77,
         77,
         77,
         77,
         77,
         397,
         77,
         398,
         77,
         77,
         396,
         396,
         396,
         77,
         398,
         396,
         424,
         425,
         426,
         424,
         424,
         424,
         424,
         424,
         424,
         427,
         424,
         428,
         424,
         424,
         426,
         426,
         426,
         424,
         428,
         426,
         77,
         429,
         396,
         77,
         77,
         77,
         77,
         77,
         77,
         397,
         77,
         398,
         77,
         77,
         396,
         396,
         396,
         77,
         398,
         396,
         77,
         78,
         396,
         77,
         77,
         77,
         77,
         77,
         77,
         397,
         77,
         398,
         77,
         430,
         396,
         396,
         396,
         77,
         398,
         396,
         77,
         904,
         409,
         77,
         77,
         77,
         77,
         77,
         77,
         397,
         77,
         398,
         77,
         77,
         409,
         409,
         409,
         77,
         398,
         409,
         77,
         905,
         409,
         77,
         77,
         77,
         77,
         77,
         77,
         397,
         77,
         398,
         77,
         77,
         409,
         409,
         409,
         77,
         398,
         409,
         77,
         906,
         409,
         77,
         77,
         77,
         77,
         77,
         77,
         397,
         77,
         398,
         77,
         77,
         409,
         409,
         409,
         77,
         398,
         409,
         411,
         412,
         413,
         411,
         411,
         411,
         411,
         411,
         411,
         414,
         411,
         415,
         411,
         411,
         413,
         413,
         413,
         411,
         415,
         413,
         424,
         1063,
         426,
         424,
         424,
         424,
         424,
         424,
         424,
         427,
         424,
         428,
         424,
         424,
         426,
         426,
         426,
         424,
         428,
         426,
         77,
         1064,
         409,
         77,
         77,
         77,
         77,
         77,
         77,
         397,
         77,
         398,
         77,
         77,
         409,
         409,
         409,
         77,
         398,
         409,
      },
   },
   [nir_op_feq] = {
      .filter = (uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         0,
         0,
         0,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         8,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         11,
         2,
         2,
         12,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         5,
         4,
         4,
         4,
         4,
         4,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         0,
         18,
         0,
         0,
         0,
         0,
         0,
         17,
         0,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         17,
         0,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         17,
         0,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         17,
         0,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         17,
         0,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         19,
         19,
         19,
         19,
         19,
         19,
         6,
         6,
         6,
         6,
         6,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         5,
         4,
         4,
         4,
         4,
         4,
         20,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 21,
      .table = (uint16_t []) {
      
         81,
         82,
         431,
         81,
         432,
         432,
         81,
         81,
         81,
         81,
         81,
         431,
         431,
         432,
         81,
         81,
         81,
         81,
         81,
         81,
         432,
         82,
         82,
         433,
         434,
         435,
         436,
         437,
         438,
         439,
         440,
         82,
         948,
         433,
         949,
         950,
         951,
         952,
         953,
         954,
         1065,
         1066,
         431,
         433,
         441,
         431,
         442,
         442,
         431,
         431,
         431,
         431,
         431,
         441,
         441,
         442,
         431,
         431,
         431,
         431,
         431,
         431,
         442,
         81,
         434,
         431,
         81,
         432,
         432,
         81,
         81,
         81,
         81,
         81,
         431,
         431,
         432,
         81,
         81,
         81,
         81,
         81,
         81,
         432,
         432,
         435,
         442,
         432,
         432,
         432,
         432,
         432,
         432,
         432,
         432,
         442,
         442,
         432,
         432,
         432,
         432,
         432,
         432,
         432,
         432,
         432,
         436,
         442,
         432,
         432,
         432,
         432,
         432,
         432,
         432,
         432,
         442,
         442,
         432,
         432,
         432,
         432,
         432,
         432,
         432,
         432,
         81,
         437,
         431,
         81,
         432,
         432,
         81,
         81,
         81,
         81,
         81,
         431,
         431,
         432,
         81,
         81,
         81,
         81,
         81,
         81,
         432,
         81,
         438,
         431,
         81,
         432,
         432,
         81,
         443,
         81,
         81,
         81,
         431,
         955,
         432,
         81,
         81,
         81,
         81,
         81,
         81,
         432,
         81,
         439,
         431,
         81,
         432,
         432,
         81,
         81,
         81,
         81,
         81,
         431,
         431,
         432,
         81,
         81,
         81,
         81,
         81,
         81,
         432,
         81,
         440,
         431,
         81,
         432,
         432,
         81,
         81,
         81,
         81,
         81,
         431,
         431,
         432,
         81,
         81,
         81,
         81,
         81,
         81,
         432,
         81,
         82,
         431,
         81,
         432,
         432,
         81,
         81,
         81,
         81,
         444,
         431,
         431,
         432,
         81,
         81,
         81,
         81,
         81,
         81,
         432,
         431,
         948,
         441,
         431,
         442,
         442,
         431,
         431,
         431,
         431,
         431,
         441,
         441,
         442,
         431,
         431,
         431,
         431,
         431,
         431,
         442,
         431,
         433,
         441,
         431,
         442,
         442,
         431,
         955,
         431,
         431,
         431,
         441,
         956,
         442,
         431,
         431,
         431,
         431,
         431,
         431,
         442,
         432,
         949,
         442,
         432,
         432,
         432,
         432,
         432,
         432,
         432,
         432,
         442,
         442,
         432,
         432,
         432,
         432,
         432,
         432,
         432,
         432,
         81,
         950,
         431,
         81,
         432,
         432,
         81,
         81,
         81,
         81,
         81,
         431,
         431,
         432,
         81,
         81,
         81,
         81,
         81,
         81,
         432,
         81,
         951,
         431,
         81,
         432,
         432,
         81,
         81,
         81,
         81,
         81,
         431,
         431,
         432,
         81,
         81,
         81,
         81,
         81,
         81,
         432,
         81,
         952,
         431,
         81,
         432,
         432,
         81,
         81,
         81,
         81,
         81,
         431,
         431,
         432,
         81,
         81,
         81,
         81,
         81,
         81,
         432,
         81,
         953,
         431,
         81,
         432,
         432,
         81,
         81,
         81,
         81,
         81,
         431,
         431,
         432,
         81,
         81,
         81,
         81,
         81,
         81,
         432,
         81,
         954,
         431,
         81,
         432,
         432,
         81,
         81,
         81,
         81,
         81,
         431,
         431,
         432,
         81,
         81,
         81,
         81,
         81,
         81,
         432,
         81,
         1065,
         431,
         81,
         432,
         432,
         81,
         81,
         81,
         81,
         81,
         431,
         431,
         432,
         81,
         81,
         81,
         81,
         81,
         81,
         432,
         432,
         1066,
         442,
         432,
         432,
         432,
         432,
         432,
         432,
         432,
         432,
         442,
         442,
         432,
         432,
         432,
         432,
         432,
         432,
         432,
         432,
      },
   },
   [nir_op_fne] = {
      .filter = (uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         0,
         0,
         0,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         8,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         11,
         2,
         2,
         12,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         5,
         4,
         4,
         4,
         4,
         4,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         0,
         18,
         0,
         0,
         0,
         0,
         0,
         17,
         0,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         17,
         0,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         17,
         0,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         17,
         0,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         17,
         0,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         5,
         4,
         4,
         4,
         4,
         4,
         19,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 20,
      .table = (uint16_t []) {
      
         83,
         84,
         445,
         83,
         446,
         446,
         83,
         83,
         83,
         83,
         83,
         445,
         445,
         446,
         83,
         83,
         83,
         83,
         83,
         446,
         84,
         84,
         447,
         448,
         449,
         450,
         451,
         452,
         453,
         454,
         84,
         957,
         447,
         958,
         959,
         960,
         961,
         962,
         963,
         1088,
         445,
         447,
         455,
         445,
         456,
         456,
         445,
         445,
         445,
         445,
         445,
         455,
         455,
         456,
         445,
         445,
         445,
         445,
         445,
         456,
         83,
         448,
         445,
         83,
         446,
         446,
         83,
         83,
         83,
         83,
         83,
         445,
         445,
         446,
         83,
         83,
         83,
         83,
         83,
         446,
         446,
         449,
         456,
         446,
         446,
         446,
         446,
         446,
         446,
         446,
         446,
         456,
         456,
         446,
         446,
         446,
         446,
         446,
         446,
         446,
         446,
         450,
         456,
         446,
         446,
         446,
         446,
         446,
         446,
         446,
         446,
         456,
         456,
         446,
         446,
         446,
         446,
         446,
         446,
         446,
         83,
         451,
         445,
         83,
         446,
         446,
         83,
         83,
         83,
         83,
         83,
         445,
         445,
         446,
         83,
         83,
         83,
         83,
         83,
         446,
         83,
         452,
         445,
         83,
         446,
         446,
         83,
         457,
         83,
         83,
         83,
         445,
         964,
         446,
         83,
         83,
         83,
         83,
         83,
         446,
         83,
         453,
         445,
         83,
         446,
         446,
         83,
         83,
         83,
         83,
         83,
         445,
         445,
         446,
         83,
         83,
         83,
         83,
         83,
         446,
         83,
         454,
         445,
         83,
         446,
         446,
         83,
         83,
         83,
         83,
         83,
         445,
         445,
         446,
         83,
         83,
         83,
         83,
         83,
         446,
         83,
         84,
         445,
         83,
         446,
         446,
         83,
         83,
         83,
         83,
         458,
         445,
         445,
         446,
         83,
         83,
         83,
         83,
         83,
         446,
         445,
         957,
         455,
         445,
         456,
         456,
         445,
         445,
         445,
         445,
         445,
         455,
         455,
         456,
         445,
         445,
         445,
         445,
         445,
         456,
         445,
         447,
         455,
         445,
         456,
         456,
         445,
         964,
         445,
         445,
         445,
         455,
         965,
         456,
         445,
         445,
         445,
         445,
         445,
         456,
         446,
         958,
         456,
         446,
         446,
         446,
         446,
         446,
         446,
         446,
         446,
         456,
         456,
         446,
         446,
         446,
         446,
         446,
         446,
         446,
         83,
         959,
         445,
         83,
         446,
         446,
         83,
         83,
         83,
         83,
         83,
         445,
         445,
         446,
         83,
         83,
         83,
         83,
         83,
         446,
         83,
         960,
         445,
         83,
         446,
         446,
         83,
         83,
         83,
         83,
         83,
         445,
         445,
         446,
         83,
         83,
         83,
         83,
         83,
         446,
         83,
         961,
         445,
         83,
         446,
         446,
         83,
         83,
         83,
         83,
         83,
         445,
         445,
         446,
         83,
         83,
         83,
         83,
         83,
         446,
         83,
         962,
         445,
         83,
         446,
         446,
         83,
         83,
         83,
         83,
         83,
         445,
         445,
         446,
         83,
         83,
         83,
         83,
         83,
         446,
         83,
         963,
         445,
         83,
         446,
         446,
         83,
         83,
         83,
         83,
         83,
         445,
         445,
         446,
         83,
         83,
         83,
         83,
         83,
         446,
         446,
         1088,
         456,
         446,
         446,
         446,
         446,
         446,
         446,
         446,
         446,
         456,
         456,
         446,
         446,
         446,
         446,
         446,
         446,
         446,
      },
   },
   [nir_op_ilt] = {
      .filter = (uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         5,
         5,
         5,
         6,
         6,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         3,
         3,
         3,
         5,
         5,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         4,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 9,
      .table = (uint16_t []) {
      
         85,
         86,
         85,
         772,
         772,
         773,
         773,
         774,
         85,
         85,
         86,
         775,
         772,
         776,
         773,
         777,
         774,
         778,
         85,
         779,
         85,
         772,
         772,
         773,
         773,
         774,
         85,
         780,
         781,
         780,
         782,
         782,
         783,
         783,
         784,
         780,
         780,
         785,
         780,
         782,
         782,
         783,
         783,
         784,
         780,
         786,
         787,
         786,
         788,
         788,
         789,
         789,
         790,
         786,
         786,
         791,
         786,
         788,
         788,
         789,
         789,
         790,
         786,
         792,
         793,
         792,
         794,
         794,
         795,
         795,
         796,
         792,
         85,
         797,
         85,
         772,
         772,
         773,
         773,
         774,
         798,
      },
   },
   [nir_op_ult] = {
      .filter = (uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         5,
         6,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         6,
         6,
         5,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         8,
         7,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         4,
         2,
         0,
         0,
         4,
         2,
         0,
         0,
         4,
      },
      
      .num_filtered_states = 10,
      .table = (uint16_t []) {
      
         87,
         87,
         684,
         87,
         87,
         685,
         685,
         686,
         686,
         87,
         88,
         88,
         687,
         688,
         88,
         689,
         690,
         691,
         692,
         693,
         87,
         87,
         684,
         87,
         87,
         685,
         685,
         686,
         686,
         87,
         87,
         694,
         684,
         87,
         87,
         685,
         685,
         686,
         686,
         87,
         695,
         695,
         696,
         695,
         695,
         697,
         697,
         698,
         698,
         695,
         699,
         699,
         700,
         699,
         699,
         701,
         701,
         702,
         702,
         699,
         699,
         703,
         700,
         699,
         699,
         701,
         701,
         702,
         702,
         699,
         704,
         704,
         705,
         704,
         704,
         706,
         706,
         707,
         707,
         704,
         704,
         708,
         705,
         704,
         704,
         706,
         706,
         707,
         707,
         704,
         87,
         709,
         684,
         87,
         87,
         685,
         685,
         686,
         686,
         710,
      },
   },
   [nir_op_ige] = {
      .filter = (uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         5,
         5,
         5,
         6,
         6,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         3,
         3,
         3,
         5,
         5,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         4,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 12,
      .table = (uint16_t []) {
      
         89,
         89,
         89,
         799,
         799,
         800,
         800,
         801,
         89,
         89,
         89,
         89,
         89,
         89,
         802,
         799,
         803,
         800,
         804,
         801,
         89,
         89,
         89,
         805,
         89,
         806,
         89,
         799,
         799,
         800,
         800,
         801,
         89,
         89,
         89,
         89,
         807,
         807,
         807,
         808,
         808,
         809,
         809,
         810,
         807,
         807,
         807,
         807,
         807,
         811,
         807,
         808,
         808,
         809,
         809,
         810,
         807,
         807,
         807,
         807,
         812,
         812,
         812,
         813,
         813,
         814,
         814,
         815,
         812,
         812,
         812,
         812,
         812,
         816,
         812,
         813,
         813,
         814,
         814,
         815,
         812,
         812,
         812,
         812,
         817,
         817,
         817,
         818,
         818,
         819,
         819,
         820,
         817,
         817,
         817,
         817,
         89,
         821,
         89,
         799,
         799,
         800,
         800,
         801,
         89,
         89,
         89,
         89,
         89,
         822,
         89,
         799,
         799,
         800,
         800,
         801,
         89,
         89,
         89,
         89,
         89,
         823,
         89,
         799,
         799,
         800,
         800,
         801,
         89,
         89,
         89,
         89,
         89,
         824,
         89,
         799,
         799,
         800,
         800,
         801,
         89,
         89,
         89,
         825,
      },
   },
   [nir_op_uge] = {
      .filter = (uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         5,
         6,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         6,
         6,
         5,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         8,
         7,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         4,
         2,
         0,
         0,
         4,
         2,
         0,
         0,
         4,
      },
      
      .num_filtered_states = 10,
      .table = (uint16_t []) {
      
         90,
         90,
         711,
         90,
         90,
         712,
         712,
         713,
         713,
         90,
         91,
         91,
         714,
         715,
         91,
         716,
         717,
         718,
         719,
         720,
         90,
         90,
         711,
         90,
         90,
         712,
         712,
         713,
         713,
         90,
         90,
         721,
         711,
         90,
         90,
         712,
         712,
         713,
         713,
         90,
         722,
         722,
         723,
         722,
         722,
         724,
         724,
         725,
         725,
         722,
         726,
         726,
         727,
         726,
         726,
         728,
         728,
         729,
         729,
         726,
         726,
         730,
         727,
         726,
         726,
         728,
         728,
         729,
         729,
         726,
         731,
         731,
         732,
         731,
         731,
         733,
         733,
         734,
         734,
         731,
         731,
         735,
         732,
         731,
         731,
         733,
         733,
         734,
         734,
         731,
         90,
         736,
         711,
         90,
         90,
         712,
         712,
         713,
         713,
         737,
      },
   },
   [nir_op_ieq] = {
      .filter = (uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 10,
      .table = (uint16_t []) {
      
         92,
         93,
         627,
         92,
         92,
         92,
         92,
         92,
         92,
         92,
         93,
         93,
         628,
         629,
         630,
         631,
         632,
         633,
         634,
         1012,
         627,
         628,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         627,
         92,
         629,
         627,
         92,
         92,
         92,
         92,
         92,
         92,
         92,
         92,
         630,
         627,
         92,
         92,
         92,
         92,
         92,
         92,
         92,
         92,
         631,
         627,
         92,
         92,
         92,
         92,
         92,
         92,
         92,
         92,
         632,
         627,
         92,
         92,
         92,
         92,
         92,
         92,
         92,
         92,
         633,
         627,
         92,
         92,
         92,
         92,
         635,
         92,
         92,
         92,
         634,
         627,
         92,
         92,
         92,
         92,
         92,
         636,
         92,
         92,
         1012,
         627,
         92,
         92,
         92,
         92,
         92,
         92,
         92,
      },
   },
   [nir_op_ine] = {
      .filter = (uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 8,
      .table = (uint16_t []) {
      
         94,
         95,
         637,
         94,
         94,
         94,
         94,
         94,
         95,
         95,
         638,
         639,
         640,
         641,
         642,
         1013,
         637,
         638,
         637,
         637,
         637,
         637,
         637,
         637,
         94,
         639,
         637,
         94,
         94,
         94,
         94,
         94,
         94,
         640,
         637,
         94,
         94,
         94,
         94,
         94,
         94,
         641,
         637,
         94,
         94,
         643,
         94,
         94,
         94,
         642,
         637,
         94,
         94,
         94,
         644,
         94,
         94,
         1013,
         637,
         94,
         94,
         94,
         94,
         1014,
      },
   },
   [nir_op_fmax] = {
      .filter = (uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         8,
         2,
         2,
         2,
         2,
         9,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         7,
         7,
         0,
         10,
         11,
         10,
         10,
         11,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         10,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         10,
         11,
         10,
         10,
         10,
         10,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 14,
      .table = (uint16_t []) {
      
         96,
         97,
         459,
         460,
         96,
         96,
         96,
         96,
         907,
         459,
         96,
         96,
         96,
         96,
         96,
         97,
         459,
         460,
         96,
         96,
         96,
         96,
         907,
         459,
         96,
         96,
         96,
         96,
         96,
         97,
         459,
         460,
         96,
         96,
         96,
         96,
         907,
         459,
         96,
         96,
         96,
         96,
         96,
         461,
         459,
         460,
         96,
         96,
         96,
         96,
         907,
         459,
         96,
         96,
         96,
         96,
         96,
         462,
         459,
         460,
         96,
         96,
         96,
         96,
         907,
         459,
         96,
         96,
         96,
         96,
         96,
         97,
         459,
         460,
         96,
         463,
         96,
         96,
         907,
         459,
         96,
         96,
         96,
         96,
         464,
         465,
         466,
         467,
         464,
         464,
         464,
         464,
         908,
         466,
         464,
         464,
         464,
         464,
         96,
         468,
         459,
         460,
         96,
         96,
         96,
         96,
         907,
         459,
         96,
         96,
         96,
         96,
         96,
         97,
         459,
         460,
         96,
         96,
         96,
         96,
         907,
         459,
         96,
         96,
         96,
         96,
         96,
         97,
         459,
         460,
         96,
         96,
         96,
         96,
         907,
         909,
         96,
         96,
         96,
         96,
         910,
         911,
         912,
         913,
         910,
         910,
         910,
         910,
         914,
         912,
         910,
         910,
         910,
         910,
         910,
         915,
         912,
         913,
         910,
         910,
         910,
         910,
         914,
         912,
         910,
         910,
         910,
         910,
         96,
         1108,
         459,
         460,
         96,
         96,
         96,
         96,
         907,
         459,
         96,
         96,
         96,
         96,
         96,
         1109,
         459,
         460,
         96,
         96,
         96,
         96,
         907,
         459,
         96,
         96,
         96,
         96,
      },
   },
   [nir_op_bcsel] = {
      .filter = (uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         5,
         6,
         7,
         6,
         7,
         8,
         8,
         8,
         8,
         0,
         9,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         15,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         7,
         6,
         7,
         6,
         7,
         6,
         6,
         6,
         7,
         7,
         6,
         7,
         6,
         6,
         6,
         7,
         6,
         7,
         6,
         6,
         6,
         7,
         6,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         10,
         0,
         0,
         0,
         10,
         0,
         10,
         0,
         0,
         0,
         10,
         0,
         10,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         19,
         20,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         6,
         7,
         7,
         7,
         7,
         7,
         7,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         21,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 22,
      .table = (uint16_t []) {
      
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         100,
         101,
         100,
         538,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         539,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         540,
         98,
         541,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         542,
         543,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         544,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         102,
         103,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         545,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         104,
         105,
         104,
         546,
         104,
         104,
         104,
         104,
         104,
         104,
         104,
         104,
         547,
         104,
         104,
         104,
         104,
         104,
         104,
         104,
         104,
         104,
         102,
         103,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         545,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         548,
         102,
         549,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         545,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         103,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         545,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         103,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         545,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         103,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         545,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         103,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         545,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         103,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         545,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         103,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         545,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         103,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         545,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         103,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         545,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         550,
         551,
         550,
         550,
         550,
         550,
         550,
         550,
         550,
         550,
         550,
         550,
         552,
         550,
         550,
         550,
         550,
         550,
         550,
         550,
         550,
         550,
         102,
         103,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         545,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         103,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         545,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         103,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         545,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         103,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         545,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         103,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         545,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         103,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         545,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         103,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         545,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         103,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         545,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         103,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         545,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         102,
         553,
         554,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         555,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         556,
         557,
         556,
         558,
         556,
         556,
         556,
         556,
         556,
         556,
         556,
         556,
         559,
         556,
         556,
         556,
         556,
         556,
         556,
         556,
         556,
         556,
         553,
         554,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         555,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         560,
         553,
         561,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         555,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         554,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         555,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         554,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         555,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         554,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         555,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         554,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         555,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         554,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         555,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         554,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         555,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         554,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         555,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         554,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         555,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         562,
         563,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         564,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         562,
         553,
         554,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         555,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         554,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         555,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         554,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         555,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         554,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         555,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         554,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         555,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         554,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         555,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         554,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         555,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         554,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         555,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         554,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         555,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         553,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         100,
         101,
         100,
         538,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         539,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         540,
         98,
         541,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         542,
         543,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         544,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         100,
         101,
         100,
         538,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         539,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         540,
         98,
         541,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         542,
         543,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         544,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         565,
         566,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         568,
         569,
         568,
         570,
         568,
         568,
         568,
         568,
         568,
         568,
         568,
         568,
         571,
         568,
         568,
         568,
         568,
         568,
         568,
         568,
         568,
         568,
         565,
         566,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         572,
         565,
         573,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         566,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         566,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         566,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         566,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         566,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         566,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         566,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         566,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         574,
         575,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         576,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         574,
         565,
         566,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         566,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         566,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         566,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         566,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         566,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         566,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         566,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         566,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         567,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         565,
         577,
         578,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         579,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         577,
         578,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         579,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         584,
         577,
         585,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         579,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         578,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         579,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         578,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         579,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         578,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         579,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         578,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         579,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         578,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         579,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         578,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         579,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         578,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         579,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         578,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         579,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         586,
         587,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         588,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         577,
         578,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         579,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         578,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         579,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         578,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         579,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         578,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         579,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         578,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         579,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         578,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         579,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         578,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         579,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         578,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         579,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         578,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         579,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         578,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         579,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         580,
         581,
         580,
         582,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         583,
         589,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         580,
         577,
         578,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         579,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         584,
         577,
         585,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         579,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         578,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         579,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         578,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         579,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         578,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         579,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         578,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         579,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         578,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         579,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         578,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         579,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         578,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         579,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         578,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         579,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         586,
         587,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         588,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         577,
         578,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         579,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         578,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         579,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         578,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         579,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         578,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         579,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         578,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         579,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         578,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         579,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         578,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         579,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         578,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         579,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         578,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         579,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         577,
         590,
         591,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         592,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         593,
         594,
         593,
         595,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         596,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         593,
         590,
         591,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         592,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         597,
         590,
         598,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         592,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         591,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         592,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         591,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         592,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         591,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         592,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         591,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         592,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         591,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         592,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         591,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         592,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         591,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         592,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         591,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         592,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         599,
         600,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         601,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         599,
         590,
         591,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         592,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         591,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         592,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         591,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         592,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         591,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         592,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         591,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         592,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         591,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         592,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         591,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         592,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         591,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         592,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         591,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         592,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         100,
         101,
         100,
         538,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         539,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         1121,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         540,
         98,
         541,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         542,
         543,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         544,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         100,
         101,
         100,
         538,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         539,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         540,
         98,
         541,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         542,
         543,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         544,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         1015,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         100,
         101,
         100,
         538,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         539,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         540,
         98,
         541,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         542,
         543,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         544,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         602,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         603,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         604,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         100,
         101,
         100,
         538,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         539,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         540,
         98,
         541,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         542,
         543,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         544,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         100,
         101,
         100,
         538,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         539,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         540,
         98,
         541,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         542,
         543,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         544,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         100,
         101,
         100,
         538,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         539,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         540,
         98,
         541,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         542,
         543,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         544,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         100,
         101,
         100,
         538,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         539,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         540,
         98,
         541,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         542,
         543,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         544,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         100,
         101,
         100,
         538,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         539,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         540,
         98,
         541,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         542,
         543,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         544,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         100,
         101,
         100,
         538,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         539,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         540,
         98,
         541,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         542,
         543,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         544,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         100,
         101,
         100,
         538,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         539,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         540,
         98,
         541,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         542,
         543,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         544,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         1016,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         100,
         101,
         100,
         538,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         539,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         540,
         98,
         541,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         542,
         543,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         544,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         1017,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         100,
         101,
         100,
         538,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         539,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         540,
         98,
         541,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         542,
         543,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         544,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         1018,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         100,
         101,
         100,
         538,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         539,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         100,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         540,
         98,
         541,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         542,
         543,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         544,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         99,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         537,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
         98,
      },
   },
   [nir_op_fmin] = {
      .filter = (uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         9,
         2,
         2,
         2,
         2,
         10,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         7,
         7,
         6,
         6,
         7,
         6,
         6,
         7,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         11,
         12,
         11,
         11,
         11,
         12,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 14,
      .table = (uint16_t []) {
      
         106,
         107,
         469,
         470,
         106,
         106,
         106,
         106,
         106,
         916,
         469,
         106,
         106,
         1052,
         106,
         107,
         469,
         470,
         106,
         106,
         106,
         106,
         106,
         916,
         469,
         106,
         106,
         1052,
         106,
         107,
         469,
         470,
         106,
         106,
         106,
         106,
         106,
         916,
         469,
         106,
         106,
         1052,
         106,
         107,
         469,
         470,
         106,
         106,
         106,
         106,
         106,
         916,
         469,
         106,
         106,
         1052,
         106,
         471,
         469,
         470,
         106,
         106,
         106,
         106,
         106,
         916,
         469,
         106,
         106,
         1052,
         106,
         472,
         469,
         470,
         106,
         473,
         106,
         106,
         106,
         916,
         469,
         106,
         106,
         1052,
         474,
         475,
         476,
         477,
         474,
         474,
         474,
         474,
         474,
         917,
         476,
         474,
         474,
         1053,
         474,
         478,
         476,
         477,
         474,
         474,
         474,
         474,
         474,
         917,
         476,
         474,
         474,
         1053,
         479,
         480,
         481,
         482,
         479,
         479,
         479,
         479,
         479,
         918,
         481,
         479,
         479,
         1054,
         106,
         107,
         469,
         470,
         106,
         106,
         106,
         106,
         106,
         916,
         469,
         106,
         106,
         1052,
         919,
         920,
         921,
         922,
         919,
         919,
         919,
         919,
         919,
         923,
         924,
         919,
         919,
         1055,
         1056,
         1057,
         1058,
         1059,
         1056,
         1056,
         1056,
         1056,
         1056,
         1060,
         1058,
         1056,
         1056,
         1061,
         1056,
         1062,
         1058,
         1059,
         1056,
         1056,
         1056,
         1056,
         1056,
         1060,
         1058,
         1056,
         1056,
         1061,
         106,
         107,
         469,
         470,
         106,
         106,
         106,
         106,
         106,
         916,
         469,
         106,
         106,
         1052,
      },
   },
   [nir_search_op_i2f] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (uint16_t []) {
      
         108,
         754,
         1119,
      },
   },
   [nir_op_ior] = {
      .filter = (uint16_t []) {
         0,
         1,
         0,
         0,
         2,
         3,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         6,
         0,
         0,
         0,
         0,
         7,
         8,
         9,
         10,
         11,
         12,
         13,
         14,
         15,
         16,
         16,
         17,
         17,
         18,
         18,
         19,
         19,
         20,
         21,
         22,
         0,
         23,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         24,
         24,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         25,
         2,
         25,
         3,
         3,
         3,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         5,
         26,
         5,
         26,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         9,
         8,
         9,
         8,
         9,
         8,
         8,
         8,
         9,
         9,
         8,
         9,
         8,
         8,
         8,
         9,
         8,
         9,
         8,
         8,
         8,
         9,
         8,
         12,
         12,
         12,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         13,
         12,
         13,
         12,
         13,
         12,
         12,
         12,
         13,
         13,
         12,
         13,
         12,
         12,
         12,
         13,
         12,
         13,
         12,
         12,
         12,
         13,
         12,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         27,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         21,
         21,
         21,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         21,
         21,
         21,
         21,
         21,
         21,
         21,
         21,
         21,
         21,
         21,
         21,
         21,
         21,
         21,
         21,
         21,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         28,
         28,
         3,
         29,
         29,
         24,
         24,
         24,
         24,
         4,
         4,
         4,
         4,
         4,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         10,
         9,
         9,
         9,
         9,
         9,
         9,
         14,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         23,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         27,
         0,
         0,
         0,
         24,
         24,
         24,
         24,
         24,
         30,
         31,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         16,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         24,
         0,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         32,
         33,
         24,
         4,
         34,
         35,
         24,
         4,
         36,
         37,
         24,
      },
      
      .num_filtered_states = 38,
      .table = (uint16_t []) {
      
         109,
         110,
         109,
         109,
         229,
         109,
         109,
         230,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         231,
         232,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         110,
         110,
         110,
         110,
         233,
         110,
         110,
         234,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         235,
         236,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         109,
         110,
         109,
         109,
         229,
         109,
         109,
         230,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         231,
         232,
         109,
         866,
         109,
         109,
         1024,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         110,
         109,
         109,
         229,
         109,
         237,
         230,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         231,
         232,
         109,
         866,
         109,
         109,
         1024,
         109,
         237,
         109,
         237,
         109,
         237,
         109,
         237,
         229,
         233,
         229,
         229,
         229,
         229,
         229,
         238,
         229,
         229,
         229,
         229,
         229,
         229,
         229,
         229,
         229,
         229,
         229,
         229,
         229,
         229,
         229,
         239,
         240,
         229,
         229,
         229,
         229,
         229,
         229,
         229,
         229,
         229,
         229,
         229,
         229,
         229,
         109,
         110,
         109,
         109,
         229,
         109,
         109,
         230,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         231,
         232,
         867,
         109,
         109,
         1025,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         110,
         109,
         237,
         229,
         109,
         109,
         230,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         231,
         232,
         867,
         109,
         109,
         1025,
         109,
         237,
         109,
         237,
         109,
         237,
         109,
         237,
         109,
         230,
         234,
         230,
         230,
         238,
         230,
         230,
         241,
         230,
         230,
         230,
         230,
         230,
         230,
         230,
         230,
         230,
         230,
         230,
         230,
         230,
         230,
         230,
         242,
         243,
         230,
         230,
         230,
         230,
         230,
         230,
         230,
         230,
         230,
         230,
         230,
         230,
         230,
         109,
         110,
         109,
         109,
         229,
         109,
         109,
         230,
         244,
         244,
         244,
         244,
         245,
         245,
         245,
         245,
         246,
         247,
         109,
         109,
         109,
         109,
         109,
         231,
         232,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         110,
         109,
         109,
         229,
         109,
         109,
         230,
         244,
         248,
         249,
         250,
         245,
         245,
         245,
         245,
         246,
         247,
         109,
         109,
         109,
         109,
         109,
         231,
         232,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         110,
         109,
         109,
         229,
         109,
         109,
         230,
         244,
         249,
         251,
         252,
         245,
         245,
         245,
         245,
         246,
         247,
         109,
         109,
         109,
         109,
         109,
         231,
         232,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         110,
         109,
         109,
         229,
         109,
         109,
         230,
         244,
         250,
         252,
         253,
         245,
         245,
         245,
         245,
         246,
         247,
         109,
         109,
         109,
         109,
         109,
         231,
         232,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         110,
         109,
         109,
         229,
         109,
         109,
         230,
         245,
         245,
         245,
         245,
         254,
         254,
         254,
         254,
         255,
         256,
         109,
         109,
         109,
         109,
         109,
         231,
         232,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         110,
         109,
         109,
         229,
         109,
         109,
         230,
         245,
         245,
         245,
         245,
         254,
         257,
         258,
         259,
         255,
         256,
         109,
         109,
         109,
         109,
         109,
         231,
         232,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         110,
         109,
         109,
         229,
         109,
         109,
         230,
         245,
         245,
         245,
         245,
         254,
         258,
         260,
         261,
         255,
         256,
         109,
         109,
         109,
         109,
         109,
         231,
         232,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         110,
         109,
         109,
         229,
         109,
         109,
         230,
         245,
         245,
         245,
         245,
         254,
         259,
         261,
         262,
         255,
         256,
         109,
         109,
         109,
         109,
         109,
         231,
         232,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         110,
         109,
         109,
         229,
         109,
         109,
         230,
         246,
         246,
         246,
         246,
         255,
         255,
         255,
         255,
         263,
         264,
         109,
         109,
         109,
         109,
         109,
         231,
         232,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         110,
         109,
         109,
         229,
         109,
         109,
         230,
         247,
         247,
         247,
         247,
         256,
         256,
         256,
         256,
         264,
         265,
         109,
         109,
         109,
         109,
         109,
         231,
         232,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         110,
         109,
         109,
         229,
         109,
         109,
         230,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         266,
         109,
         109,
         109,
         109,
         231,
         232,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         110,
         109,
         109,
         229,
         109,
         109,
         230,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         267,
         109,
         109,
         109,
         231,
         232,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         110,
         109,
         109,
         229,
         109,
         109,
         230,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         268,
         109,
         109,
         231,
         232,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         110,
         109,
         109,
         229,
         109,
         109,
         230,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         269,
         269,
         231,
         232,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         110,
         109,
         109,
         229,
         109,
         109,
         230,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         269,
         269,
         270,
         232,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         231,
         235,
         231,
         231,
         239,
         231,
         231,
         242,
         231,
         231,
         231,
         231,
         231,
         231,
         231,
         231,
         231,
         231,
         231,
         231,
         231,
         231,
         270,
         271,
         272,
         231,
         231,
         231,
         231,
         231,
         231,
         231,
         231,
         231,
         231,
         231,
         231,
         231,
         232,
         236,
         232,
         232,
         240,
         232,
         232,
         243,
         232,
         232,
         232,
         232,
         232,
         232,
         232,
         232,
         232,
         232,
         232,
         232,
         232,
         232,
         232,
         272,
         232,
         232,
         232,
         232,
         232,
         232,
         232,
         232,
         232,
         232,
         232,
         232,
         232,
         232,
         109,
         110,
         109,
         109,
         229,
         867,
         867,
         230,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         231,
         232,
         109,
         868,
         109,
         109,
         1026,
         109,
         867,
         109,
         867,
         109,
         867,
         109,
         867,
         109,
         110,
         866,
         866,
         229,
         109,
         109,
         230,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         231,
         232,
         868,
         109,
         109,
         1027,
         109,
         866,
         109,
         866,
         109,
         866,
         109,
         866,
         109,
         109,
         110,
         109,
         109,
         229,
         109,
         109,
         230,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         231,
         232,
         109,
         109,
         869,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         110,
         109,
         109,
         229,
         1025,
         1025,
         230,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         231,
         232,
         109,
         1027,
         109,
         109,
         1028,
         109,
         1025,
         109,
         1025,
         109,
         1025,
         109,
         1025,
         109,
         110,
         1024,
         1024,
         229,
         109,
         109,
         230,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         231,
         232,
         1026,
         109,
         109,
         1028,
         109,
         1024,
         109,
         1024,
         109,
         1024,
         109,
         1024,
         109,
         109,
         110,
         109,
         109,
         229,
         109,
         237,
         230,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         231,
         232,
         109,
         866,
         109,
         109,
         1024,
         109,
         1103,
         109,
         1103,
         109,
         1103,
         109,
         1103,
         109,
         110,
         109,
         237,
         229,
         109,
         109,
         230,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         231,
         232,
         867,
         109,
         109,
         1025,
         109,
         1103,
         109,
         1103,
         109,
         1103,
         109,
         1103,
         109,
         109,
         110,
         109,
         109,
         229,
         109,
         237,
         230,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         231,
         232,
         109,
         866,
         109,
         109,
         1024,
         109,
         1103,
         109,
         1124,
         109,
         1124,
         109,
         1124,
         109,
         110,
         109,
         237,
         229,
         109,
         109,
         230,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         231,
         232,
         867,
         109,
         109,
         1025,
         109,
         1103,
         109,
         1124,
         109,
         1124,
         109,
         1124,
         109,
         109,
         110,
         109,
         109,
         229,
         109,
         237,
         230,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         231,
         232,
         109,
         866,
         109,
         109,
         1024,
         109,
         1103,
         109,
         1124,
         109,
         1128,
         109,
         1128,
         109,
         110,
         109,
         237,
         229,
         109,
         109,
         230,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         231,
         232,
         867,
         109,
         109,
         1025,
         109,
         1103,
         109,
         1124,
         109,
         1128,
         109,
         1128,
         109,
         109,
         110,
         109,
         109,
         229,
         109,
         237,
         230,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         231,
         232,
         109,
         866,
         109,
         109,
         1024,
         109,
         1103,
         109,
         1124,
         109,
         1128,
         109,
         1132,
         109,
         110,
         109,
         237,
         229,
         109,
         109,
         230,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         231,
         232,
         867,
         109,
         109,
         1025,
         109,
         1103,
         109,
         1124,
         109,
         1128,
         109,
         1132,
         109,
      },
   },
   [nir_op_imin] = {
      .filter = (uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         7,
         2,
         2,
         3,
         3,
         3,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         5,
         5,
         5,
         6,
         6,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         5,
         8,
         6,
         9,
         8,
         5,
         8,
         5,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 10,
      .table = (uint16_t []) {
      
         111,
         112,
         493,
         494,
         495,
         496,
         496,
         997,
         1092,
         1092,
         112,
         112,
         497,
         498,
         499,
         500,
         501,
         998,
         1093,
         1094,
         493,
         497,
         493,
         502,
         503,
         504,
         504,
         997,
         1095,
         1095,
         494,
         498,
         502,
         494,
         505,
         506,
         506,
         999,
         1096,
         1096,
         495,
         499,
         503,
         505,
         495,
         507,
         507,
         1000,
         1097,
         1097,
         496,
         500,
         504,
         506,
         507,
         496,
         496,
         1001,
         1092,
         1092,
         496,
         501,
         504,
         506,
         507,
         496,
         496,
         1001,
         1092,
         1092,
         997,
         998,
         997,
         999,
         1000,
         1001,
         1001,
         997,
         1098,
         1098,
         1092,
         1093,
         1095,
         1096,
         1097,
         1092,
         1092,
         1098,
         1092,
         1092,
         1092,
         1094,
         1095,
         1096,
         1097,
         1092,
         1092,
         1098,
         1092,
         1092,
      },
   },
   [nir_op_imax] = {
      .filter = (uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         5,
         2,
         2,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         6,
         0,
         6,
         6,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 7,
      .table = (uint16_t []) {
      
         113,
         114,
         508,
         509,
         510,
         1002,
         1003,
         114,
         114,
         511,
         512,
         513,
         1004,
         1005,
         508,
         511,
         508,
         514,
         515,
         1002,
         1006,
         509,
         512,
         514,
         509,
         516,
         1007,
         1008,
         510,
         513,
         515,
         516,
         510,
         1009,
         1010,
         1002,
         1004,
         1002,
         1007,
         1009,
         1002,
         1011,
         1003,
         1005,
         1006,
         1008,
         1010,
         1011,
         1003,
      },
   },
   [nir_op_umin] = {
      .filter = (uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (uint16_t []) {
      
         115,
         116,
         826,
         827,
         1100,
         116,
         116,
         828,
         829,
         1101,
         826,
         828,
         826,
         830,
         1102,
         827,
         829,
         830,
         827,
         1100,
         1100,
         1101,
         1102,
         1100,
         1100,
      },
   },
   [nir_op_umax] = {
      .filter = (uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         3,
         3,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (uint16_t []) {
      
         117,
         118,
         831,
         1021,
         118,
         118,
         832,
         1022,
         831,
         832,
         831,
         1023,
         1021,
         1022,
         1023,
         1021,
      },
   },
   [nir_op_extract_u8] = {
      .filter = (uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         3,
         0,
         4,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         4,
         0,
         4,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         2,
         3,
         0,
         0,
         2,
         3,
         0,
      },
      
      .num_filtered_states = 7,
      .table = (uint16_t []) {
      
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         119,
         286,
         119,
         119,
         119,
         119,
         119,
         119,
         287,
         119,
         119,
         119,
         119,
         119,
         119,
         288,
         119,
         119,
         119,
         119,
         119,
         119,
         289,
         119,
         119,
         119,
         119,
         119,
         119,
         1019,
         119,
         119,
         119,
         119,
         119,
      },
   },
   [nir_op_slt] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         120,
      },
   },
   [nir_op_sge] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         121,
      },
   },
   [nir_op_seq] = {
      .filter = (uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (uint16_t []) {
      
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         122,
         833,
         834,
         835,
         836,
         122,
         833,
         122,
         122,
         122,
         122,
         122,
         834,
         122,
         122,
         122,
         122,
         122,
         835,
         122,
         122,
         122,
         122,
         122,
         836,
         122,
         122,
         122,
         122,
      },
   },
   [nir_op_sne] = {
      .filter = (uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (uint16_t []) {
      
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         837,
         838,
         839,
         840,
         123,
         837,
         123,
         123,
         123,
         123,
         123,
         838,
         123,
         123,
         123,
         123,
         123,
         839,
         123,
         123,
         123,
         123,
         123,
         840,
         123,
         123,
         123,
         123,
      },
   },
   [nir_op_fall_equal2] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         124,
      },
   },
   [nir_op_fall_equal3] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         125,
      },
   },
   [nir_op_fall_equal4] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         126,
      },
   },
   [nir_op_fany_nequal2] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         127,
      },
   },
   [nir_op_fany_nequal3] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         128,
      },
   },
   [nir_op_fany_nequal4] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         129,
      },
   },
   [nir_op_fsub] = {
      .filter = (uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (uint16_t []) {
      
         130,
         130,
         130,
         680,
         131,
         131,
         681,
         682,
         130,
         130,
         130,
         680,
         130,
         130,
         130,
         680,
      },
   },
   [nir_op_ixor] = {
      .filter = (uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (uint16_t []) {
      
         132,
         133,
         133,
         133,
      },
   },
   [nir_op_isub] = {
      .filter = (uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (uint16_t []) {
      
         134,
         134,
         841,
         135,
         135,
         842,
         134,
         134,
         841,
      },
   },
   [nir_op_urol] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         136,
      },
   },
   [nir_op_uror] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         137,
      },
   },
   [nir_op_fexp2] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (uint16_t []) {
      
         138,
         854,
         995,
         996,
         1089,
      },
   },
   [nir_op_flog2] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         2,
         2,
         2,
         2,
         3,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         4,
         4,
         4,
         5,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (uint16_t []) {
      
         139,
         843,
         844,
         845,
         846,
         847,
      },
   },
   [nir_op_fpow] = {
      .filter = (uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (uint16_t []) {
      
         140,
         141,
         140,
         140,
         142,
         143,
         142,
         142,
         140,
         855,
         140,
         140,
         140,
         992,
         140,
         140,
      },
   },
   [nir_op_fsqrt] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (uint16_t []) {
      
         144,
         848,
      },
   },
   [nir_op_frcp] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         3,
         3,
         3,
         4,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (uint16_t []) {
      
         145,
         849,
         850,
         851,
         852,
      },
   },
   [nir_op_frsq] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (uint16_t []) {
      
         146,
         853,
      },
   },
   [nir_op_fdiv] = {
      .filter = (uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (uint16_t []) {
      
         147,
         147,
         148,
         148,
      },
   },
   [nir_op_fsin] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         149,
      },
   },
   [nir_op_fcos] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         150,
      },
   },
   [nir_op_fcsel] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         151,
      },
   },
   [nir_search_op_f2i] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (uint16_t []) {
      
         0,
         517,
         518,
         519,
         520,
      },
   },
   [nir_search_op_f2u] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (uint16_t []) {
      
         152,
         521,
         522,
         523,
         524,
      },
   },
   [nir_op_pack_64_2x32_split] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (uint16_t []) {
      
         153,
         153,
         153,
         153,
         153,
         291,
         153,
         153,
         153,
      },
   },
   [nir_op_unpack_64_2x32_split_y] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (uint16_t []) {
      
         154,
         738,
         739,
      },
   },
   [nir_op_unpack_32_2x16_split_x] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (uint16_t []) {
      
         155,
         740,
      },
   },
   [nir_op_unpack_32_2x16_split_y] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (uint16_t []) {
      
         156,
         741,
      },
   },
   [nir_op_unpack_half_2x16_split_x] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (uint16_t []) {
      
         0,
         742,
      },
   },
   [nir_op_unpack_half_2x16_split_y] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (uint16_t []) {
      
         0,
         743,
      },
   },
   [nir_op_extract_u16] = {
      .filter = (uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (uint16_t []) {
      
         157,
         158,
         157,
         158,
      },
   },
   [nir_op_extract_i8] = {
      .filter = (uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (uint16_t []) {
      
         159,
         159,
         159,
         159,
         159,
         159,
         159,
         290,
         159,
      },
   },
   [nir_op_ussub_4x8] = {
      .filter = (uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (uint16_t []) {
      
         0,
         160,
         0,
         160,
      },
   },
   [nir_op_find_lsb] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         161,
      },
   },
   [nir_op_ifind_msb] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         162,
      },
   },
   [nir_op_ufind_msb] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         163,
      },
   },
   [nir_op_fmod] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         164,
      },
   },
   [nir_op_frem] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         165,
      },
   },
   [nir_op_uadd_carry] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         166,
      },
   },
   [nir_op_usub_borrow] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         167,
      },
   },
   [nir_op_bitfield_insert] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         168,
      },
   },
   [nir_op_ihadd] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         169,
      },
   },
   [nir_op_uhadd] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         170,
      },
   },
   [nir_op_irhadd] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         171,
      },
   },
   [nir_op_urhadd] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         172,
      },
   },
   [nir_op_uadd_sat] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         173,
      },
   },
   [nir_op_usub_sat] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         174,
      },
   },
   [nir_op_ibitfield_extract] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         175,
      },
   },
   [nir_op_ubitfield_extract] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         176,
      },
   },
   [nir_op_ubfe] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (uint16_t []) {
      
         0,
         744,
         745,
         746,
         0,
         744,
         745,
         746,
      },
   },
   [nir_op_ibfe] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (uint16_t []) {
      
         0,
         747,
         748,
         749,
         0,
         747,
         748,
         749,
      },
   },
   [nir_op_bfm] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (uint16_t []) {
      
         0,
         750,
         751,
         752,
      },
   },
   [nir_op_extract_i16] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         177,
      },
   },
   [nir_op_pack_unorm_2x16] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         178,
      },
   },
   [nir_op_pack_unorm_4x8] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         179,
      },
   },
   [nir_op_pack_snorm_2x16] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         180,
      },
   },
   [nir_op_pack_snorm_4x8] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         181,
      },
   },
   [nir_op_unpack_unorm_2x16] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         182,
      },
   },
   [nir_op_unpack_unorm_4x8] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         183,
      },
   },
   [nir_op_unpack_snorm_2x16] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         184,
      },
   },
   [nir_op_unpack_snorm_4x8] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         185,
      },
   },
   [nir_op_isign] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         186,
      },
   },
   [nir_op_iadd_sat] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         187,
      },
   },
   [nir_op_isub_sat] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         188,
      },
   },
   [nir_search_op_f2f] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (uint16_t []) {
      
         189,
         683,
      },
   },
   [nir_search_op_u2u] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (uint16_t []) {
      
         190,
         755,
         756,
         757,
      },
   },
   [nir_search_op_i2i] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (uint16_t []) {
      
         191,
         758,
         759,
         760,
      },
   },
   [nir_op_ldexp] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         192,
      },
   },
   [nir_op_fddx] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         193,
      },
   },
   [nir_op_fddx_fine] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         194,
      },
   },
   [nir_op_fddx_coarse] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         195,
      },
   },
   [nir_op_fddy] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         196,
      },
   },
   [nir_op_fddy_fine] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         197,
      },
   },
   [nir_op_fddy_coarse] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         198,
      },
   },
   [nir_op_umul_low] = {
      .filter = (uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (uint16_t []) {
      
         0,
         199,
         199,
         199,
      },
   },
   [nir_op_imadsh_mix16] = {
      .filter = (uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (uint16_t []) {
      
         0,
         0,
         200,
         200,
         201,
         201,
         202,
         202,
      },
   },
};

static void
nir_opt_algebraic_pre_block(nir_block *block, uint16_t *states)
{
   nir_foreach_instr(instr, block) {
      switch (instr->type) {
      case nir_instr_type_alu: {
         nir_alu_instr *alu = nir_instr_as_alu(instr);
         nir_op op = alu->op;
         uint16_t search_op = nir_search_op_for_nir_op(op);
         const struct per_op_table *tbl = &nir_opt_algebraic_table[search_op];
         if (tbl->num_filtered_states == 0)
            continue;

         /* Calculate the index into the transition table. Note the index
          * calculated must match the iteration order of Python's
          * itertools.product(), which was used to emit the transition
          * table.
          */
         uint16_t index = 0;
         for (unsigned i = 0; i < nir_op_infos[op].num_inputs; i++) {
            index *= tbl->num_filtered_states;
            index += tbl->filter[states[alu->src[i].src.ssa->index]];
         }
         states[alu->dest.dest.ssa.index] = tbl->table[index];
         break;
      }

      case nir_instr_type_load_const: {
         nir_load_const_instr *load_const = nir_instr_as_load_const(instr);
         states[load_const->def.index] = CONST_STATE;
         break;
      }

      default:
         break;
      }
   }
}

static bool
nir_opt_algebraic_block(nir_builder *build, nir_block *block,
                   const uint16_t *states, const bool *condition_flags)
{
   bool progress = false;

   nir_foreach_instr_reverse_safe(instr, block) {
      if (instr->type != nir_instr_type_alu)
         continue;

      nir_alu_instr *alu = nir_instr_as_alu(instr);
      if (!alu->dest.dest.is_ssa)
         continue;

      switch (states[alu->dest.dest.ssa.index]) {
      case 0:
         break;
      case 1:
         break;
      case 2:
         break;
      case 3:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state3_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state3_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 4:
         break;
      case 5:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state5_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state5_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 6:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state6_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state6_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 7:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state7_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state7_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 8:
         break;
      case 9:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state9_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state9_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 10:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state10_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state10_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 11:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state11_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state11_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 12:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state12_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state12_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 13:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state13_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state13_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 14:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state14_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state14_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 15:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state15_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state15_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 16:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state16_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state16_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 17:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state17_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state17_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 18:
         break;
      case 19:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state19_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state19_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 20:
         break;
      case 21:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state21_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state21_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 22:
         break;
      case 23:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state23_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state23_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 24:
         break;
      case 25:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state25_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state25_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 26:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state26_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state26_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 27:
         break;
      case 28:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state28_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state28_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 29:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state29_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state29_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 30:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state30_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state30_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 31:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state31_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state31_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 32:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state32_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state32_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 33:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state33_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state33_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 34:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state34_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state34_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 35:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state35_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state35_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 36:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state36_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state36_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 37:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state37_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state37_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 38:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state38_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state38_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 39:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state39_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state39_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 40:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state40_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state40_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 41:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state41_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state41_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 42:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state42_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state42_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 43:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state43_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state43_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 44:
         break;
      case 45:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state45_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state45_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 46:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state46_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state46_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 47:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state47_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state47_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 48:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state48_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state48_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 49:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state49_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state49_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 50:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state50_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state50_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 51:
         break;
      case 52:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state52_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state52_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 53:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state53_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state53_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 54:
         break;
      case 55:
         break;
      case 56:
         break;
      case 57:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state57_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state57_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 58:
         break;
      case 59:
         break;
      case 60:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state60_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state60_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 61:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state61_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state61_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 62:
         break;
      case 63:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state63_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state63_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 64:
         break;
      case 65:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state65_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state65_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 66:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state66_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state66_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 67:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state67_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state67_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 68:
         break;
      case 69:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state69_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state69_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 70:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state70_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state70_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 71:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state71_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state71_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 72:
         break;
      case 73:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state73_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state73_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 74:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state74_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state74_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 75:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state75_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state75_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 76:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state76_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state76_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 77:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state77_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state77_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 78:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state78_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state78_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 79:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state79_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state79_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 80:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state80_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state80_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 81:
         break;
      case 82:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state82_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state82_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 83:
         break;
      case 84:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state84_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state84_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 85:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state85_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state85_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 86:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state86_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state86_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 87:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state87_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state87_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 88:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state88_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state88_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 89:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state89_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state89_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 90:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state90_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state90_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 91:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state91_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state91_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 92:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state92_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state92_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 93:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state93_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state93_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 94:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state94_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state94_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 95:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state95_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state95_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 96:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state96_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state96_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 97:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state97_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state97_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 98:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state98_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state98_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 99:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state99_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state99_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 100:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state100_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state100_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 101:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state101_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state101_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 102:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state102_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state102_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 103:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state103_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state103_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 104:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state104_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state104_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 105:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state105_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state105_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 106:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state106_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state106_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 107:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state107_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state107_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 108:
         break;
      case 109:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state109_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state109_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 110:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state110_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state110_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 111:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state111_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state111_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 112:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state112_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state112_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 113:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state113_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state113_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 114:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state114_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state114_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 115:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state115_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state115_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 116:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state116_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state116_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 117:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state117_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state117_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 118:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state118_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state118_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 119:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state119_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state119_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 120:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state120_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state120_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 121:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state121_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state121_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 122:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state122_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state122_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 123:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state123_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state123_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 124:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state124_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state124_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 125:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state125_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state125_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 126:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state126_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state126_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 127:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state127_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state127_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 128:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state128_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state128_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 129:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state129_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state129_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 130:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state130_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state130_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 131:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state131_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state131_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 132:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state132_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state132_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 133:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state133_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state133_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 134:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state134_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state134_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 135:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state135_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state135_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 136:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state136_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state136_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 137:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state137_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state137_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 138:
         break;
      case 139:
         break;
      case 140:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state140_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state140_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 141:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state141_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state141_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 142:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state142_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state142_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 143:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state143_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state143_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 144:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state144_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state144_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 145:
         break;
      case 146:
         break;
      case 147:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state147_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state147_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 148:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state148_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state148_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 149:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state149_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state149_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 150:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state150_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state150_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 151:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state151_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state151_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 152:
         break;
      case 153:
         break;
      case 154:
         break;
      case 155:
         break;
      case 156:
         break;
      case 157:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state157_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state157_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 158:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state158_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state158_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 159:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state159_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state159_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 160:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state160_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state160_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 161:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state161_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state161_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 162:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state162_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state162_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 163:
         break;
      case 164:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state164_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state164_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 165:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state165_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state165_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 166:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state166_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state166_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 167:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state167_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state167_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 168:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state168_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state168_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 169:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state169_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state169_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 170:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state170_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state170_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 171:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state171_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state171_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 172:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state172_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state172_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 173:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state173_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state173_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 174:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state174_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state174_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 175:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state175_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state175_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 176:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state176_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state176_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 177:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state177_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state177_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 178:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state178_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state178_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 179:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state179_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state179_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 180:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state180_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state180_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 181:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state181_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state181_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 182:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state182_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state182_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 183:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state183_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state183_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 184:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state184_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state184_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 185:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state185_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state185_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 186:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state186_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state186_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 187:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state187_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state187_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 188:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state188_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state188_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 189:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state189_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state189_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 190:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state190_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state190_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 191:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state191_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state191_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 192:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state192_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state192_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 193:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state193_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state193_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 194:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state194_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state194_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 195:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state195_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state195_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 196:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state196_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state196_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 197:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state197_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state197_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 198:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state198_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state198_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 199:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state199_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state199_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 200:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state200_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state200_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 201:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state201_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state201_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 202:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state202_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state202_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 203:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state203_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state203_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 204:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state204_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state204_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 205:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state205_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state205_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 206:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state206_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state206_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 207:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state207_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state207_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 208:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state208_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state208_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 209:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state209_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state209_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 210:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state210_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state210_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 211:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state211_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state211_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 212:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state212_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state212_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 213:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state213_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state213_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 214:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state214_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state214_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 215:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state215_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state215_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 216:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state216_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state216_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 217:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state217_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state217_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 218:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state218_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state218_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 219:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state219_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state219_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 220:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state220_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state220_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 221:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state221_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state221_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 222:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state222_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state222_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 223:
         break;
      case 224:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state224_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state224_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 225:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state225_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state225_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 226:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state226_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state226_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 227:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state227_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state227_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 228:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state228_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state228_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 229:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state229_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state229_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 230:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state230_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state230_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 231:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state231_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state231_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 232:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state232_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state232_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 233:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state233_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state233_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 234:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state234_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state234_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 235:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state235_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state235_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 236:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state236_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state236_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 237:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state237_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state237_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 238:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state238_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state238_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 239:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state239_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state239_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 240:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state240_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state240_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 241:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state241_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state241_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 242:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state242_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state242_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 243:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state243_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state243_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 244:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state244_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state244_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 245:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state245_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state245_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 246:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state246_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state246_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 247:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state247_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state247_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 248:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state248_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state248_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 249:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state249_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state249_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 250:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state250_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state250_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 251:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state251_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state251_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 252:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state252_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state252_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 253:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state253_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state253_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 254:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state254_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state254_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 255:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state255_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state255_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 256:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state256_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state256_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 257:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state257_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state257_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 258:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state258_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state258_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 259:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state259_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state259_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 260:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state260_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state260_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 261:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state261_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state261_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 262:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state262_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state262_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 263:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state263_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state263_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 264:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state264_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state264_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 265:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state265_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state265_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 266:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state266_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state266_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 267:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state267_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state267_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 268:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state268_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state268_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 269:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state269_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state269_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 270:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state270_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state270_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 271:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state271_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state271_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 272:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state272_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state272_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 273:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state273_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state273_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 274:
         break;
      case 275:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state275_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state275_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 276:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state276_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state276_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 277:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state277_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state277_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 278:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state278_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state278_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 279:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state279_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state279_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 280:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state280_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state280_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 281:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state281_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state281_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 282:
         break;
      case 283:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state283_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state283_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 284:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state284_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state284_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 285:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state285_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state285_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 286:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state286_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state286_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 287:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state287_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state287_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 288:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state288_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state288_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 289:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state289_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state289_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 290:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state290_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state290_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 291:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state291_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state291_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 292:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state292_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state292_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 293:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state293_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state293_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 294:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state294_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state294_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 295:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state295_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state295_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 296:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state296_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state296_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 297:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state297_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state297_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 298:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state298_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state298_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 299:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state299_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state299_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 300:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state300_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state300_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 301:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state301_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state301_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 302:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state302_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state302_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 303:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state303_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state303_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 304:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state304_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state304_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 305:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state305_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state305_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 306:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state306_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state306_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 307:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state307_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state307_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 308:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state308_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state308_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 309:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state309_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state309_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 310:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state310_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state310_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 311:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state311_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state311_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 312:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state312_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state312_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 313:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state313_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state313_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 314:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state314_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state314_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 315:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state315_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state315_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 316:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state316_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state316_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 317:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state317_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state317_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 318:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state318_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state318_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 319:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state319_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state319_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 320:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state320_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state320_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 321:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state321_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state321_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 322:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state322_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state322_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 323:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state323_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state323_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 324:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state324_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state324_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 325:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state325_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state325_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 326:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state326_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state326_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 327:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state327_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state327_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 328:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state328_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state328_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 329:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state329_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state329_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 330:
         break;
      case 331:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state331_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state331_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 332:
         break;
      case 333:
         break;
      case 334:
         break;
      case 335:
         break;
      case 336:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state336_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state336_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 337:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state337_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state337_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 338:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state338_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state338_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 339:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state339_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state339_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 340:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state340_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state340_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 341:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state341_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state341_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 342:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state342_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state342_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 343:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state343_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state343_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 344:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state344_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state344_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 345:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state345_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state345_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 346:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state346_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state346_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 347:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state347_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state347_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 348:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state348_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state348_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 349:
         break;
      case 350:
         break;
      case 351:
         break;
      case 352:
         break;
      case 353:
         break;
      case 354:
         break;
      case 355:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state355_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state355_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 356:
         break;
      case 357:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state357_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state357_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 358:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state358_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state358_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 359:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state359_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state359_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 360:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state360_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state360_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 361:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state361_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state361_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 362:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state362_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state362_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 363:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state363_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state363_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 364:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state364_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state364_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 365:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state365_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state365_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 366:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state366_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state366_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 367:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state367_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state367_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 368:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state368_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state368_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 369:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state369_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state369_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 370:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state370_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state370_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 371:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state371_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state371_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 372:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state372_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state372_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 373:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state373_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state373_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 374:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state374_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state374_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 375:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state375_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state375_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 376:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state376_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state376_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 377:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state377_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state377_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 378:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state378_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state378_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 379:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state379_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state379_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 380:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state380_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state380_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 381:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state381_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state381_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 382:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state382_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state382_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 383:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state383_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state383_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 384:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state384_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state384_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 385:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state385_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state385_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 386:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state386_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state386_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 387:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state387_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state387_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 388:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state388_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state388_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 389:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state389_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state389_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 390:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state390_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state390_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 391:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state391_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state391_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 392:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state392_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state392_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 393:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state393_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state393_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 394:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state394_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state394_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 395:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state395_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state395_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 396:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state396_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state396_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 397:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state397_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state397_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 398:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state398_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state398_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 399:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state399_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state399_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 400:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state400_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state400_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 401:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state401_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state401_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 402:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state402_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state402_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 403:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state403_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state403_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 404:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state404_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state404_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 405:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state405_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state405_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 406:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state406_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state406_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 407:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state407_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state407_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 408:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state408_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state408_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 409:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state409_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state409_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 410:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state410_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state410_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 411:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state411_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state411_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 412:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state412_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state412_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 413:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state413_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state413_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 414:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state414_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state414_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 415:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state415_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state415_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 416:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state416_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state416_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 417:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state417_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state417_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 418:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state418_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state418_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 419:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state419_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state419_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 420:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state420_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state420_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 421:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state421_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state421_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 422:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state422_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state422_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 423:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state423_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state423_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 424:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state424_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state424_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 425:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state425_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state425_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 426:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state426_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state426_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 427:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state427_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state427_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 428:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state428_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state428_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 429:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state429_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state429_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 430:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state430_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state430_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 431:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state431_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state431_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 432:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state432_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state432_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 433:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state433_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state433_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 434:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state434_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state434_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 435:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state435_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state435_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 436:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state436_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state436_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 437:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state437_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state437_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 438:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state438_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state438_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 439:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state439_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state439_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 440:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state440_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state440_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 441:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state441_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state441_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 442:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state442_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state442_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 443:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state443_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state443_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 444:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state444_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state444_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 445:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state445_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state445_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 446:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state446_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state446_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 447:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state447_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state447_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 448:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state448_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state448_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 449:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state449_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state449_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 450:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state450_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state450_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 451:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state451_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state451_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 452:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state452_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state452_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 453:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state453_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state453_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 454:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state454_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state454_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 455:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state455_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state455_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 456:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state456_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state456_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 457:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state457_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state457_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 458:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state458_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state458_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 459:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state459_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state459_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 460:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state460_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state460_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 461:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state461_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state461_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 462:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state462_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state462_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 463:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state463_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state463_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 464:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state464_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state464_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 465:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state465_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state465_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 466:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state466_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state466_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 467:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state467_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state467_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 468:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state468_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state468_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 469:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state469_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state469_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 470:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state470_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state470_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 471:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state471_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state471_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 472:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state472_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state472_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 473:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state473_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state473_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 474:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state474_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state474_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 475:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state475_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state475_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 476:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state476_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state476_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 477:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state477_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state477_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 478:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state478_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state478_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 479:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state479_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state479_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 480:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state480_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state480_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 481:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state481_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state481_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 482:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state482_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state482_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 483:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state483_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state483_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 484:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state484_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state484_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 485:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state485_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state485_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 486:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state486_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state486_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 487:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state487_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state487_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 488:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state488_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state488_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 489:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state489_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state489_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 490:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state490_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state490_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 491:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state491_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state491_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 492:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state492_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state492_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 493:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state493_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state493_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 494:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state494_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state494_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 495:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state495_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state495_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 496:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state496_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state496_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 497:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state497_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state497_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 498:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state498_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state498_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 499:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state499_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state499_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 500:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state500_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state500_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 501:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state501_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state501_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 502:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state502_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state502_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 503:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state503_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state503_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 504:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state504_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state504_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 505:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state505_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state505_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 506:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state506_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state506_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 507:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state507_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state507_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 508:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state508_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state508_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 509:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state509_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state509_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 510:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state510_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state510_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 511:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state511_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state511_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 512:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state512_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state512_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 513:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state513_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state513_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 514:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state514_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state514_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 515:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state515_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state515_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 516:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state516_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state516_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 517:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state517_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state517_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 518:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state518_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state518_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 519:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state519_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state519_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 520:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state520_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state520_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 521:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state521_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state521_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 522:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state522_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state522_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 523:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state523_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state523_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 524:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state524_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state524_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 525:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state525_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state525_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 526:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state526_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state526_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 527:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state527_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state527_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 528:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state528_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state528_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 529:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state529_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state529_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 530:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state530_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state530_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 531:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state531_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state531_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 532:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state532_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state532_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 533:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state533_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state533_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 534:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state534_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state534_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 535:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state535_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state535_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 536:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state536_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state536_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 537:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state537_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state537_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 538:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state538_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state538_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 539:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state539_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state539_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 540:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state540_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state540_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 541:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state541_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state541_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 542:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state542_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state542_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 543:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state543_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state543_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 544:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state544_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state544_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 545:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state545_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state545_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 546:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state546_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state546_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 547:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state547_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state547_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 548:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state548_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state548_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 549:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state549_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state549_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 550:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state550_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state550_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 551:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state551_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state551_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 552:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state552_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state552_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 553:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state553_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state553_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 554:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state554_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state554_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 555:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state555_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state555_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 556:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state556_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state556_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 557:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state557_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state557_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 558:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state558_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state558_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 559:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state559_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state559_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 560:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state560_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state560_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 561:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state561_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state561_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 562:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state562_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state562_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 563:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state563_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state563_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 564:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state564_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state564_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 565:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state565_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state565_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 566:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state566_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state566_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 567:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state567_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state567_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 568:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state568_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state568_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 569:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state569_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state569_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 570:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state570_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state570_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 571:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state571_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state571_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 572:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state572_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state572_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 573:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state573_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state573_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 574:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state574_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state574_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 575:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state575_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state575_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 576:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state576_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state576_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 577:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state577_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state577_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 578:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state578_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state578_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 579:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state579_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state579_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 580:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state580_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state580_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 581:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state581_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state581_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 582:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state582_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state582_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 583:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state583_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state583_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 584:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state584_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state584_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 585:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state585_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state585_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 586:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state586_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state586_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 587:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state587_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state587_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 588:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state588_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state588_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 589:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state589_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state589_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 590:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state590_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state590_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 591:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state591_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state591_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 592:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state592_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state592_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 593:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state593_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state593_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 594:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state594_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state594_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 595:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state595_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state595_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 596:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state596_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state596_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 597:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state597_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state597_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 598:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state598_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state598_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 599:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state599_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state599_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 600:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state600_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state600_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 601:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state601_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state601_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 602:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state602_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state602_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 603:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state603_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state603_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 604:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state604_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state604_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 605:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state605_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state605_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 606:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state606_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state606_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 607:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state607_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state607_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 608:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state608_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state608_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 609:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state609_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state609_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 610:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state610_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state610_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 611:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state611_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state611_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 612:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state612_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state612_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 613:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state613_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state613_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 614:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state614_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state614_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 615:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state615_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state615_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 616:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state616_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state616_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 617:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state617_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state617_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 618:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state618_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state618_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 619:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state619_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state619_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 620:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state620_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state620_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 621:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state621_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state621_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 622:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state622_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state622_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 623:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state623_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state623_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 624:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state624_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state624_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 625:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state625_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state625_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 626:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state626_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state626_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 627:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state627_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state627_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 628:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state628_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state628_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 629:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state629_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state629_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 630:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state630_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state630_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 631:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state631_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state631_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 632:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state632_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state632_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 633:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state633_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state633_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 634:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state634_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state634_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 635:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state635_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state635_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 636:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state636_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state636_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 637:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state637_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state637_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 638:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state638_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state638_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 639:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state639_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state639_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 640:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state640_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state640_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 641:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state641_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state641_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 642:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state642_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state642_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 643:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state643_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state643_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 644:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state644_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state644_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 645:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state645_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state645_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 646:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state646_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state646_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 647:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state647_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state647_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 648:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state648_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state648_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 649:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state649_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state649_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 650:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state650_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state650_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 651:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state651_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state651_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 652:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state652_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state652_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 653:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state653_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state653_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 654:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state654_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state654_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 655:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state655_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state655_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 656:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state656_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state656_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 657:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state657_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state657_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 658:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state658_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state658_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 659:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state659_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state659_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 660:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state660_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state660_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 661:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state661_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state661_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 662:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state662_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state662_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 663:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state663_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state663_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 664:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state664_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state664_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 665:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state665_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state665_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 666:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state666_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state666_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 667:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state667_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state667_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 668:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state668_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state668_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 669:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state669_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state669_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 670:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state670_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state670_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 671:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state671_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state671_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 672:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state672_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state672_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 673:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state673_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state673_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 674:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state674_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state674_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 675:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state675_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state675_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 676:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state676_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state676_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 677:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state677_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state677_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 678:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state678_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state678_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 679:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state679_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state679_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 680:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state680_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state680_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 681:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state681_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state681_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 682:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state682_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state682_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 683:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state683_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state683_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 684:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state684_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state684_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 685:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state685_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state685_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 686:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state686_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state686_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 687:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state687_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state687_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 688:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state688_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state688_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 689:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state689_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state689_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 690:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state690_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state690_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 691:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state691_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state691_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 692:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state692_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state692_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 693:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state693_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state693_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 694:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state694_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state694_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 695:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state695_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state695_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 696:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state696_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state696_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 697:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state697_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state697_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 698:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state698_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state698_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 699:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state699_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state699_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 700:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state700_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state700_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 701:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state701_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state701_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 702:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state702_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state702_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 703:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state703_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state703_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 704:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state704_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state704_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 705:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state705_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state705_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 706:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state706_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state706_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 707:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state707_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state707_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 708:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state708_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state708_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 709:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state709_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state709_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 710:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state710_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state710_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 711:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state711_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state711_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 712:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state712_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state712_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 713:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state713_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state713_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 714:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state714_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state714_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 715:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state715_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state715_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 716:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state716_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state716_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 717:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state717_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state717_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 718:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state718_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state718_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 719:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state719_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state719_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 720:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state720_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state720_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 721:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state721_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state721_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 722:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state722_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state722_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 723:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state723_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state723_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 724:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state724_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state724_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 725:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state725_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state725_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 726:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state726_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state726_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 727:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state727_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state727_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 728:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state728_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state728_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 729:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state729_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state729_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 730:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state730_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state730_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 731:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state731_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state731_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 732:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state732_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state732_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 733:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state733_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state733_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 734:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state734_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state734_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 735:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state735_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state735_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 736:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state736_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state736_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 737:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state737_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state737_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 738:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state738_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state738_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 739:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state739_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state739_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 740:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state740_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state740_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 741:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state741_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state741_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 742:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state742_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state742_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 743:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state743_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state743_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 744:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state744_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state744_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 745:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state745_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state745_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 746:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state746_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state746_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 747:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state747_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state747_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 748:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state748_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state748_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 749:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state749_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state749_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 750:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state750_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state750_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 751:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state751_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state751_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 752:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state752_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state752_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 753:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state753_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state753_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 754:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state754_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state754_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 755:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state755_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state755_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 756:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state756_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state756_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 757:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state757_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state757_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 758:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state758_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state758_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 759:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state759_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state759_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 760:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state760_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state760_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 761:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state761_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state761_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 762:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state762_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state762_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 763:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state763_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state763_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 764:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state764_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state764_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 765:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state765_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state765_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 766:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state766_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state766_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 767:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state767_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state767_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 768:
         break;
      case 769:
         break;
      case 770:
         break;
      case 771:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state771_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state771_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 772:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state772_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state772_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 773:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state773_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state773_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 774:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state774_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state774_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 775:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state775_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state775_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 776:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state776_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state776_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 777:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state777_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state777_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 778:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state778_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state778_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 779:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state779_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state779_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 780:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state780_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state780_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 781:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state781_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state781_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 782:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state782_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state782_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 783:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state783_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state783_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 784:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state784_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state784_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 785:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state785_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state785_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 786:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state786_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state786_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 787:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state787_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state787_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 788:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state788_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state788_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 789:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state789_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state789_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 790:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state790_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state790_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 791:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state791_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state791_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 792:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state792_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state792_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 793:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state793_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state793_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 794:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state794_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state794_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 795:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state795_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state795_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 796:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state796_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state796_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 797:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state797_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state797_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 798:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state798_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state798_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 799:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state799_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state799_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 800:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state800_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state800_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 801:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state801_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state801_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 802:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state802_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state802_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 803:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state803_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state803_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 804:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state804_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state804_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 805:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state805_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state805_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 806:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state806_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state806_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 807:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state807_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state807_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 808:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state808_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state808_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 809:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state809_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state809_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 810:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state810_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state810_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 811:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state811_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state811_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 812:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state812_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state812_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 813:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state813_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state813_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 814:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state814_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state814_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 815:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state815_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state815_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 816:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state816_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state816_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 817:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state817_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state817_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 818:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state818_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state818_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 819:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state819_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state819_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 820:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state820_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state820_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 821:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state821_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state821_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 822:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state822_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state822_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 823:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state823_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state823_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 824:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state824_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state824_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 825:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state825_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state825_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 826:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state826_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state826_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 827:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state827_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state827_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 828:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state828_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state828_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 829:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state829_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state829_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 830:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state830_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state830_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 831:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state831_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state831_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 832:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state832_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state832_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 833:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state833_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state833_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 834:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state834_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state834_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 835:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state835_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state835_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 836:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state836_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state836_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 837:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state837_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state837_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 838:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state838_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state838_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 839:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state839_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state839_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 840:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state840_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state840_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 841:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state841_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state841_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 842:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state842_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state842_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 843:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state843_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state843_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 844:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state844_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state844_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 845:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state845_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state845_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 846:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state846_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state846_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 847:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state847_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state847_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 848:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state848_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state848_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 849:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state849_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state849_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 850:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state850_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state850_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 851:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state851_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state851_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 852:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state852_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state852_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 853:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state853_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state853_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 854:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state854_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state854_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 855:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state855_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state855_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 856:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state856_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state856_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 857:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state857_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state857_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 858:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state858_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state858_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 859:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state859_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state859_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 860:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state860_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state860_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 861:
         break;
      case 862:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state862_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state862_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 863:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state863_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state863_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 864:
         break;
      case 865:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state865_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state865_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 866:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state866_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state866_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 867:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state867_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state867_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 868:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state868_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state868_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 869:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state869_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state869_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 870:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state870_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state870_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 871:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state871_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state871_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 872:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state872_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state872_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 873:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state873_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state873_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 874:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state874_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state874_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 875:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state875_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state875_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 876:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state876_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state876_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 877:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state877_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state877_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 878:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state878_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state878_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 879:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state879_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state879_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 880:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state880_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state880_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 881:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state881_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state881_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 882:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state882_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state882_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 883:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state883_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state883_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 884:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state884_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state884_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 885:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state885_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state885_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 886:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state886_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state886_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 887:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state887_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state887_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 888:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state888_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state888_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 889:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state889_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state889_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 890:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state890_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state890_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 891:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state891_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state891_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 892:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state892_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state892_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 893:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state893_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state893_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 894:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state894_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state894_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 895:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state895_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state895_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 896:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state896_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state896_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 897:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state897_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state897_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 898:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state898_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state898_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 899:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state899_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state899_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 900:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state900_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state900_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 901:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state901_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state901_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 902:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state902_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state902_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 903:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state903_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state903_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 904:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state904_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state904_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 905:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state905_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state905_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 906:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state906_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state906_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 907:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state907_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state907_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 908:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state908_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state908_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 909:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state909_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state909_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 910:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state910_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state910_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 911:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state911_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state911_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 912:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state912_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state912_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 913:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state913_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state913_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 914:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state914_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state914_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 915:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state915_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state915_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 916:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state916_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state916_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 917:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state917_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state917_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 918:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state918_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state918_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 919:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state919_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state919_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 920:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state920_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state920_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 921:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state921_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state921_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 922:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state922_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state922_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 923:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state923_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state923_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 924:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state924_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state924_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 925:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state925_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state925_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 926:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state926_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state926_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 927:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state927_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state927_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 928:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state928_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state928_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 929:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state929_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state929_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 930:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state930_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state930_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 931:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state931_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state931_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 932:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state932_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state932_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 933:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state933_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state933_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 934:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state934_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state934_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 935:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state935_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state935_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 936:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state936_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state936_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 937:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state937_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state937_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 938:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state938_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state938_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 939:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state939_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state939_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 940:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state940_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state940_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 941:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state941_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state941_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 942:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state942_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state942_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 943:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state943_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state943_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 944:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state944_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state944_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 945:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state945_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state945_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 946:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state946_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state946_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 947:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state947_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state947_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 948:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state948_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state948_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 949:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state949_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state949_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 950:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state950_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state950_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 951:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state951_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state951_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 952:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state952_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state952_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 953:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state953_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state953_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 954:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state954_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state954_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 955:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state955_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state955_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 956:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state956_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state956_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 957:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state957_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state957_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 958:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state958_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state958_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 959:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state959_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state959_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 960:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state960_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state960_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 961:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state961_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state961_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 962:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state962_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state962_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 963:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state963_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state963_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 964:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state964_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state964_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 965:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state965_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state965_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 966:
         break;
      case 967:
         break;
      case 968:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state968_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state968_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 969:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state969_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state969_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 970:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state970_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state970_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 971:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state971_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state971_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 972:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state972_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state972_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 973:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state973_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state973_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 974:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state974_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state974_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 975:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state975_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state975_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 976:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state976_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state976_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 977:
         break;
      case 978:
         break;
      case 979:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state979_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state979_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 980:
         break;
      case 981:
         break;
      case 982:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state982_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state982_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 983:
         break;
      case 984:
         break;
      case 985:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state985_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state985_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 986:
         break;
      case 987:
         break;
      case 988:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state988_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state988_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 989:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state989_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state989_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 990:
         break;
      case 991:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state991_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state991_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 992:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state992_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state992_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 993:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state993_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state993_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 994:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state994_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state994_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 995:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state995_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state995_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 996:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state996_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state996_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 997:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state997_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state997_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 998:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state998_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state998_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 999:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state999_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state999_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1000:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1000_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1000_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1001:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1001_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1001_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1002:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1002_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1002_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1003:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1003_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1003_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1004:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1004_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1004_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1005:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1005_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1005_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1006:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1006_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1006_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1007:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1007_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1007_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1008:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1008_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1008_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1009:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1009_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1009_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1010:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1010_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1010_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1011:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1011_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1011_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1012:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1012_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1012_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1013:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1013_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1013_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1014:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1014_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1014_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1015:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1015_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1015_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1016:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1016_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1016_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1017:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1017_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1017_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1018:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1018_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1018_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1019:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1019_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1019_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1020:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1020_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1020_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1021:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1021_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1021_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1022:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1022_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1022_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1023:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1023_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1023_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1024:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1024_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1024_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1025:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1025_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1025_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1026:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1026_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1026_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1027:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1027_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1027_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1028:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1028_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1028_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1029:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1029_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1029_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1030:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1030_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1030_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1031:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1031_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1031_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1032:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1032_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1032_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1033:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1033_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1033_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1034:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1034_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1034_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1035:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1035_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1035_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1036:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1036_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1036_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1037:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1037_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1037_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1038:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1038_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1038_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1039:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1039_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1039_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1040:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1040_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1040_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1041:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1041_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1041_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1042:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1042_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1042_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1043:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1043_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1043_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1044:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1044_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1044_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1045:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1045_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1045_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1046:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1046_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1046_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1047:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1047_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1047_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1048:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1048_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1048_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1049:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1049_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1049_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1050:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1050_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1050_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1051:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1051_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1051_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1052:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1052_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1052_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1053:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1053_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1053_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1054:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1054_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1054_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1055:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1055_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1055_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1056:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1056_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1056_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1057:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1057_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1057_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1058:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1058_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1058_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1059:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1059_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1059_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1060:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1060_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1060_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1061:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1061_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1061_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1062:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1062_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1062_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1063:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1063_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1063_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1064:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1064_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1064_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1065:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1065_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1065_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1066:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1066_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1066_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1067:
         break;
      case 1068:
         break;
      case 1069:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1069_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1069_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1070:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1070_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1070_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1071:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1071_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1071_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1072:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1072_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1072_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1073:
         break;
      case 1074:
         break;
      case 1075:
         break;
      case 1076:
         break;
      case 1077:
         break;
      case 1078:
         break;
      case 1079:
         break;
      case 1080:
         break;
      case 1081:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1081_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1081_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1082:
         break;
      case 1083:
         break;
      case 1084:
         break;
      case 1085:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1085_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1085_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1086:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1086_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1086_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1087:
         break;
      case 1088:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1088_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1088_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1089:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1089_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1089_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1090:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1090_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1090_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1091:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1091_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1091_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1092:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1092_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1092_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1093:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1093_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1093_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1094:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1094_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1094_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1095:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1095_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1095_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1096:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1096_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1096_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1097:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1097_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1097_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1098:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1098_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1098_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1099:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1099_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1099_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1100:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1100_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1100_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1101:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1101_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1101_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1102:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1102_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1102_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1103:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1103_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1103_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1104:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1104_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1104_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1105:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1105_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1105_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1106:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1106_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1106_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1107:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1107_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1107_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1108:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1108_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1108_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1109:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1109_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1109_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1110:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1110_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1110_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1111:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1111_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1111_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1112:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1112_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1112_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1113:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1113_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1113_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1114:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1114_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1114_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1115:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1115_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1115_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1116:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1116_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1116_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1117:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1117_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1117_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1118:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1118_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1118_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1119:
         break;
      case 1120:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1120_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1120_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1121:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1121_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1121_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1122:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1122_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1122_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1123:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1123_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1123_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1124:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1124_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1124_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1125:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1125_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1125_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1126:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1126_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1126_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1127:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1127_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1127_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1128:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1128_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1128_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1129:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1129_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1129_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1130:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1130_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1130_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1131:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1131_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1131_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 1132:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_state1132_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_state1132_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      default: assert(0);
      }
   }

   return progress;
}

static bool
nir_opt_algebraic_impl(nir_function_impl *impl, const bool *condition_flags)
{
   bool progress = false;

   nir_builder build;
   nir_builder_init(&build, impl);

   /* Note: it's important here that we're allocating a zeroed array, since
    * state 0 is the default state, which means we don't have to visit
    * anything other than constants and ALU instructions.
    */
   uint16_t *states = calloc(impl->ssa_alloc, sizeof(*states));

   nir_foreach_block(block, impl) {
      nir_opt_algebraic_pre_block(block, states);
   }

   nir_foreach_block_reverse(block, impl) {
      progress |= nir_opt_algebraic_block(&build, block, states, condition_flags);
   }

   free(states);

   if (progress) {
      nir_metadata_preserve(impl, nir_metadata_block_index |
                                  nir_metadata_dominance);
    } else {
#ifndef NDEBUG
      impl->valid_metadata &= ~nir_metadata_not_properly_reset;
#endif
    }

   return progress;
}


bool
nir_opt_algebraic(nir_shader *shader)
{
   bool progress = false;
   bool condition_flags[63];
   const nir_shader_compiler_options *options = shader->options;
   const shader_info *info = &shader->info;
   (void) options;
   (void) info;

   condition_flags[0] = true;
   condition_flags[1] = !options->lower_bitops;
   condition_flags[2] = options->lower_bitops;
   condition_flags[3] = options->lower_mul_2x32_64;
   condition_flags[4] = options->lower_idiv;
   condition_flags[5] = options->lower_flrp32;
   condition_flags[6] = options->lower_flrp64;
   condition_flags[7] = options->lower_ftrunc;
   condition_flags[8] = options->lower_ffloor;
   condition_flags[9] = !options->lower_ffloor;
   condition_flags[10] = options->lower_ffract;
   condition_flags[11] = options->lower_fceil;
   condition_flags[12] = !options->lower_flrp32;
   condition_flags[13] = !options->lower_flrp64;
   condition_flags[14] = options->lower_ffma;
   condition_flags[15] = options->fuse_ffma;
   condition_flags[16] = options->lower_fdph;
   condition_flags[17] = !options->lower_fdph;
   condition_flags[18] = options->lower_fdot;
   condition_flags[19] = !options->lower_fsat;
   condition_flags[20] = !options->lower_negate && !options->lower_fsat;
   condition_flags[21] = options->lower_fsat;
   condition_flags[22] = options->lower_scmp;
   condition_flags[23] = options->lower_vector_cmp;
   condition_flags[24] = !options->lower_rotate;
   condition_flags[25] = options->lower_rotate;
   condition_flags[26] = options->lower_fpow;
   condition_flags[27] = !options->lower_fpow;
   condition_flags[28] = options->lower_fdiv;
   condition_flags[29] = options->lower_fsqrt;
   condition_flags[30] = !options->lower_fsqrt;
   condition_flags[31] = options->lower_sincos;
   condition_flags[32] = !options->lower_extract_byte;
   condition_flags[33] = !options->lower_extract_word;
   condition_flags[34] = options->lower_sub;
   condition_flags[35] = options->lower_negate;
   condition_flags[36] = options->lower_fmod;
   condition_flags[37] = options->lower_uadd_carry;
   condition_flags[38] = options->lower_usub_borrow;
   condition_flags[39] = options->lower_bitfield_insert;
   condition_flags[40] = options->lower_hadd;
   condition_flags[41] = options->lower_add_sat;
   condition_flags[42] = options->lower_bitfield_insert_to_shifts;
   condition_flags[43] = options->lower_bitfield_insert_to_bitfield_select;
   condition_flags[44] = options->lower_bitfield_extract;
   condition_flags[45] = options->lower_bitfield_extract_to_shifts;
   condition_flags[46] = options->lower_ifind_msb;
   condition_flags[47] = options->lower_find_lsb;
   condition_flags[48] = options->lower_extract_byte;
   condition_flags[49] = options->lower_extract_word;
   condition_flags[50] = options->lower_pack_unorm_2x16;
   condition_flags[51] = options->lower_pack_unorm_4x8;
   condition_flags[52] = options->lower_pack_snorm_2x16;
   condition_flags[53] = options->lower_pack_snorm_4x8;
   condition_flags[54] = options->lower_unpack_unorm_2x16;
   condition_flags[55] = options->lower_unpack_unorm_4x8;
   condition_flags[56] = options->lower_unpack_snorm_2x16;
   condition_flags[57] = options->lower_unpack_snorm_4x8;
   condition_flags[58] = options->lower_isign;
   condition_flags[59] = options->lower_fsign;
   condition_flags[60] = options->lower_ldexp;
   condition_flags[61] = !options->lower_bitfield_reverse;
   condition_flags[62] = info->stage == MESA_SHADER_COMPUTE && info->cs.derivative_group == DERIVATIVE_GROUP_NONE;

   nir_foreach_function(function, shader) {
      if (function->impl)
         progress |= nir_opt_algebraic_impl(function->impl, condition_flags);
   }

   return progress;
}


#include "nir.h"
#include "nir_builder.h"
#include "nir_search.h"
#include "nir_search_helpers.h"

/* What follows is NIR algebraic transform code for the following 15
 * transforms:
 *    ('~fmul(is_used_once)', ('fmul(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('fmul', ('fmul', 'a', 'c'), 'b')
 *    ('imul(is_used_once)', ('imul(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('imul', ('imul', 'a', 'c'), 'b')
 *    ('~fadd(is_used_once)', ('fadd(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('fadd', ('fadd', 'a', 'c'), 'b')
 *    ('iadd(is_used_once)', ('iadd(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('iadd', ('iadd', 'a', 'c'), 'b')
 *    ('~fadd', ('fmul', 'a', 'b'), ('fmul', 'a', 'c')) => ('fmul', 'a', ('fadd', 'b', 'c'))
 *    ('iadd', ('imul', 'a', 'b'), ('imul', 'a', 'c')) => ('imul', 'a', ('iadd', 'b', 'c'))
 *    ('~fadd', ('fneg', 'a'), 'a') => 0.0
 *    ('iadd', ('ineg', 'a'), 'a') => 0
 *    ('iadd', ('ineg', 'a'), ('iadd', 'a', 'b')) => b
 *    ('iadd', 'a', ('iadd', ('ineg', 'a'), 'b')) => b
 *    ('~fadd', ('fneg', 'a'), ('fadd', 'a', 'b')) => b
 *    ('~fadd', 'a', ('fadd', ('fneg', 'a'), 'b')) => b
 *    ('~flrp@32', ('fadd(is_used_once)', 'a', -1.0), ('fadd(is_used_once)', 'a', 1.0), 'd') => ('fadd', ('flrp', -1.0, 1.0, 'd'), 'a')
 *    ('~flrp@32', ('fadd(is_used_once)', 'a', 1.0), ('fadd(is_used_once)', 'a', -1.0), 'd') => ('fadd', ('flrp', 1.0, -1.0, 'd'), 'a')
 *    ('~flrp@32', ('fadd(is_used_once)', 'a', '#b'), ('fadd(is_used_once)', 'a', '#c'), 'd') => ('fadd', ('fmul', 'd', ('fadd', 'c', ('fneg', 'b'))), ('fadd', 'a', 'b'))
 */

#ifndef NIR_OPT_ALGEBRAIC_STRUCT_DEFS
#define NIR_OPT_ALGEBRAIC_STRUCT_DEFS

struct transform {
   const nir_search_expression *search;
   const nir_search_value *replace;
   unsigned condition_offset;
};

struct per_op_table {
   const uint16_t *filter;
   unsigned num_filtered_states;
   const uint16_t *table;
};

/* Note: these must match the start states created in
 * TreeAutomaton._build_table()
 */

/* WILDCARD_STATE = 0 is set by zeroing the state array */
static const uint16_t CONST_STATE = 1;

#endif


   static const nir_search_variable search1090_0_0 = {
   { nir_search_value_variable, -3 },
   0, /* a */
   false,
   nir_type_invalid,
   (is_not_const),
   {0, 1, 2, 3},
};

static const nir_search_variable search1090_0_1 = {
   { nir_search_value_variable, -3 },
   1, /* b */
   true,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search1090_0 = {
   { nir_search_value_expression, -3 },
   false,
   1, 1,
   nir_op_fmul,
   { &search1090_0_0.value, &search1090_0_1.value },
   (is_used_once),
};

static const nir_search_variable search1090_1 = {
   { nir_search_value_variable, -3 },
   2, /* c */
   false,
   nir_type_invalid,
   (is_not_const),
   {0, 1, 2, 3},
};
static const nir_search_expression search1090 = {
   { nir_search_value_expression, -3 },
   true,
   0, 2,
   nir_op_fmul,
   { &search1090_0.value, &search1090_1.value },
   (is_used_once),
};

   static const nir_search_variable replace1090_0_0 = {
   { nir_search_value_variable, -3 },
   0, /* a */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

static const nir_search_variable replace1090_0_1 = {
   { nir_search_value_variable, -3 },
   2, /* c */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression replace1090_0 = {
   { nir_search_value_expression, -3 },
   false,
   1, 1,
   nir_op_fmul,
   { &replace1090_0_0.value, &replace1090_0_1.value },
   NULL,
};

static const nir_search_variable replace1090_1 = {
   { nir_search_value_variable, -3 },
   1, /* b */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression replace1090 = {
   { nir_search_value_expression, -3 },
   false,
   0, 2,
   nir_op_fmul,
   { &replace1090_0.value, &replace1090_1.value },
   NULL,
};

   /* search1091_0_0 -> search1090_0_0 in the cache */

/* search1091_0_1 -> search1090_0_1 in the cache */
static const nir_search_expression search1091_0 = {
   { nir_search_value_expression, -3 },
   false,
   1, 1,
   nir_op_imul,
   { &search1090_0_0.value, &search1090_0_1.value },
   (is_used_once),
};

/* search1091_1 -> search1090_1 in the cache */
static const nir_search_expression search1091 = {
   { nir_search_value_expression, -3 },
   false,
   0, 2,
   nir_op_imul,
   { &search1091_0.value, &search1090_1.value },
   (is_used_once),
};

   /* replace1091_0_0 -> replace1090_0_0 in the cache */

/* replace1091_0_1 -> replace1090_0_1 in the cache */
static const nir_search_expression replace1091_0 = {
   { nir_search_value_expression, -3 },
   false,
   1, 1,
   nir_op_imul,
   { &replace1090_0_0.value, &replace1090_0_1.value },
   NULL,
};

/* replace1091_1 -> replace1090_1 in the cache */
static const nir_search_expression replace1091 = {
   { nir_search_value_expression, -3 },
   false,
   0, 2,
   nir_op_imul,
   { &replace1091_0.value, &replace1090_1.value },
   NULL,
};

   /* search1092_0_0 -> search1090_0_0 in the cache */

/* search1092_0_1 -> search1090_0_1 in the cache */
static const nir_search_expression search1092_0 = {
   { nir_search_value_expression, -3 },
   false,
   1, 1,
   nir_op_fadd,
   { &search1090_0_0.value, &search1090_0_1.value },
   (is_used_once),
};

/* search1092_1 -> search1090_1 in the cache */
static const nir_search_expression search1092 = {
   { nir_search_value_expression, -3 },
   true,
   0, 2,
   nir_op_fadd,
   { &search1092_0.value, &search1090_1.value },
   (is_used_once),
};

   /* replace1092_0_0 -> replace1090_0_0 in the cache */

/* replace1092_0_1 -> replace1090_0_1 in the cache */
static const nir_search_expression replace1092_0 = {
   { nir_search_value_expression, -3 },
   false,
   1, 1,
   nir_op_fadd,
   { &replace1090_0_0.value, &replace1090_0_1.value },
   NULL,
};

/* replace1092_1 -> replace1090_1 in the cache */
static const nir_search_expression replace1092 = {
   { nir_search_value_expression, -3 },
   false,
   0, 2,
   nir_op_fadd,
   { &replace1092_0.value, &replace1090_1.value },
   NULL,
};

   /* search1093_0_0 -> search1090_0_0 in the cache */

/* search1093_0_1 -> search1090_0_1 in the cache */
static const nir_search_expression search1093_0 = {
   { nir_search_value_expression, -3 },
   false,
   1, 1,
   nir_op_iadd,
   { &search1090_0_0.value, &search1090_0_1.value },
   (is_used_once),
};

/* search1093_1 -> search1090_1 in the cache */
static const nir_search_expression search1093 = {
   { nir_search_value_expression, -3 },
   false,
   0, 2,
   nir_op_iadd,
   { &search1093_0.value, &search1090_1.value },
   (is_used_once),
};

   /* replace1093_0_0 -> replace1090_0_0 in the cache */

/* replace1093_0_1 -> replace1090_0_1 in the cache */
static const nir_search_expression replace1093_0 = {
   { nir_search_value_expression, -3 },
   false,
   1, 1,
   nir_op_iadd,
   { &replace1090_0_0.value, &replace1090_0_1.value },
   NULL,
};

/* replace1093_1 -> replace1090_1 in the cache */
static const nir_search_expression replace1093 = {
   { nir_search_value_expression, -3 },
   false,
   0, 2,
   nir_op_iadd,
   { &replace1093_0.value, &replace1090_1.value },
   NULL,
};

   /* search1094_0_0 -> replace1090_0_0 in the cache */

/* search1094_0_1 -> replace1090_1 in the cache */
static const nir_search_expression search1094_0 = {
   { nir_search_value_expression, -3 },
   false,
   1, 1,
   nir_op_fmul,
   { &replace1090_0_0.value, &replace1090_1.value },
   NULL,
};

/* search1094_1_0 -> replace1090_0_0 in the cache */

/* search1094_1_1 -> replace1090_0_1 in the cache */
static const nir_search_expression search1094_1 = {
   { nir_search_value_expression, -3 },
   false,
   2, 1,
   nir_op_fmul,
   { &replace1090_0_0.value, &replace1090_0_1.value },
   NULL,
};
static const nir_search_expression search1094 = {
   { nir_search_value_expression, -3 },
   true,
   0, 3,
   nir_op_fadd,
   { &search1094_0.value, &search1094_1.value },
   NULL,
};

   /* replace1094_0 -> replace1090_0_0 in the cache */

/* replace1094_1_0 -> replace1090_1 in the cache */

/* replace1094_1_1 -> replace1090_0_1 in the cache */
static const nir_search_expression replace1094_1 = {
   { nir_search_value_expression, -3 },
   false,
   1, 1,
   nir_op_fadd,
   { &replace1090_1.value, &replace1090_0_1.value },
   NULL,
};
static const nir_search_expression replace1094 = {
   { nir_search_value_expression, -3 },
   false,
   0, 2,
   nir_op_fmul,
   { &replace1090_0_0.value, &replace1094_1.value },
   NULL,
};

   /* search1095_0_0 -> replace1090_0_0 in the cache */

/* search1095_0_1 -> replace1090_1 in the cache */
static const nir_search_expression search1095_0 = {
   { nir_search_value_expression, -3 },
   false,
   1, 1,
   nir_op_imul,
   { &replace1090_0_0.value, &replace1090_1.value },
   NULL,
};

/* search1095_1_0 -> replace1090_0_0 in the cache */

/* search1095_1_1 -> replace1090_0_1 in the cache */
static const nir_search_expression search1095_1 = {
   { nir_search_value_expression, -3 },
   false,
   2, 1,
   nir_op_imul,
   { &replace1090_0_0.value, &replace1090_0_1.value },
   NULL,
};
static const nir_search_expression search1095 = {
   { nir_search_value_expression, -3 },
   false,
   0, 3,
   nir_op_iadd,
   { &search1095_0.value, &search1095_1.value },
   NULL,
};

   /* replace1095_0 -> replace1090_0_0 in the cache */

/* replace1095_1_0 -> replace1090_1 in the cache */

/* replace1095_1_1 -> replace1090_0_1 in the cache */
static const nir_search_expression replace1095_1 = {
   { nir_search_value_expression, -3 },
   false,
   1, 1,
   nir_op_iadd,
   { &replace1090_1.value, &replace1090_0_1.value },
   NULL,
};
static const nir_search_expression replace1095 = {
   { nir_search_value_expression, -3 },
   false,
   0, 2,
   nir_op_imul,
   { &replace1090_0_0.value, &replace1095_1.value },
   NULL,
};

   static const nir_search_variable search1096_0_0 = {
   { nir_search_value_variable, -1 },
   0, /* a */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search1096_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fneg,
   { &search1096_0_0.value },
   NULL,
};

/* search1096_1 -> search1096_0_0 in the cache */
static const nir_search_expression search1096 = {
   { nir_search_value_expression, -1 },
   true,
   0, 1,
   nir_op_fadd,
   { &search1096_0.value, &search1096_0_0.value },
   NULL,
};

   static const nir_search_constant replace1096 = {
   { nir_search_value_constant, -1 },
   nir_type_float, { 0x0 /* 0.0 */ },
};

   /* search1097_0_0 -> search1096_0_0 in the cache */
static const nir_search_expression search1097_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_ineg,
   { &search1096_0_0.value },
   NULL,
};

/* search1097_1 -> search1096_0_0 in the cache */
static const nir_search_expression search1097 = {
   { nir_search_value_expression, -1 },
   false,
   0, 1,
   nir_op_iadd,
   { &search1097_0.value, &search1096_0_0.value },
   NULL,
};

   static const nir_search_constant replace1097 = {
   { nir_search_value_constant, -1 },
   nir_type_int, { 0x0 /* 0 */ },
};

   static const nir_search_variable search1098_0_0 = {
   { nir_search_value_variable, -2 },
   0, /* a */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search1098_0 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_ineg,
   { &search1098_0_0.value },
   NULL,
};

/* search1098_1_0 -> search1098_0_0 in the cache */

static const nir_search_variable search1098_1_1 = {
   { nir_search_value_variable, -2 },
   1, /* b */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search1098_1 = {
   { nir_search_value_expression, -2 },
   false,
   1, 1,
   nir_op_iadd,
   { &search1098_0_0.value, &search1098_1_1.value },
   NULL,
};
static const nir_search_expression search1098 = {
   { nir_search_value_expression, -2 },
   false,
   0, 2,
   nir_op_iadd,
   { &search1098_0.value, &search1098_1.value },
   NULL,
};

   /* replace1098 -> search1098_1_1 in the cache */

   /* search1099_0 -> search1098_0_0 in the cache */

/* search1099_1_0_0 -> search1098_0_0 in the cache */
/* search1099_1_0 -> search1098_0 in the cache */

/* search1099_1_1 -> search1098_1_1 in the cache */
static const nir_search_expression search1099_1 = {
   { nir_search_value_expression, -2 },
   false,
   1, 1,
   nir_op_iadd,
   { &search1098_0.value, &search1098_1_1.value },
   NULL,
};
static const nir_search_expression search1099 = {
   { nir_search_value_expression, -2 },
   false,
   0, 2,
   nir_op_iadd,
   { &search1098_0_0.value, &search1099_1.value },
   NULL,
};

   /* replace1099 -> search1098_1_1 in the cache */

   /* search1100_0_0 -> search1098_0_0 in the cache */
static const nir_search_expression search1100_0 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_fneg,
   { &search1098_0_0.value },
   NULL,
};

/* search1100_1_0 -> search1098_0_0 in the cache */

/* search1100_1_1 -> search1098_1_1 in the cache */
static const nir_search_expression search1100_1 = {
   { nir_search_value_expression, -2 },
   false,
   1, 1,
   nir_op_fadd,
   { &search1098_0_0.value, &search1098_1_1.value },
   NULL,
};
static const nir_search_expression search1100 = {
   { nir_search_value_expression, -2 },
   true,
   0, 2,
   nir_op_fadd,
   { &search1100_0.value, &search1100_1.value },
   NULL,
};

   /* replace1100 -> search1098_1_1 in the cache */

   /* search1101_0 -> search1098_0_0 in the cache */

/* search1101_1_0_0 -> search1098_0_0 in the cache */
/* search1101_1_0 -> search1100_0 in the cache */

/* search1101_1_1 -> search1098_1_1 in the cache */
static const nir_search_expression search1101_1 = {
   { nir_search_value_expression, -2 },
   false,
   1, 1,
   nir_op_fadd,
   { &search1100_0.value, &search1098_1_1.value },
   NULL,
};
static const nir_search_expression search1101 = {
   { nir_search_value_expression, -2 },
   true,
   0, 2,
   nir_op_fadd,
   { &search1098_0_0.value, &search1101_1.value },
   NULL,
};

   /* replace1101 -> search1098_1_1 in the cache */

   static const nir_search_variable search1102_0_0 = {
   { nir_search_value_variable, 32 },
   0, /* a */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

static const nir_search_constant search1102_0_1 = {
   { nir_search_value_constant, 32 },
   nir_type_float, { 0xbff0000000000000L /* -1.0 */ },
};
static const nir_search_expression search1102_0 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_fadd,
   { &search1102_0_0.value, &search1102_0_1.value },
   (is_used_once),
};

/* search1102_1_0 -> search1102_0_0 in the cache */

static const nir_search_constant search1102_1_1 = {
   { nir_search_value_constant, 32 },
   nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
};
static const nir_search_expression search1102_1 = {
   { nir_search_value_expression, 32 },
   false,
   1, 1,
   nir_op_fadd,
   { &search1102_0_0.value, &search1102_1_1.value },
   (is_used_once),
};

static const nir_search_variable search1102_2 = {
   { nir_search_value_variable, 32 },
   1, /* d */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search1102 = {
   { nir_search_value_expression, 32 },
   true,
   -1, 2,
   nir_op_flrp,
   { &search1102_0.value, &search1102_1.value, &search1102_2.value },
   NULL,
};

   /* replace1102_0_0 -> search1102_0_1 in the cache */

/* replace1102_0_1 -> search1102_1_1 in the cache */

/* replace1102_0_2 -> search1102_2 in the cache */
static const nir_search_expression replace1102_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_flrp,
   { &search1102_0_1.value, &search1102_1_1.value, &search1102_2.value },
   NULL,
};

/* replace1102_1 -> search1102_0_0 in the cache */
static const nir_search_expression replace1102 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_fadd,
   { &replace1102_0.value, &search1102_0_0.value },
   NULL,
};

   /* search1103_0_0 -> search1102_0_0 in the cache */

/* search1103_0_1 -> search1102_1_1 in the cache */
static const nir_search_expression search1103_0 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_fadd,
   { &search1102_0_0.value, &search1102_1_1.value },
   (is_used_once),
};

/* search1103_1_0 -> search1102_0_0 in the cache */

/* search1103_1_1 -> search1102_0_1 in the cache */
static const nir_search_expression search1103_1 = {
   { nir_search_value_expression, 32 },
   false,
   1, 1,
   nir_op_fadd,
   { &search1102_0_0.value, &search1102_0_1.value },
   (is_used_once),
};

/* search1103_2 -> search1102_2 in the cache */
static const nir_search_expression search1103 = {
   { nir_search_value_expression, 32 },
   true,
   -1, 2,
   nir_op_flrp,
   { &search1103_0.value, &search1103_1.value, &search1102_2.value },
   NULL,
};

   /* replace1103_0_0 -> search1102_1_1 in the cache */

/* replace1103_0_1 -> search1102_0_1 in the cache */

/* replace1103_0_2 -> search1102_2 in the cache */
static const nir_search_expression replace1103_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_flrp,
   { &search1102_1_1.value, &search1102_0_1.value, &search1102_2.value },
   NULL,
};

/* replace1103_1 -> search1102_0_0 in the cache */
static const nir_search_expression replace1103 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_fadd,
   { &replace1103_0.value, &search1102_0_0.value },
   NULL,
};

   /* search1104_0_0 -> search1102_0_0 in the cache */

static const nir_search_variable search1104_0_1 = {
   { nir_search_value_variable, 32 },
   1, /* b */
   true,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search1104_0 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_fadd,
   { &search1102_0_0.value, &search1104_0_1.value },
   (is_used_once),
};

/* search1104_1_0 -> search1102_0_0 in the cache */

static const nir_search_variable search1104_1_1 = {
   { nir_search_value_variable, 32 },
   2, /* c */
   true,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search1104_1 = {
   { nir_search_value_expression, 32 },
   false,
   1, 1,
   nir_op_fadd,
   { &search1102_0_0.value, &search1104_1_1.value },
   (is_used_once),
};

static const nir_search_variable search1104_2 = {
   { nir_search_value_variable, 32 },
   3, /* d */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search1104 = {
   { nir_search_value_expression, 32 },
   true,
   -1, 2,
   nir_op_flrp,
   { &search1104_0.value, &search1104_1.value, &search1104_2.value },
   NULL,
};

   /* replace1104_0_0 -> search1104_2 in the cache */

static const nir_search_variable replace1104_0_1_0 = {
   { nir_search_value_variable, 32 },
   2, /* c */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

static const nir_search_variable replace1104_0_1_1_0 = {
   { nir_search_value_variable, 32 },
   1, /* b */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression replace1104_0_1_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_fneg,
   { &replace1104_0_1_1_0.value },
   NULL,
};
static const nir_search_expression replace1104_0_1 = {
   { nir_search_value_expression, 32 },
   false,
   2, 1,
   nir_op_fadd,
   { &replace1104_0_1_0.value, &replace1104_0_1_1.value },
   NULL,
};
static const nir_search_expression replace1104_0 = {
   { nir_search_value_expression, 32 },
   false,
   1, 2,
   nir_op_fmul,
   { &search1104_2.value, &replace1104_0_1.value },
   NULL,
};

/* replace1104_1_0 -> search1102_0_0 in the cache */

/* replace1104_1_1 -> replace1104_0_1_1_0 in the cache */
static const nir_search_expression replace1104_1 = {
   { nir_search_value_expression, 32 },
   false,
   3, 1,
   nir_op_fadd,
   { &search1102_0_0.value, &replace1104_0_1_1_0.value },
   NULL,
};
static const nir_search_expression replace1104 = {
   { nir_search_value_expression, 32 },
   false,
   0, 4,
   nir_op_fadd,
   { &replace1104_0.value, &replace1104_1.value },
   NULL,
};


static const struct transform nir_opt_algebraic_before_ffma_state12_xforms[] = {
  { &search1092, &replace1092.value, 0 },
};
static const struct transform nir_opt_algebraic_before_ffma_state13_xforms[] = {
  { &search1096, &replace1096.value, 0 },
};
static const struct transform nir_opt_algebraic_before_ffma_state14_xforms[] = {
  { &search1092, &replace1092.value, 0 },
};
static const struct transform nir_opt_algebraic_before_ffma_state15_xforms[] = {
  { &search1096, &replace1096.value, 0 },
};
static const struct transform nir_opt_algebraic_before_ffma_state16_xforms[] = {
  { &search1094, &replace1094.value, 0 },
};
static const struct transform nir_opt_algebraic_before_ffma_state17_xforms[] = {
  { &search1096, &replace1096.value, 0 },
  { &search1100, &search1098_1_1.value, 0 },
};
static const struct transform nir_opt_algebraic_before_ffma_state18_xforms[] = {
  { &search1092, &replace1092.value, 0 },
  { &search1096, &replace1096.value, 0 },
  { &search1100, &search1098_1_1.value, 0 },
};
static const struct transform nir_opt_algebraic_before_ffma_state19_xforms[] = {
  { &search1090, &replace1090.value, 0 },
};
static const struct transform nir_opt_algebraic_before_ffma_state20_xforms[] = {
  { &search1090, &replace1090.value, 0 },
};
static const struct transform nir_opt_algebraic_before_ffma_state21_xforms[] = {
  { &search1093, &replace1093.value, 0 },
};
static const struct transform nir_opt_algebraic_before_ffma_state22_xforms[] = {
  { &search1097, &replace1097.value, 0 },
};
static const struct transform nir_opt_algebraic_before_ffma_state23_xforms[] = {
  { &search1093, &replace1093.value, 0 },
};
static const struct transform nir_opt_algebraic_before_ffma_state24_xforms[] = {
  { &search1097, &replace1097.value, 0 },
};
static const struct transform nir_opt_algebraic_before_ffma_state25_xforms[] = {
  { &search1095, &replace1095.value, 0 },
};
static const struct transform nir_opt_algebraic_before_ffma_state26_xforms[] = {
  { &search1097, &replace1097.value, 0 },
  { &search1098, &search1098_1_1.value, 0 },
};
static const struct transform nir_opt_algebraic_before_ffma_state27_xforms[] = {
  { &search1093, &replace1093.value, 0 },
  { &search1097, &replace1097.value, 0 },
  { &search1098, &search1098_1_1.value, 0 },
};
static const struct transform nir_opt_algebraic_before_ffma_state28_xforms[] = {
  { &search1091, &replace1091.value, 0 },
};
static const struct transform nir_opt_algebraic_before_ffma_state29_xforms[] = {
  { &search1091, &replace1091.value, 0 },
};
static const struct transform nir_opt_algebraic_before_ffma_state30_xforms[] = {
  { &search1102, &replace1102.value, 0 },
  { &search1103, &replace1103.value, 0 },
  { &search1104, &replace1104.value, 0 },
};
static const struct transform nir_opt_algebraic_before_ffma_state31_xforms[] = {
  { &search1101, &search1098_1_1.value, 0 },
};
static const struct transform nir_opt_algebraic_before_ffma_state32_xforms[] = {
  { &search1092, &replace1092.value, 0 },
  { &search1101, &search1098_1_1.value, 0 },
};
static const struct transform nir_opt_algebraic_before_ffma_state33_xforms[] = {
  { &search1101, &search1098_1_1.value, 0 },
};
static const struct transform nir_opt_algebraic_before_ffma_state34_xforms[] = {
  { &search1092, &replace1092.value, 0 },
  { &search1101, &search1098_1_1.value, 0 },
};
static const struct transform nir_opt_algebraic_before_ffma_state35_xforms[] = {
  { &search1096, &replace1096.value, 0 },
  { &search1100, &search1098_1_1.value, 0 },
  { &search1101, &search1098_1_1.value, 0 },
};
static const struct transform nir_opt_algebraic_before_ffma_state36_xforms[] = {
  { &search1092, &replace1092.value, 0 },
  { &search1096, &replace1096.value, 0 },
  { &search1100, &search1098_1_1.value, 0 },
  { &search1101, &search1098_1_1.value, 0 },
};
static const struct transform nir_opt_algebraic_before_ffma_state37_xforms[] = {
  { &search1099, &search1098_1_1.value, 0 },
};
static const struct transform nir_opt_algebraic_before_ffma_state38_xforms[] = {
  { &search1093, &replace1093.value, 0 },
  { &search1099, &search1098_1_1.value, 0 },
};
static const struct transform nir_opt_algebraic_before_ffma_state39_xforms[] = {
  { &search1099, &search1098_1_1.value, 0 },
};
static const struct transform nir_opt_algebraic_before_ffma_state40_xforms[] = {
  { &search1093, &replace1093.value, 0 },
  { &search1099, &search1098_1_1.value, 0 },
};
static const struct transform nir_opt_algebraic_before_ffma_state41_xforms[] = {
  { &search1097, &replace1097.value, 0 },
  { &search1098, &search1098_1_1.value, 0 },
  { &search1099, &search1098_1_1.value, 0 },
};
static const struct transform nir_opt_algebraic_before_ffma_state42_xforms[] = {
  { &search1093, &replace1093.value, 0 },
  { &search1097, &replace1097.value, 0 },
  { &search1098, &search1098_1_1.value, 0 },
  { &search1099, &search1098_1_1.value, 0 },
};

static const struct per_op_table nir_opt_algebraic_before_ffma_table[nir_num_search_ops] = {
   [nir_op_fmul] = {
      .filter = (uint16_t []) {
         0,
         1,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (uint16_t []) {
      
         2,
         3,
         19,
         3,
         3,
         20,
         19,
         20,
         19,
      },
   },
   [nir_op_imul] = {
      .filter = (uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (uint16_t []) {
      
         4,
         5,
         28,
         5,
         5,
         29,
         28,
         29,
         28,
      },
   },
   [nir_op_fadd] = {
      .filter = (uint16_t []) {
         0,
         1,
         2,
         2,
         0,
         0,
         3,
         4,
         0,
         0,
         5,
         0,
         3,
         6,
         4,
         7,
         3,
         6,
         6,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 8,
      .table = (uint16_t []) {
      
         6,
         7,
         6,
         6,
         12,
         13,
         31,
         32,
         7,
         7,
         7,
         7,
         14,
         15,
         33,
         34,
         6,
         7,
         16,
         6,
         12,
         13,
         31,
         32,
         6,
         7,
         6,
         6,
         12,
         17,
         31,
         32,
         12,
         14,
         12,
         12,
         12,
         18,
         32,
         32,
         13,
         15,
         13,
         17,
         18,
         13,
         35,
         36,
         31,
         33,
         31,
         31,
         32,
         35,
         31,
         32,
         32,
         34,
         32,
         32,
         32,
         36,
         32,
         32,
      },
   },
   [nir_op_iadd] = {
      .filter = (uint16_t []) {
         0,
         1,
         0,
         0,
         2,
         2,
         0,
         0,
         3,
         4,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         6,
         4,
         7,
         3,
         6,
         6,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         6,
         6,
      },
      
      .num_filtered_states = 8,
      .table = (uint16_t []) {
      
         8,
         9,
         8,
         8,
         21,
         22,
         37,
         38,
         9,
         9,
         9,
         9,
         23,
         24,
         39,
         40,
         8,
         9,
         25,
         8,
         21,
         22,
         37,
         38,
         8,
         9,
         8,
         8,
         21,
         26,
         37,
         38,
         21,
         23,
         21,
         21,
         21,
         27,
         38,
         38,
         22,
         24,
         22,
         26,
         27,
         22,
         41,
         42,
         37,
         39,
         37,
         37,
         38,
         41,
         37,
         38,
         38,
         40,
         38,
         38,
         38,
         42,
         38,
         38,
      },
   },
   [nir_op_fneg] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         10,
      },
   },
   [nir_op_ineg] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         11,
      },
   },
   [nir_op_flrp] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         30,
         30,
      },
   },
};

static void
nir_opt_algebraic_before_ffma_pre_block(nir_block *block, uint16_t *states)
{
   nir_foreach_instr(instr, block) {
      switch (instr->type) {
      case nir_instr_type_alu: {
         nir_alu_instr *alu = nir_instr_as_alu(instr);
         nir_op op = alu->op;
         uint16_t search_op = nir_search_op_for_nir_op(op);
         const struct per_op_table *tbl = &nir_opt_algebraic_before_ffma_table[search_op];
         if (tbl->num_filtered_states == 0)
            continue;

         /* Calculate the index into the transition table. Note the index
          * calculated must match the iteration order of Python's
          * itertools.product(), which was used to emit the transition
          * table.
          */
         uint16_t index = 0;
         for (unsigned i = 0; i < nir_op_infos[op].num_inputs; i++) {
            index *= tbl->num_filtered_states;
            index += tbl->filter[states[alu->src[i].src.ssa->index]];
         }
         states[alu->dest.dest.ssa.index] = tbl->table[index];
         break;
      }

      case nir_instr_type_load_const: {
         nir_load_const_instr *load_const = nir_instr_as_load_const(instr);
         states[load_const->def.index] = CONST_STATE;
         break;
      }

      default:
         break;
      }
   }
}

static bool
nir_opt_algebraic_before_ffma_block(nir_builder *build, nir_block *block,
                   const uint16_t *states, const bool *condition_flags)
{
   bool progress = false;

   nir_foreach_instr_reverse_safe(instr, block) {
      if (instr->type != nir_instr_type_alu)
         continue;

      nir_alu_instr *alu = nir_instr_as_alu(instr);
      if (!alu->dest.dest.is_ssa)
         continue;

      switch (states[alu->dest.dest.ssa.index]) {
      case 0:
         break;
      case 1:
         break;
      case 2:
         break;
      case 3:
         break;
      case 4:
         break;
      case 5:
         break;
      case 6:
         break;
      case 7:
         break;
      case 8:
         break;
      case 9:
         break;
      case 10:
         break;
      case 11:
         break;
      case 12:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_before_ffma_state12_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_before_ffma_state12_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 13:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_before_ffma_state13_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_before_ffma_state13_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 14:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_before_ffma_state14_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_before_ffma_state14_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 15:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_before_ffma_state15_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_before_ffma_state15_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 16:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_before_ffma_state16_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_before_ffma_state16_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 17:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_before_ffma_state17_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_before_ffma_state17_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 18:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_before_ffma_state18_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_before_ffma_state18_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 19:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_before_ffma_state19_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_before_ffma_state19_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 20:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_before_ffma_state20_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_before_ffma_state20_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 21:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_before_ffma_state21_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_before_ffma_state21_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 22:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_before_ffma_state22_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_before_ffma_state22_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 23:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_before_ffma_state23_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_before_ffma_state23_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 24:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_before_ffma_state24_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_before_ffma_state24_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 25:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_before_ffma_state25_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_before_ffma_state25_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 26:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_before_ffma_state26_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_before_ffma_state26_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 27:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_before_ffma_state27_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_before_ffma_state27_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 28:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_before_ffma_state28_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_before_ffma_state28_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 29:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_before_ffma_state29_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_before_ffma_state29_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 30:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_before_ffma_state30_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_before_ffma_state30_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 31:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_before_ffma_state31_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_before_ffma_state31_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 32:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_before_ffma_state32_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_before_ffma_state32_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 33:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_before_ffma_state33_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_before_ffma_state33_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 34:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_before_ffma_state34_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_before_ffma_state34_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 35:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_before_ffma_state35_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_before_ffma_state35_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 36:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_before_ffma_state36_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_before_ffma_state36_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 37:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_before_ffma_state37_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_before_ffma_state37_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 38:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_before_ffma_state38_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_before_ffma_state38_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 39:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_before_ffma_state39_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_before_ffma_state39_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 40:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_before_ffma_state40_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_before_ffma_state40_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 41:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_before_ffma_state41_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_before_ffma_state41_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 42:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_before_ffma_state42_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_before_ffma_state42_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      default: assert(0);
      }
   }

   return progress;
}

static bool
nir_opt_algebraic_before_ffma_impl(nir_function_impl *impl, const bool *condition_flags)
{
   bool progress = false;

   nir_builder build;
   nir_builder_init(&build, impl);

   /* Note: it's important here that we're allocating a zeroed array, since
    * state 0 is the default state, which means we don't have to visit
    * anything other than constants and ALU instructions.
    */
   uint16_t *states = calloc(impl->ssa_alloc, sizeof(*states));

   nir_foreach_block(block, impl) {
      nir_opt_algebraic_before_ffma_pre_block(block, states);
   }

   nir_foreach_block_reverse(block, impl) {
      progress |= nir_opt_algebraic_before_ffma_block(&build, block, states, condition_flags);
   }

   free(states);

   if (progress) {
      nir_metadata_preserve(impl, nir_metadata_block_index |
                                  nir_metadata_dominance);
    } else {
#ifndef NDEBUG
      impl->valid_metadata &= ~nir_metadata_not_properly_reset;
#endif
    }

   return progress;
}


bool
nir_opt_algebraic_before_ffma(nir_shader *shader)
{
   bool progress = false;
   bool condition_flags[63];
   const nir_shader_compiler_options *options = shader->options;
   const shader_info *info = &shader->info;
   (void) options;
   (void) info;

   condition_flags[0] = true;
   condition_flags[1] = !options->lower_bitops;
   condition_flags[2] = options->lower_bitops;
   condition_flags[3] = options->lower_mul_2x32_64;
   condition_flags[4] = options->lower_idiv;
   condition_flags[5] = options->lower_flrp32;
   condition_flags[6] = options->lower_flrp64;
   condition_flags[7] = options->lower_ftrunc;
   condition_flags[8] = options->lower_ffloor;
   condition_flags[9] = !options->lower_ffloor;
   condition_flags[10] = options->lower_ffract;
   condition_flags[11] = options->lower_fceil;
   condition_flags[12] = !options->lower_flrp32;
   condition_flags[13] = !options->lower_flrp64;
   condition_flags[14] = options->lower_ffma;
   condition_flags[15] = options->fuse_ffma;
   condition_flags[16] = options->lower_fdph;
   condition_flags[17] = !options->lower_fdph;
   condition_flags[18] = options->lower_fdot;
   condition_flags[19] = !options->lower_fsat;
   condition_flags[20] = !options->lower_negate && !options->lower_fsat;
   condition_flags[21] = options->lower_fsat;
   condition_flags[22] = options->lower_scmp;
   condition_flags[23] = options->lower_vector_cmp;
   condition_flags[24] = !options->lower_rotate;
   condition_flags[25] = options->lower_rotate;
   condition_flags[26] = options->lower_fpow;
   condition_flags[27] = !options->lower_fpow;
   condition_flags[28] = options->lower_fdiv;
   condition_flags[29] = options->lower_fsqrt;
   condition_flags[30] = !options->lower_fsqrt;
   condition_flags[31] = options->lower_sincos;
   condition_flags[32] = !options->lower_extract_byte;
   condition_flags[33] = !options->lower_extract_word;
   condition_flags[34] = options->lower_sub;
   condition_flags[35] = options->lower_negate;
   condition_flags[36] = options->lower_fmod;
   condition_flags[37] = options->lower_uadd_carry;
   condition_flags[38] = options->lower_usub_borrow;
   condition_flags[39] = options->lower_bitfield_insert;
   condition_flags[40] = options->lower_hadd;
   condition_flags[41] = options->lower_add_sat;
   condition_flags[42] = options->lower_bitfield_insert_to_shifts;
   condition_flags[43] = options->lower_bitfield_insert_to_bitfield_select;
   condition_flags[44] = options->lower_bitfield_extract;
   condition_flags[45] = options->lower_bitfield_extract_to_shifts;
   condition_flags[46] = options->lower_ifind_msb;
   condition_flags[47] = options->lower_find_lsb;
   condition_flags[48] = options->lower_extract_byte;
   condition_flags[49] = options->lower_extract_word;
   condition_flags[50] = options->lower_pack_unorm_2x16;
   condition_flags[51] = options->lower_pack_unorm_4x8;
   condition_flags[52] = options->lower_pack_snorm_2x16;
   condition_flags[53] = options->lower_pack_snorm_4x8;
   condition_flags[54] = options->lower_unpack_unorm_2x16;
   condition_flags[55] = options->lower_unpack_unorm_4x8;
   condition_flags[56] = options->lower_unpack_snorm_2x16;
   condition_flags[57] = options->lower_unpack_snorm_4x8;
   condition_flags[58] = options->lower_isign;
   condition_flags[59] = options->lower_fsign;
   condition_flags[60] = options->lower_ldexp;
   condition_flags[61] = !options->lower_bitfield_reverse;
   condition_flags[62] = info->stage == MESA_SHADER_COMPUTE && info->cs.derivative_group == DERIVATIVE_GROUP_NONE;

   nir_foreach_function(function, shader) {
      if (function->impl)
         progress |= nir_opt_algebraic_before_ffma_impl(function->impl, condition_flags);
   }

   return progress;
}


#include "nir.h"
#include "nir_builder.h"
#include "nir_search.h"
#include "nir_search_helpers.h"

/* What follows is NIR algebraic transform code for the following 55
 * transforms:
 *    ('flt', ('fadd', 'a', 'b'), 0.0) => ('flt', 'a', ('fneg', 'b'))
 *    ('flt', ('fneg', ('fadd', 'a', 'b')), 0.0) => ('flt', ('fneg', 'a'), 'b')
 *    ('~fge', ('fadd', 'a', 'b'), 0.0) => ('fge', 'a', ('fneg', 'b'))
 *    ('~fge', ('fneg', ('fadd', 'a', 'b')), 0.0) => ('fge', ('fneg', 'a'), 'b')
 *    ('~feq', ('fadd', 'a', 'b'), 0.0) => ('feq', 'a', ('fneg', 'b'))
 *    ('~fne', ('fadd', 'a', 'b'), 0.0) => ('fne', 'a', ('fneg', 'b'))
 *    ('fneg', ('fneg', 'a')) => a
 *    ('flt', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('flt', 'a', 'b')
 *    ('flt', '#b(is_gt_0_and_lt_1)', ('fsat(is_used_once)', 'a')) => ('flt', 'b', 'a')
 *    ('fge', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fge', 'a', 'b')
 *    ('fge', '#b(is_gt_0_and_lt_1)', ('fsat(is_used_once)', 'a')) => ('fge', 'b', 'a')
 *    ('feq', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('feq', 'a', 'b')
 *    ('fne', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fne', 'a', 'b')
 *    ('fge', ('fsat(is_used_once)', 'a'), 1.0) => ('fge', 'a', 1.0)
 *    ('flt', ('fsat(is_used_once)', 'a'), 1.0) => ('flt', 'a', 1.0)
 *    ('~fge', ('fmin(is_used_once)', ('fadd(is_used_once)', 'a', 'b'), ('fadd', 'c', 'd')), 0.0) => ('iand', ('fge', 'a', ('fneg', 'b')), ('fge', 'c', ('fneg', 'd')))
 *    ('flt', ('fneg', 'a'), ('fneg', 'b')) => ('flt', 'b', 'a')
 *    ('fge', ('fneg', 'a'), ('fneg', 'b')) => ('fge', 'b', 'a')
 *    ('feq', ('fneg', 'a'), ('fneg', 'b')) => ('feq', 'b', 'a')
 *    ('fne', ('fneg', 'a'), ('fneg', 'b')) => ('fne', 'b', 'a')
 *    ('flt', ('fneg', 'a'), -1.0) => ('flt', 1.0, 'a')
 *    ('flt', -1.0, ('fneg', 'a')) => ('flt', 'a', 1.0)
 *    ('fge', ('fneg', 'a'), -1.0) => ('fge', 1.0, 'a')
 *    ('fge', -1.0, ('fneg', 'a')) => ('fge', 'a', 1.0)
 *    ('fne', ('fneg', 'a'), -1.0) => ('fne', 1.0, 'a')
 *    ('feq', -1.0, ('fneg', 'a')) => ('feq', 'a', 1.0)
 *    ('ior', 'a', 'a') => a
 *    ('iand', 'a', 'a') => a
 *    ('~fadd', ('fneg(is_used_once)', ('fsat(is_used_once)', 'a(is_not_fmul)')), 1.0) => ('fsat', ('fadd', 1.0, ('fneg', 'a')))
 *    ('fdot2', 'a', 'b') => ('fdot_replicated2', 'a', 'b')
 *    ('fdot3', 'a', 'b') => ('fdot_replicated3', 'a', 'b')
 *    ('fdot4', 'a', 'b') => ('fdot_replicated4', 'a', 'b')
 *    ('fdph', 'a', 'b') => ('fdph_replicated', 'a', 'b')
 *    ('~flrp@32', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a')
 *    ('~flrp@64', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a')
 *    ('~fadd@32', 1.0, ('fmul(is_used_once)', 'c', ('fadd', 'b', -1.0))) => ('fadd', ('fadd', 1.0, ('fneg', 'c')), ('fmul', 'b', 'c'))
 *    ('~fadd@64', 1.0, ('fmul(is_used_once)', 'c', ('fadd', 'b', -1.0))) => ('fadd', ('fadd', 1.0, ('fneg', 'c')), ('fmul', 'b', 'c'))
 *    ('~ffma@32', 'a', 2.0, -1.0) => ('flrp', -1.0, 1.0, 'a')
 *    ('~ffma@32', 'a', -2.0, -1.0) => ('flrp', -1.0, 1.0, ('fneg', 'a'))
 *    ('~ffma@32', 'a', -2.0, 1.0) => ('flrp', 1.0, -1.0, 'a')
 *    ('~ffma@32', 'a', 2.0, 1.0) => ('flrp', 1.0, -1.0, ('fneg', 'a'))
 *    ('~fadd@32', ('fmul(is_used_once)', 2.0, 'a'), -1.0) => ('flrp', -1.0, 1.0, 'a')
 *    ('~fadd@32', ('fmul(is_used_once)', -2.0, 'a'), -1.0) => ('flrp', -1.0, 1.0, ('fneg', 'a'))
 *    ('~fadd@32', ('fmul(is_used_once)', -2.0, 'a'), 1.0) => ('flrp', 1.0, -1.0, 'a')
 *    ('~fadd@32', ('fmul(is_used_once)', 2.0, 'a'), 1.0) => ('flrp', 1.0, -1.0, ('fneg', 'a'))
 *    ('~ffma@32', ('fadd', 'b', ('fneg', 'a')), 'a', 'a') => ('flrp', 'a', 'b', 'a')
 *    ('~ffma@32', 'a', 2.0, ('fneg', ('fmul', 'a', 'a'))) => ('flrp', 'a', 1.0, 'a')
 *    ('~ffma@32', 'a', 2.0, ('fmul', ('fneg', 'a'), 'a')) => ('flrp', 'a', 1.0, 'a')
 *    ('~ffma@32', 'a', ('fneg', 'a'), ('fmul', 2.0, 'a')) => ('flrp', 'a', 1.0, 'a')
 *    ('~fmul@32', 'a', ('fadd', 2.0, ('fneg', 'a'))) => ('flrp', 'a', 1.0, 'a')
 *    ('fmin', ('fadd(is_used_once)', '#c', 'a'), ('fadd(is_used_once)', '#c', 'b')) => ('fadd', 'c', ('fmin', 'a', 'b'))
 *    ('fmax', ('fadd(is_used_once)', '#c', 'a'), ('fadd(is_used_once)', '#c', 'b')) => ('fadd', 'c', ('fmax', 'a', 'b'))
 *    ('bcsel', 'a', 0, ('b2f32', ('inot', 'b@bool'))) => ('b2f32', ('inot', ('ior', 'a', 'b')))
 *    ('~fadd', ('ffma(is_used_once)', 'a', 'b', ('ffma', 'c', 'd', ('fmul', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)'))), 'g(is_not_const)') => ('ffma', 'a', 'b', ('ffma', 'c', 'd', ('ffma', 'e', 'f', 'g')))
 *    ('~fadd', ('ffma(is_used_once)', 'a', 'b', ('fmul', 'c(is_not_const_and_not_fsign)', 'd(is_not_const_and_not_fsign)')), 'e(is_not_const)') => ('ffma', 'a', 'b', ('ffma', 'c', 'd', 'e'))
 */

#ifndef NIR_OPT_ALGEBRAIC_STRUCT_DEFS
#define NIR_OPT_ALGEBRAIC_STRUCT_DEFS

struct transform {
   const nir_search_expression *search;
   const nir_search_value *replace;
   unsigned condition_offset;
};

struct per_op_table {
   const uint16_t *filter;
   unsigned num_filtered_states;
   const uint16_t *table;
};

/* Note: these must match the start states created in
 * TreeAutomaton._build_table()
 */

/* WILDCARD_STATE = 0 is set by zeroing the state array */
static const uint16_t CONST_STATE = 1;

#endif


   static const nir_search_variable search1105_0_0 = {
   { nir_search_value_variable, -2 },
   0, /* a */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

static const nir_search_variable search1105_0_1 = {
   { nir_search_value_variable, -2 },
   1, /* b */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search1105_0 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_fadd,
   { &search1105_0_0.value, &search1105_0_1.value },
   NULL,
};

static const nir_search_constant search1105_1 = {
   { nir_search_value_constant, -2 },
   nir_type_float, { 0x0 /* 0.0 */ },
};
static const nir_search_expression search1105 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_flt,
   { &search1105_0.value, &search1105_1.value },
   NULL,
};

   /* replace1105_0 -> search1105_0_0 in the cache */

/* replace1105_1_0 -> search1105_0_1 in the cache */
static const nir_search_expression replace1105_1 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_fneg,
   { &search1105_0_1.value },
   NULL,
};
static const nir_search_expression replace1105 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search1105_0_0.value, &replace1105_1.value },
   NULL,
};

   /* search1106_0_0_0 -> search1105_0_0 in the cache */

/* search1106_0_0_1 -> search1105_0_1 in the cache */
/* search1106_0_0 -> search1105_0 in the cache */
static const nir_search_expression search1106_0 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 1,
   nir_op_fneg,
   { &search1105_0.value },
   NULL,
};

/* search1106_1 -> search1105_1 in the cache */
static const nir_search_expression search1106 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_flt,
   { &search1106_0.value, &search1105_1.value },
   NULL,
};

   /* replace1106_0_0 -> search1105_0_0 in the cache */
static const nir_search_expression replace1106_0 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_fneg,
   { &search1105_0_0.value },
   NULL,
};

/* replace1106_1 -> search1105_0_1 in the cache */
static const nir_search_expression replace1106 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &replace1106_0.value, &search1105_0_1.value },
   NULL,
};

   /* search1107_0_0 -> search1105_0_0 in the cache */

/* search1107_0_1 -> search1105_0_1 in the cache */
/* search1107_0 -> search1105_0 in the cache */

/* search1107_1 -> search1105_1 in the cache */
static const nir_search_expression search1107 = {
   { nir_search_value_expression, 1 },
   true,
   -1, 1,
   nir_op_fge,
   { &search1105_0.value, &search1105_1.value },
   NULL,
};

   /* replace1107_0 -> search1105_0_0 in the cache */

/* replace1107_1_0 -> search1105_0_1 in the cache */
/* replace1107_1 -> replace1105_1 in the cache */
static const nir_search_expression replace1107 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search1105_0_0.value, &replace1105_1.value },
   NULL,
};

   /* search1108_0_0_0 -> search1105_0_0 in the cache */

/* search1108_0_0_1 -> search1105_0_1 in the cache */
/* search1108_0_0 -> search1105_0 in the cache */
/* search1108_0 -> search1106_0 in the cache */

/* search1108_1 -> search1105_1 in the cache */
static const nir_search_expression search1108 = {
   { nir_search_value_expression, 1 },
   true,
   -1, 1,
   nir_op_fge,
   { &search1106_0.value, &search1105_1.value },
   NULL,
};

   /* replace1108_0_0 -> search1105_0_0 in the cache */
/* replace1108_0 -> replace1106_0 in the cache */

/* replace1108_1 -> search1105_0_1 in the cache */
static const nir_search_expression replace1108 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &replace1106_0.value, &search1105_0_1.value },
   NULL,
};

   /* search1109_0_0 -> search1105_0_0 in the cache */

/* search1109_0_1 -> search1105_0_1 in the cache */
static const nir_search_expression search1109_0 = {
   { nir_search_value_expression, -2 },
   false,
   1, 1,
   nir_op_fadd,
   { &search1105_0_0.value, &search1105_0_1.value },
   NULL,
};

/* search1109_1 -> search1105_1 in the cache */
static const nir_search_expression search1109 = {
   { nir_search_value_expression, 1 },
   true,
   0, 2,
   nir_op_feq,
   { &search1109_0.value, &search1105_1.value },
   NULL,
};

   /* replace1109_0 -> search1105_0_0 in the cache */

/* replace1109_1_0 -> search1105_0_1 in the cache */
/* replace1109_1 -> replace1105_1 in the cache */
static const nir_search_expression replace1109 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_feq,
   { &search1105_0_0.value, &replace1105_1.value },
   NULL,
};

   /* search1110_0_0 -> search1105_0_0 in the cache */

/* search1110_0_1 -> search1105_0_1 in the cache */
/* search1110_0 -> search1109_0 in the cache */

/* search1110_1 -> search1105_1 in the cache */
static const nir_search_expression search1110 = {
   { nir_search_value_expression, 1 },
   true,
   0, 2,
   nir_op_fne,
   { &search1109_0.value, &search1105_1.value },
   NULL,
};

   /* replace1110_0 -> search1105_0_0 in the cache */

/* replace1110_1_0 -> search1105_0_1 in the cache */
/* replace1110_1 -> replace1105_1 in the cache */
static const nir_search_expression replace1110 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_fne,
   { &search1105_0_0.value, &replace1105_1.value },
   NULL,
};

   static const nir_search_variable search1111_0_0 = {
   { nir_search_value_variable, -1 },
   0, /* a */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search1111_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fneg,
   { &search1111_0_0.value },
   NULL,
};
static const nir_search_expression search1111 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fneg,
   { &search1111_0.value },
   NULL,
};

   /* replace1111 -> search1111_0_0 in the cache */

   /* search1112_0_0 -> search1105_0_0 in the cache */
static const nir_search_expression search1112_0 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_fsat,
   { &search1105_0_0.value },
   (is_used_once),
};

static const nir_search_variable search1112_1 = {
   { nir_search_value_variable, -2 },
   1, /* b */
   true,
   nir_type_invalid,
   (is_gt_0_and_lt_1),
   {0, 1, 2, 3},
};
static const nir_search_expression search1112 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search1112_0.value, &search1112_1.value },
   NULL,
};

   /* replace1112_0 -> search1105_0_0 in the cache */

/* replace1112_1 -> search1105_0_1 in the cache */
static const nir_search_expression replace1112 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search1105_0_0.value, &search1105_0_1.value },
   NULL,
};

   static const nir_search_variable search1113_0 = {
   { nir_search_value_variable, -2 },
   0, /* b */
   true,
   nir_type_invalid,
   (is_gt_0_and_lt_1),
   {0, 1, 2, 3},
};

static const nir_search_variable search1113_1_0 = {
   { nir_search_value_variable, -2 },
   1, /* a */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search1113_1 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_fsat,
   { &search1113_1_0.value },
   (is_used_once),
};
static const nir_search_expression search1113 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search1113_0.value, &search1113_1.value },
   NULL,
};

   static const nir_search_variable replace1113_0 = {
   { nir_search_value_variable, -2 },
   0, /* b */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

/* replace1113_1 -> search1113_1_0 in the cache */
static const nir_search_expression replace1113 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &replace1113_0.value, &search1113_1_0.value },
   NULL,
};

   /* search1114_0_0 -> search1105_0_0 in the cache */
/* search1114_0 -> search1112_0 in the cache */

/* search1114_1 -> search1112_1 in the cache */
static const nir_search_expression search1114 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search1112_0.value, &search1112_1.value },
   NULL,
};

   /* replace1114_0 -> search1105_0_0 in the cache */

/* replace1114_1 -> search1105_0_1 in the cache */
static const nir_search_expression replace1114 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search1105_0_0.value, &search1105_0_1.value },
   NULL,
};

   /* search1115_0 -> search1113_0 in the cache */

/* search1115_1_0 -> search1113_1_0 in the cache */
/* search1115_1 -> search1113_1 in the cache */
static const nir_search_expression search1115 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search1113_0.value, &search1113_1.value },
   NULL,
};

   /* replace1115_0 -> replace1113_0 in the cache */

/* replace1115_1 -> search1113_1_0 in the cache */
static const nir_search_expression replace1115 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &replace1113_0.value, &search1113_1_0.value },
   NULL,
};

   /* search1116_0_0 -> search1105_0_0 in the cache */
/* search1116_0 -> search1112_0 in the cache */

/* search1116_1 -> search1112_1 in the cache */
static const nir_search_expression search1116 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_feq,
   { &search1112_0.value, &search1112_1.value },
   NULL,
};

   /* replace1116_0 -> search1105_0_0 in the cache */

/* replace1116_1 -> search1105_0_1 in the cache */
static const nir_search_expression replace1116 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_feq,
   { &search1105_0_0.value, &search1105_0_1.value },
   NULL,
};

   /* search1117_0_0 -> search1105_0_0 in the cache */
/* search1117_0 -> search1112_0 in the cache */

/* search1117_1 -> search1112_1 in the cache */
static const nir_search_expression search1117 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_fne,
   { &search1112_0.value, &search1112_1.value },
   NULL,
};

   /* replace1117_0 -> search1105_0_0 in the cache */

/* replace1117_1 -> search1105_0_1 in the cache */
static const nir_search_expression replace1117 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_fne,
   { &search1105_0_0.value, &search1105_0_1.value },
   NULL,
};

   /* search1118_0_0 -> search1111_0_0 in the cache */
static const nir_search_expression search1118_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fsat,
   { &search1111_0_0.value },
   (is_used_once),
};

static const nir_search_constant search1118_1 = {
   { nir_search_value_constant, -1 },
   nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
};
static const nir_search_expression search1118 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search1118_0.value, &search1118_1.value },
   NULL,
};

   /* replace1118_0 -> search1111_0_0 in the cache */

/* replace1118_1 -> search1118_1 in the cache */
static const nir_search_expression replace1118 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search1111_0_0.value, &search1118_1.value },
   NULL,
};

   /* search1119_0_0 -> search1111_0_0 in the cache */
/* search1119_0 -> search1118_0 in the cache */

/* search1119_1 -> search1118_1 in the cache */
static const nir_search_expression search1119 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search1118_0.value, &search1118_1.value },
   NULL,
};

   /* replace1119_0 -> search1111_0_0 in the cache */

/* replace1119_1 -> search1118_1 in the cache */
static const nir_search_expression replace1119 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search1111_0_0.value, &search1118_1.value },
   NULL,
};

   static const nir_search_variable search1120_0_0_0 = {
   { nir_search_value_variable, -4 },
   0, /* a */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

static const nir_search_variable search1120_0_0_1 = {
   { nir_search_value_variable, -4 },
   1, /* b */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search1120_0_0 = {
   { nir_search_value_expression, -4 },
   false,
   0, 1,
   nir_op_fadd,
   { &search1120_0_0_0.value, &search1120_0_0_1.value },
   (is_used_once),
};

static const nir_search_variable search1120_0_1_0 = {
   { nir_search_value_variable, -4 },
   2, /* c */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

static const nir_search_variable search1120_0_1_1 = {
   { nir_search_value_variable, -4 },
   3, /* d */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search1120_0_1 = {
   { nir_search_value_expression, -4 },
   false,
   1, 1,
   nir_op_fadd,
   { &search1120_0_1_0.value, &search1120_0_1_1.value },
   NULL,
};
static const nir_search_expression search1120_0 = {
   { nir_search_value_expression, -4 },
   false,
   -1, 2,
   nir_op_fmin,
   { &search1120_0_0.value, &search1120_0_1.value },
   (is_used_once),
};

static const nir_search_constant search1120_1 = {
   { nir_search_value_constant, -4 },
   nir_type_float, { 0x0 /* 0.0 */ },
};
static const nir_search_expression search1120 = {
   { nir_search_value_expression, 1 },
   true,
   -1, 2,
   nir_op_fge,
   { &search1120_0.value, &search1120_1.value },
   NULL,
};

   /* replace1120_0_0 -> search1120_0_0_0 in the cache */

/* replace1120_0_1_0 -> search1120_0_0_1 in the cache */
static const nir_search_expression replace1120_0_1 = {
   { nir_search_value_expression, -4 },
   false,
   -1, 0,
   nir_op_fneg,
   { &search1120_0_0_1.value },
   NULL,
};
static const nir_search_expression replace1120_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search1120_0_0_0.value, &replace1120_0_1.value },
   NULL,
};

/* replace1120_1_0 -> search1120_0_1_0 in the cache */

/* replace1120_1_1_0 -> search1120_0_1_1 in the cache */
static const nir_search_expression replace1120_1_1 = {
   { nir_search_value_expression, -4 },
   false,
   -1, 0,
   nir_op_fneg,
   { &search1120_0_1_1.value },
   NULL,
};
static const nir_search_expression replace1120_1 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search1120_0_1_0.value, &replace1120_1_1.value },
   NULL,
};
static const nir_search_expression replace1120 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_iand,
   { &replace1120_0.value, &replace1120_1.value },
   NULL,
};

   /* search1121_0_0 -> search1105_0_0 in the cache */
/* search1121_0 -> replace1106_0 in the cache */

/* search1121_1_0 -> search1105_0_1 in the cache */
/* search1121_1 -> replace1105_1 in the cache */
static const nir_search_expression search1121 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &replace1106_0.value, &replace1105_1.value },
   NULL,
};

   /* replace1121_0 -> search1105_0_1 in the cache */

/* replace1121_1 -> search1105_0_0 in the cache */
static const nir_search_expression replace1121 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search1105_0_1.value, &search1105_0_0.value },
   NULL,
};

   /* search1122_0_0 -> search1105_0_0 in the cache */
/* search1122_0 -> replace1106_0 in the cache */

/* search1122_1_0 -> search1105_0_1 in the cache */
/* search1122_1 -> replace1105_1 in the cache */
static const nir_search_expression search1122 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &replace1106_0.value, &replace1105_1.value },
   NULL,
};

   /* replace1122_0 -> search1105_0_1 in the cache */

/* replace1122_1 -> search1105_0_0 in the cache */
static const nir_search_expression replace1122 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search1105_0_1.value, &search1105_0_0.value },
   NULL,
};

   /* search1123_0_0 -> search1105_0_0 in the cache */
/* search1123_0 -> replace1106_0 in the cache */

/* search1123_1_0 -> search1105_0_1 in the cache */
/* search1123_1 -> replace1105_1 in the cache */
static const nir_search_expression search1123 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_feq,
   { &replace1106_0.value, &replace1105_1.value },
   NULL,
};

   /* replace1123_0 -> search1105_0_1 in the cache */

/* replace1123_1 -> search1105_0_0 in the cache */
static const nir_search_expression replace1123 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_feq,
   { &search1105_0_1.value, &search1105_0_0.value },
   NULL,
};

   /* search1124_0_0 -> search1105_0_0 in the cache */
/* search1124_0 -> replace1106_0 in the cache */

/* search1124_1_0 -> search1105_0_1 in the cache */
/* search1124_1 -> replace1105_1 in the cache */
static const nir_search_expression search1124 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_fne,
   { &replace1106_0.value, &replace1105_1.value },
   NULL,
};

   /* replace1124_0 -> search1105_0_1 in the cache */

/* replace1124_1 -> search1105_0_0 in the cache */
static const nir_search_expression replace1124 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_fne,
   { &search1105_0_1.value, &search1105_0_0.value },
   NULL,
};

   /* search1125_0_0 -> search1111_0_0 in the cache */
/* search1125_0 -> search1111_0 in the cache */

static const nir_search_constant search1125_1 = {
   { nir_search_value_constant, -1 },
   nir_type_float, { 0xbff0000000000000L /* -1.0 */ },
};
static const nir_search_expression search1125 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search1111_0.value, &search1125_1.value },
   NULL,
};

   /* replace1125_0 -> search1118_1 in the cache */

/* replace1125_1 -> search1111_0_0 in the cache */
static const nir_search_expression replace1125 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search1118_1.value, &search1111_0_0.value },
   NULL,
};

   /* search1126_0 -> search1125_1 in the cache */

/* search1126_1_0 -> search1111_0_0 in the cache */
/* search1126_1 -> search1111_0 in the cache */
static const nir_search_expression search1126 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_flt,
   { &search1125_1.value, &search1111_0.value },
   NULL,
};

   /* replace1126_0 -> search1111_0_0 in the cache */

/* replace1126_1 -> search1118_1 in the cache */
/* replace1126 -> replace1119 in the cache */

   /* search1127_0_0 -> search1111_0_0 in the cache */
/* search1127_0 -> search1111_0 in the cache */

/* search1127_1 -> search1125_1 in the cache */
static const nir_search_expression search1127 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search1111_0.value, &search1125_1.value },
   NULL,
};

   /* replace1127_0 -> search1118_1 in the cache */

/* replace1127_1 -> search1111_0_0 in the cache */
static const nir_search_expression replace1127 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search1118_1.value, &search1111_0_0.value },
   NULL,
};

   /* search1128_0 -> search1125_1 in the cache */

/* search1128_1_0 -> search1111_0_0 in the cache */
/* search1128_1 -> search1111_0 in the cache */
static const nir_search_expression search1128 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_fge,
   { &search1125_1.value, &search1111_0.value },
   NULL,
};

   /* replace1128_0 -> search1111_0_0 in the cache */

/* replace1128_1 -> search1118_1 in the cache */
/* replace1128 -> replace1118 in the cache */

   /* search1129_0_0 -> search1111_0_0 in the cache */
/* search1129_0 -> search1111_0 in the cache */

/* search1129_1 -> search1125_1 in the cache */
static const nir_search_expression search1129 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_fne,
   { &search1111_0.value, &search1125_1.value },
   NULL,
};

   /* replace1129_0 -> search1118_1 in the cache */

/* replace1129_1 -> search1111_0_0 in the cache */
static const nir_search_expression replace1129 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_fne,
   { &search1118_1.value, &search1111_0_0.value },
   NULL,
};

   /* search1130_0 -> search1125_1 in the cache */

/* search1130_1_0 -> search1111_0_0 in the cache */
/* search1130_1 -> search1111_0 in the cache */
static const nir_search_expression search1130 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_feq,
   { &search1125_1.value, &search1111_0.value },
   NULL,
};

   /* replace1130_0 -> search1111_0_0 in the cache */

/* replace1130_1 -> search1118_1 in the cache */
static const nir_search_expression replace1130 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_feq,
   { &search1111_0_0.value, &search1118_1.value },
   NULL,
};

   /* search1131_0 -> search1111_0_0 in the cache */

/* search1131_1 -> search1111_0_0 in the cache */
static const nir_search_expression search1131 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_ior,
   { &search1111_0_0.value, &search1111_0_0.value },
   NULL,
};

   /* replace1131 -> search1111_0_0 in the cache */

   /* search1132_0 -> search1111_0_0 in the cache */

/* search1132_1 -> search1111_0_0 in the cache */
static const nir_search_expression search1132 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_iand,
   { &search1111_0_0.value, &search1111_0_0.value },
   NULL,
};

   /* replace1132 -> search1111_0_0 in the cache */

   static const nir_search_variable search1133_0_0_0 = {
   { nir_search_value_variable, -1 },
   0, /* a */
   false,
   nir_type_invalid,
   (is_not_fmul),
   {0, 1, 2, 3},
};
static const nir_search_expression search1133_0_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fsat,
   { &search1133_0_0_0.value },
   (is_used_once),
};
static const nir_search_expression search1133_0 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 0,
   nir_op_fneg,
   { &search1133_0_0.value },
   (is_used_once),
};

/* search1133_1 -> search1118_1 in the cache */
static const nir_search_expression search1133 = {
   { nir_search_value_expression, -1 },
   true,
   0, 1,
   nir_op_fadd,
   { &search1133_0.value, &search1118_1.value },
   NULL,
};

   /* replace1133_0_0 -> search1118_1 in the cache */

/* replace1133_0_1_0 -> search1111_0_0 in the cache */
/* replace1133_0_1 -> search1111_0 in the cache */
static const nir_search_expression replace1133_0 = {
   { nir_search_value_expression, -1 },
   false,
   0, 1,
   nir_op_fadd,
   { &search1118_1.value, &search1111_0.value },
   NULL,
};
static const nir_search_expression replace1133 = {
   { nir_search_value_expression, -1 },
   false,
   -1, 1,
   nir_op_fsat,
   { &replace1133_0.value },
   NULL,
};

   /* search1134_0 -> search1105_0_0 in the cache */

/* search1134_1 -> search1105_0_1 in the cache */
static const nir_search_expression search1134 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_fdot2,
   { &search1105_0_0.value, &search1105_0_1.value },
   NULL,
};

   /* replace1134_0 -> search1105_0_0 in the cache */

/* replace1134_1 -> search1105_0_1 in the cache */
static const nir_search_expression replace1134 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_fdot_replicated2,
   { &search1105_0_0.value, &search1105_0_1.value },
   NULL,
};

   /* search1135_0 -> search1105_0_0 in the cache */

/* search1135_1 -> search1105_0_1 in the cache */
static const nir_search_expression search1135 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_fdot3,
   { &search1105_0_0.value, &search1105_0_1.value },
   NULL,
};

   /* replace1135_0 -> search1105_0_0 in the cache */

/* replace1135_1 -> search1105_0_1 in the cache */
static const nir_search_expression replace1135 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_fdot_replicated3,
   { &search1105_0_0.value, &search1105_0_1.value },
   NULL,
};

   /* search1136_0 -> search1105_0_0 in the cache */

/* search1136_1 -> search1105_0_1 in the cache */
static const nir_search_expression search1136 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_fdot4,
   { &search1105_0_0.value, &search1105_0_1.value },
   NULL,
};

   /* replace1136_0 -> search1105_0_0 in the cache */

/* replace1136_1 -> search1105_0_1 in the cache */
static const nir_search_expression replace1136 = {
   { nir_search_value_expression, -2 },
   false,
   0, 1,
   nir_op_fdot_replicated4,
   { &search1105_0_0.value, &search1105_0_1.value },
   NULL,
};

   /* search1137_0 -> search1105_0_0 in the cache */

/* search1137_1 -> search1105_0_1 in the cache */
static const nir_search_expression search1137 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_fdph,
   { &search1105_0_0.value, &search1105_0_1.value },
   NULL,
};

   /* replace1137_0 -> search1105_0_0 in the cache */

/* replace1137_1 -> search1105_0_1 in the cache */
static const nir_search_expression replace1137 = {
   { nir_search_value_expression, -2 },
   false,
   -1, 0,
   nir_op_fdph_replicated,
   { &search1105_0_0.value, &search1105_0_1.value },
   NULL,
};

   static const nir_search_variable search1138_0_0 = {
   { nir_search_value_variable, 32 },
   0, /* a */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

static const nir_search_variable search1138_0_1 = {
   { nir_search_value_variable, 32 },
   1, /* b */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search1138_0 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_fadd,
   { &search1138_0_0.value, &search1138_0_1.value },
   (is_used_once),
};

/* search1138_1_0 -> search1138_0_0 in the cache */

static const nir_search_variable search1138_1_1 = {
   { nir_search_value_variable, 32 },
   2, /* c */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search1138_1 = {
   { nir_search_value_expression, 32 },
   false,
   1, 1,
   nir_op_fadd,
   { &search1138_0_0.value, &search1138_1_1.value },
   (is_used_once),
};

static const nir_search_variable search1138_2 = {
   { nir_search_value_variable, 32 },
   3, /* d */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search1138 = {
   { nir_search_value_expression, 32 },
   true,
   -1, 2,
   nir_op_flrp,
   { &search1138_0.value, &search1138_1.value, &search1138_2.value },
   NULL,
};

   /* replace1138_0_0 -> search1138_0_1 in the cache */

/* replace1138_0_1 -> search1138_1_1 in the cache */

/* replace1138_0_2 -> search1138_2 in the cache */
static const nir_search_expression replace1138_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_flrp,
   { &search1138_0_1.value, &search1138_1_1.value, &search1138_2.value },
   NULL,
};

/* replace1138_1 -> search1138_0_0 in the cache */
static const nir_search_expression replace1138 = {
   { nir_search_value_expression, 32 },
   false,
   0, 1,
   nir_op_fadd,
   { &replace1138_0.value, &search1138_0_0.value },
   NULL,
};

   static const nir_search_variable search1139_0_0 = {
   { nir_search_value_variable, 64 },
   0, /* a */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

static const nir_search_variable search1139_0_1 = {
   { nir_search_value_variable, 64 },
   1, /* b */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search1139_0 = {
   { nir_search_value_expression, 64 },
   false,
   0, 1,
   nir_op_fadd,
   { &search1139_0_0.value, &search1139_0_1.value },
   (is_used_once),
};

/* search1139_1_0 -> search1139_0_0 in the cache */

static const nir_search_variable search1139_1_1 = {
   { nir_search_value_variable, 64 },
   2, /* c */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search1139_1 = {
   { nir_search_value_expression, 64 },
   false,
   1, 1,
   nir_op_fadd,
   { &search1139_0_0.value, &search1139_1_1.value },
   (is_used_once),
};

static const nir_search_variable search1139_2 = {
   { nir_search_value_variable, 64 },
   3, /* d */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search1139 = {
   { nir_search_value_expression, 64 },
   true,
   -1, 2,
   nir_op_flrp,
   { &search1139_0.value, &search1139_1.value, &search1139_2.value },
   NULL,
};

   /* replace1139_0_0 -> search1139_0_1 in the cache */

/* replace1139_0_1 -> search1139_1_1 in the cache */

/* replace1139_0_2 -> search1139_2 in the cache */
static const nir_search_expression replace1139_0 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_flrp,
   { &search1139_0_1.value, &search1139_1_1.value, &search1139_2.value },
   NULL,
};

/* replace1139_1 -> search1139_0_0 in the cache */
static const nir_search_expression replace1139 = {
   { nir_search_value_expression, 64 },
   false,
   0, 1,
   nir_op_fadd,
   { &replace1139_0.value, &search1139_0_0.value },
   NULL,
};

   static const nir_search_constant search1140_0 = {
   { nir_search_value_constant, 32 },
   nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
};

static const nir_search_variable search1140_1_0 = {
   { nir_search_value_variable, 32 },
   0, /* c */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

/* search1140_1_1_0 -> search1138_0_1 in the cache */

static const nir_search_constant search1140_1_1_1 = {
   { nir_search_value_constant, 32 },
   nir_type_float, { 0xbff0000000000000L /* -1.0 */ },
};
static const nir_search_expression search1140_1_1 = {
   { nir_search_value_expression, 32 },
   false,
   2, 1,
   nir_op_fadd,
   { &search1138_0_1.value, &search1140_1_1_1.value },
   NULL,
};
static const nir_search_expression search1140_1 = {
   { nir_search_value_expression, 32 },
   false,
   1, 2,
   nir_op_fmul,
   { &search1140_1_0.value, &search1140_1_1.value },
   (is_used_once),
};
static const nir_search_expression search1140 = {
   { nir_search_value_expression, 32 },
   true,
   0, 3,
   nir_op_fadd,
   { &search1140_0.value, &search1140_1.value },
   NULL,
};

   /* replace1140_0_0 -> search1140_0 in the cache */

/* replace1140_0_1_0 -> search1140_1_0 in the cache */
static const nir_search_expression replace1140_0_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_fneg,
   { &search1140_1_0.value },
   NULL,
};
static const nir_search_expression replace1140_0 = {
   { nir_search_value_expression, 32 },
   false,
   1, 1,
   nir_op_fadd,
   { &search1140_0.value, &replace1140_0_1.value },
   NULL,
};

/* replace1140_1_0 -> search1138_0_1 in the cache */

/* replace1140_1_1 -> search1140_1_0 in the cache */
static const nir_search_expression replace1140_1 = {
   { nir_search_value_expression, 32 },
   false,
   2, 1,
   nir_op_fmul,
   { &search1138_0_1.value, &search1140_1_0.value },
   NULL,
};
static const nir_search_expression replace1140 = {
   { nir_search_value_expression, 32 },
   false,
   0, 3,
   nir_op_fadd,
   { &replace1140_0.value, &replace1140_1.value },
   NULL,
};

   static const nir_search_constant search1141_0 = {
   { nir_search_value_constant, 64 },
   nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
};

static const nir_search_variable search1141_1_0 = {
   { nir_search_value_variable, 64 },
   0, /* c */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

/* search1141_1_1_0 -> search1139_0_1 in the cache */

static const nir_search_constant search1141_1_1_1 = {
   { nir_search_value_constant, 64 },
   nir_type_float, { 0xbff0000000000000L /* -1.0 */ },
};
static const nir_search_expression search1141_1_1 = {
   { nir_search_value_expression, 64 },
   false,
   2, 1,
   nir_op_fadd,
   { &search1139_0_1.value, &search1141_1_1_1.value },
   NULL,
};
static const nir_search_expression search1141_1 = {
   { nir_search_value_expression, 64 },
   false,
   1, 2,
   nir_op_fmul,
   { &search1141_1_0.value, &search1141_1_1.value },
   (is_used_once),
};
static const nir_search_expression search1141 = {
   { nir_search_value_expression, 64 },
   true,
   0, 3,
   nir_op_fadd,
   { &search1141_0.value, &search1141_1.value },
   NULL,
};

   /* replace1141_0_0 -> search1141_0 in the cache */

/* replace1141_0_1_0 -> search1141_1_0 in the cache */
static const nir_search_expression replace1141_0_1 = {
   { nir_search_value_expression, 64 },
   false,
   -1, 0,
   nir_op_fneg,
   { &search1141_1_0.value },
   NULL,
};
static const nir_search_expression replace1141_0 = {
   { nir_search_value_expression, 64 },
   false,
   1, 1,
   nir_op_fadd,
   { &search1141_0.value, &replace1141_0_1.value },
   NULL,
};

/* replace1141_1_0 -> search1139_0_1 in the cache */

/* replace1141_1_1 -> search1141_1_0 in the cache */
static const nir_search_expression replace1141_1 = {
   { nir_search_value_expression, 64 },
   false,
   2, 1,
   nir_op_fmul,
   { &search1139_0_1.value, &search1141_1_0.value },
   NULL,
};
static const nir_search_expression replace1141 = {
   { nir_search_value_expression, 64 },
   false,
   0, 3,
   nir_op_fadd,
   { &replace1141_0.value, &replace1141_1.value },
   NULL,
};

   /* search1142_0 -> search1138_0_0 in the cache */

static const nir_search_constant search1142_1 = {
   { nir_search_value_constant, 32 },
   nir_type_float, { 0x4000000000000000 /* 2.0 */ },
};

/* search1142_2 -> search1140_1_1_1 in the cache */
static const nir_search_expression search1142 = {
   { nir_search_value_expression, 32 },
   true,
   0, 1,
   nir_op_ffma,
   { &search1138_0_0.value, &search1142_1.value, &search1140_1_1_1.value },
   NULL,
};

   /* replace1142_0 -> search1140_1_1_1 in the cache */

/* replace1142_1 -> search1140_0 in the cache */

/* replace1142_2 -> search1138_0_0 in the cache */
static const nir_search_expression replace1142 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_flrp,
   { &search1140_1_1_1.value, &search1140_0.value, &search1138_0_0.value },
   NULL,
};

   /* search1143_0 -> search1138_0_0 in the cache */

static const nir_search_constant search1143_1 = {
   { nir_search_value_constant, 32 },
   nir_type_float, { 0xc000000000000000L /* -2.0 */ },
};

/* search1143_2 -> search1140_1_1_1 in the cache */
static const nir_search_expression search1143 = {
   { nir_search_value_expression, 32 },
   true,
   0, 1,
   nir_op_ffma,
   { &search1138_0_0.value, &search1143_1.value, &search1140_1_1_1.value },
   NULL,
};

   /* replace1143_0 -> search1140_1_1_1 in the cache */

/* replace1143_1 -> search1140_0 in the cache */

/* replace1143_2_0 -> search1138_0_0 in the cache */
static const nir_search_expression replace1143_2 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_fneg,
   { &search1138_0_0.value },
   NULL,
};
static const nir_search_expression replace1143 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_flrp,
   { &search1140_1_1_1.value, &search1140_0.value, &replace1143_2.value },
   NULL,
};

   /* search1144_0 -> search1138_0_0 in the cache */

/* search1144_1 -> search1143_1 in the cache */

/* search1144_2 -> search1140_0 in the cache */
static const nir_search_expression search1144 = {
   { nir_search_value_expression, 32 },
   true,
   0, 1,
   nir_op_ffma,
   { &search1138_0_0.value, &search1143_1.value, &search1140_0.value },
   NULL,
};

   /* replace1144_0 -> search1140_0 in the cache */

/* replace1144_1 -> search1140_1_1_1 in the cache */

/* replace1144_2 -> search1138_0_0 in the cache */
static const nir_search_expression replace1144 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_flrp,
   { &search1140_0.value, &search1140_1_1_1.value, &search1138_0_0.value },
   NULL,
};

   /* search1145_0 -> search1138_0_0 in the cache */

/* search1145_1 -> search1142_1 in the cache */

/* search1145_2 -> search1140_0 in the cache */
static const nir_search_expression search1145 = {
   { nir_search_value_expression, 32 },
   true,
   0, 1,
   nir_op_ffma,
   { &search1138_0_0.value, &search1142_1.value, &search1140_0.value },
   NULL,
};

   /* replace1145_0 -> search1140_0 in the cache */

/* replace1145_1 -> search1140_1_1_1 in the cache */

/* replace1145_2_0 -> search1138_0_0 in the cache */
/* replace1145_2 -> replace1143_2 in the cache */
static const nir_search_expression replace1145 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_flrp,
   { &search1140_0.value, &search1140_1_1_1.value, &replace1143_2.value },
   NULL,
};

   /* search1146_0_0 -> search1142_1 in the cache */

/* search1146_0_1 -> search1138_0_0 in the cache */
static const nir_search_expression search1146_0 = {
   { nir_search_value_expression, 32 },
   false,
   1, 1,
   nir_op_fmul,
   { &search1142_1.value, &search1138_0_0.value },
   (is_used_once),
};

/* search1146_1 -> search1140_1_1_1 in the cache */
static const nir_search_expression search1146 = {
   { nir_search_value_expression, 32 },
   true,
   0, 2,
   nir_op_fadd,
   { &search1146_0.value, &search1140_1_1_1.value },
   NULL,
};

   /* replace1146_0 -> search1140_1_1_1 in the cache */

/* replace1146_1 -> search1140_0 in the cache */

/* replace1146_2 -> search1138_0_0 in the cache */
/* replace1146 -> replace1142 in the cache */

   /* search1147_0_0 -> search1143_1 in the cache */

/* search1147_0_1 -> search1138_0_0 in the cache */
static const nir_search_expression search1147_0 = {
   { nir_search_value_expression, 32 },
   false,
   1, 1,
   nir_op_fmul,
   { &search1143_1.value, &search1138_0_0.value },
   (is_used_once),
};

/* search1147_1 -> search1140_1_1_1 in the cache */
static const nir_search_expression search1147 = {
   { nir_search_value_expression, 32 },
   true,
   0, 2,
   nir_op_fadd,
   { &search1147_0.value, &search1140_1_1_1.value },
   NULL,
};

   /* replace1147_0 -> search1140_1_1_1 in the cache */

/* replace1147_1 -> search1140_0 in the cache */

/* replace1147_2_0 -> search1138_0_0 in the cache */
/* replace1147_2 -> replace1143_2 in the cache */
/* replace1147 -> replace1143 in the cache */

   /* search1148_0_0 -> search1143_1 in the cache */

/* search1148_0_1 -> search1138_0_0 in the cache */
/* search1148_0 -> search1147_0 in the cache */

/* search1148_1 -> search1140_0 in the cache */
static const nir_search_expression search1148 = {
   { nir_search_value_expression, 32 },
   true,
   0, 2,
   nir_op_fadd,
   { &search1147_0.value, &search1140_0.value },
   NULL,
};

   /* replace1148_0 -> search1140_0 in the cache */

/* replace1148_1 -> search1140_1_1_1 in the cache */

/* replace1148_2 -> search1138_0_0 in the cache */
/* replace1148 -> replace1144 in the cache */

   /* search1149_0_0 -> search1142_1 in the cache */

/* search1149_0_1 -> search1138_0_0 in the cache */
/* search1149_0 -> search1146_0 in the cache */

/* search1149_1 -> search1140_0 in the cache */
static const nir_search_expression search1149 = {
   { nir_search_value_expression, 32 },
   true,
   0, 2,
   nir_op_fadd,
   { &search1146_0.value, &search1140_0.value },
   NULL,
};

   /* replace1149_0 -> search1140_0 in the cache */

/* replace1149_1 -> search1140_1_1_1 in the cache */

/* replace1149_2_0 -> search1138_0_0 in the cache */
/* replace1149_2 -> replace1143_2 in the cache */
/* replace1149 -> replace1145 in the cache */

   static const nir_search_variable search1150_0_0 = {
   { nir_search_value_variable, 32 },
   0, /* b */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

static const nir_search_variable search1150_0_1_0 = {
   { nir_search_value_variable, 32 },
   1, /* a */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search1150_0_1 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_fneg,
   { &search1150_0_1_0.value },
   NULL,
};
static const nir_search_expression search1150_0 = {
   { nir_search_value_expression, 32 },
   false,
   1, 1,
   nir_op_fadd,
   { &search1150_0_0.value, &search1150_0_1.value },
   NULL,
};

/* search1150_1 -> search1150_0_1_0 in the cache */

/* search1150_2 -> search1150_0_1_0 in the cache */
static const nir_search_expression search1150 = {
   { nir_search_value_expression, 32 },
   true,
   0, 2,
   nir_op_ffma,
   { &search1150_0.value, &search1150_0_1_0.value, &search1150_0_1_0.value },
   NULL,
};

   /* replace1150_0 -> search1150_0_1_0 in the cache */

/* replace1150_1 -> search1150_0_0 in the cache */

/* replace1150_2 -> search1150_0_1_0 in the cache */
static const nir_search_expression replace1150 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_flrp,
   { &search1150_0_1_0.value, &search1150_0_0.value, &search1150_0_1_0.value },
   NULL,
};

   /* search1151_0 -> search1138_0_0 in the cache */

/* search1151_1 -> search1142_1 in the cache */

/* search1151_2_0_0 -> search1138_0_0 in the cache */

/* search1151_2_0_1 -> search1138_0_0 in the cache */
static const nir_search_expression search1151_2_0 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_fmul,
   { &search1138_0_0.value, &search1138_0_0.value },
   NULL,
};
static const nir_search_expression search1151_2 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_fneg,
   { &search1151_2_0.value },
   NULL,
};
static const nir_search_expression search1151 = {
   { nir_search_value_expression, 32 },
   true,
   0, 1,
   nir_op_ffma,
   { &search1138_0_0.value, &search1142_1.value, &search1151_2.value },
   NULL,
};

   /* replace1151_0 -> search1138_0_0 in the cache */

/* replace1151_1 -> search1140_0 in the cache */

/* replace1151_2 -> search1138_0_0 in the cache */
static const nir_search_expression replace1151 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_flrp,
   { &search1138_0_0.value, &search1140_0.value, &search1138_0_0.value },
   NULL,
};

   /* search1152_0 -> search1138_0_0 in the cache */

/* search1152_1 -> search1142_1 in the cache */

/* search1152_2_0_0 -> search1138_0_0 in the cache */
/* search1152_2_0 -> replace1143_2 in the cache */

/* search1152_2_1 -> search1138_0_0 in the cache */
static const nir_search_expression search1152_2 = {
   { nir_search_value_expression, 32 },
   false,
   1, 1,
   nir_op_fmul,
   { &replace1143_2.value, &search1138_0_0.value },
   NULL,
};
static const nir_search_expression search1152 = {
   { nir_search_value_expression, 32 },
   true,
   0, 2,
   nir_op_ffma,
   { &search1138_0_0.value, &search1142_1.value, &search1152_2.value },
   NULL,
};

   /* replace1152_0 -> search1138_0_0 in the cache */

/* replace1152_1 -> search1140_0 in the cache */

/* replace1152_2 -> search1138_0_0 in the cache */
/* replace1152 -> replace1151 in the cache */

   /* search1153_0 -> search1138_0_0 in the cache */

/* search1153_1_0 -> search1138_0_0 in the cache */
/* search1153_1 -> replace1143_2 in the cache */

/* search1153_2_0 -> search1142_1 in the cache */

/* search1153_2_1 -> search1138_0_0 in the cache */
static const nir_search_expression search1153_2 = {
   { nir_search_value_expression, 32 },
   false,
   1, 1,
   nir_op_fmul,
   { &search1142_1.value, &search1138_0_0.value },
   NULL,
};
static const nir_search_expression search1153 = {
   { nir_search_value_expression, 32 },
   true,
   0, 2,
   nir_op_ffma,
   { &search1138_0_0.value, &replace1143_2.value, &search1153_2.value },
   NULL,
};

   /* replace1153_0 -> search1138_0_0 in the cache */

/* replace1153_1 -> search1140_0 in the cache */

/* replace1153_2 -> search1138_0_0 in the cache */
/* replace1153 -> replace1151 in the cache */

   /* search1154_0 -> search1138_0_0 in the cache */

/* search1154_1_0 -> search1142_1 in the cache */

/* search1154_1_1_0 -> search1138_0_0 in the cache */
/* search1154_1_1 -> replace1143_2 in the cache */
static const nir_search_expression search1154_1 = {
   { nir_search_value_expression, 32 },
   false,
   1, 1,
   nir_op_fadd,
   { &search1142_1.value, &replace1143_2.value },
   NULL,
};
static const nir_search_expression search1154 = {
   { nir_search_value_expression, 32 },
   true,
   0, 2,
   nir_op_fmul,
   { &search1138_0_0.value, &search1154_1.value },
   NULL,
};

   /* replace1154_0 -> search1138_0_0 in the cache */

/* replace1154_1 -> search1140_0 in the cache */

/* replace1154_2 -> search1138_0_0 in the cache */
/* replace1154 -> replace1151 in the cache */

   static const nir_search_variable search1155_0_0 = {
   { nir_search_value_variable, -3 },
   0, /* c */
   true,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

static const nir_search_variable search1155_0_1 = {
   { nir_search_value_variable, -3 },
   1, /* a */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search1155_0 = {
   { nir_search_value_expression, -3 },
   false,
   0, 1,
   nir_op_fadd,
   { &search1155_0_0.value, &search1155_0_1.value },
   (is_used_once),
};

/* search1155_1_0 -> search1155_0_0 in the cache */

static const nir_search_variable search1155_1_1 = {
   { nir_search_value_variable, -3 },
   2, /* b */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search1155_1 = {
   { nir_search_value_expression, -3 },
   false,
   1, 1,
   nir_op_fadd,
   { &search1155_0_0.value, &search1155_1_1.value },
   (is_used_once),
};
static const nir_search_expression search1155 = {
   { nir_search_value_expression, -3 },
   false,
   -1, 2,
   nir_op_fmin,
   { &search1155_0.value, &search1155_1.value },
   NULL,
};

   static const nir_search_variable replace1155_0 = {
   { nir_search_value_variable, -3 },
   0, /* c */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

/* replace1155_1_0 -> search1155_0_1 in the cache */

/* replace1155_1_1 -> search1155_1_1 in the cache */
static const nir_search_expression replace1155_1 = {
   { nir_search_value_expression, -3 },
   false,
   -1, 0,
   nir_op_fmin,
   { &search1155_0_1.value, &search1155_1_1.value },
   NULL,
};
static const nir_search_expression replace1155 = {
   { nir_search_value_expression, -3 },
   false,
   0, 1,
   nir_op_fadd,
   { &replace1155_0.value, &replace1155_1.value },
   NULL,
};

   /* search1156_0_0 -> search1155_0_0 in the cache */

/* search1156_0_1 -> search1155_0_1 in the cache */
/* search1156_0 -> search1155_0 in the cache */

/* search1156_1_0 -> search1155_0_0 in the cache */

/* search1156_1_1 -> search1155_1_1 in the cache */
/* search1156_1 -> search1155_1 in the cache */
static const nir_search_expression search1156 = {
   { nir_search_value_expression, -3 },
   false,
   -1, 2,
   nir_op_fmax,
   { &search1155_0.value, &search1155_1.value },
   NULL,
};

   /* replace1156_0 -> replace1155_0 in the cache */

/* replace1156_1_0 -> search1155_0_1 in the cache */

/* replace1156_1_1 -> search1155_1_1 in the cache */
static const nir_search_expression replace1156_1 = {
   { nir_search_value_expression, -3 },
   false,
   -1, 0,
   nir_op_fmax,
   { &search1155_0_1.value, &search1155_1_1.value },
   NULL,
};
static const nir_search_expression replace1156 = {
   { nir_search_value_expression, -3 },
   false,
   0, 1,
   nir_op_fadd,
   { &replace1155_0.value, &replace1156_1.value },
   NULL,
};

   static const nir_search_variable search1157_0 = {
   { nir_search_value_variable, 1 },
   0, /* a */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

static const nir_search_constant search1157_1 = {
   { nir_search_value_constant, 32 },
   nir_type_int, { 0x0 /* 0 */ },
};

static const nir_search_variable search1157_2_0_0 = {
   { nir_search_value_variable, 1 },
   1, /* b */
   false,
   nir_type_bool,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression search1157_2_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 0,
   nir_op_inot,
   { &search1157_2_0_0.value },
   NULL,
};
static const nir_search_expression search1157_2 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_b2f32,
   { &search1157_2_0.value },
   NULL,
};
static const nir_search_expression search1157 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 0,
   nir_op_bcsel,
   { &search1157_0.value, &search1157_1.value, &search1157_2.value },
   NULL,
};

   /* replace1157_0_0_0 -> search1157_0 in the cache */

static const nir_search_variable replace1157_0_0_1 = {
   { nir_search_value_variable, 1 },
   1, /* b */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression replace1157_0_0 = {
   { nir_search_value_expression, 1 },
   false,
   0, 1,
   nir_op_ior,
   { &search1157_0.value, &replace1157_0_0_1.value },
   NULL,
};
static const nir_search_expression replace1157_0 = {
   { nir_search_value_expression, 1 },
   false,
   -1, 1,
   nir_op_inot,
   { &replace1157_0_0.value },
   NULL,
};
static const nir_search_expression replace1157 = {
   { nir_search_value_expression, 32 },
   false,
   -1, 1,
   nir_op_b2f32,
   { &replace1157_0.value },
   NULL,
};

   static const nir_search_variable search1158_0_0 = {
   { nir_search_value_variable, -7 },
   0, /* a */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

static const nir_search_variable search1158_0_1 = {
   { nir_search_value_variable, -7 },
   1, /* b */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

static const nir_search_variable search1158_0_2_0 = {
   { nir_search_value_variable, -7 },
   2, /* c */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

static const nir_search_variable search1158_0_2_1 = {
   { nir_search_value_variable, -7 },
   3, /* d */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

static const nir_search_variable search1158_0_2_2_0 = {
   { nir_search_value_variable, -7 },
   4, /* e */
   false,
   nir_type_invalid,
   (is_not_const_and_not_fsign),
   {0, 1, 2, 3},
};

static const nir_search_variable search1158_0_2_2_1 = {
   { nir_search_value_variable, -7 },
   5, /* f */
   false,
   nir_type_invalid,
   (is_not_const_and_not_fsign),
   {0, 1, 2, 3},
};
static const nir_search_expression search1158_0_2_2 = {
   { nir_search_value_expression, -7 },
   false,
   3, 1,
   nir_op_fmul,
   { &search1158_0_2_2_0.value, &search1158_0_2_2_1.value },
   NULL,
};
static const nir_search_expression search1158_0_2 = {
   { nir_search_value_expression, -7 },
   false,
   2, 2,
   nir_op_ffma,
   { &search1158_0_2_0.value, &search1158_0_2_1.value, &search1158_0_2_2.value },
   NULL,
};
static const nir_search_expression search1158_0 = {
   { nir_search_value_expression, -7 },
   false,
   1, 3,
   nir_op_ffma,
   { &search1158_0_0.value, &search1158_0_1.value, &search1158_0_2.value },
   (is_used_once),
};

static const nir_search_variable search1158_1 = {
   { nir_search_value_variable, -7 },
   6, /* g */
   false,
   nir_type_invalid,
   (is_not_const),
   {0, 1, 2, 3},
};
static const nir_search_expression search1158 = {
   { nir_search_value_expression, -7 },
   true,
   0, 4,
   nir_op_fadd,
   { &search1158_0.value, &search1158_1.value },
   NULL,
};

   /* replace1158_0 -> search1158_0_0 in the cache */

/* replace1158_1 -> search1158_0_1 in the cache */

/* replace1158_2_0 -> search1158_0_2_0 in the cache */

/* replace1158_2_1 -> search1158_0_2_1 in the cache */

static const nir_search_variable replace1158_2_2_0 = {
   { nir_search_value_variable, -7 },
   4, /* e */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

static const nir_search_variable replace1158_2_2_1 = {
   { nir_search_value_variable, -7 },
   5, /* f */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

static const nir_search_variable replace1158_2_2_2 = {
   { nir_search_value_variable, -7 },
   6, /* g */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression replace1158_2_2 = {
   { nir_search_value_expression, -7 },
   false,
   2, 1,
   nir_op_ffma,
   { &replace1158_2_2_0.value, &replace1158_2_2_1.value, &replace1158_2_2_2.value },
   NULL,
};
static const nir_search_expression replace1158_2 = {
   { nir_search_value_expression, -7 },
   false,
   1, 2,
   nir_op_ffma,
   { &search1158_0_2_0.value, &search1158_0_2_1.value, &replace1158_2_2.value },
   NULL,
};
static const nir_search_expression replace1158 = {
   { nir_search_value_expression, -7 },
   false,
   0, 3,
   nir_op_ffma,
   { &search1158_0_0.value, &search1158_0_1.value, &replace1158_2.value },
   NULL,
};

   static const nir_search_variable search1159_0_0 = {
   { nir_search_value_variable, -5 },
   0, /* a */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

static const nir_search_variable search1159_0_1 = {
   { nir_search_value_variable, -5 },
   1, /* b */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

static const nir_search_variable search1159_0_2_0 = {
   { nir_search_value_variable, -5 },
   2, /* c */
   false,
   nir_type_invalid,
   (is_not_const_and_not_fsign),
   {0, 1, 2, 3},
};

static const nir_search_variable search1159_0_2_1 = {
   { nir_search_value_variable, -5 },
   3, /* d */
   false,
   nir_type_invalid,
   (is_not_const_and_not_fsign),
   {0, 1, 2, 3},
};
static const nir_search_expression search1159_0_2 = {
   { nir_search_value_expression, -5 },
   false,
   2, 1,
   nir_op_fmul,
   { &search1159_0_2_0.value, &search1159_0_2_1.value },
   NULL,
};
static const nir_search_expression search1159_0 = {
   { nir_search_value_expression, -5 },
   false,
   1, 2,
   nir_op_ffma,
   { &search1159_0_0.value, &search1159_0_1.value, &search1159_0_2.value },
   (is_used_once),
};

static const nir_search_variable search1159_1 = {
   { nir_search_value_variable, -5 },
   4, /* e */
   false,
   nir_type_invalid,
   (is_not_const),
   {0, 1, 2, 3},
};
static const nir_search_expression search1159 = {
   { nir_search_value_expression, -5 },
   true,
   0, 3,
   nir_op_fadd,
   { &search1159_0.value, &search1159_1.value },
   NULL,
};

   /* replace1159_0 -> search1159_0_0 in the cache */

/* replace1159_1 -> search1159_0_1 in the cache */

static const nir_search_variable replace1159_2_0 = {
   { nir_search_value_variable, -5 },
   2, /* c */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

static const nir_search_variable replace1159_2_1 = {
   { nir_search_value_variable, -5 },
   3, /* d */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};

static const nir_search_variable replace1159_2_2 = {
   { nir_search_value_variable, -5 },
   4, /* e */
   false,
   nir_type_invalid,
   NULL,
   {0, 1, 2, 3},
};
static const nir_search_expression replace1159_2 = {
   { nir_search_value_expression, -5 },
   false,
   1, 1,
   nir_op_ffma,
   { &replace1159_2_0.value, &replace1159_2_1.value, &replace1159_2_2.value },
   NULL,
};
static const nir_search_expression replace1159 = {
   { nir_search_value_expression, -5 },
   false,
   0, 2,
   nir_op_ffma,
   { &search1159_0_0.value, &search1159_0_1.value, &replace1159_2.value },
   NULL,
};


static const struct transform nir_opt_algebraic_late_state6_xforms[] = {
  { &search1131, &search1111_0_0.value, 0 },
};
static const struct transform nir_opt_algebraic_late_state7_xforms[] = {
  { &search1132, &search1111_0_0.value, 0 },
};
static const struct transform nir_opt_algebraic_late_state8_xforms[] = {
  { &search1134, &replace1134.value, 63 },
};
static const struct transform nir_opt_algebraic_late_state9_xforms[] = {
  { &search1135, &replace1135.value, 63 },
};
static const struct transform nir_opt_algebraic_late_state10_xforms[] = {
  { &search1136, &replace1136.value, 63 },
};
static const struct transform nir_opt_algebraic_late_state11_xforms[] = {
  { &search1137, &replace1137.value, 63 },
};
static const struct transform nir_opt_algebraic_late_state14_xforms[] = {
  { &search1142, &replace1142.value, 12 },
  { &search1143, &replace1143.value, 12 },
  { &search1144, &replace1144.value, 12 },
  { &search1145, &replace1145.value, 12 },
};
static const struct transform nir_opt_algebraic_late_state16_xforms[] = {
  { &search1126, &replace1119.value, 0 },
};
static const struct transform nir_opt_algebraic_late_state17_xforms[] = {
  { &search1113, &replace1113.value, 0 },
};
static const struct transform nir_opt_algebraic_late_state18_xforms[] = {
  { &search1105, &replace1105.value, 0 },
};
static const struct transform nir_opt_algebraic_late_state19_xforms[] = {
  { &search1125, &replace1125.value, 0 },
};
static const struct transform nir_opt_algebraic_late_state20_xforms[] = {
  { &search1121, &replace1121.value, 0 },
};
static const struct transform nir_opt_algebraic_late_state21_xforms[] = {
  { &search1112, &replace1112.value, 0 },
  { &search1119, &replace1119.value, 0 },
};
static const struct transform nir_opt_algebraic_late_state23_xforms[] = {
  { &search1111, &search1111_0_0.value, 0 },
};
static const struct transform nir_opt_algebraic_late_state26_xforms[] = {
  { &search1128, &replace1118.value, 0 },
};
static const struct transform nir_opt_algebraic_late_state27_xforms[] = {
  { &search1115, &replace1115.value, 0 },
};
static const struct transform nir_opt_algebraic_late_state28_xforms[] = {
  { &search1107, &replace1107.value, 0 },
};
static const struct transform nir_opt_algebraic_late_state29_xforms[] = {
  { &search1127, &replace1127.value, 0 },
};
static const struct transform nir_opt_algebraic_late_state30_xforms[] = {
  { &search1122, &replace1122.value, 0 },
};
static const struct transform nir_opt_algebraic_late_state31_xforms[] = {
  { &search1114, &replace1114.value, 0 },
  { &search1118, &replace1118.value, 0 },
};
static const struct transform nir_opt_algebraic_late_state32_xforms[] = {
  { &search1109, &replace1109.value, 0 },
};
static const struct transform nir_opt_algebraic_late_state33_xforms[] = {
  { &search1130, &replace1130.value, 0 },
};
static const struct transform nir_opt_algebraic_late_state34_xforms[] = {
  { &search1116, &replace1116.value, 0 },
};
static const struct transform nir_opt_algebraic_late_state35_xforms[] = {
  { &search1123, &replace1123.value, 0 },
};
static const struct transform nir_opt_algebraic_late_state36_xforms[] = {
  { &search1110, &replace1110.value, 0 },
};
static const struct transform nir_opt_algebraic_late_state37_xforms[] = {
  { &search1129, &replace1129.value, 0 },
};
static const struct transform nir_opt_algebraic_late_state38_xforms[] = {
  { &search1117, &replace1117.value, 0 },
};
static const struct transform nir_opt_algebraic_late_state39_xforms[] = {
  { &search1124, &replace1124.value, 0 },
};
static const struct transform nir_opt_algebraic_late_state41_xforms[] = {
  { &search1155, &replace1155.value, 0 },
};
static const struct transform nir_opt_algebraic_late_state42_xforms[] = {
  { &search1138, &replace1138.value, 0 },
  { &search1139, &replace1139.value, 0 },
};
static const struct transform nir_opt_algebraic_late_state48_xforms[] = {
  { &search1156, &replace1156.value, 0 },
};
static const struct transform nir_opt_algebraic_late_state51_xforms[] = {
  { &search1146, &replace1142.value, 12 },
  { &search1147, &replace1143.value, 12 },
  { &search1148, &replace1144.value, 12 },
  { &search1149, &replace1145.value, 12 },
};
static const struct transform nir_opt_algebraic_late_state53_xforms[] = {
  { &search1153, &replace1151.value, 12 },
};
static const struct transform nir_opt_algebraic_late_state55_xforms[] = {
  { &search1106, &replace1106.value, 0 },
  { &search1125, &replace1125.value, 0 },
};
static const struct transform nir_opt_algebraic_late_state56_xforms[] = {
  { &search1108, &replace1108.value, 0 },
  { &search1127, &replace1127.value, 0 },
};
static const struct transform nir_opt_algebraic_late_state57_xforms[] = {
  { &search1120, &replace1120.value, 0 },
};
static const struct transform nir_opt_algebraic_late_state58_xforms[] = {
  { &search1159, &replace1159.value, 64 },
};
static const struct transform nir_opt_algebraic_late_state59_xforms[] = {
  { &search1133, &replace1133.value, 0 },
};
static const struct transform nir_opt_algebraic_late_state60_xforms[] = {
  { &search1140, &replace1140.value, 5 },
  { &search1141, &replace1141.value, 6 },
};
static const struct transform nir_opt_algebraic_late_state61_xforms[] = {
  { &search1140, &replace1140.value, 5 },
  { &search1141, &replace1141.value, 6 },
  { &search1146, &replace1142.value, 12 },
  { &search1147, &replace1143.value, 12 },
  { &search1148, &replace1144.value, 12 },
  { &search1149, &replace1145.value, 12 },
};
static const struct transform nir_opt_algebraic_late_state62_xforms[] = {
  { &search1159, &replace1159.value, 64 },
};
static const struct transform nir_opt_algebraic_late_state63_xforms[] = {
  { &search1159, &replace1159.value, 64 },
};
static const struct transform nir_opt_algebraic_late_state65_xforms[] = {
  { &search1151, &replace1151.value, 12 },
};
static const struct transform nir_opt_algebraic_late_state66_xforms[] = {
  { &search1152, &replace1151.value, 12 },
};
static const struct transform nir_opt_algebraic_late_state67_xforms[] = {
  { &search1150, &replace1150.value, 12 },
};
static const struct transform nir_opt_algebraic_late_state68_xforms[] = {
  { &search1150, &replace1150.value, 12 },
};
static const struct transform nir_opt_algebraic_late_state69_xforms[] = {
  { &search1150, &replace1150.value, 12 },
};
static const struct transform nir_opt_algebraic_late_state70_xforms[] = {
  { &search1152, &replace1151.value, 12 },
  { &search1153, &replace1151.value, 12 },
};
static const struct transform nir_opt_algebraic_late_state71_xforms[] = {
  { &search1142, &replace1142.value, 12 },
  { &search1143, &replace1143.value, 12 },
  { &search1144, &replace1144.value, 12 },
  { &search1145, &replace1145.value, 12 },
  { &search1150, &replace1150.value, 12 },
};
static const struct transform nir_opt_algebraic_late_state72_xforms[] = {
  { &search1150, &replace1150.value, 12 },
  { &search1151, &replace1151.value, 12 },
};
static const struct transform nir_opt_algebraic_late_state73_xforms[] = {
  { &search1150, &replace1150.value, 12 },
  { &search1152, &replace1151.value, 12 },
};
static const struct transform nir_opt_algebraic_late_state74_xforms[] = {
  { &search1150, &replace1150.value, 12 },
  { &search1153, &replace1151.value, 12 },
};
static const struct transform nir_opt_algebraic_late_state75_xforms[] = {
  { &search1154, &replace1151.value, 12 },
};
static const struct transform nir_opt_algebraic_late_state76_xforms[] = {
  { &search1154, &replace1151.value, 12 },
};
static const struct transform nir_opt_algebraic_late_state77_xforms[] = {
  { &search1154, &replace1151.value, 12 },
};
static const struct transform nir_opt_algebraic_late_state78_xforms[] = {
  { &search1157, &replace1157.value, 0 },
};
static const struct transform nir_opt_algebraic_late_state79_xforms[] = {
  { &search1158, &replace1158.value, 64 },
};
static const struct transform nir_opt_algebraic_late_state80_xforms[] = {
  { &search1158, &replace1158.value, 64 },
};
static const struct transform nir_opt_algebraic_late_state81_xforms[] = {
  { &search1158, &replace1158.value, 64 },
};
static const struct transform nir_opt_algebraic_late_state82_xforms[] = {
  { &search1158, &replace1158.value, 64 },
  { &search1159, &replace1159.value, 64 },
};

static const struct per_op_table nir_opt_algebraic_late_table[nir_num_search_ops] = {
   [nir_op_flt] = {
      .filter = (uint16_t []) {
         0,
         1,
         2,
         2,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
      },
      
      .num_filtered_states = 6,
      .table = (uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         17,
         16,
         0,
         18,
         0,
         0,
         0,
         0,
         0,
         19,
         0,
         20,
         0,
         20,
         0,
         21,
         0,
         0,
         0,
         0,
         0,
         55,
         0,
         20,
         0,
         20,
      },
   },
   [nir_op_fadd] = {
      .filter = (uint16_t []) {
         0,
         1,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         4,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         6,
         3,
         5,
         0,
         0,
         0,
         0,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         7,
         0,
         7,
         8,
         7,
         0,
         0,
         7,
         7,
         5,
         6,
         5,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 9,
      .table = (uint16_t []) {
      
         2,
         3,
         49,
         2,
         49,
         2,
         2,
         58,
         79,
         3,
         3,
         50,
         51,
         59,
         60,
         61,
         62,
         80,
         49,
         50,
         49,
         49,
         49,
         49,
         49,
         63,
         81,
         2,
         51,
         49,
         2,
         49,
         2,
         2,
         58,
         79,
         49,
         59,
         49,
         49,
         49,
         49,
         49,
         63,
         81,
         2,
         60,
         49,
         2,
         49,
         2,
         2,
         58,
         79,
         2,
         61,
         49,
         2,
         49,
         2,
         2,
         58,
         79,
         58,
         62,
         63,
         58,
         63,
         58,
         58,
         58,
         82,
         79,
         80,
         81,
         79,
         81,
         79,
         79,
         82,
         79,
      },
   },
   [nir_op_fneg] = {
      .filter = (uint16_t []) {
         0,
         0,
         1,
         1,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         1,
         1,
         1,
         1,
      },
      
      .num_filtered_states = 5,
      .table = (uint16_t []) {
      
         4,
         22,
         23,
         24,
         25,
      },
   },
   [nir_op_fge] = {
      .filter = (uint16_t []) {
         0,
         1,
         2,
         2,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
      },
      
      .num_filtered_states = 7,
      .table = (uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         26,
         27,
         26,
         0,
         0,
         28,
         0,
         0,
         0,
         0,
         0,
         0,
         29,
         0,
         30,
         0,
         30,
         0,
         0,
         31,
         0,
         0,
         0,
         0,
         0,
         0,
         56,
         0,
         30,
         0,
         30,
         0,
         0,
         57,
         0,
         0,
         0,
         0,
         0,
      },
   },
   [nir_op_feq] = {
      .filter = (uint16_t []) {
         0,
         1,
         2,
         2,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
      },
      
      .num_filtered_states = 5,
      .table = (uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         32,
         33,
         34,
         0,
         32,
         0,
         0,
         0,
         0,
         33,
         0,
         35,
         0,
         0,
         34,
         0,
         0,
         0,
      },
   },
   [nir_op_fne] = {
      .filter = (uint16_t []) {
         0,
         1,
         2,
         2,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
      },
      
      .num_filtered_states = 5,
      .table = (uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         36,
         37,
         38,
         0,
         36,
         0,
         0,
         0,
         0,
         37,
         0,
         39,
         0,
         0,
         38,
         0,
         0,
         0,
      },
   },
   [nir_op_fsat] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         5,
      },
   },
   [nir_op_fmin] = {
      .filter = (uint16_t []) {
         0,
         0,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         2,
         2,
         2,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         1,
         1,
      },
      
      .num_filtered_states = 3,
      .table = (uint16_t []) {
      
         0,
         0,
         0,
         0,
         40,
         40,
         0,
         40,
         41,
      },
   },
   [nir_op_ior] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         6,
      },
   },
   [nir_op_iand] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         7,
      },
   },
   [nir_op_fdot2] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         8,
      },
   },
   [nir_op_fdot3] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         9,
      },
   },
   [nir_op_fdot4] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         10,
      },
   },
   [nir_op_fdph] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         11,
      },
   },
   [nir_op_flrp] = {
      .filter = (uint16_t []) {
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
      },
      
      .num_filtered_states = 2,
      .table = (uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         42,
         42,
      },
   },
   [nir_op_fmul] = {
      .filter = (uint16_t []) {
         0,
         1,
         0,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (uint16_t []) {
      
         12,
         13,
         43,
         44,
         75,
         13,
         13,
         45,
         46,
         76,
         43,
         45,
         43,
         47,
         75,
         44,
         46,
         47,
         44,
         77,
         75,
         76,
         75,
         77,
         75,
      },
   },
   [nir_op_ffma] = {
      .filter = (uint16_t []) {
         0,
         1,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         6,
         4,
         7,
         6,
         0,
         8,
         8,
         0,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         8,
         0,
         0,
         9,
         0,
         9,
         0,
         9,
         0,
         0,
         9,
         9,
         3,
         4,
         6,
         0,
         0,
         0,
         8,
         0,
      },
      
      .num_filtered_states = 10,
      .table = (uint16_t []) {
      
         0,
         0,
         0,
         52,
         52,
         0,
         52,
         52,
         0,
         64,
         0,
         14,
         0,
         52,
         52,
         65,
         66,
         66,
         0,
         64,
         0,
         0,
         0,
         52,
         53,
         0,
         52,
         53,
         0,
         64,
         0,
         0,
         0,
         52,
         52,
         0,
         52,
         52,
         0,
         64,
         0,
         0,
         0,
         52,
         52,
         0,
         52,
         52,
         0,
         64,
         0,
         0,
         0,
         52,
         53,
         0,
         52,
         53,
         0,
         64,
         0,
         0,
         0,
         52,
         52,
         0,
         52,
         52,
         0,
         64,
         0,
         0,
         0,
         52,
         52,
         0,
         52,
         52,
         0,
         64,
         67,
         67,
         67,
         68,
         68,
         67,
         68,
         68,
         67,
         69,
         0,
         0,
         0,
         52,
         52,
         0,
         52,
         52,
         0,
         64,
         0,
         14,
         0,
         52,
         52,
         65,
         66,
         66,
         0,
         64,
         0,
         14,
         0,
         52,
         52,
         65,
         66,
         66,
         0,
         64,
         0,
         14,
         0,
         52,
         53,
         65,
         66,
         70,
         0,
         64,
         0,
         14,
         0,
         52,
         52,
         65,
         66,
         66,
         0,
         64,
         0,
         14,
         0,
         52,
         52,
         65,
         66,
         66,
         0,
         64,
         0,
         14,
         0,
         52,
         53,
         65,
         66,
         70,
         0,
         64,
         0,
         14,
         0,
         52,
         52,
         65,
         66,
         66,
         0,
         64,
         0,
         14,
         0,
         52,
         52,
         65,
         66,
         66,
         0,
         64,
         67,
         71,
         67,
         68,
         68,
         72,
         73,
         73,
         67,
         69,
         0,
         14,
         0,
         52,
         52,
         65,
         66,
         66,
         0,
         64,
         0,
         0,
         0,
         52,
         53,
         0,
         52,
         53,
         0,
         64,
         0,
         14,
         0,
         52,
         53,
         65,
         66,
         70,
         0,
         64,
         0,
         0,
         0,
         52,
         53,
         0,
         52,
         53,
         0,
         64,
         0,
         0,
         0,
         52,
         53,
         0,
         52,
         53,
         0,
         64,
         0,
         0,
         0,
         52,
         53,
         0,
         52,
         53,
         0,
         64,
         0,
         0,
         0,
         52,
         53,
         0,
         52,
         53,
         0,
         64,
         0,
         0,
         0,
         52,
         53,
         0,
         52,
         53,
         0,
         64,
         0,
         0,
         0,
         52,
         53,
         0,
         52,
         53,
         0,
         64,
         67,
         67,
         67,
         68,
         74,
         67,
         68,
         74,
         67,
         69,
         0,
         0,
         0,
         52,
         53,
         0,
         52,
         53,
         0,
         64,
         0,
         0,
         0,
         52,
         52,
         0,
         52,
         52,
         0,
         64,
         0,
         14,
         0,
         52,
         52,
         65,
         66,
         66,
         0,
         64,
         0,
         0,
         0,
         52,
         53,
         0,
         52,
         53,
         0,
         64,
         0,
         0,
         0,
         52,
         52,
         0,
         52,
         52,
         0,
         64,
         0,
         0,
         0,
         52,
         52,
         0,
         52,
         52,
         0,
         64,
         0,
         0,
         0,
         52,
         53,
         0,
         52,
         53,
         0,
         64,
         0,
         0,
         0,
         52,
         52,
         0,
         52,
         52,
         0,
         64,
         0,
         0,
         0,
         52,
         52,
         0,
         52,
         52,
         0,
         64,
         67,
         67,
         67,
         68,
         68,
         67,
         68,
         68,
         67,
         69,
         0,
         0,
         0,
         52,
         52,
         0,
         52,
         52,
         0,
         64,
         0,
         0,
         0,
         52,
         52,
         0,
         52,
         52,
         0,
         64,
         0,
         14,
         0,
         52,
         52,
         65,
         66,
         66,
         0,
         64,
         0,
         0,
         0,
         52,
         53,
         0,
         52,
         53,
         0,
         64,
         0,
         0,
         0,
         52,
         52,
         0,
         52,
         52,
         0,
         64,
         0,
         0,
         0,
         52,
         52,
         0,
         52,
         52,
         0,
         64,
         0,
         0,
         0,
         52,
         53,
         0,
         52,
         53,
         0,
         64,
         0,
         0,
         0,
         52,
         52,
         0,
         52,
         52,
         0,
         64,
         0,
         0,
         0,
         52,
         52,
         0,
         52,
         52,
         0,
         64,
         67,
         67,
         67,
         68,
         68,
         67,
         68,
         68,
         67,
         69,
         0,
         0,
         0,
         52,
         52,
         0,
         52,
         52,
         0,
         64,
         0,
         0,
         0,
         52,
         53,
         0,
         52,
         53,
         0,
         64,
         0,
         14,
         0,
         52,
         53,
         65,
         66,
         70,
         0,
         64,
         0,
         0,
         0,
         52,
         53,
         0,
         52,
         53,
         0,
         64,
         0,
         0,
         0,
         52,
         53,
         0,
         52,
         53,
         0,
         64,
         0,
         0,
         0,
         52,
         53,
         0,
         52,
         53,
         0,
         64,
         0,
         0,
         0,
         52,
         53,
         0,
         52,
         53,
         0,
         64,
         0,
         0,
         0,
         52,
         53,
         0,
         52,
         53,
         0,
         64,
         0,
         0,
         0,
         52,
         53,
         0,
         52,
         53,
         0,
         64,
         67,
         67,
         67,
         68,
         74,
         67,
         68,
         74,
         67,
         69,
         0,
         0,
         0,
         52,
         53,
         0,
         52,
         53,
         0,
         64,
         0,
         0,
         0,
         52,
         52,
         0,
         52,
         52,
         0,
         64,
         0,
         14,
         0,
         52,
         52,
         65,
         66,
         66,
         0,
         64,
         0,
         0,
         0,
         52,
         53,
         0,
         52,
         53,
         0,
         64,
         0,
         0,
         0,
         52,
         52,
         0,
         52,
         52,
         0,
         64,
         0,
         0,
         0,
         52,
         52,
         0,
         52,
         52,
         0,
         64,
         0,
         0,
         0,
         52,
         53,
         0,
         52,
         53,
         0,
         64,
         0,
         0,
         0,
         52,
         52,
         0,
         52,
         52,
         0,
         64,
         0,
         0,
         0,
         52,
         52,
         0,
         52,
         52,
         0,
         64,
         67,
         67,
         67,
         68,
         68,
         67,
         68,
         68,
         67,
         69,
         0,
         0,
         0,
         52,
         52,
         0,
         52,
         52,
         0,
         64,
         0,
         0,
         0,
         52,
         52,
         0,
         52,
         52,
         0,
         64,
         0,
         14,
         0,
         52,
         52,
         65,
         66,
         66,
         0,
         64,
         0,
         0,
         0,
         52,
         53,
         0,
         52,
         53,
         0,
         64,
         0,
         0,
         0,
         52,
         52,
         0,
         52,
         52,
         0,
         64,
         0,
         0,
         0,
         52,
         52,
         0,
         52,
         52,
         0,
         64,
         0,
         0,
         0,
         52,
         53,
         0,
         52,
         53,
         0,
         64,
         0,
         0,
         0,
         52,
         52,
         0,
         52,
         52,
         0,
         64,
         0,
         0,
         0,
         52,
         52,
         0,
         52,
         52,
         0,
         64,
         67,
         67,
         67,
         68,
         68,
         67,
         68,
         68,
         67,
         69,
         0,
         0,
         0,
         52,
         52,
         0,
         52,
         52,
         0,
         64,
         67,
         67,
         67,
         68,
         68,
         67,
         68,
         68,
         67,
         69,
         67,
         71,
         67,
         68,
         68,
         72,
         73,
         73,
         67,
         69,
         67,
         67,
         67,
         68,
         74,
         67,
         68,
         74,
         67,
         69,
         67,
         67,
         67,
         68,
         68,
         67,
         68,
         68,
         67,
         69,
         67,
         67,
         67,
         68,
         68,
         67,
         68,
         68,
         67,
         69,
         67,
         67,
         67,
         68,
         74,
         67,
         68,
         74,
         67,
         69,
         67,
         67,
         67,
         68,
         68,
         67,
         68,
         68,
         67,
         69,
         67,
         67,
         67,
         68,
         68,
         67,
         68,
         68,
         67,
         69,
         67,
         67,
         67,
         68,
         68,
         67,
         68,
         68,
         67,
         69,
         67,
         67,
         67,
         68,
         68,
         67,
         68,
         68,
         67,
         69,
         0,
         0,
         0,
         52,
         52,
         0,
         52,
         52,
         0,
         64,
         0,
         14,
         0,
         52,
         52,
         65,
         66,
         66,
         0,
         64,
         0,
         0,
         0,
         52,
         53,
         0,
         52,
         53,
         0,
         64,
         0,
         0,
         0,
         52,
         52,
         0,
         52,
         52,
         0,
         64,
         0,
         0,
         0,
         52,
         52,
         0,
         52,
         52,
         0,
         64,
         0,
         0,
         0,
         52,
         53,
         0,
         52,
         53,
         0,
         64,
         0,
         0,
         0,
         52,
         52,
         0,
         52,
         52,
         0,
         64,
         0,
         0,
         0,
         52,
         52,
         0,
         52,
         52,
         0,
         64,
         67,
         67,
         67,
         68,
         68,
         67,
         68,
         68,
         67,
         69,
         0,
         0,
         0,
         52,
         52,
         0,
         52,
         52,
         0,
         64,
      },
   },
   [nir_op_fmax] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (uint16_t []) {
      
         0,
         0,
         0,
         48,
      },
   },
   [nir_op_bcsel] = {
      .filter = (uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         78,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         78,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         78,
         0,
         0,
         0,
      },
   },
   [nir_search_op_b2f] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (uint16_t []) {
      
         0,
         54,
      },
   },
   [nir_op_inot] = {
      .filter = (uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 1,
      .table = (uint16_t []) {
      
         15,
      },
   },
};

static void
nir_opt_algebraic_late_pre_block(nir_block *block, uint16_t *states)
{
   nir_foreach_instr(instr, block) {
      switch (instr->type) {
      case nir_instr_type_alu: {
         nir_alu_instr *alu = nir_instr_as_alu(instr);
         nir_op op = alu->op;
         uint16_t search_op = nir_search_op_for_nir_op(op);
         const struct per_op_table *tbl = &nir_opt_algebraic_late_table[search_op];
         if (tbl->num_filtered_states == 0)
            continue;

         /* Calculate the index into the transition table. Note the index
          * calculated must match the iteration order of Python's
          * itertools.product(), which was used to emit the transition
          * table.
          */
         uint16_t index = 0;
         for (unsigned i = 0; i < nir_op_infos[op].num_inputs; i++) {
            index *= tbl->num_filtered_states;
            index += tbl->filter[states[alu->src[i].src.ssa->index]];
         }
         states[alu->dest.dest.ssa.index] = tbl->table[index];
         break;
      }

      case nir_instr_type_load_const: {
         nir_load_const_instr *load_const = nir_instr_as_load_const(instr);
         states[load_const->def.index] = CONST_STATE;
         break;
      }

      default:
         break;
      }
   }
}

static bool
nir_opt_algebraic_late_block(nir_builder *build, nir_block *block,
                   const uint16_t *states, const bool *condition_flags)
{
   bool progress = false;

   nir_foreach_instr_reverse_safe(instr, block) {
      if (instr->type != nir_instr_type_alu)
         continue;

      nir_alu_instr *alu = nir_instr_as_alu(instr);
      if (!alu->dest.dest.is_ssa)
         continue;

      switch (states[alu->dest.dest.ssa.index]) {
      case 0:
         break;
      case 1:
         break;
      case 2:
         break;
      case 3:
         break;
      case 4:
         break;
      case 5:
         break;
      case 6:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state6_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state6_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 7:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state7_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state7_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 8:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state8_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state8_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 9:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state9_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state9_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 10:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state10_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state10_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 11:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state11_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state11_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 12:
         break;
      case 13:
         break;
      case 14:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state14_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state14_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 15:
         break;
      case 16:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state16_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state16_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 17:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state17_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state17_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 18:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state18_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state18_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 19:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state19_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state19_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 20:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state20_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state20_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 21:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state21_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state21_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 22:
         break;
      case 23:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state23_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state23_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 24:
         break;
      case 25:
         break;
      case 26:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state26_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state26_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 27:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state27_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state27_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 28:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state28_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state28_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 29:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state29_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state29_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 30:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state30_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state30_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 31:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state31_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state31_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 32:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state32_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state32_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 33:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state33_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state33_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 34:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state34_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state34_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 35:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state35_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state35_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 36:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state36_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state36_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 37:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state37_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state37_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 38:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state38_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state38_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 39:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state39_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state39_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 40:
         break;
      case 41:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state41_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state41_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 42:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state42_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state42_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 43:
         break;
      case 44:
         break;
      case 45:
         break;
      case 46:
         break;
      case 47:
         break;
      case 48:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state48_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state48_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 49:
         break;
      case 50:
         break;
      case 51:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state51_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state51_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 52:
         break;
      case 53:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state53_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state53_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 54:
         break;
      case 55:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state55_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state55_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 56:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state56_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state56_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 57:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state57_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state57_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 58:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state58_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state58_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 59:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state59_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state59_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 60:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state60_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state60_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 61:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state61_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state61_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 62:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state62_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state62_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 63:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state63_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state63_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 64:
         break;
      case 65:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state65_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state65_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 66:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state66_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state66_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 67:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state67_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state67_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 68:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state68_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state68_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 69:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state69_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state69_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 70:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state70_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state70_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 71:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state71_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state71_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 72:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state72_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state72_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 73:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state73_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state73_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 74:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state74_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state74_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 75:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state75_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state75_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 76:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state76_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state76_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 77:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state77_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state77_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 78:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state78_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state78_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 79:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state79_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state79_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 80:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state80_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state80_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 81:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state81_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state81_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      case 82:
         for (unsigned i = 0; i < ARRAY_SIZE(nir_opt_algebraic_late_state82_xforms); i++) {
            const struct transform *xform = &nir_opt_algebraic_late_state82_xforms[i];
            if (condition_flags[xform->condition_offset] &&
                nir_replace_instr(build, alu, xform->search, xform->replace)) {
               progress = true;
               break;
            }
         }
         break;
      default: assert(0);
      }
   }

   return progress;
}

static bool
nir_opt_algebraic_late_impl(nir_function_impl *impl, const bool *condition_flags)
{
   bool progress = false;

   nir_builder build;
   nir_builder_init(&build, impl);

   /* Note: it's important here that we're allocating a zeroed array, since
    * state 0 is the default state, which means we don't have to visit
    * anything other than constants and ALU instructions.
    */
   uint16_t *states = calloc(impl->ssa_alloc, sizeof(*states));

   nir_foreach_block(block, impl) {
      nir_opt_algebraic_late_pre_block(block, states);
   }

   nir_foreach_block_reverse(block, impl) {
      progress |= nir_opt_algebraic_late_block(&build, block, states, condition_flags);
   }

   free(states);

   if (progress) {
      nir_metadata_preserve(impl, nir_metadata_block_index |
                                  nir_metadata_dominance);
    } else {
#ifndef NDEBUG
      impl->valid_metadata &= ~nir_metadata_not_properly_reset;
#endif
    }

   return progress;
}


bool
nir_opt_algebraic_late(nir_shader *shader)
{
   bool progress = false;
   bool condition_flags[65];
   const nir_shader_compiler_options *options = shader->options;
   const shader_info *info = &shader->info;
   (void) options;
   (void) info;

   condition_flags[0] = true;
   condition_flags[1] = !options->lower_bitops;
   condition_flags[2] = options->lower_bitops;
   condition_flags[3] = options->lower_mul_2x32_64;
   condition_flags[4] = options->lower_idiv;
   condition_flags[5] = options->lower_flrp32;
   condition_flags[6] = options->lower_flrp64;
   condition_flags[7] = options->lower_ftrunc;
   condition_flags[8] = options->lower_ffloor;
   condition_flags[9] = !options->lower_ffloor;
   condition_flags[10] = options->lower_ffract;
   condition_flags[11] = options->lower_fceil;
   condition_flags[12] = !options->lower_flrp32;
   condition_flags[13] = !options->lower_flrp64;
   condition_flags[14] = options->lower_ffma;
   condition_flags[15] = options->fuse_ffma;
   condition_flags[16] = options->lower_fdph;
   condition_flags[17] = !options->lower_fdph;
   condition_flags[18] = options->lower_fdot;
   condition_flags[19] = !options->lower_fsat;
   condition_flags[20] = !options->lower_negate && !options->lower_fsat;
   condition_flags[21] = options->lower_fsat;
   condition_flags[22] = options->lower_scmp;
   condition_flags[23] = options->lower_vector_cmp;
   condition_flags[24] = !options->lower_rotate;
   condition_flags[25] = options->lower_rotate;
   condition_flags[26] = options->lower_fpow;
   condition_flags[27] = !options->lower_fpow;
   condition_flags[28] = options->lower_fdiv;
   condition_flags[29] = options->lower_fsqrt;
   condition_flags[30] = !options->lower_fsqrt;
   condition_flags[31] = options->lower_sincos;
   condition_flags[32] = !options->lower_extract_byte;
   condition_flags[33] = !options->lower_extract_word;
   condition_flags[34] = options->lower_sub;
   condition_flags[35] = options->lower_negate;
   condition_flags[36] = options->lower_fmod;
   condition_flags[37] = options->lower_uadd_carry;
   condition_flags[38] = options->lower_usub_borrow;
   condition_flags[39] = options->lower_bitfield_insert;
   condition_flags[40] = options->lower_hadd;
   condition_flags[41] = options->lower_add_sat;
   condition_flags[42] = options->lower_bitfield_insert_to_shifts;
   condition_flags[43] = options->lower_bitfield_insert_to_bitfield_select;
   condition_flags[44] = options->lower_bitfield_extract;
   condition_flags[45] = options->lower_bitfield_extract_to_shifts;
   condition_flags[46] = options->lower_ifind_msb;
   condition_flags[47] = options->lower_find_lsb;
   condition_flags[48] = options->lower_extract_byte;
   condition_flags[49] = options->lower_extract_word;
   condition_flags[50] = options->lower_pack_unorm_2x16;
   condition_flags[51] = options->lower_pack_unorm_4x8;
   condition_flags[52] = options->lower_pack_snorm_2x16;
   condition_flags[53] = options->lower_pack_snorm_4x8;
   condition_flags[54] = options->lower_unpack_unorm_2x16;
   condition_flags[55] = options->lower_unpack_unorm_4x8;
   condition_flags[56] = options->lower_unpack_snorm_2x16;
   condition_flags[57] = options->lower_unpack_snorm_4x8;
   condition_flags[58] = options->lower_isign;
   condition_flags[59] = options->lower_fsign;
   condition_flags[60] = options->lower_ldexp;
   condition_flags[61] = !options->lower_bitfield_reverse;
   condition_flags[62] = info->stage == MESA_SHADER_COMPUTE && info->cs.derivative_group == DERIVATIVE_GROUP_NONE;
   condition_flags[63] = options->fdot_replicates;
   condition_flags[64] = (info->stage != MESA_SHADER_VERTEX && info->stage != MESA_SHADER_GEOMETRY) && !options->intel_vec4;

   nir_foreach_function(function, shader) {
      if (function->impl)
         progress |= nir_opt_algebraic_late_impl(function->impl, condition_flags);
   }

   return progress;
}

